(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    208921,       6710]*)
(*NotebookOutlinePosition[    209572,       6733]*)
(*  CellTagsIndexPosition[    209528,       6729]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Public versus Private Education
when Differential Fertility Matters\
\>", "Title"],

Cell["David de la Croix and Matthias Doepke", "Title"],

Cell["Dynamics", "Subtitle"],

Cell[BoxData[
    \(<< Graphics`MultipleListPlot`\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetOptions[MultipleListPlot, 
      TextStyle \[Rule] {FontSize \[Rule] 20, 
          FontFamily -> "\<Palatino\>"}]\)], "Input"],

Cell[BoxData[
    \({AspectRatio \[Rule] 1\/GoldenRatio, Axes \[Rule] Automatic, 
      AxesLabel \[Rule] None, AxesOrigin \[Rule] Automatic, 
      AxesStyle \[Rule] Automatic, Background \[Rule] Automatic, 
      ColorOutput \[Rule] Automatic, DefaultColor \[Rule] Automatic, 
      Epilog \[Rule] {}, Frame \[Rule] False, FrameLabel \[Rule] None, 
      FrameStyle \[Rule] Automatic, FrameTicks \[Rule] Automatic, 
      GridLines \[Rule] None, ImageSize \[Rule] Automatic, 
      PlotJoined \[Rule] False, PlotLabel \[Rule] None, 
      PlotRange \[Rule] Automatic, PlotRegion \[Rule] Automatic, 
      PlotStyle \[Rule] Automatic, Prolog \[Rule] {}, 
      RotateLabel \[Rule] True, Ticks \[Rule] Automatic, 
      DefaultFont \[RuleDelayed] $DefaultFont, 
      DisplayFunction \[RuleDelayed] $DisplayFunction, 
      FormatType \[RuleDelayed] $FormatType, 
      TextStyle \[Rule] {FontSize \[Rule] 20, FontFamily \[Rule] "Palatino"}, 
      ErrorBarFunction \[Rule] Automatic, SymbolLabel \[Rule] None, 
      SymbolShape \[Rule] Automatic, SymbolStyle \[Rule] Automatic, 
      PlotLegend \[Rule] Automatic, LegendPosition \[Rule] Automatic, 
      LegendSize \[Rule] Automatic, LegendShadow \[Rule] {0, 0}, 
      LegendTextSpace \[Rule] Automatic, 
      LegendTextDirection \[Rule] Automatic, 
      LegendTextOffset \[Rule] Automatic, LegendLabel \[Rule] None, 
      LegendLabelSpace \[Rule] Automatic, LegendOrientation \[Rule] Vertical, 
      LegendSpacing \[Rule] Automatic, LegendBorder \[Rule] Automatic, 
      LegendBorderSpace \[Rule] Automatic, 
      LegendBackground \[Rule] Automatic}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\[Eta] = 0.6; \[Theta] = 0.017; \[Phi] =  .075; \[Gamma] = 
      0.169; \[Mu] = 7.86;\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Print["\<Threshold for xA to get an interior solution :\>", \
\[Theta]/\((\[Eta]\ \[Phi])\)\ ]\), "\[IndentingNewLine]", 
    \(Print["\<Threshold for \[Tau] to get stability :\>", 
      1 - \(\[Eta]\ \[Phi]\)\/\(\[Phi] - \[Theta]\)\ ]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Threshold for xA to get an interior solution :"\
\[InvisibleSpace]0.37777777777777777`\),
      SequenceForm[ 
      "Threshold for xA to get an interior solution :", .37777777777777777],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Threshold for \[Tau] to get stability :"\
\[InvisibleSpace]0.22413793103448276`\),
      SequenceForm[ 
      "Threshold for \[Tau] to get stability :", .22413793103448276],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stable situation", "Section"],

Cell[BoxData[
    \(\(\[Tau] =  .22;\)\)], "Input"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(xi[1] = 90;\)\), "\[IndentingNewLine]", 
    \(\(xa[1] =  .377;\)\), "\[IndentingNewLine]", 
    \(\(xb[1] = 1 + xi[1] \((1 - xa[1])\);\)\), "\[IndentingNewLine]", 
    \(\(h[1] = 1;\)\), "\[IndentingNewLine]", 
    \(\(ha[1] = h[1]\ xa[1];\)\)}], "Input"],

Cell[BoxData[{
    \(\(axi[1] = 90;\)\), "\[IndentingNewLine]", 
    \(\(axa[1] =  .377;\)\), "\[IndentingNewLine]", 
    \(\(axb[1] = 1 + axi[1] \((1 - axa[1])\);\)\), "\[IndentingNewLine]", 
    \(\(ah[1] = 1;\)\), "\[IndentingNewLine]", 
    \(\(aha[1] = ah[1]\ axa[1];\)\)}], "Input"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\(Do[
      na[t] = \[Gamma]\/\(\[Phi] + \[Gamma]\ \[Phi]\); \[IndentingNewLine]nb[
          t] = \[Gamma]\/\(\[Phi] + \[Gamma]\ \[Phi]\); \[IndentingNewLine]e[
          t] = \(\[Phi]\ \[Eta] - \[Theta]\)\/\(1 + \[Gamma]\ \[Eta]\); \
\[IndentingNewLine]xa[
          t + 1] = \(1 + xi[t]\)\/\(xi[t] + \((\(1 + xi[t]\)\/xa[t] - \
xi[t])\)\^\[Tau]\); \[IndentingNewLine]g[
          t] = \[Mu]\ \(\((\[Theta] + \(\[Phi]\ \[Eta] - \[Theta]\)\/\(1 + \
\[Gamma]\ \[Eta]\))\)\^\[Eta]\) 
          xa[t]\^\[Tau]/xa[t + 1]; \[IndentingNewLine]xi[t + 1] = 
        xi[t]; \[IndentingNewLine]xb[t + 1] = 
        1 + xi[t + 1] \((1 - xa[t + 1])\); \[IndentingNewLine]gini[t] = 
        2 \((1\/2 - \(\((xi[t]\/\(1 + xi[t]\))\)\^2\) 
                xa[t]\/2\  - \((1\/\(1 + xi[t]\))\) \((1 - \(xi[t]\/\(1 + 
                            xi[t]\)\) xa[t])\) 
                1\/2 - \((1\/\(1 + xi[t]\))\) \(xi[t] xa[t]\)\/\(1 + xi[t]\))\
\); \[IndentingNewLine]h[t + 1] = h[t]\ g[t]; \[IndentingNewLine]ha[t + 1] = 
        h[t + 1]\ xa[t + 1]; \[IndentingNewLine]y[t] = 
        h[t] \((1 - \[Phi] \((xi[t]\/\(1 + xi[t]\)\ xa[t]\ na[t] + 
                    1\/\(1 + xi[t]\)\ xb[t]\ nb[
                        t])\))\), \[IndentingNewLine]{t, 1, 
        50}]\)\(\[IndentingNewLine]\)
    \)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[ana[t] = 
        If[axa[t] > \[Theta]/\((\[Phi]\ \[Eta])\), \(\((1 - \[Eta])\) \
\[Gamma]\ axa[t]\)\/\(\((\[Phi]\ axa[t] - \[Theta])\) \((1 + \[Gamma])\)\), \
\[Gamma]\/\(\[Phi] + \[Gamma]\ \[Phi]\)]; \[IndentingNewLine]anb[
          t] = \(\((1 - \[Eta])\) \[Gamma]\ axb[t]\)\/\(\((\[Phi]\ axb[t] - \
\[Theta])\) \((1 + \[Gamma])\)\); \[IndentingNewLine]aea[t] = 
        If[axa[t] > \[Theta]/\((\[Phi]\ \[Eta])\), \(\[Eta]\ \[Phi]\ axa[t] - \
\[Theta]\)\/\(1 - \[Eta]\), 0]; \[IndentingNewLine]aeb[
          t] = \(\[Eta]\ \[Phi]\ axb[t] - \[Theta]\)\/\(1 - \[Eta]\); \
\[IndentingNewLine]axi[t + 1] = \(ana[t]\/anb[t]\) 
          axi[t]; \[IndentingNewLine]ag[
          t] = \[Mu]\ \((axi[t] 
                  ana[t] \((\[Theta] + aea[t])\)\^\[Eta]\ axa[t]\^\[Tau] + 
                anb[t] \((\[Theta] + aeb[t])\)\^\[Eta]\ \
axb[t]\^\[Tau])\)/\((axi[t]\ ana[t] + anb[t])\); \[IndentingNewLine]axa[
          t + 1] = \[Mu]\ \(\((\[Theta] + aea[t])\)\^\[Eta]\) 
          axa[t]\^\[Tau]/ag[t]; \[IndentingNewLine]axb[
          t + 1] = \[Mu]\ \(\((\[Theta] + aeb[t])\)\^\[Eta]\) 
          axb[t]\^\[Tau]/ag[t]; \[IndentingNewLine]ah[t + 1] = 
        ah[t] ag[t]; \[IndentingNewLine]aha[t + 1] = 
        ah[t + 1]\ axa[t + 1]; \[IndentingNewLine]ay[t] = 
        ah[t] \((1 - \[Phi] \((axi[t]\/\(1 + axi[t]\)\ axa[t]\ ana[t] + 
                    1\/\(1 + axi[t]\)\ axb[t]\ anb[
                        t])\))\); \[IndentingNewLine]agini[t] = 
        2 \((1\/2 - \(\((axi[t]\/\(1 + axi[t]\))\)\^2\) 
                axa[t]\/2\  - \((1\/\(1 + axi[t]\))\) \((1 - \(axi[t]\/\(1 + 
                            axi[t]\)\) axa[t])\) 
                1\/2 - \((1\/\(1 + axi[t]\))\) \(axi[t] axa[t]\)\/\(1 + \
axi[t]\))\); \[IndentingNewLine]Print["\<Time= \>", t, "\< Fertility= \>", 
        ana[t], "\< \>", anb[t], "\< Education= \>", aea[t], "\< \>", 
        aeb[t], "\< Human cap= \>", axa[t], "\< \>", axb[t]], {t, 1, 
        10}]\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(agini\)\" is similar to \
existing symbol \"\!\(gini\)\"."\)], "Message"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]1\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.9275734245794125`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7741039020049055`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]6.3778749999999995`\
\[InvisibleSpace]" Human cap= "\[InvisibleSpace]0.377`\[InvisibleSpace]" "\
\[InvisibleSpace]57.07`\),
      SequenceForm[ 
      "Time= ", 1, " Fertility= ", 1.9275734245794125, 
        " ", .77410390200490553, " Education= ", 0, " ", 6.3778749999999995, 
        " Human cap= ", .377, " ", 57.07],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]2\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.1547215731601617`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7734565224360626`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0.03424224250624722`\[InvisibleSpace]" \
"\[InvisibleSpace]8.083540895491934`\[InvisibleSpace]" Human cap= "\
\[InvisibleSpace]0.6821532667221976`\[InvisibleSpace]" \
"\[InvisibleSpace]72.23147462659497`\),
      SequenceForm[ 
      "Time= ", 2, " Fertility= ", 1.1547215731601617, 
        " ", .77345652243606255, " Education= ", .034242242506247217, " ", 
        8.0835408954919341, " Human cap= ", .68215326672219756, " ", 
        72.231474626594974],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]3\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.0494354447247736`\[InvisibleSpace]" "\
\[InvisibleSpace]0.774561049490396`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0.05362076119662913`\[InvisibleSpace]" \
"\[InvisibleSpace]5.550109939504543`\[InvisibleSpace]" Human cap= "\
\[InvisibleSpace]0.8544067661922591`\[InvisibleSpace]" \
"\[InvisibleSpace]49.71208835115149`\),
      SequenceForm[ 
      "Time= ", 3, " Fertility= ", 1.0494354447247736, 
        " ", .77456104949039595, " Education= ", .053620761196629133, " ", 
        5.5501099395045426, " Human cap= ", .85440676619225908, " ", 
        49.712088351151493],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]4\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.0184374505995237`\[InvisibleSpace]" "\
\[InvisibleSpace]0.776645387066047`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0.062468903641696244`\[InvisibleSpace]" \
"\[InvisibleSpace]3.483923895085565`\[InvisibleSpace]" Human cap= "\
\[InvisibleSpace]0.9330569212595222`\[InvisibleSpace]" \
"\[InvisibleSpace]31.345990178538354`\),
      SequenceForm[ 
      "Time= ", 4, " Fertility= ", 1.0184374505995237, 
        " ", .77664538706604702, " Education= ", .062468903641696244, " ", 
        3.4839238950855651, " Human cap= ", .93305692125952222, " ", 
        31.345990178538354],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]5\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.006932799482088`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7797291042571743`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0.06634448108640757`\[InvisibleSpace]" \
"\[InvisibleSpace]2.2429826580091383`\[InvisibleSpace]" Human cap= "\
\[InvisibleSpace]0.9675064985458451`\[InvisibleSpace]" \
"\[InvisibleSpace]20.315401404525677`\),
      SequenceForm[ 
      "Time= ", 5, " Fertility= ", 1.006932799482088, " ", .77972910425717434,
         " Education= ", .066344481086407572, " ", 2.2429826580091383, 
        " Human cap= ", .96750649854584514, " ", 20.315401404525677],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]6\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.0020461031051087`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7837980265448617`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0.0681074666848762`\[InvisibleSpace]" \
"\[InvisibleSpace]1.5228055858564673`\[InvisibleSpace]" Human cap= "\
\[InvisibleSpace]0.9831774816433442`\[InvisibleSpace]" \
"\[InvisibleSpace]13.913827429835267`\),
      SequenceForm[ 
      "Time= ", 6, " Fertility= ", 1.0020461031051087, 
        " ", .78379802654486175, " Education= ", .068107466684876203, " ", 
        1.5228055858564673, " Human cap= ", .98317748164334418, " ", 
        13.913827429835267],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]7\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]0.9997584737248557`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7887587000563968`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0.0689586672446363`\[InvisibleSpace]" \
"\[InvisibleSpace]1.0919673823884428`\[InvisibleSpace]" Human cap= "\
\[InvisibleSpace]0.9907437088412117`\[InvisibleSpace]" \
"\[InvisibleSpace]10.084154510119493`\),
      SequenceForm[ 
      "Time= ", 7, " Fertility= ", .99975847372485571, 
        " ", .78875870005639681, " Education= ", .068958667244636299, " ", 
        1.0919673823884428, " Human cap= ", .99074370884121166, " ", 
        10.084154510119493],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]8\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]0.9986025370494821`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7944572094686586`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0.06939528627687591`\[InvisibleSpace]" \
"\[InvisibleSpace]0.8222258627102806`\[InvisibleSpace]" Human cap= "\
\[InvisibleSpace]0.9946247669055638`\[InvisibleSpace]" \
"\[InvisibleSpace]7.686452112980274`\),
      SequenceForm[ 
      "Time= ", 8, " Fertility= ", .9986025370494821, " ", .79445720946865861,
         " Education= ", .069395286276875912, " ", .82222586271028064, 
        " Human cap= ", .99462476690556378, " ", 7.6864521129802741],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]9\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]0.9979807504331604`\[InvisibleSpace]" "\
\[InvisibleSpace]0.8007103441019695`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0.0696319864572313`\[InvisibleSpace]" \
"\[InvisibleSpace]0.645419257256228`\[InvisibleSpace]" Human cap= "\
\[InvisibleSpace]0.9967287685087226`\[InvisibleSpace]" \
"\[InvisibleSpace]6.114837842277583`\),
      SequenceForm[ 
      "Time= ", 9, " Fertility= ", .99798075043316037, 
        " ", .80071034410196951, " Education= ", .069631986457231301, 
        " ", .64541925725622795, " Human cap= ", .99672876850872261, " ", 
        6.1148378422775833],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]10\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]0.9976282815749324`\[InvisibleSpace]" "\
\[InvisibleSpace]0.8073331017679742`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0.06976674031424544`\[InvisibleSpace]" \
"\[InvisibleSpace]0.5245765234620426`\[InvisibleSpace]" Human cap= "\
\[InvisibleSpace]0.9979265805710706`\[InvisibleSpace]" \
"\[InvisibleSpace]5.040680208551491`\),
      SequenceForm[ 
      "Time= ", 10, " Fertility= ", .99762828157493244, 
        " ", .80733310176797424, " Education= ", .069766740314245443, 
        " ", .52457652346204264, " Human cap= ", .99792658057107064, " ", 
        5.0406802085514908],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MultipleListPlot[Array[g, 5], Array[ag, 5], PlotJoined \[Rule] True, 
      PlotStyle \[Rule] {GrayLevel[ .1], Dashing[{0.02, 0.02}]}, 
      PlotLabel -> "\<Growth - stable (\[Tau]=0.22)\>"]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 -0.469363 0.60022 [
[.2619 .11836 -7.03125 -24.5625 ]
[.2619 .11836 7.03125 0 ]
[.5 .11836 -7.03125 -24.5625 ]
[.5 .11836 7.03125 0 ]
[.7381 .11836 -7.03125 -24.5625 ]
[.7381 .11836 7.03125 0 ]
[.97619 .11836 -7.03125 -24.5625 ]
[.97619 .11836 7.03125 0 ]
[.01131 .01081 -29.125 -12.2813 ]
[.01131 .01081 0 12.2813 ]
[.01131 .2509 -29.125 -12.2813 ]
[.01131 .2509 0 12.2813 ]
[.01131 .37094 -29.125 -12.2813 ]
[.01131 .37094 0 12.2813 ]
[.01131 .49099 -29.125 -12.2813 ]
[.01131 .49099 0 12.2813 ]
[.01131 .61103 -29.125 -12.2813 ]
[.01131 .61103 0 12.2813 ]
[.5 .63053 -105.188 0 ]
[.5 .63053 105.188 24.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .13086 m
.2619 .13711 L
s
gsave
.2619 .11836 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .13086 m
.5 .13711 L
s
gsave
.5 .11836 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 .13086 m
.7381 .13711 L
s
gsave
.7381 .11836 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 .13086 m
.97619 .13711 L
s
gsave
.97619 .11836 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .13086 m
.07143 .13461 L
s
.11905 .13086 m
.11905 .13461 L
s
.16667 .13086 m
.16667 .13461 L
s
.21429 .13086 m
.21429 .13461 L
s
.30952 .13086 m
.30952 .13461 L
s
.35714 .13086 m
.35714 .13461 L
s
.40476 .13086 m
.40476 .13461 L
s
.45238 .13086 m
.45238 .13461 L
s
.54762 .13086 m
.54762 .13461 L
s
.59524 .13086 m
.59524 .13461 L
s
.64286 .13086 m
.64286 .13461 L
s
.69048 .13086 m
.69048 .13461 L
s
.78571 .13086 m
.78571 .13461 L
s
.83333 .13086 m
.83333 .13461 L
s
.88095 .13086 m
.88095 .13461 L
s
.92857 .13086 m
.92857 .13461 L
s
.25 Mabswid
0 .13086 m
1 .13086 L
s
.02381 .01081 m
.03006 .01081 L
s
gsave
.01131 .01081 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.02381 .2509 m
.03006 .2509 L
s
gsave
.01131 .2509 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .37094 m
.03006 .37094 L
s
gsave
.01131 .37094 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .49099 m
.03006 .49099 L
s
gsave
.01131 .49099 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.02381 .61103 m
.03006 .61103 L
s
gsave
.01131 .61103 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .04082 m
.02756 .04082 L
s
.02381 .07083 m
.02756 .07083 L
s
.02381 .10085 m
.02756 .10085 L
s
.02381 .16087 m
.02756 .16087 L
s
.02381 .19088 m
.02756 .19088 L
s
.02381 .22089 m
.02756 .22089 L
s
.02381 .28091 m
.02756 .28091 L
s
.02381 .31092 m
.02756 .31092 L
s
.02381 .34093 m
.02756 .34093 L
s
.02381 .40096 m
.02756 .40096 L
s
.02381 .43097 m
.02756 .43097 L
s
.02381 .46098 m
.02756 .46098 L
s
.02381 .521 m
.02756 .521 L
s
.02381 .55101 m
.02756 .55101 L
s
.02381 .58102 m
.02756 .58102 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -166.188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Growth) show
129.313 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
147.250 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(stable) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
198.875 23.000 moveto
(H) show
205.313 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
214.813 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
227.750 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
262.938 23.000 moveto
(L) show
269.375 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.1 g
.001 w
.02381 .1149 m
.2619 .23778 L
.5 .23901 L
.7381 .23905 L
.97619 .23905 L
s
0 g
.0001 w
.02381 .1149 -1.875 0 Mabsadd m
.02381 .1149 0 2.5 Mabsadd L
.02381 .1149 1.875 0 Mabsadd L
.02381 .1149 0 -2.5 Mabsadd L
.02381 .1149 -1.875 0 Mabsadd L closepath F
.2619 .23778 -1.875 0 Mabsadd m
.2619 .23778 0 2.5 Mabsadd L
.2619 .23778 1.875 0 Mabsadd L
.2619 .23778 0 -2.5 Mabsadd L
.2619 .23778 -1.875 0 Mabsadd L closepath F
.5 .23901 -1.875 0 Mabsadd m
.5 .23901 0 2.5 Mabsadd L
.5 .23901 1.875 0 Mabsadd L
.5 .23901 0 -2.5 Mabsadd L
.5 .23901 -1.875 0 Mabsadd L closepath F
.7381 .23905 -1.875 0 Mabsadd m
.7381 .23905 0 2.5 Mabsadd L
.7381 .23905 1.875 0 Mabsadd L
.7381 .23905 0 -2.5 Mabsadd L
.7381 .23905 -1.875 0 Mabsadd L closepath F
.97619 .23905 -1.875 0 Mabsadd m
.97619 .23905 0 2.5 Mabsadd L
.97619 .23905 1.875 0 Mabsadd L
.97619 .23905 0 -2.5 Mabsadd L
.97619 .23905 -1.875 0 Mabsadd L closepath F
.001 w
[ .02 .02 ] 0 setdash
.02381 .01472 m
.2619 .38432 L
.5 .52639 L
.7381 .58158 L
.97619 .60332 L
s
.0001 w
[ ] 0 setdash
.02381 .01472 0 2.5 Mabsadd m
.02381 .01472 -0.56518 .7779 Mabsadd L
.02381 .01472 -2.37764 .77254 Mabsadd L
.02381 .01472 -0.91448 -0.29713 Mabsadd L
.02381 .01472 -1.46946 -2.02254 Mabsadd L
.02381 .01472 0 -0.96154 Mabsadd L
.02381 .01472 1.46946 -2.02254 Mabsadd L
.02381 .01472 .91448 -0.29713 Mabsadd L
.02381 .01472 2.37764 .77254 Mabsadd L
.02381 .01472 .56518 .7779 Mabsadd L
.02381 .01472 0 2.5 Mabsadd L closepath F
.2619 .38432 0 2.5 Mabsadd m
.2619 .38432 -0.56518 .7779 Mabsadd L
.2619 .38432 -2.37764 .77254 Mabsadd L
.2619 .38432 -0.91448 -0.29713 Mabsadd L
.2619 .38432 -1.46946 -2.02254 Mabsadd L
.2619 .38432 0 -0.96154 Mabsadd L
.2619 .38432 1.46946 -2.02254 Mabsadd L
.2619 .38432 .91448 -0.29713 Mabsadd L
.2619 .38432 2.37764 .77254 Mabsadd L
.2619 .38432 .56518 .7779 Mabsadd L
.2619 .38432 0 2.5 Mabsadd L closepath F
.5 .52639 0 2.5 Mabsadd m
.5 .52639 -0.56518 .7779 Mabsadd L
.5 .52639 -2.37764 .77254 Mabsadd L
.5 .52639 -0.91448 -0.29713 Mabsadd L
.5 .52639 -1.46946 -2.02254 Mabsadd L
.5 .52639 0 -0.96154 Mabsadd L
.5 .52639 1.46946 -2.02254 Mabsadd L
.5 .52639 .91448 -0.29713 Mabsadd L
.5 .52639 2.37764 .77254 Mabsadd L
.5 .52639 .56518 .7779 Mabsadd L
.5 .52639 0 2.5 Mabsadd L closepath F
.7381 .58158 0 2.5 Mabsadd m
.7381 .58158 -0.56518 .7779 Mabsadd L
.7381 .58158 -2.37764 .77254 Mabsadd L
.7381 .58158 -0.91448 -0.29713 Mabsadd L
.7381 .58158 -1.46946 -2.02254 Mabsadd L
.7381 .58158 0 -0.96154 Mabsadd L
.7381 .58158 1.46946 -2.02254 Mabsadd L
.7381 .58158 .91448 -0.29713 Mabsadd L
.7381 .58158 2.37764 .77254 Mabsadd L
.7381 .58158 .56518 .7779 Mabsadd L
.7381 .58158 0 2.5 Mabsadd L closepath F
.97619 .60332 0 2.5 Mabsadd m
.97619 .60332 -0.56518 .7779 Mabsadd L
.97619 .60332 -2.37764 .77254 Mabsadd L
.97619 .60332 -0.91448 -0.29713 Mabsadd L
.97619 .60332 -1.46946 -2.02254 Mabsadd L
.97619 .60332 0 -0.96154 Mabsadd L
.97619 .60332 1.46946 -2.02254 Mabsadd L
.97619 .60332 .91448 -0.29713 Mabsadd L
.97619 .60332 2.37764 .77254 Mabsadd L
.97619 .60332 .56518 .7779 Mabsadd L
.97619 .60332 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gini1 = 
      MultipleListPlot[Array[gini, 5], Array[agini, 5], 
        PlotJoined \[Rule] True, 
        PlotStyle \[Rule] {GrayLevel[ .1], Dashing[{0.02, 0.02}]}, 
        PlotLabel -> "\<Gini\>", PlotRange \[Rule] {0,  .8}, 
        AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 -2.77556e-017 1.25 [
[.2619 -0.0125 -7.03125 -24.5625 ]
[.2619 -0.0125 7.03125 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.7381 -0.0125 -7.03125 -24.5625 ]
[.7381 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[.01131 .25 -29.125 -12.2813 ]
[.01131 .25 0 12.2813 ]
[.01131 .5 -29.125 -12.2813 ]
[.01131 .5 0 12.2813 ]
[.01131 .75 -29.125 -12.2813 ]
[.01131 .75 0 12.2813 ]
[.01131 1 -29.125 -12.2813 ]
[.01131 1 0 12.2813 ]
[.5 1.0125 -19.7813 0 ]
[.5 1.0125 19.7813 24.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .25 m
.03006 .25 L
s
gsave
.01131 .25 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .5 m
.03006 .5 L
s
gsave
.01131 .5 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .75 m
.03006 .75 L
s
gsave
.01131 .75 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 1 m
.03006 1 L
s
gsave
.01131 1 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .0625 m
.02756 .0625 L
s
.02381 .125 m
.02756 .125 L
s
.02381 .1875 m
.02756 .1875 L
s
.02381 .3125 m
.02756 .3125 L
s
.02381 .375 m
.02756 .375 L
s
.02381 .4375 m
.02756 .4375 L
s
.02381 .5625 m
.02756 .5625 L
s
.02381 .625 m
.02756 .625 L
s
.02381 .6875 m
.02756 .6875 L
s
.02381 .8125 m
.02756 .8125 L
s
.02381 .875 m
.02756 .875 L
s
.02381 .9375 m
.02756 .9375 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
gsave
.5 1.0125 -80.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Gini) show
98.563 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.001 w
.02381 .77019 m
.2619 .02681 L
.5 .00372 L
.7381 .00075 L
.97619 .00016 L
s
0 g
.0001 w
.02381 .77019 -1.875 0 Mabsadd m
.02381 .77019 0 2.5 Mabsadd L
.02381 .77019 1.875 0 Mabsadd L
.02381 .77019 0 -2.5 Mabsadd L
.02381 .77019 -1.875 0 Mabsadd L closepath F
.2619 .02681 -1.875 0 Mabsadd m
.2619 .02681 0 2.5 Mabsadd L
.2619 .02681 1.875 0 Mabsadd L
.2619 .02681 0 -2.5 Mabsadd L
.2619 .02681 -1.875 0 Mabsadd L closepath F
.5 .00372 -1.875 0 Mabsadd m
.5 .00372 0 2.5 Mabsadd L
.5 .00372 1.875 0 Mabsadd L
.5 .00372 0 -2.5 Mabsadd L
.5 .00372 -1.875 0 Mabsadd L closepath F
.7381 .00075 -1.875 0 Mabsadd m
.7381 .00075 0 2.5 Mabsadd L
.7381 .00075 1.875 0 Mabsadd L
.7381 .00075 0 -2.5 Mabsadd L
.7381 .00075 -1.875 0 Mabsadd L closepath F
.97619 .00016 -1.875 0 Mabsadd m
.97619 .00016 0 2.5 Mabsadd L
.97619 .00016 1.875 0 Mabsadd L
.97619 .00016 0 -2.5 Mabsadd L
.97619 .00016 -1.875 0 Mabsadd L closepath F
.001 w
[ .02 .02 ] 0 setdash
.02381 .77019 m
.2619 .39554 L
.5 .18145 L
.7381 .08349 L
.97619 .04055 L
s
.0001 w
[ ] 0 setdash
.02381 .77019 0 2.5 Mabsadd m
.02381 .77019 -0.56518 .7779 Mabsadd L
.02381 .77019 -2.37764 .77254 Mabsadd L
.02381 .77019 -0.91448 -0.29713 Mabsadd L
.02381 .77019 -1.46946 -2.02254 Mabsadd L
.02381 .77019 0 -0.96154 Mabsadd L
.02381 .77019 1.46946 -2.02254 Mabsadd L
.02381 .77019 .91448 -0.29713 Mabsadd L
.02381 .77019 2.37764 .77254 Mabsadd L
.02381 .77019 .56518 .7779 Mabsadd L
.02381 .77019 0 2.5 Mabsadd L closepath F
.2619 .39554 0 2.5 Mabsadd m
.2619 .39554 -0.56518 .7779 Mabsadd L
.2619 .39554 -2.37764 .77254 Mabsadd L
.2619 .39554 -0.91448 -0.29713 Mabsadd L
.2619 .39554 -1.46946 -2.02254 Mabsadd L
.2619 .39554 0 -0.96154 Mabsadd L
.2619 .39554 1.46946 -2.02254 Mabsadd L
.2619 .39554 .91448 -0.29713 Mabsadd L
.2619 .39554 2.37764 .77254 Mabsadd L
.2619 .39554 .56518 .7779 Mabsadd L
.2619 .39554 0 2.5 Mabsadd L closepath F
.5 .18145 0 2.5 Mabsadd m
.5 .18145 -0.56518 .7779 Mabsadd L
.5 .18145 -2.37764 .77254 Mabsadd L
.5 .18145 -0.91448 -0.29713 Mabsadd L
.5 .18145 -1.46946 -2.02254 Mabsadd L
.5 .18145 0 -0.96154 Mabsadd L
.5 .18145 1.46946 -2.02254 Mabsadd L
.5 .18145 .91448 -0.29713 Mabsadd L
.5 .18145 2.37764 .77254 Mabsadd L
.5 .18145 .56518 .7779 Mabsadd L
.5 .18145 0 2.5 Mabsadd L closepath F
.7381 .08349 0 2.5 Mabsadd m
.7381 .08349 -0.56518 .7779 Mabsadd L
.7381 .08349 -2.37764 .77254 Mabsadd L
.7381 .08349 -0.91448 -0.29713 Mabsadd L
.7381 .08349 -1.46946 -2.02254 Mabsadd L
.7381 .08349 0 -0.96154 Mabsadd L
.7381 .08349 1.46946 -2.02254 Mabsadd L
.7381 .08349 .91448 -0.29713 Mabsadd L
.7381 .08349 2.37764 .77254 Mabsadd L
.7381 .08349 .56518 .7779 Mabsadd L
.7381 .08349 0 2.5 Mabsadd L closepath F
.97619 .04055 0 2.5 Mabsadd m
.97619 .04055 -0.56518 .7779 Mabsadd L
.97619 .04055 -2.37764 .77254 Mabsadd L
.97619 .04055 -0.91448 -0.29713 Mabsadd L
.97619 .04055 -1.46946 -2.02254 Mabsadd L
.97619 .04055 0 -0.96154 Mabsadd L
.97619 .04055 1.46946 -2.02254 Mabsadd L
.97619 .04055 .91448 -0.29713 Mabsadd L
.97619 .04055 2.37764 .77254 Mabsadd L
.97619 .04055 .56518 .7779 Mabsadd L
.97619 .04055 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(MultipleListPlot[Log[Array[y, 5]], Log[Array[ay, 5]], 
      PlotJoined \[Rule] True, 
      PlotStyle \[Rule] {GrayLevel[ .1], Dashing[{0.02, 0.02}]}, 
      PlotLabel -> "\<Log GDP per capita: \[Tau]=0.22\>", 
      PlotRange \[Rule] {\(- .4\), 1.4}, 
      AxesOrigin \[Rule] {1, \(- .4\)}]\), "\[IndentingNewLine]", 
    \(gdp1 = 
      MultipleListPlot[Log[Array[h, 5]], Log[Array[ah, 5]], 
        PlotJoined \[Rule] True, 
        PlotStyle \[Rule] {GrayLevel[ .1], Dashing[{0.02, 0.02}]}, 
        PlotLabel -> "\<Log average human capital\>", 
        PlotRange \[Rule] {\(- .4\), 1.4}, AxesOrigin \[Rule] {1, \(- .4\)}, 
        AspectRatio \[Rule] 1]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 0.137341 0.343352 [
[.2619 -0.0125 -7.03125 -24.5625 ]
[.2619 -0.0125 7.03125 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.7381 -0.0125 -7.03125 -24.5625 ]
[.7381 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[.01131 .0515 -53.125 -12.2813 ]
[.01131 .0515 0 12.2813 ]
[.01131 .13734 -14.0625 -12.2813 ]
[.01131 .13734 0 12.2813 ]
[.01131 .22318 -39.1875 -12.2813 ]
[.01131 .22318 0 12.2813 ]
[.01131 .30902 -29.125 -12.2813 ]
[.01131 .30902 0 12.2813 ]
[.01131 .39486 -39.1875 -12.2813 ]
[.01131 .39486 0 12.2813 ]
[.01131 .48069 -14.0625 -12.2813 ]
[.01131 .48069 0 12.2813 ]
[.01131 .56653 -39.1875 -12.2813 ]
[.01131 .56653 0 12.2813 ]
[.5 .63053 -116.563 0 ]
[.5 .63053 116.563 24.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .0515 m
.03006 .0515 L
s
gsave
.01131 .0515 -114.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .13734 m
.03006 .13734 L
s
gsave
.01131 .13734 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02381 .22318 m
.03006 .22318 L
s
gsave
.01131 .22318 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .30902 m
.03006 .30902 L
s
gsave
.01131 .30902 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .39486 m
.03006 .39486 L
s
gsave
.01131 .39486 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.02381 .48069 m
.03006 .48069 L
s
gsave
.01131 .48069 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .56653 m
.03006 .56653 L
s
gsave
.01131 .56653 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .06867 m
.02756 .06867 L
s
.02381 .08584 m
.02756 .08584 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12017 m
.02756 .12017 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .17168 m
.02756 .17168 L
s
.02381 .18884 m
.02756 .18884 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .24035 m
.02756 .24035 L
s
.02381 .25751 m
.02756 .25751 L
s
.02381 .27468 m
.02756 .27468 L
s
.02381 .29185 m
.02756 .29185 L
s
.02381 .32618 m
.02756 .32618 L
s
.02381 .34335 m
.02756 .34335 L
s
.02381 .36052 m
.02756 .36052 L
s
.02381 .37769 m
.02756 .37769 L
s
.02381 .41202 m
.02756 .41202 L
s
.02381 .42919 m
.02756 .42919 L
s
.02381 .44636 m
.02756 .44636 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .49786 m
.02756 .49786 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .5322 m
.02756 .5322 L
s
.02381 .54936 m
.02756 .54936 L
s
.02381 .03434 m
.02756 .03434 L
s
.02381 .01717 m
.02756 .01717 L
s
.02381 0 m
.02756 0 L
s
.02381 .5837 m
.02756 .5837 L
s
.02381 .60087 m
.02756 .60087 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -177.563 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
100.375 23.000 moveto
(GDP) show
145.563 23.000 moveto
(per) show
176.188 23.000 moveto
(capita) show
224.000 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
234.500 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
244.000 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
256.938 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
292.125 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.1 g
.001 w
.02381 .08373 m
.2619 .07447 L
.5 .13076 L
.7381 .18764 L
.97619 .24455 L
s
0 g
.0001 w
.02381 .08373 -1.875 0 Mabsadd m
.02381 .08373 0 2.5 Mabsadd L
.02381 .08373 1.875 0 Mabsadd L
.02381 .08373 0 -2.5 Mabsadd L
.02381 .08373 -1.875 0 Mabsadd L closepath F
.2619 .07447 -1.875 0 Mabsadd m
.2619 .07447 0 2.5 Mabsadd L
.2619 .07447 1.875 0 Mabsadd L
.2619 .07447 0 -2.5 Mabsadd L
.2619 .07447 -1.875 0 Mabsadd L closepath F
.5 .13076 -1.875 0 Mabsadd m
.5 .13076 0 2.5 Mabsadd L
.5 .13076 1.875 0 Mabsadd L
.5 .13076 0 -2.5 Mabsadd L
.5 .13076 -1.875 0 Mabsadd L closepath F
.7381 .18764 -1.875 0 Mabsadd m
.7381 .18764 0 2.5 Mabsadd L
.7381 .18764 1.875 0 Mabsadd L
.7381 .18764 0 -2.5 Mabsadd L
.7381 .18764 -1.875 0 Mabsadd L closepath F
.97619 .24455 -1.875 0 Mabsadd m
.97619 .24455 0 2.5 Mabsadd L
.97619 .24455 1.875 0 Mabsadd L
.97619 .24455 0 -2.5 Mabsadd L
.97619 .24455 -1.875 0 Mabsadd L closepath F
.001 w
[ .02 .02 ] 0 setdash
.02381 .10484 m
.2619 .03583 L
.5 .15744 L
.7381 .33144 L
.97619 .52384 L
s
.0001 w
[ ] 0 setdash
.02381 .10484 0 2.5 Mabsadd m
.02381 .10484 -0.56518 .7779 Mabsadd L
.02381 .10484 -2.37764 .77254 Mabsadd L
.02381 .10484 -0.91448 -0.29713 Mabsadd L
.02381 .10484 -1.46946 -2.02254 Mabsadd L
.02381 .10484 0 -0.96154 Mabsadd L
.02381 .10484 1.46946 -2.02254 Mabsadd L
.02381 .10484 .91448 -0.29713 Mabsadd L
.02381 .10484 2.37764 .77254 Mabsadd L
.02381 .10484 .56518 .7779 Mabsadd L
.02381 .10484 0 2.5 Mabsadd L closepath F
.2619 .03583 0 2.5 Mabsadd m
.2619 .03583 -0.56518 .7779 Mabsadd L
.2619 .03583 -2.37764 .77254 Mabsadd L
.2619 .03583 -0.91448 -0.29713 Mabsadd L
.2619 .03583 -1.46946 -2.02254 Mabsadd L
.2619 .03583 0 -0.96154 Mabsadd L
.2619 .03583 1.46946 -2.02254 Mabsadd L
.2619 .03583 .91448 -0.29713 Mabsadd L
.2619 .03583 2.37764 .77254 Mabsadd L
.2619 .03583 .56518 .7779 Mabsadd L
.2619 .03583 0 2.5 Mabsadd L closepath F
.5 .15744 0 2.5 Mabsadd m
.5 .15744 -0.56518 .7779 Mabsadd L
.5 .15744 -2.37764 .77254 Mabsadd L
.5 .15744 -0.91448 -0.29713 Mabsadd L
.5 .15744 -1.46946 -2.02254 Mabsadd L
.5 .15744 0 -0.96154 Mabsadd L
.5 .15744 1.46946 -2.02254 Mabsadd L
.5 .15744 .91448 -0.29713 Mabsadd L
.5 .15744 2.37764 .77254 Mabsadd L
.5 .15744 .56518 .7779 Mabsadd L
.5 .15744 0 2.5 Mabsadd L closepath F
.7381 .33144 0 2.5 Mabsadd m
.7381 .33144 -0.56518 .7779 Mabsadd L
.7381 .33144 -2.37764 .77254 Mabsadd L
.7381 .33144 -0.91448 -0.29713 Mabsadd L
.7381 .33144 -1.46946 -2.02254 Mabsadd L
.7381 .33144 0 -0.96154 Mabsadd L
.7381 .33144 1.46946 -2.02254 Mabsadd L
.7381 .33144 .91448 -0.29713 Mabsadd L
.7381 .33144 2.37764 .77254 Mabsadd L
.7381 .33144 .56518 .7779 Mabsadd L
.7381 .33144 0 2.5 Mabsadd L closepath F
.97619 .52384 0 2.5 Mabsadd m
.97619 .52384 -0.56518 .7779 Mabsadd L
.97619 .52384 -2.37764 .77254 Mabsadd L
.97619 .52384 -0.91448 -0.29713 Mabsadd L
.97619 .52384 -1.46946 -2.02254 Mabsadd L
.97619 .52384 0 -0.96154 Mabsadd L
.97619 .52384 1.46946 -2.02254 Mabsadd L
.97619 .52384 .91448 -0.29713 Mabsadd L
.97619 .52384 2.37764 .77254 Mabsadd L
.97619 .52384 .56518 .7779 Mabsadd L
.97619 .52384 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 0.222222 0.555556 [
[.2619 -0.0125 -7.03125 -24.5625 ]
[.2619 -0.0125 7.03125 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.7381 -0.0125 -7.03125 -24.5625 ]
[.7381 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[.01131 .08333 -53.125 -12.2813 ]
[.01131 .08333 0 12.2813 ]
[.01131 .22222 -14.0625 -12.2813 ]
[.01131 .22222 0 12.2813 ]
[.01131 .36111 -39.1875 -12.2813 ]
[.01131 .36111 0 12.2813 ]
[.01131 .5 -29.125 -12.2813 ]
[.01131 .5 0 12.2813 ]
[.01131 .63889 -39.1875 -12.2813 ]
[.01131 .63889 0 12.2813 ]
[.01131 .77778 -14.0625 -12.2813 ]
[.01131 .77778 0 12.2813 ]
[.01131 .91667 -39.1875 -12.2813 ]
[.01131 .91667 0 12.2813 ]
[.5 1.0125 -110.656 0 ]
[.5 1.0125 110.656 24.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .08333 m
.03006 .08333 L
s
gsave
.01131 .08333 -114.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .22222 m
.03006 .22222 L
s
gsave
.01131 .22222 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02381 .36111 m
.03006 .36111 L
s
gsave
.01131 .36111 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .5 m
.03006 .5 L
s
gsave
.01131 .5 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .63889 m
.03006 .63889 L
s
gsave
.01131 .63889 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.02381 .77778 m
.03006 .77778 L
s
gsave
.01131 .77778 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .91667 m
.03006 .91667 L
s
gsave
.01131 .91667 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .11111 m
.02756 .11111 L
s
.02381 .13889 m
.02756 .13889 L
s
.02381 .16667 m
.02756 .16667 L
s
.02381 .19444 m
.02756 .19444 L
s
.02381 .25 m
.02756 .25 L
s
.02381 .27778 m
.02756 .27778 L
s
.02381 .30556 m
.02756 .30556 L
s
.02381 .33333 m
.02756 .33333 L
s
.02381 .38889 m
.02756 .38889 L
s
.02381 .41667 m
.02756 .41667 L
s
.02381 .44444 m
.02756 .44444 L
s
.02381 .47222 m
.02756 .47222 L
s
.02381 .52778 m
.02756 .52778 L
s
.02381 .55556 m
.02756 .55556 L
s
.02381 .58333 m
.02756 .58333 L
s
.02381 .61111 m
.02756 .61111 L
s
.02381 .66667 m
.02756 .66667 L
s
.02381 .69444 m
.02756 .69444 L
s
.02381 .72222 m
.02756 .72222 L
s
.02381 .75 m
.02756 .75 L
s
.02381 .80556 m
.02756 .80556 L
s
.02381 .83333 m
.02756 .83333 L
s
.02381 .86111 m
.02756 .86111 L
s
.02381 .88889 m
.02756 .88889 L
s
.02381 .05556 m
.02756 .05556 L
s
.02381 .02778 m
.02756 .02778 L
s
.02381 0 m
.02756 0 L
s
.02381 .94444 m
.02756 .94444 L
s
.02381 .97222 m
.02756 .97222 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
gsave
.5 1.0125 -171.656 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
100.375 23.000 moveto
(average) show
167.688 23.000 moveto
(human) show
227.125 23.000 moveto
(capital) show
280.313 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.001 w
.02381 .22222 m
.2619 .20725 L
.5 .29832 L
.7381 .39036 L
.97619 .48244 L
s
0 g
.0001 w
.02381 .22222 -1.875 0 Mabsadd m
.02381 .22222 0 2.5 Mabsadd L
.02381 .22222 1.875 0 Mabsadd L
.02381 .22222 0 -2.5 Mabsadd L
.02381 .22222 -1.875 0 Mabsadd L closepath F
.2619 .20725 -1.875 0 Mabsadd m
.2619 .20725 0 2.5 Mabsadd L
.2619 .20725 1.875 0 Mabsadd L
.2619 .20725 0 -2.5 Mabsadd L
.2619 .20725 -1.875 0 Mabsadd L closepath F
.5 .29832 -1.875 0 Mabsadd m
.5 .29832 0 2.5 Mabsadd L
.5 .29832 1.875 0 Mabsadd L
.5 .29832 0 -2.5 Mabsadd L
.5 .29832 -1.875 0 Mabsadd L closepath F
.7381 .39036 -1.875 0 Mabsadd m
.7381 .39036 0 2.5 Mabsadd L
.7381 .39036 1.875 0 Mabsadd L
.7381 .39036 0 -2.5 Mabsadd L
.7381 .39036 -1.875 0 Mabsadd L closepath F
.97619 .48244 -1.875 0 Mabsadd m
.97619 .48244 0 2.5 Mabsadd L
.97619 .48244 1.875 0 Mabsadd L
.97619 .48244 0 -2.5 Mabsadd L
.97619 .48244 -1.875 0 Mabsadd L closepath F
.001 w
[ .02 .02 ] 0 setdash
.02381 .22222 m
.2619 .10275 L
.5 .29846 L
.7381 .57968 L
.97619 .89087 L
s
.0001 w
[ ] 0 setdash
.02381 .22222 0 2.5 Mabsadd m
.02381 .22222 -0.56518 .7779 Mabsadd L
.02381 .22222 -2.37764 .77254 Mabsadd L
.02381 .22222 -0.91448 -0.29713 Mabsadd L
.02381 .22222 -1.46946 -2.02254 Mabsadd L
.02381 .22222 0 -0.96154 Mabsadd L
.02381 .22222 1.46946 -2.02254 Mabsadd L
.02381 .22222 .91448 -0.29713 Mabsadd L
.02381 .22222 2.37764 .77254 Mabsadd L
.02381 .22222 .56518 .7779 Mabsadd L
.02381 .22222 0 2.5 Mabsadd L closepath F
.2619 .10275 0 2.5 Mabsadd m
.2619 .10275 -0.56518 .7779 Mabsadd L
.2619 .10275 -2.37764 .77254 Mabsadd L
.2619 .10275 -0.91448 -0.29713 Mabsadd L
.2619 .10275 -1.46946 -2.02254 Mabsadd L
.2619 .10275 0 -0.96154 Mabsadd L
.2619 .10275 1.46946 -2.02254 Mabsadd L
.2619 .10275 .91448 -0.29713 Mabsadd L
.2619 .10275 2.37764 .77254 Mabsadd L
.2619 .10275 .56518 .7779 Mabsadd L
.2619 .10275 0 2.5 Mabsadd L closepath F
.5 .29846 0 2.5 Mabsadd m
.5 .29846 -0.56518 .7779 Mabsadd L
.5 .29846 -2.37764 .77254 Mabsadd L
.5 .29846 -0.91448 -0.29713 Mabsadd L
.5 .29846 -1.46946 -2.02254 Mabsadd L
.5 .29846 0 -0.96154 Mabsadd L
.5 .29846 1.46946 -2.02254 Mabsadd L
.5 .29846 .91448 -0.29713 Mabsadd L
.5 .29846 2.37764 .77254 Mabsadd L
.5 .29846 .56518 .7779 Mabsadd L
.5 .29846 0 2.5 Mabsadd L closepath F
.7381 .57968 0 2.5 Mabsadd m
.7381 .57968 -0.56518 .7779 Mabsadd L
.7381 .57968 -2.37764 .77254 Mabsadd L
.7381 .57968 -0.91448 -0.29713 Mabsadd L
.7381 .57968 -1.46946 -2.02254 Mabsadd L
.7381 .57968 0 -0.96154 Mabsadd L
.7381 .57968 1.46946 -2.02254 Mabsadd L
.7381 .57968 .91448 -0.29713 Mabsadd L
.7381 .57968 2.37764 .77254 Mabsadd L
.7381 .57968 .56518 .7779 Mabsadd L
.7381 .57968 0 2.5 Mabsadd L closepath F
.97619 .89087 0 2.5 Mabsadd m
.97619 .89087 -0.56518 .7779 Mabsadd L
.97619 .89087 -2.37764 .77254 Mabsadd L
.97619 .89087 -0.91448 -0.29713 Mabsadd L
.97619 .89087 -1.46946 -2.02254 Mabsadd L
.97619 .89087 0 -0.96154 Mabsadd L
.97619 .89087 1.46946 -2.02254 Mabsadd L
.97619 .89087 .91448 -0.29713 Mabsadd L
.97619 .89087 2.37764 .77254 Mabsadd L
.97619 .89087 .56518 .7779 Mabsadd L
.97619 .89087 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rel1 = 
      MultipleListPlot[Log[Array[ha, 5]], Log[Array[aha, 5]], 
        PlotJoined \[Rule] True, 
        PlotStyle \[Rule] {GrayLevel[ .1], Dashing[{0.02, 0.02}]}, 
        PlotLabel -> "\<Log human capital of A\>", 
        AxesOrigin \[Rule] {1, \(-1\)}, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 0.456727 0.443785 [
[.2619 .00044 -7.03125 -24.5625 ]
[.2619 .00044 7.03125 0 ]
[.5 .00044 -7.03125 -24.5625 ]
[.5 .00044 7.03125 0 ]
[.7381 .00044 -7.03125 -24.5625 ]
[.7381 .00044 7.03125 0 ]
[.97619 .00044 -7.03125 -24.5625 ]
[.97619 .00044 7.03125 0 ]
[.01131 .23483 -43.0625 -12.2813 ]
[.01131 .23483 0 12.2813 ]
[.01131 .45673 -14.0625 -12.2813 ]
[.01131 .45673 0 12.2813 ]
[.01131 .67862 -29.125 -12.2813 ]
[.01131 .67862 0 12.2813 ]
[.01131 .90051 -14.0625 -12.2813 ]
[.01131 .90051 0 12.2813 ]
[.5 1.0125 -98.7188 0 ]
[.5 1.0125 98.7188 24.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01294 m
.2619 .01919 L
s
gsave
.2619 .00044 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .01294 m
.5 .01919 L
s
gsave
.5 .00044 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 .01294 m
.7381 .01919 L
s
gsave
.7381 .00044 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 .01294 m
.97619 .01919 L
s
gsave
.97619 .00044 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .01294 m
.07143 .01669 L
s
.11905 .01294 m
.11905 .01669 L
s
.16667 .01294 m
.16667 .01669 L
s
.21429 .01294 m
.21429 .01669 L
s
.30952 .01294 m
.30952 .01669 L
s
.35714 .01294 m
.35714 .01669 L
s
.40476 .01294 m
.40476 .01669 L
s
.45238 .01294 m
.45238 .01669 L
s
.54762 .01294 m
.54762 .01669 L
s
.59524 .01294 m
.59524 .01669 L
s
.64286 .01294 m
.64286 .01669 L
s
.69048 .01294 m
.69048 .01669 L
s
.78571 .01294 m
.78571 .01669 L
s
.83333 .01294 m
.83333 .01669 L
s
.88095 .01294 m
.88095 .01669 L
s
.92857 .01294 m
.92857 .01669 L
s
.25 Mabswid
0 .01294 m
1 .01294 L
s
.02381 .23483 m
.03006 .23483 L
s
gsave
.01131 .23483 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .45673 m
.03006 .45673 L
s
gsave
.01131 .45673 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02381 .67862 m
.03006 .67862 L
s
gsave
.01131 .67862 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .90051 m
.03006 .90051 L
s
gsave
.01131 .90051 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .05732 m
.02756 .05732 L
s
.02381 .1017 m
.02756 .1017 L
s
.02381 .14608 m
.02756 .14608 L
s
.02381 .19046 m
.02756 .19046 L
s
.02381 .27921 m
.02756 .27921 L
s
.02381 .32359 m
.02756 .32359 L
s
.02381 .36797 m
.02756 .36797 L
s
.02381 .41235 m
.02756 .41235 L
s
.02381 .50111 m
.02756 .50111 L
s
.02381 .54548 m
.02756 .54548 L
s
.02381 .58986 m
.02756 .58986 L
s
.02381 .63424 m
.02756 .63424 L
s
.02381 .723 m
.02756 .723 L
s
.02381 .76738 m
.02756 .76738 L
s
.02381 .81175 m
.02756 .81175 L
s
.02381 .85613 m
.02756 .85613 L
s
.02381 .94489 m
.02756 .94489 L
s
.02381 .98927 m
.02756 .98927 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
gsave
.5 1.0125 -159.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
100.375 23.000 moveto
(human) show
159.813 23.000 moveto
(capital) show
218.000 23.000 moveto
(of) show
241.938 23.000 moveto
(A) show
256.438 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.001 w
.02381 .02381 m
.2619 .43504 L
.5 .51618 L
.7381 .59077 L
.97619 .66453 L
s
0 g
.0001 w
.02381 .02381 -1.875 0 Mabsadd m
.02381 .02381 0 2.5 Mabsadd L
.02381 .02381 1.875 0 Mabsadd L
.02381 .02381 0 -2.5 Mabsadd L
.02381 .02381 -1.875 0 Mabsadd L closepath F
.2619 .43504 -1.875 0 Mabsadd m
.2619 .43504 0 2.5 Mabsadd L
.2619 .43504 1.875 0 Mabsadd L
.2619 .43504 0 -2.5 Mabsadd L
.2619 .43504 -1.875 0 Mabsadd L closepath F
.5 .51618 -1.875 0 Mabsadd m
.5 .51618 0 2.5 Mabsadd L
.5 .51618 1.875 0 Mabsadd L
.5 .51618 0 -2.5 Mabsadd L
.5 .51618 -1.875 0 Mabsadd L closepath F
.7381 .59077 -1.875 0 Mabsadd m
.7381 .59077 0 2.5 Mabsadd L
.7381 .59077 1.875 0 Mabsadd L
.7381 .59077 0 -2.5 Mabsadd L
.7381 .59077 -1.875 0 Mabsadd L closepath F
.97619 .66453 -1.875 0 Mabsadd m
.97619 .66453 0 2.5 Mabsadd L
.97619 .66453 1.875 0 Mabsadd L
.97619 .66453 0 -2.5 Mabsadd L
.97619 .66453 -1.875 0 Mabsadd L closepath F
.001 w
[ .02 .02 ] 0 setdash
.02381 .02381 m
.2619 .19154 L
.5 .44779 L
.7381 .71152 L
.97619 .97619 L
s
.0001 w
[ ] 0 setdash
.02381 .02381 0 2.5 Mabsadd m
.02381 .02381 -0.56518 .7779 Mabsadd L
.02381 .02381 -2.37764 .77254 Mabsadd L
.02381 .02381 -0.91448 -0.29713 Mabsadd L
.02381 .02381 -1.46946 -2.02254 Mabsadd L
.02381 .02381 0 -0.96154 Mabsadd L
.02381 .02381 1.46946 -2.02254 Mabsadd L
.02381 .02381 .91448 -0.29713 Mabsadd L
.02381 .02381 2.37764 .77254 Mabsadd L
.02381 .02381 .56518 .7779 Mabsadd L
.02381 .02381 0 2.5 Mabsadd L closepath F
.2619 .19154 0 2.5 Mabsadd m
.2619 .19154 -0.56518 .7779 Mabsadd L
.2619 .19154 -2.37764 .77254 Mabsadd L
.2619 .19154 -0.91448 -0.29713 Mabsadd L
.2619 .19154 -1.46946 -2.02254 Mabsadd L
.2619 .19154 0 -0.96154 Mabsadd L
.2619 .19154 1.46946 -2.02254 Mabsadd L
.2619 .19154 .91448 -0.29713 Mabsadd L
.2619 .19154 2.37764 .77254 Mabsadd L
.2619 .19154 .56518 .7779 Mabsadd L
.2619 .19154 0 2.5 Mabsadd L closepath F
.5 .44779 0 2.5 Mabsadd m
.5 .44779 -0.56518 .7779 Mabsadd L
.5 .44779 -2.37764 .77254 Mabsadd L
.5 .44779 -0.91448 -0.29713 Mabsadd L
.5 .44779 -1.46946 -2.02254 Mabsadd L
.5 .44779 0 -0.96154 Mabsadd L
.5 .44779 1.46946 -2.02254 Mabsadd L
.5 .44779 .91448 -0.29713 Mabsadd L
.5 .44779 2.37764 .77254 Mabsadd L
.5 .44779 .56518 .7779 Mabsadd L
.5 .44779 0 2.5 Mabsadd L closepath F
.7381 .71152 0 2.5 Mabsadd m
.7381 .71152 -0.56518 .7779 Mabsadd L
.7381 .71152 -2.37764 .77254 Mabsadd L
.7381 .71152 -0.91448 -0.29713 Mabsadd L
.7381 .71152 -1.46946 -2.02254 Mabsadd L
.7381 .71152 0 -0.96154 Mabsadd L
.7381 .71152 1.46946 -2.02254 Mabsadd L
.7381 .71152 .91448 -0.29713 Mabsadd L
.7381 .71152 2.37764 .77254 Mabsadd L
.7381 .71152 .56518 .7779 Mabsadd L
.7381 .71152 0 2.5 Mabsadd L closepath F
.97619 .97619 0 2.5 Mabsadd m
.97619 .97619 -0.56518 .7779 Mabsadd L
.97619 .97619 -2.37764 .77254 Mabsadd L
.97619 .97619 -0.91448 -0.29713 Mabsadd L
.97619 .97619 -1.46946 -2.02254 Mabsadd L
.97619 .97619 0 -0.96154 Mabsadd L
.97619 .97619 1.46946 -2.02254 Mabsadd L
.97619 .97619 .91448 -0.29713 Mabsadd L
.97619 .97619 2.37764 .77254 Mabsadd L
.97619 .97619 .56518 .7779 Mabsadd L
.97619 .97619 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unstable situation", "Section"],

Cell[BoxData[
    \(\(\[Tau] =  .5;\)\)], "Input"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(xi[1] = 90;\)\), "\[IndentingNewLine]", 
    \(\(xa[1] =  .377;\)\), "\[IndentingNewLine]", 
    \(\(xb[1] = 1 + xi[1] \((1 - xa[1])\);\)\), "\[IndentingNewLine]", 
    \(\(h[1] = 1;\)\), "\[IndentingNewLine]", 
    \(\(ha[1] = h[1]\ xa[1];\)\)}], "Input"],

Cell[BoxData[{
    \(\(axi[1] = 90;\)\), "\[IndentingNewLine]", 
    \(\(axa[1] =  .377;\)\), "\[IndentingNewLine]", 
    \(\(axb[1] = 1 + axi[1] \((1 - axa[1])\);\)\), "\[IndentingNewLine]", 
    \(\(ah[1] = 1;\)\), "\[IndentingNewLine]", 
    \(\(aha[1] = ah[1]\ axa[1];\)\)}], "Input"],

Cell[BoxData[
    \(\(\(Do[
      na[t] = \[Gamma]\/\(\[Phi] + \[Gamma]\ \[Phi]\); \[IndentingNewLine]nb[
          t] = \[Gamma]\/\(\[Phi] + \[Gamma]\ \[Phi]\); \[IndentingNewLine]e[
          t] = \(\[Phi]\ \[Eta] - \[Theta]\)\/\(1 + \[Gamma]\ \[Eta]\); \
\[IndentingNewLine]xa[
          t + 1] = \(1 + xi[t]\)\/\(xi[t] + \((\(1 + xi[t]\)\/xa[t] - \
xi[t])\)\^\[Tau]\); \[IndentingNewLine]g[
          t] = \[Mu]\ \(\((\[Theta] + \(\[Phi]\ \[Eta] - \[Theta]\)\/\(1 + \
\[Gamma]\ \[Eta]\))\)\^\[Eta]\) 
          xa[t]\^\[Tau]/xa[t + 1]; \[IndentingNewLine]xi[t + 1] = 
        xi[t]; \[IndentingNewLine]xb[t + 1] = 
        1 + xi[t + 1] \((1 - xa[t + 1])\); \[IndentingNewLine]h[t + 1] = 
        h[t]\ g[t]; \[IndentingNewLine]ha[t + 1] = 
        h[t + 1]\ xa[t + 1]; \[IndentingNewLine]y[t] = 
        h[t] \((1 - \[Phi] \((xi[t]\/\(1 + xi[t]\)\ xa[t]\ na[t] + 
                    1\/\(1 + xi[t]\)\ xb[t]\ nb[
                        t])\))\); \[IndentingNewLine]gini[t] = 
        2 \((1\/2 - \(\((xi[t]\/\(1 + xi[t]\))\)\^2\) 
                xa[t]\/2\  - \((1\/\(1 + xi[t]\))\) \((1 - \(xi[t]\/\(1 + 
                            xi[t]\)\) xa[t])\) 
                1\/2 - \((1\/\(1 + xi[t]\))\) \(xi[t] xa[t]\)\/\(1 + xi[t]\))\
\), \[IndentingNewLine]{t, 1, 50}]\)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[ana[t] = 
        If[axa[t] > \[Theta]/\((\[Phi]\ \[Eta])\), \(\((1 - \[Eta])\) \
\[Gamma]\ axa[t]\)\/\(\((\[Phi]\ axa[t] - \[Theta])\) \((1 + \[Gamma])\)\), \
\[Gamma]\/\(\[Phi] + \[Gamma]\ \[Phi]\)]; \[IndentingNewLine]anb[
          t] = \(\((1 - \[Eta])\) \[Gamma]\ axb[t]\)\/\(\((\[Phi]\ axb[t] - \
\[Theta])\) \((1 + \[Gamma])\)\); \[IndentingNewLine]aea[t] = 
        If[axa[t] > \[Theta]/\((\[Phi]\ \[Eta])\), \(\[Eta]\ \[Phi]\ axa[t] - \
\[Theta]\)\/\(1 - \[Eta]\), 0]; \[IndentingNewLine]aeb[
          t] = \(\[Eta]\ \[Phi]\ axb[t] - \[Theta]\)\/\(1 - \[Eta]\); \
\[IndentingNewLine]axi[t + 1] = \(ana[t]\/anb[t]\) 
          axi[t]; \[IndentingNewLine]ag[
          t] = \[Mu]\ \((axi[t] 
                  ana[t] \((\[Theta] + aea[t])\)\^\[Eta]\ axa[t]\^\[Tau] + 
                anb[t] \((\[Theta] + aeb[t])\)\^\[Eta]\ \
axb[t]\^\[Tau])\)/\((axi[t]\ ana[t] + anb[t])\); \[IndentingNewLine]axa[
          t + 1] = \[Mu]\ \(\((\[Theta] + aea[t])\)\^\[Eta]\) 
          axa[t]\^\[Tau]/ag[t]; \[IndentingNewLine]axb[
          t + 1] = \[Mu]\ \(\((\[Theta] + aeb[t])\)\^\[Eta]\) 
          axb[t]\^\[Tau]/ag[t]; \[IndentingNewLine]ah[t + 1] = 
        ah[t] ag[t]; \[IndentingNewLine]aha[t + 1] = 
        ah[t + 1]\ axa[t + 1]; \[IndentingNewLine]\[IndentingNewLine]ay[t] = 
        ah[t] \((1 - \[Phi] \((axi[t]\/\(1 + axi[t]\)\ axa[t]\ ana[t] + 
                    1\/\(1 + axi[t]\)\ axb[t]\ anb[
                        t])\))\); \[IndentingNewLine]agini[t] = 
        2 \((1\/2 - \(\((axi[t]\/\(1 + axi[t]\))\)\^2\) 
                axa[t]\/2\  - \((1\/\(1 + axi[t]\))\) \((1 - \(axi[t]\/\(1 + 
                            axi[t]\)\) axa[t])\) 
                1\/2 - \((1\/\(1 + axi[t]\))\) \(axi[t] axa[t]\)\/\(1 + \
axi[t]\))\); \[IndentingNewLine]Print["\<Time= \>", t, "\< Fertility= \>", 
        ana[t], "\< \>", anb[t], "\< Education= \>", aea[t], "\< \>", 
        aeb[t], "\< Human cap= \>", axa[t], "\< \>", axb[t]], {t, 1, 
        10}]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]1\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.9275734245794125`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7741039020049055`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]6.3778749999999995`\
\[InvisibleSpace]" Human cap= "\[InvisibleSpace]0.377`\[InvisibleSpace]" "\
\[InvisibleSpace]57.07`\),
      SequenceForm[ 
      "Time= ", 1, " Fertility= ", 1.9275734245794125, 
        " ", .77410390200490553, " Education= ", 0, " ", 6.3778749999999995, 
        " Human cap= ", .377, " ", 57.07],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]2\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.9275734245794125`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7722105100692165`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]16.62899029589573`\
\[InvisibleSpace]" Human cap= "\[InvisibleSpace]0.3432090706755925`\
\[InvisibleSpace]" "\[InvisibleSpace]148.19102485240649`\),
      SequenceForm[ 
      "Time= ", 2, " Fertility= ", 1.9275734245794125, 
        " ", .77221051006921648, " Education= ", 0, " ", 16.628990295895729, 
        " Human cap= ", .34320907067559248, " ", 148.19102485240649],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]3\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.9275734245794125`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7714762361636108`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]43.98105384645834`\
\[InvisibleSpace]" Human cap= "\[InvisibleSpace]0.3022627118876877`\
\[InvisibleSpace]" "\[InvisibleSpace]391.3204786351852`\),
      SequenceForm[ 
      "Time= ", 3, " Fertility= ", 1.9275734245794125, 
        " ", .77147623616361083, " Education= ", 0, " ", 43.981053846458337, 
        " Human cap= ", .30226271188768772, " ", 391.32047863518522],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]4\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.9275734245794125`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7711978342558291`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]116.6916109719368`\
\[InvisibleSpace]" Human cap= "\[InvisibleSpace]0.2583333820084146`\
\[InvisibleSpace]" "\[InvisibleSpace]1037.6365419727717`\),
      SequenceForm[ 
      "Time= ", 4, " Fertility= ", 1.9275734245794125, 
        " ", .77119783425582911, " Education= ", 0, " ", 116.6916109719368, 
        " Human cap= ", .2583333820084146, " ", 1037.6365419727717],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]5\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.9275734245794125`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7710931401602318`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]308.2964335901262`\
\[InvisibleSpace]" Human cap= "\[InvisibleSpace]0.2157501429909176`\
\[InvisibleSpace]" "\[InvisibleSpace]2740.790520801122`\),
      SequenceForm[ 
      "Time= ", 5, " Fertility= ", 1.9275734245794125, 
        " ", .77109314016023178, " Education= ", 0, " ", 308.29643359012618, 
        " Human cap= ", .2157501429909176, " ", 2740.7905208011221],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]6\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.9275734245794125`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7710536987331787`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]808.1267215975975`\
\[InvisibleSpace]" Human cap= "\[InvisibleSpace]0.17752572407142023`\
\[InvisibleSpace]" "\[InvisibleSpace]7183.726414200866`\),
      SequenceForm[ 
      "Time= ", 6, " Fertility= ", 1.9275734245794125, 
        " ", .77105369873317875, " Education= ", 0, " ", 808.12672159759745, 
        " Human cap= ", .17752572407142023, " ", 7183.7264142008662],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]7\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.9275734245794125`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7710387319350515`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]2100.0718720765854`\
\[InvisibleSpace]" Human cap= "\[InvisibleSpace]0.14498476522611078`\
\[InvisibleSpace]" "\[InvisibleSpace]18667.683307347426`\),
      SequenceForm[ 
      "Time= ", 7, " Fertility= ", 1.9275734245794125, 
        " ", .77103873193505146, " Education= ", 0, " ", 2100.0718720765854, 
        " Human cap= ", .14498476522611078, " ", 18667.683307347426],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]8\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.9275734245794125`\[InvisibleSpace]" "\
\[InvisibleSpace]0.771033000893717`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]5414.720944881055`\
\[InvisibleSpace]" Human cap= "\[InvisibleSpace]0.11815978362335233`\
\[InvisibleSpace]" "\[InvisibleSpace]48131.230621164934`\),
      SequenceForm[ 
      "Time= ", 8, " Fertility= ", 1.9275734245794125, 
        " ", .77103300089371696, " Education= ", 0, " ", 5414.7209448810554, 
        " Human cap= ", .11815978362335233, " ", 48131.230621164934],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]9\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.9275734245794125`\[InvisibleSpace]" "\
\[InvisibleSpace]0.7710307873050343`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]13870.614183962483`\
\[InvisibleSpace]" Human cap= "\[InvisibleSpace]0.09640260012339887`\
\[InvisibleSpace]" "\[InvisibleSpace]123294.72607966654`\),
      SequenceForm[ 
      "Time= ", 9, " Fertility= ", 1.9275734245794125, 
        " ", .77103078730503427, " Education= ", 0, " ", 13870.614183962483, 
        " Human cap= ", .096402600123398866, " ", 123294.72607966654],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Time= "\[InvisibleSpace]10\[InvisibleSpace]" \
Fertility= "\[InvisibleSpace]1.9275734245794125`\[InvisibleSpace]" "\
\[InvisibleSpace]0.771029926022099`\[InvisibleSpace]" Education= "\
\[InvisibleSpace]0\[InvisibleSpace]" "\[InvisibleSpace]35349.84030531908`\
\[InvisibleSpace]" Human cap= "\[InvisibleSpace]0.07885317740633958`\
\[InvisibleSpace]" "\[InvisibleSpace]314221.18049172516`\),
      SequenceForm[ 
      "Time= ", 10, " Fertility= ", 1.9275734245794125, 
        " ", .77102992602209897, " Education= ", 0, " ", 35349.840305319078, 
        " Human cap= ", .078853177406339583, " ", 314221.18049172516],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\(MultipleListPlot[Array[g, 5], 
      Array[ag, 5], PlotJoined \[Rule] True, 
      PlotStyle \[Rule] {GrayLevel[ .1], Dashing[{0.02, 0.02}]}, 
      PlotLabel -> "\<Growth - unstable (\[Tau]=0.5)\>", 
      PlotRange \[Rule] All]\)\(\[IndentingNewLine]\)
    \)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 -0.479987 0.607218 [
[.2619 .11473 -7.03125 -24.5625 ]
[.2619 .11473 7.03125 0 ]
[.5 .11473 -7.03125 -24.5625 ]
[.5 .11473 7.03125 0 ]
[.7381 .11473 -7.03125 -24.5625 ]
[.7381 .11473 7.03125 0 ]
[.97619 .11473 -7.03125 -24.5625 ]
[.97619 .11473 7.03125 0 ]
[.01131 .00579 -29.125 -12.2813 ]
[.01131 .00579 0 12.2813 ]
[.01131 .24868 -29.125 -12.2813 ]
[.01131 .24868 0 12.2813 ]
[.01131 .37012 -29.125 -12.2813 ]
[.01131 .37012 0 12.2813 ]
[.01131 .49156 -29.125 -12.2813 ]
[.01131 .49156 0 12.2813 ]
[.01131 .61301 -29.125 -12.2813 ]
[.01131 .61301 0 12.2813 ]
[.5 .63053 -110.219 0 ]
[.5 .63053 110.219 24.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .12723 m
.2619 .13348 L
s
gsave
.2619 .11473 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .12723 m
.5 .13348 L
s
gsave
.5 .11473 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 .12723 m
.7381 .13348 L
s
gsave
.7381 .11473 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 .12723 m
.97619 .13348 L
s
gsave
.97619 .11473 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .12723 m
.07143 .13098 L
s
.11905 .12723 m
.11905 .13098 L
s
.16667 .12723 m
.16667 .13098 L
s
.21429 .12723 m
.21429 .13098 L
s
.30952 .12723 m
.30952 .13098 L
s
.35714 .12723 m
.35714 .13098 L
s
.40476 .12723 m
.40476 .13098 L
s
.45238 .12723 m
.45238 .13098 L
s
.54762 .12723 m
.54762 .13098 L
s
.59524 .12723 m
.59524 .13098 L
s
.64286 .12723 m
.64286 .13098 L
s
.69048 .12723 m
.69048 .13098 L
s
.78571 .12723 m
.78571 .13098 L
s
.83333 .12723 m
.83333 .13098 L
s
.88095 .12723 m
.88095 .13098 L
s
.92857 .12723 m
.92857 .13098 L
s
.25 Mabswid
0 .12723 m
1 .12723 L
s
.02381 .00579 m
.03006 .00579 L
s
gsave
.01131 .00579 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.02381 .24868 m
.03006 .24868 L
s
gsave
.01131 .24868 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.02381 .37012 m
.03006 .37012 L
s
gsave
.01131 .37012 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.02381 .49156 m
.03006 .49156 L
s
gsave
.01131 .49156 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
1.000 setlinewidth
grestore
.02381 .61301 m
.03006 .61301 L
s
gsave
.01131 .61301 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .03615 m
.02756 .03615 L
s
.02381 .06651 m
.02756 .06651 L
s
.02381 .09687 m
.02756 .09687 L
s
.02381 .15759 m
.02756 .15759 L
s
.02381 .18795 m
.02756 .18795 L
s
.02381 .21831 m
.02756 .21831 L
s
.02381 .27904 m
.02756 .27904 L
s
.02381 .3094 m
.02756 .3094 L
s
.02381 .33976 m
.02756 .33976 L
s
.02381 .40048 m
.02756 .40048 L
s
.02381 .43084 m
.02756 .43084 L
s
.02381 .4612 m
.02756 .4612 L
s
.02381 .52192 m
.02756 .52192 L
s
.02381 .55228 m
.02756 .55228 L
s
.02381 .58265 m
.02756 .58265 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -171.219 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Growth) show
129.313 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
147.250 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(unstable) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
219.000 23.000 moveto
(H) show
225.438 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
234.938 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
247.875 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
273.000 23.000 moveto
(L) show
279.438 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.1 g
.001 w
.02381 .01472 m
.2619 .21456 L
.5 .2338 L
.7381 .23617 L
.97619 .23658 L
s
0 g
.0001 w
.02381 .01472 -1.875 0 Mabsadd m
.02381 .01472 0 2.5 Mabsadd L
.02381 .01472 1.875 0 Mabsadd L
.02381 .01472 0 -2.5 Mabsadd L
.02381 .01472 -1.875 0 Mabsadd L closepath F
.2619 .21456 -1.875 0 Mabsadd m
.2619 .21456 0 2.5 Mabsadd L
.2619 .21456 1.875 0 Mabsadd L
.2619 .21456 0 -2.5 Mabsadd L
.2619 .21456 -1.875 0 Mabsadd L closepath F
.5 .2338 -1.875 0 Mabsadd m
.5 .2338 0 2.5 Mabsadd L
.5 .2338 1.875 0 Mabsadd L
.5 .2338 0 -2.5 Mabsadd L
.5 .2338 -1.875 0 Mabsadd L closepath F
.7381 .23617 -1.875 0 Mabsadd m
.7381 .23617 0 2.5 Mabsadd L
.7381 .23617 1.875 0 Mabsadd L
.7381 .23617 0 -2.5 Mabsadd L
.7381 .23617 -1.875 0 Mabsadd L closepath F
.97619 .23658 -1.875 0 Mabsadd m
.97619 .23658 0 2.5 Mabsadd L
.97619 .23658 1.875 0 Mabsadd L
.97619 .23658 0 -2.5 Mabsadd L
.97619 .23658 -1.875 0 Mabsadd L closepath F
.001 w
[ .02 .02 ] 0 setdash
.02381 .26072 m
.2619 .32249 L
.5 .40116 L
.7381 .4954 L
.97619 .60332 L
s
.0001 w
[ ] 0 setdash
.02381 .26072 0 2.5 Mabsadd m
.02381 .26072 -0.56518 .7779 Mabsadd L
.02381 .26072 -2.37764 .77254 Mabsadd L
.02381 .26072 -0.91448 -0.29713 Mabsadd L
.02381 .26072 -1.46946 -2.02254 Mabsadd L
.02381 .26072 0 -0.96154 Mabsadd L
.02381 .26072 1.46946 -2.02254 Mabsadd L
.02381 .26072 .91448 -0.29713 Mabsadd L
.02381 .26072 2.37764 .77254 Mabsadd L
.02381 .26072 .56518 .7779 Mabsadd L
.02381 .26072 0 2.5 Mabsadd L closepath F
.2619 .32249 0 2.5 Mabsadd m
.2619 .32249 -0.56518 .7779 Mabsadd L
.2619 .32249 -2.37764 .77254 Mabsadd L
.2619 .32249 -0.91448 -0.29713 Mabsadd L
.2619 .32249 -1.46946 -2.02254 Mabsadd L
.2619 .32249 0 -0.96154 Mabsadd L
.2619 .32249 1.46946 -2.02254 Mabsadd L
.2619 .32249 .91448 -0.29713 Mabsadd L
.2619 .32249 2.37764 .77254 Mabsadd L
.2619 .32249 .56518 .7779 Mabsadd L
.2619 .32249 0 2.5 Mabsadd L closepath F
.5 .40116 0 2.5 Mabsadd m
.5 .40116 -0.56518 .7779 Mabsadd L
.5 .40116 -2.37764 .77254 Mabsadd L
.5 .40116 -0.91448 -0.29713 Mabsadd L
.5 .40116 -1.46946 -2.02254 Mabsadd L
.5 .40116 0 -0.96154 Mabsadd L
.5 .40116 1.46946 -2.02254 Mabsadd L
.5 .40116 .91448 -0.29713 Mabsadd L
.5 .40116 2.37764 .77254 Mabsadd L
.5 .40116 .56518 .7779 Mabsadd L
.5 .40116 0 2.5 Mabsadd L closepath F
.7381 .4954 0 2.5 Mabsadd m
.7381 .4954 -0.56518 .7779 Mabsadd L
.7381 .4954 -2.37764 .77254 Mabsadd L
.7381 .4954 -0.91448 -0.29713 Mabsadd L
.7381 .4954 -1.46946 -2.02254 Mabsadd L
.7381 .4954 0 -0.96154 Mabsadd L
.7381 .4954 1.46946 -2.02254 Mabsadd L
.7381 .4954 .91448 -0.29713 Mabsadd L
.7381 .4954 2.37764 .77254 Mabsadd L
.7381 .4954 .56518 .7779 Mabsadd L
.7381 .4954 0 2.5 Mabsadd L closepath F
.97619 .60332 0 2.5 Mabsadd m
.97619 .60332 -0.56518 .7779 Mabsadd L
.97619 .60332 -2.37764 .77254 Mabsadd L
.97619 .60332 -0.91448 -0.29713 Mabsadd L
.97619 .60332 -1.46946 -2.02254 Mabsadd L
.97619 .60332 0 -0.96154 Mabsadd L
.97619 .60332 1.46946 -2.02254 Mabsadd L
.97619 .60332 .91448 -0.29713 Mabsadd L
.97619 .60332 2.37764 .77254 Mabsadd L
.97619 .60332 .56518 .7779 Mabsadd L
.97619 .60332 0 2.5 Mabsadd L closepath F
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`005Woo100017oo0P001Goo1000mgoo000E
Ool20002Ool20003Ool20004Ool20002Ool2003fOol001Eoo`03001oogoo009oo`03001oogoo00Io
o`8000Aoo`800?Eoo`0057oo0P0017oo0P001goo0P0017oo0P00mGoo000DOol20004Ool20007Ool2
0003Ool3003eOol001Aoo`8000Aoo`8000Qoo`800004Ool000000007Ool00`00Oomoo`3/Ool001Ao
o`8000Aoo`8000Yoo`8000Uoo`800>eoo`0057oo0P0017oo0P002Goo0P0000=oo`00Ool01Woo0`00
kGoo000DOol20004Ool20008Ool20002Ool20005Ool4003]Ool001Aoo`8000Aoo`8000Moo`8000Ao
o`8000Eoo`80000336=oogoo0>]oo`005Goo00<007ooOol00Woo00<007ooOol01Woo0P0017oo0P00
1Woo00<007oo36<0k7oo000EOol20002Ool20009Ool20003Ool00`00Oomoo`05Ool00`00Oomoo`02
36?ZOol001Ioo`@000]oo`@000Qoo`03001oogoo009oo`0336=oogoo02Uoo`L002ioo`D003Eoo`80
02moo`D001Uoo`00<Goo0P0017oo00<<HgooOol0:Goo1`00;Goo0P000Woo0P00=7oo0P00;goo0P00
0goo00<007ooOol05Woo000aOol00`00Oomoo`04Ool00`aSOomoo`0XOol00`00Oomoo`03Ool00`00
Oomoo`0`Ool2000cOol2000dOol00`00Oomoo`0FOol0035oo`03001oogoo00Eoo`0336=oogoo02Qo
o`03001oogoo03Eoo`8002ioo`T003=oo`03001oogoo01Eoo`00<Goo00<007ooOol01Woo0PaS:Goo
00<007ooOol0=7oo0P00;Woo00<007ooOol00Woo0P00=Goo00<007ooOol05Goo000aOol00`00Oomo
o`08Ool00`aSOomoo`0WOol00`00Oomoo`0bOol3000_Ool01000Oomoogoo0P00=7oo0P005goo000a
Ool00`00Oomoo`09Ool00`aSOomoo`0VOol2000aOol4000`Ool01000Oomoogoo0P00=7oo0P005goo
000aOol2000;Ool00`aSOomoo`0VOol00`00Oomoo`0`Ool2000bOol00`00Oomoo`02000bOol3000H
Ool0035oo`03001oogoo00]oo`0336=oogoo02Eoo`8003=oo`03001oogoo031oo`04001oo`00000`
Ool5000HOol0035oo`03001oogoo00aoo`0336=oogoo01moo`03001oogoo009oo`8003=oo`80035o
o`04001oo`00000`Ool3000JOol0035oo`03001oogoo00eoo`8<Hamoo`04001oogooOol3000^Ool0
0`00Oomoo`02Ool2000bOol3000aOol00`00Oomoo`0IOol0035oo`03001oogoo00moo`0336=oogoo
01eoo`H002ioo`8000=oo`8003=oo`80035oo`D001Moo`00<Goo00<007ooOol047oo00<<HgooOol0
7Goo0`00<Woo1000=7oo0P00<Goo1@005goo000aOol00`00Oomoo`0AOol00`aSOomoo`3HOol0035o
o`8001=oo`0336=oogoo0=Moo`00<Goo00<007ooOol04goo00<<HgooOol0eWoo000aOol00`00Oomo
o`0DOol236?FOol0035oo`03001oogoo01Ioo`0336=oogoo0==oo`00<Goo00<007ooOol05goo00<<
HgooOol0dWoo000aOol00`00Oomoo`0HOol00`aSOomoo`3AOol0035oo`03001oogoo01Uoo`0336=o
ogoo0=1oo`00:goo8`000PaS_@004goo000aOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`aS001oo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0GOol0035oo`03001oogoo01eoo`03
36=oogoo0<aoo`00<Goo00<007ooOol07Woo00<<HgooOol0bgoo000aOol00`00Oomoo`0OOol00`aS
Oomoo`3:Ool0035oo`03001oogoo021oo`0336=oogoo0<Uoo`00<Goo00<007ooOol08Goo0PaSbGoo
000aOol2000TOol00`aSOomoo`36Ool0035oo`03001oogoo02Aoo`0336=oogoo0<Eoo`00<Goo00<0
07ooOol09Goo00<<HgooOol0a7oo000aOol00`00Oomoo`0VOol00`aSOomoo`33Ool0035oo`03001o
ogoo02Moo`0336=oogoo0<9oo`00<Goo00<007ooOol0:7oo0PaS`Woo000aOol00`00Oomoo`0ZOol0
0`aSOomoo`2oOol0035oo`8002aoo`0336=oogoo0;ioo`00<Goo00<007ooOol0;7oo00<<HgooOol0
_Goo000aOol00`00Oomoo`0]Ool00`aSOomoo`2lOol0035oo`03001oogoo02ioo`8<Hkaoo`00<Goo
00<007ooOol0<7oo00<<Hgoo0000^Goo000aOol00`00Oomoo`0aOol3002hOol0035oo`80035oo`@0
00D<Hk=oo`00<Goo00<007ooOol0<Goo0P001Woo3@aSYWoo000EOol60003Ool20003Ool70007Ool0
0`00Oomoo`16Ool>36<COol00`00Oomoo`22Ool001Moo`8000Eoo`8000Aoo`L000Ioo`03001oogoo
05Aoo`d<H`Ioo`8003Aoo`03001oogoo039oo`03001oogoo01Moo`005goo0P002goo00<007ooOol0
0goo00<007ooOol017oo00<007ooOol0HGoo1@aS0`006@aS6Woo0`00<Woo0`0067oo000GOol2000<
Ool00`00Oomoo`09Ool00`00Oomoo`1WOol00`00Oomoo`0HOolI36<4000a36<4000HOol001Moo`80
00eoo`03001oogoo00Qoo`03001oogoo09aoo`8003=oo`8001Uoo`005goo0P003Woo00<007ooOol0
1goo0P00kGoo000GOol2000>Ool20008Ool00`00Oomoo`3/Ool001Moo`8000moo`03001oogoo00Eo
o`800>ioo`005goo0P003goo0P001Woo0`00kGoo000GOol2000:Ool00`00Oomoo`02Ool20004Ool8
003ZOol001Moo`8000Yoo`04001oogooOol30007Ool00`00Oomoo`05Ool3003TOol001Eoo`@000]o
o`H000Moo`03001oogoo00Qoo`<00>5oo`005goo0P0037oo0`002Goo0P00kGoo000aOol00`00Oomo
o`0>Ool2003LOol0035oo`03001oogoo011oo`<00=Uoo`00<Goo00<007ooOol05goo0P00dgoo000a
Ool00`00Oomoo`0IOol3003@Ool0035oo`03001oogoo01moo`<00<Yoo`00<Goo00<007ooOol08Woo
0`00agoo000aOol2000YOol20032Ool0035oo`03001oogoo02Yoo`<00;moo`00<Goo00<007ooOol0
<Goo0`00^7oo000aOol00`00Oomoo`0aOol3002hOol0035oo`03001oogoo031oo`H00;Ioo`00<Goo
00<007ooOol0>Goo0P00/Goo000aOol00`00Oomoo`0kOol2002_Ool0035oo`8003ioo`800:eoo`00
5Goo1P000goo0P001goo0P0027oo00<007ooOol0@Woo00<007ooOol0Ygoo000GOol20005Ool20007
Ool20008Ool00`00Oomoo`13Ool2002WOol001Moo`8000ioo`8000Qoo`03001oogoo04Eoo`800:Eo
o`005goo0P002Goo2@001Woo00<007ooOol0BWoo0`00Wgoo000GOol20009Ool00`00Oomoo`02Ool2
0008Ool00`00Oomoo`1=Ool3002LOol001Moo`8000Yoo`04001oogooOol20008Ool00`00Oomoo`3/
Ool001Moo`8000Yoo`04001oogooOol20008Ool2001DOol2002GOol001Moo`8000]oo`03001oogoo
008000Qoo`03001oogoo05Eoo`<009Aoo`005goo0P0037oo00@007oo000000Qoo`03001oogoo0>ao
o`005goo0P0037oo00@007oo000000Qoo`03001oogoo05]oo`<008ioo`005goo0P003Goo0`0027oo
00<007ooOol0GWoo0`00Rgoo000EOol4000>Ool20008Ool00`00Oomoo`1TOol01@00Oomoogoo0000
Pgoo000GOol2000>Ool20008Ool2001VOol30024Ool0035oo`03001oogoo06Eoo`D0089oo`00<Goo
00<007ooOol0Igoo00<007ooOol00Woo00<007ooOol0OGoo000aOol00`00Oomoo`1]Ool2001mOol0
035oo`03001oogoo06moo`8007]oo`00<Goo00<007ooOol0k7oo000aOol00`00Oomoo`1eOol2001e
Ool0035oo`8007Qoo`<0079oo`00<Goo00<007ooOol0k7oo000aOol00`00Oomoo`1mOol00`00Oomo
o`1/Ool0035oo`03001oogoo07ioo`8006aoo`00<Goo00<007ooOol0P7oo0P00JWoo000aOol00`00
Oomoo`25Ool00`00Oomoo`1TOol0035oo`03001oogoo08Ioo`8006Aoo`00<Goo0P00RGoo0P00HWoo
000EOol60003Ool20005Ool40008Ool00`00Oomoo`3/Ool001Moo`8000Eoo`8000Aoo`80009oo`80
00Moo`03001oogoo08ioo`8005aoo`005goo0P002goo00<007ooOol00Woo0P001Woo00<007ooOol0
T7oo0`00FGoo000GOol2000:Ool20004Ool20006Ool00`00Oomoo`3/Ool001Moo`8000Yoo`8000Ao
o`8000Ioo`03001oogoo09Ioo`03001oogoo05=oo`005goo0P002Woo0P0017oo0P001Woo00<007oo
Ool0Ugoo0P00Dgoo000GOol2000:Ool30002Ool20007Ool2002JOol200000goo0000001>Ool001Mo
o`8000Yoo`800004Ool000000008Ool00`00Oomoo`2JOol5001=Ool001Moo`8000]oo`8000]oo`03
001oogoo09moo`8004]oo`005goo0P002goo0P002goo00<007ooOol0XGoo0P00BGoo000GOol2000<
Ool2000:Ool00`00Oomoo`3/Ool001Eoo`@000eoo`<000Qoo`03001oogoo0:Ioo`8004Aoo`005goo
0P003goo0`001Woo00<007ooOol0Z7oo0P00@Woo000aOol2002[Ool20010Ool0035oo`03001oogoo
0>aoo`00<Goo00<007ooOol0[goo00<007ooOol0>Woo000aOol00`00Oomoo`2`Ool2000jOol0035o
o`03001oogoo0;9oo`8003Qoo`00<Goo00<007ooOol0]goo00<007ooOol0<Woo000aOol2002iOol2
000bOol0035oo`03001oogoo0;Yoo`80031oo`00<Goo00<007ooOol0k7oo000aOol00`00Oomoo`2o
Ool00`00Oomoo`0ZOol0035oo`03001oogoo0<1oo`8002Yoo`00<Goo00<007ooOol0`Woo0P00:7oo
000aOol00`00Oomoo`3/Ool0035oo`800<Qoo`03001oogoo029oo`005Goo1P000goo0P001Goo1000
27oo00<007ooOol0b7oo0P008Woo000GOol20005Ool20004Ool20002Ool20007Ool00`00Oomoo`3:
Ool2000POol001Moo`8000Yoo`8000Aoo`8000Ioo`03001oogoo0>aoo`005goo0P002Woo0P0017oo
0P001Woo00<007ooOol0cgoo1@0067oo000GOol2000:Ool20003Ool30006Ool00`00Oomoo`3AOol2
000IOol001Moo`8000]oo`800004Ool000000007Ool00`00Oomoo`3@Ool5000GOol001Moo`8000eo
o`8000Uoo`800>eoo`005goo0P0037oo0P0000=oo`00Ool01goo00<007ooOol0k7oo000GOol2000;
Ool20002Ool2003fOol001Moo`8000Yoo`8000Aoo`800?Eoo`005goo0P002Woo0P0017oo0P00mGoo
000EOol4000;Ool20003Ool00`00Oomoo`3dOol001Moo`8000aoo`@00:Moo`03001oogoo02ioo`03
001oogoo01aoo`00cgoo00<007ooOol0<7oo00<007ooOol06goo003>Ool00`00Oomoo`0bOol00`00
Oomoo`0JOol00<eoo`8003Aoo`8001]oo`00=7oo1`000Woo10001Woo10001goo00<007ooOol00goo
00<007ooOol00goo0`0000=oo`0000000P0000=oo`0000000P006goo0`0000Aoo`00001oo`@00003
Ool0000000800003Ool007oo00<000=oo`<000=oo`<00004Ool000000002Ool50004Ool40004Ool3
000;Ool20006Ool3000COol40004Ool20003Ool50006Ool2000KOol0039oo`<000Eoo`80009oo`80
00Ioo`80009oo`8000Eoo`8000Aoo`8000Eoo`800003Ool007oo008000=oo`8001]oo`80009oo`@0
0003Ool0000000=oo`80009oo`8000=oo`03001oogoo00800003Ool007oo0080009oo`<00004Ool0
00000003Ool20004Ool20004Ool50009Ool20007Ool3000BOol20002Ool20003Ool20003Ool20003
Ool00`00Oomoo`04Ool2000JOol0035oo`<000Ioo`80009oo`8000Eoo`8000Aoo`8000Aoo`<000=o
o`<000Aoo`8000=oo`8000=oo`8001]oo`8000=oo`80009oo`8000=oo`80009oo`03001oogoo009o
o`03001oogoo008000=oo`8000=oo`80009oo`8000Aoo`8000=oo`8000=oo`<000=oo`03001oogoo
00Ioo`8000Moo`8001=oo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Aoo`8001Yoo`00
<Goo0P001goo0P000Woo0P001Goo0P0017oo0P000goo0P0000=oo`00Ool00Woo00<007oo000017oo
0P000goo0P000goo0P006goo0P000goo0P000Woo0P000goo0P001Goo0`000Woo0P000goo0P000goo
0P000Woo0P0017oo0P000goo0P000goo0P003Goo0P001goo0P001Goo2`000Woo0P0017oo0P003Goo
00<007ooOol00goo0P006Woo000`Ool20008Ool20002Ool20005Ool20004Ool20003Ool20002Ool0
1000Ool000000Woo00@007ooOomoo`8000=oo`8000=oo`8001]oo`8000=oo`80009oo`8000=oo`80
00=oo`@000=oo`8000Aoo`<00003Ool00000009oo`8000Aoo`8000=oo`8000=oo`8000eoo`8000Mo
o`80019oo`8000Aoo`8000eoo`03001oogoo00=oo`8001Yoo`00<7oo0P0027oo0P000Woo0P001Goo
0P0017oo0P000goo0P000Woo00@007oo0000009oo`04001oogooOol20003Ool20003Ool20009Ool;
0007Ool20003Ool20002Ool20003Ool20002Ool30005Ool20007Ool30002Ool20004Ool20003Ool2
0003Ool70008Ool20007Ool2000BOol20004Ool2000<Ool20005Ool2000JOol0031oo`8000Ioo`D0
0003Ool0000000Eoo`8000Aoo`80009oo`8000Aoo`8000=oo`04001oogooOol20003Ool20003Ool2
000KOol20003Ool20002Ool20003Ool20002Ool00`00Oomoo`02Ool00`00Oomoo`020003Ool20003
Ool20002Ool20004Ool20003Ool20003Ool20003Ool20008Ool20008Ool2000AOol20004Ool2000<
Ool20005Ool2000JOol0031oo`8000]oo`@00003Ool00000009oo`80009oo`8000=oo`8000Aoo`80
00Aoo`03001oogoo008000=oo`<0009oo`8001]oo`8000=oo`800003Ool000000080009oo`80009o
o`04001oogooOol20002Ool20003Ool20003Ool20002Ool30002Ool20004Ool20004Ool20002Ool0
0`00Oomoo`07Ool20004Ool20002Ool20004Ool;0002Ool20004Ool2000:Ool30006Ool2000JOol0
031oo`8000aoo`800004Ool000000003Ool40003Ool40002Ool40002Ool8000017oo000007oo0`00
6goo0`000Woo0`000Woo0P0000Aoo`00000000Aoo`<00003Ool007oo00D0009oo`D000=oo`800004
Ool000000005Ool20005Ool3000:Ool20006Ool7000>Ool20004Ool20008Ool50006Ool2000JOol0
035oo`8000Qoo`03001oogoo021oo`8000=oo`8003Yoo`8000aoo`8000Uoo`8001=oo`8001Yoo`80
00Aoo`8000Qoo`<000Moo`8001]oo`00<Woo00<007ooOol01Goo0P008goo00@007ooOomoo`8003]o
o`03001oogoo00Yoo`8000Uoo`8001=oo`8001]oo`03001oogoo009oo`03001oogoo00Qoo`03001o
ogoo00Ioo`8001]oo`00<Woo0`0017oo0`008goo00@007ooOomoo`8003]oo`03001oogoo00Yoo`80
00Uoo`8001Aoo`03001oogoo01Uoo`80009oo`8000Yoo`D000Aoo`03001oogoo01Yoo`00=7oo1@00
0Woo00<007ooOol097oo0`00Agoo0`0027oo0`005Goo00<007ooOol06Goo10002goo1@000goo00<0
07ooOol06goo001SOol20018Ool20009Ool2000FOol00`00Oomoo`0^Ool00`00Oomoo`0LOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {0.0791112, 0.709804, \
0.0187299, 0.00734413}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gini2 = 
      MultipleListPlot[Array[gini, 5], Array[agini, 5], 
        PlotJoined \[Rule] True, 
        PlotStyle \[Rule] {GrayLevel[ .1], Dashing[{0.02, 0.02}]}, 
        PlotLabel -> "\<Gini\>", AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 0.0238095 1.21473 [
[.2619 .01131 -7.03125 -24.5625 ]
[.2619 .01131 7.03125 0 ]
[.5 .01131 -7.03125 -24.5625 ]
[.5 .01131 7.03125 0 ]
[.7381 .01131 -7.03125 -24.5625 ]
[.7381 .01131 7.03125 0 ]
[.97619 .01131 -7.03125 -24.5625 ]
[.97619 .01131 7.03125 0 ]
[.01131 .26676 -29.125 -12.2813 ]
[.01131 .26676 0 12.2813 ]
[.01131 .5097 -29.125 -12.2813 ]
[.01131 .5097 0 12.2813 ]
[.01131 .75265 -29.125 -12.2813 ]
[.01131 .75265 0 12.2813 ]
[.01131 .9956 -29.125 -12.2813 ]
[.01131 .9956 0 12.2813 ]
[.5 1.0125 -19.7813 0 ]
[.5 1.0125 19.7813 24.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .02381 m
.2619 .03006 L
s
gsave
.2619 .01131 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .02381 m
.5 .03006 L
s
gsave
.5 .01131 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 .02381 m
.7381 .03006 L
s
gsave
.7381 .01131 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 .02381 m
.97619 .03006 L
s
gsave
.97619 .01131 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .02381 m
.07143 .02756 L
s
.11905 .02381 m
.11905 .02756 L
s
.16667 .02381 m
.16667 .02756 L
s
.21429 .02381 m
.21429 .02756 L
s
.30952 .02381 m
.30952 .02756 L
s
.35714 .02381 m
.35714 .02756 L
s
.40476 .02381 m
.40476 .02756 L
s
.45238 .02381 m
.45238 .02756 L
s
.54762 .02381 m
.54762 .02756 L
s
.59524 .02381 m
.59524 .02756 L
s
.64286 .02381 m
.64286 .02756 L
s
.69048 .02381 m
.69048 .02756 L
s
.78571 .02381 m
.78571 .02756 L
s
.83333 .02381 m
.83333 .02756 L
s
.88095 .02381 m
.88095 .02756 L
s
.92857 .02381 m
.92857 .02756 L
s
.25 Mabswid
0 .02381 m
1 .02381 L
s
.02381 .26676 m
.03006 .26676 L
s
gsave
.01131 .26676 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .5097 m
.03006 .5097 L
s
gsave
.01131 .5097 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .75265 m
.03006 .75265 L
s
gsave
.01131 .75265 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .9956 m
.03006 .9956 L
s
gsave
.01131 .9956 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .08455 m
.02756 .08455 L
s
.02381 .14528 m
.02756 .14528 L
s
.02381 .20602 m
.02756 .20602 L
s
.02381 .32749 m
.02756 .32749 L
s
.02381 .38823 m
.02756 .38823 L
s
.02381 .44897 m
.02756 .44897 L
s
.02381 .57044 m
.02756 .57044 L
s
.02381 .63118 m
.02756 .63118 L
s
.02381 .69191 m
.02756 .69191 L
s
.02381 .81339 m
.02756 .81339 L
s
.02381 .87412 m
.02756 .87412 L
s
.02381 .93486 m
.02756 .93486 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
gsave
.5 1.0125 -80.7813 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Gini) show
98.563 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.001 w
.02381 .77227 m
.2619 .15655 L
.5 .05603 L
.7381 .03522 L
.97619 .02866 L
s
0 g
.0001 w
.02381 .77227 -1.875 0 Mabsadd m
.02381 .77227 0 2.5 Mabsadd L
.02381 .77227 1.875 0 Mabsadd L
.02381 .77227 0 -2.5 Mabsadd L
.02381 .77227 -1.875 0 Mabsadd L closepath F
.2619 .15655 -1.875 0 Mabsadd m
.2619 .15655 0 2.5 Mabsadd L
.2619 .15655 1.875 0 Mabsadd L
.2619 .15655 0 -2.5 Mabsadd L
.2619 .15655 -1.875 0 Mabsadd L closepath F
.5 .05603 -1.875 0 Mabsadd m
.5 .05603 0 2.5 Mabsadd L
.5 .05603 1.875 0 Mabsadd L
.5 .05603 0 -2.5 Mabsadd L
.5 .05603 -1.875 0 Mabsadd L closepath F
.7381 .03522 -1.875 0 Mabsadd m
.7381 .03522 0 2.5 Mabsadd L
.7381 .03522 1.875 0 Mabsadd L
.7381 .03522 0 -2.5 Mabsadd L
.7381 .03522 -1.875 0 Mabsadd L closepath F
.97619 .02866 -1.875 0 Mabsadd m
.97619 .02866 0 2.5 Mabsadd L
.97619 .02866 1.875 0 Mabsadd L
.97619 .02866 0 -2.5 Mabsadd L
.97619 .02866 -1.875 0 Mabsadd L closepath F
.001 w
[ .02 .02 ] 0 setdash
.02381 .77227 m
.2619 .81809 L
.5 .86986 L
.7381 .92409 L
.97619 .97619 L
s
.0001 w
[ ] 0 setdash
.02381 .77227 0 2.5 Mabsadd m
.02381 .77227 -0.56518 .7779 Mabsadd L
.02381 .77227 -2.37764 .77254 Mabsadd L
.02381 .77227 -0.91448 -0.29713 Mabsadd L
.02381 .77227 -1.46946 -2.02254 Mabsadd L
.02381 .77227 0 -0.96154 Mabsadd L
.02381 .77227 1.46946 -2.02254 Mabsadd L
.02381 .77227 .91448 -0.29713 Mabsadd L
.02381 .77227 2.37764 .77254 Mabsadd L
.02381 .77227 .56518 .7779 Mabsadd L
.02381 .77227 0 2.5 Mabsadd L closepath F
.2619 .81809 0 2.5 Mabsadd m
.2619 .81809 -0.56518 .7779 Mabsadd L
.2619 .81809 -2.37764 .77254 Mabsadd L
.2619 .81809 -0.91448 -0.29713 Mabsadd L
.2619 .81809 -1.46946 -2.02254 Mabsadd L
.2619 .81809 0 -0.96154 Mabsadd L
.2619 .81809 1.46946 -2.02254 Mabsadd L
.2619 .81809 .91448 -0.29713 Mabsadd L
.2619 .81809 2.37764 .77254 Mabsadd L
.2619 .81809 .56518 .7779 Mabsadd L
.2619 .81809 0 2.5 Mabsadd L closepath F
.5 .86986 0 2.5 Mabsadd m
.5 .86986 -0.56518 .7779 Mabsadd L
.5 .86986 -2.37764 .77254 Mabsadd L
.5 .86986 -0.91448 -0.29713 Mabsadd L
.5 .86986 -1.46946 -2.02254 Mabsadd L
.5 .86986 0 -0.96154 Mabsadd L
.5 .86986 1.46946 -2.02254 Mabsadd L
.5 .86986 .91448 -0.29713 Mabsadd L
.5 .86986 2.37764 .77254 Mabsadd L
.5 .86986 .56518 .7779 Mabsadd L
.5 .86986 0 2.5 Mabsadd L closepath F
.7381 .92409 0 2.5 Mabsadd m
.7381 .92409 -0.56518 .7779 Mabsadd L
.7381 .92409 -2.37764 .77254 Mabsadd L
.7381 .92409 -0.91448 -0.29713 Mabsadd L
.7381 .92409 -1.46946 -2.02254 Mabsadd L
.7381 .92409 0 -0.96154 Mabsadd L
.7381 .92409 1.46946 -2.02254 Mabsadd L
.7381 .92409 .91448 -0.29713 Mabsadd L
.7381 .92409 2.37764 .77254 Mabsadd L
.7381 .92409 .56518 .7779 Mabsadd L
.7381 .92409 0 2.5 Mabsadd L closepath F
.97619 .97619 0 2.5 Mabsadd m
.97619 .97619 -0.56518 .7779 Mabsadd L
.97619 .97619 -2.37764 .77254 Mabsadd L
.97619 .97619 -0.91448 -0.29713 Mabsadd L
.97619 .97619 -1.46946 -2.02254 Mabsadd L
.97619 .97619 0 -0.96154 Mabsadd L
.97619 .97619 1.46946 -2.02254 Mabsadd L
.97619 .97619 .91448 -0.29713 Mabsadd L
.97619 .97619 2.37764 .77254 Mabsadd L
.97619 .97619 .56518 .7779 Mabsadd L
.97619 .97619 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001OOol7000bOol5000gOol2
000cOol5000BOol0061oo`L0035oo`80009oo`8003Ioo`8003=oo`8000=oo`03001oogoo00moo`00
H7oo00<007ooOol00goo00<007ooOol0=7oo0P00=Goo0P00>7oo00<007ooOol03goo001QOol00`00
Oomoo`0iOol2000`Ool9000gOol00`00Oomoo`0>Ool0069oo`03001oogoo03Qoo`80031oo`03001o
ogoo009oo`8003Uoo`03001oogoo00ioo`00Hgoo00<007ooOol0=Woo0`00<Goo00@007ooOomoo`80
03Qoo`80011oo`00Hgoo0P00=Goo1000<Woo00@007ooOomoo`8003Qoo`80011oo`00I7oo00<007oo
Ool0=7oo0P00=7oo00<007ooOol00P00=Woo0`004Goo001TOol2000gOol00`00Oomoo`0bOol01000
Ool00000=7oo1@004Goo001OOol00`00Oomoo`02Ool2000gOol2000cOol01000Ool00000=7oo0`00
4goo001OOol01000Oomoogoo0`00<Woo00<007ooOol00Woo0P00=7oo0`00=Goo00<007ooOol04Woo
001POol6000bOol20003Ool2000eOol2000eOol5000@Ool0065oo`<003Ioo`@003Ioo`8003Eoo`D0
011oo`00ogoo8Goo003oOolQOol002Yoo`03001oogoo0?=oo`00:Woo00<007ooOol0lgoo000ZOol0
0`00Oomoo`3cOol002Yoo`03001oogoo0?=oo`00:Woo00<007ooOol0lgoo000ZOol00`00Oomoo`3c
Ool002Eoonh000eoo`00:Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool01Woo30aS10004Goo000ZOol00`00Oomoo`0fOol00`00Oomoo`0fOol00`00Oomoo`0dOol3000=
OolL36<=Ool3000AOol002Yoo`03001oogoo0:9oo`<<H`@000d<HbYoo`03001oogoo011oo`00:Woo
00<007ooOol0Ugoo2`aS17oo0P00Bgoo000ZOol00`00Oomoo`2<Ool;36=LOol002Yoo`03001oogoo
06moo`03001oogoo00ioo``<HfMoo`00:Woo00<007ooOol0KWoo0P001Goo2`aSLgoo000ZOol00`00
Oomoo`1]Ool3000536=nOol002Yoo`03001oogoo06aoo`8<H`8008=oo`00:Woo00<007ooOol0JWoo
0PaSQgoo000ZOol00`00Oomoo`1WOol336>9Ool002Yoo`03001oogoo06Eoo`8<Hhaoo`00:Woo00<0
07ooOol0HWoo0`aSSWoo000ZOol2001QOol236>AOol002Yoo`03001oogoo05ioo`8<Hi=oo`00:Woo
00<007ooOol0Fgoo0`aSUGoo000ZOol00`00Oomoo`1IOol236>HOol002Yoo`03001oogoo05Moo`8<
HiYoo`00:Woo00<007ooOol0E7oo0`aSW7oo000ZOol00`00Oomoo`1BOol236>OOol002Yoo`03001o
ogoo04moo`<<Hj5oo`00:Woo00<007ooOol0CGoo0PaSY7oo000ZOol00`00Oomoo`1;Ool236>VOol0
02Yoo`03001oogoo04Qoo`<<HjQoo`00:Woo00<007ooOol0AWoo0PaSZgoo000ZOol00`00Oomoo`14
Ool236>]Ool002Yoo`03001oogoo045oo`<<Hjmoo`00:Woo00<007ooOol0?goo0PaS/Woo000ZOol2
000mOol336>dOol002Yoo`03001oogoo03Ioo`04001oogooOol236>gOol002Yoo`03001oogoo03Eo
o`<0008<HkUoo`00:Woo00<007ooOol0=7oo1000^goo000ZOol00`00Oomoo`0eOol2002lOol002Yo
o`03001oogoo03Eoo`0336=oogoo0;]oo`00:Woo00<007ooOol0=Goo00<<HgooOol0^goo000ZOol0
0`00Oomoo`0dOol00`aSOomoo`2lOol002Yoo`03001oogoo03Aoo`0336=oogoo0;aoo`00:Woo00<0
07ooOol0=7oo00<<HgooOol0_7oo000ZOol00`00Oomoo`0cOol00`aSOomoo`2mOol002Yoo`03001o
ogoo03=oo`0336=oogoo0;eoo`00:Woo00<007ooOol0<Woo00<<HgooOol0_Woo000ZOol00`00Oomo
o`0bOol00`aSOomoo`2nOol002Yoo`8003=oo`0336=oogoo0;ioo`00:Woo00<007ooOol0<Goo00<<
HgooOol0_goo000ZOol00`00Oomoo`0aOol00`aSOomoo`2oOol002Yoo`03001oogoo035oo`0336=o
ogoo0;moo`00:Woo00<007ooOol0<7oo00<<HgooOol0`7oo000ZOol00`00Oomoo`0`Ool00`aSOomo
o`30Ool002Yoo`03001oogoo02moo`0336=oogoo0<5oo`00:Woo00<007ooOol0;goo00<<HgooOol0
`Goo000ZOol00`00Oomoo`0_Ool00`aSOomoo`31Ool000moo`@000Aoo`8000=oo`L000Moo`03001o
ogoo02ioo`0336=oogoo0<9oo`003Woo0P000Woo0P000goo0P0017oo1`001Woo00<007ooOol0;Woo
00<<HgooOol0`Woo000>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`0]Ool00`aSOomoo`33Ool000eoo`8000Aoo`8000Uoo`03001oogoo00Uoo`03
001oogoo02eoo`0336=oogoo0<=oo`003Goo0P0017oo0P002Woo00<007ooOol027oo00<007ooOol0
;Goo00<<HgooOol0`goo000=Ool20004Ool2000;Ool00`00Oomoo`07Ool00`00Oomoo`0/Ool00`aS
Oomoo`34Ool000eoo`8000Aoo`8000]oo`8000Qoo`<002aoo`0336=oogoo0<Aoo`003Goo0P0017oo
0P0037oo00<007ooOol01Woo00<007ooOol0:goo00<<HgooOol0aGoo000=Ool20004Ool2000<Ool2
0007Ool00`00Oomoo`0[Ool00`aSOomoo`35Ool000eoo`8000Aoo`8000Moo`03001oogoo009oo`80
00Moo`03001oogoo02]oo`0336=oogoo0<Eoo`003Woo00<007ooOol00Woo00<007ooOol01Woo00@0
07ooOomoo`<000Moo`03001oogoo02Yoo`0336=oogoo0<Ioo`003Woo0P000Woo0P002Goo1P001goo
00<007ooOol0:Woo00<<HgooOol0aWoo000?Ool4000;Ool30009Ool00`00Oomoo`0ZOol00`aSOomo
o`36Ool002Yoo`03001oogoo02Uoo`0336=oogoo0<Moo`00:Woo00<007ooOol0:Goo00<<HgooOol0
agoo000ZOol00`00Oomoo`0XOol00`aSOomoo`38Ool002Yoo`03001oogoo02Qoo`0336=oogoo0<Qo
o`00:Woo00<007ooOol0:7oo00<<HgooOol0b7oo000ZOol00`00Oomoo`0WOol00`aSOomoo`39Ool0
02Yoo`03001oogoo02Moo`0336=oogoo0<Uoo`00:Woo0P009goo00<<HgooOol0bWoo000ZOol00`00
Oomoo`0VOol00`aSOomoo`3:Ool002Yoo`03001oogoo02Ioo`0336=oogoo0<Yoo`00:Woo00<007oo
Ool09Goo00<<HgooOol0bgoo000ZOol00`00Oomoo`0UOol00`aSOomoo`3;Ool002Yoo`03001oogoo
02Aoo`0336=oogoo0<aoo`00:Woo00<007ooOol097oo00<<HgooOol0c7oo000ZOol00`00Oomoo`0T
Ool00`aSOomoo`3<Ool002Yoo`03001oogoo02=oo`0336=oogoo0<eoo`00:Woo00<007ooOol08goo
00<<HgooOol0cGoo000ZOol00`00Oomoo`0ROol00`aSOomoo`3>Ool002Yoo`03001oogoo029oo`03
36=oogoo0<ioo`00:Woo00<007ooOol08Woo00<<HgooOol0cWoo000ZOol00`00Oomoo`0QOol00`aS
Oomoo`3?Ool002Yoo`03001oogoo025oo`0336=oogoo0<moo`00:Woo0P008Woo00<<HgooOol0cgoo
000ZOol00`00Oomoo`0POol00`aSOomoo`3@Ool002Yoo`03001oogoo021oo`0336=oogoo0=1oo`00
:Woo00<007ooOol07goo00<<HgooOol0dGoo000ZOol00`00Oomoo`0OOol00`aSOomoo`3AOol002Yo
o`03001oogoo01moo`0336=oogoo0=5oo`00:Woo00<007ooOol07Woo00<<HgooOol0dWoo000ZOol0
0`00Oomoo`0NOol00`aSOomoo`3BOol002Yoo`03001oogoo01eoo`0336=oogoo0==oo`00:Woo00<0
07ooOol07Goo00<<HgooOol0dgoo000ZOol00`00Oomoo`0MOol00`aSOomoo`3COol002Yoo`03001o
ogoo01aoo`0336=oogoo0=Aoo`00:Woo00<007ooOol077oo00<<HgooOol0e7oo000ZOol00`00Oomo
o`0KOol00`aSOomoo`3EOol002Yoo`8001aoo`0336=oogoo0=Eoo`00:Woo00<007ooOol06goo00<<
HgooOol0eGoo000ZOol00`00Oomoo`0JOol00`aSOomoo`3FOol002Yoo`03001oogoo01Yoo`0336=o
ogoo0=Ioo`00:Woo00<007ooOol06Goo00<<HgooOol0egoo000ZOol00`00Oomoo`0IOol00`aSOomo
o`3GOol002Yoo`03001oogoo01Uoo`0336=oogoo0=Moo`00:Woo00<007ooOol067oo00<<HgooOol0
f7oo000ZOol00`00Oomoo`0HOol00`aSOomoo`3HOol000moo`@000Aoo`8000Moo`8000Qoo`03001o
ogoo01Qoo`0336=oogoo0=Qoo`003Woo0P000Woo0P000goo0P001goo0P0027oo00<007ooOol05goo
00<<HgooOol0fGoo000>Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool20008Ool00`00Oomoo`0GOol0
0`aSOomoo`3IOol000eoo`8000Aoo`8000Ioo`T000Ioo`03001oogoo01Ioo`0336=oogoo0=Yoo`00
3Goo0P0017oo0P001Woo00<007ooOol00Woo0P0027oo00<007ooOol05Woo00<<HgooOol0fWoo000=
Ool20004Ool20007Ool01000Oomoogoo0P0027oo0`005Woo00<<HgooOol0fWoo000=Ool20004Ool2
0007Ool01000Oomoogoo0P0027oo00<007ooOol05Goo00<<HgooOol0fgoo000=Ool20004Ool20008
Ool00`00Oomoo`020008Ool00`00Oomoo`0EOol00`aSOomoo`3KOol000eoo`8000Aoo`8000Uoo`04
001oo`000008Ool00`00Oomoo`0DOol00`aSOomoo`3LOol000eoo`8000Aoo`8000Uoo`04001oo`00
0008Ool00`00Oomoo`0DOol00`aSOomoo`3LOol000ioo`03001oogoo009oo`03001oogoo00Uoo`<0
00Qoo`03001oogoo01Aoo`0336=oogoo0=aoo`003Woo0P000Woo0P0037oo0P0027oo00<007ooOol0
4goo00<<HgooOol0gGoo000?Ool4000=Ool20008Ool00`00Oomoo`0COol00`aSOomoo`3MOol002Yo
o`03001oogoo019oo`0336=oogoo0=ioo`00:Woo00<007ooOol04Woo00<<HgooOol0gWoo000ZOol0
0`00Oomoo`0BOol00`aSOomoo`3NOol002Yoo`03001oogoo015oo`0336=oogoo0=moo`00:Woo00<0
07ooOol04Goo00<<HgooOol0ggoo000ZOol00`00Oomoo`0AOol00`aSOomoo`3OOol002Yoo`03001o
ogoo011oo`0336=oogoo0>1oo`00:Woo0P004Goo00<<HgooOol0h7oo000ZOol00`00Oomoo`0?Ool0
0`aSOomoo`3QOol002Yoo`03001oogoo00moo`0336=oogoo0>5oo`00:Woo00<007ooOol03goo00<<
HgooOol0hGoo000ZOol00`00Oomoo`0>Ool00`aSOomoo`3ROol002Yoo`03001oogoo00ioo`0336=o
ogoo0>9oo`00:Woo00<007ooOol03Goo00<<HgooOol0hgoo000ZOol00`00Oomoo`0=Ool00`aSOomo
o`3SOol002Yoo`03001oogoo00eoo`0336=oogoo0>=oo`00:Woo00<007ooOol037oo00<<HgooOol0
i7oo000ZOol00`00Oomoo`0<Ool00`aSOomoo`3TOol002Yoo`03001oogoo00]oo`0336=oogoo0>Eo
o`00:Woo00<007ooOol02goo00<<HgooOol0iGoo000ZOol00`00Oomoo`0;Ool00`aSOomoo`3UOol0
02Yoo`8000]oo`0336=oogoo0>Ioo`00:Woo00<007ooOol02Woo00<<HgooOol0iWoo000ZOol00`00
Oomoo`09Ool00`aSOomoo`3WOol002Yoo`03001oogoo00Uoo`0336=oogoo0>Moo`00:Woo00<007oo
Ool02Goo00<<HgooOol0igoo000ZOol00`00Oomoo`08Ool00`aSOomoo`3XOol002Yoo`03001oogoo
00Qoo`0336=oogoo0>Qoo`00:Woo00<007ooOol027oo00<<HgooOol0j7oo000ZOol00`00Oomoo`07
Ool00`aSOomoo`3YOol002Yoo`03001oogoo00Moo`0336=oogoo0>Uoo`00:Woo00<007ooOol01Woo
00<<HgooOol0jWoo000ZOol00`00Oomoo`06Ool00`aSOomoo`3ZOol002Yoo`03001oogoo00Ioo`03
36=oogoo0>Yoo`00:Woo00<007ooOol01Goo00<<HgooOol0jgoo000ZOol00`00Oomoo`05Ool00`aS
Oomoo`3[Ool002Yoo`8000Eoo`0336=oogoo0>aoo`00:Woo00<007ooOol017oo00<<HgooOol0k7oo
000ZOol00`00Oomoo`04Ool00`aSOomoo`3/Ool002Yoo`03001oogoo00=oo`0336=oogoo0>eoo`00
:Woo00<007ooOol00goo00<<HgooOol0kGoo000ZOol00`00Oomoo`02Ool00`aSOomoo`3^Ool002Yo
o`03001oogoo009oo`0336=oogoo0>ioo`00:Woo00<007ooOol00Woo00<<HgooOol0kWoo000?Ool4
0004Ool20005Ool40008Ool01@00Oomoogoo36<0lGoo000>Ool20002Ool20003Ool20004Ool20002
Ool20007Ool01@00Oomoogoo36<0lGoo000>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`02Ool20006Ool01@00Oomoogoo36<0lGoo000=Ool20004Ool20007Ool20004Ool20006Ool01000
Oomoo`aSlWoo000=Ool20004Ool20007Ool20004Ool20006Ool01000Oomoo`aSlWoo000=Ool20004
Ool20007Ool20004Ool20006Ool00`00Ool<H`3cOol000eoo`8000Aoo`8000Moo`<0009oo`8000Mo
o`80000336=oogoo0?5oo`003Goo0P0017oo0P001goo0P0000Aoo`00000000Qoo`03001oo`aS0?=o
o`003Goo0P0017oo0P0027oo0P002goo00<000aSOol0lgoo000=Ool20004Ool20008Ool2000;Ool0
0`0036=oo`3cOol000ioo`03001oogoo009oo`03001oogoo00Qoo`8000Uoo`<00?Aoo`003Woo0P00
0Woo0P002goo0`001goo1000lgoo000?Ool4000>Ool30004Ool8003`Ool002Yoo`03001oogoo00Mo
o`800>Yoo`00:Woo00<007ooOol02Goo0`0017oo0`00h7oo000ZOol00`00Oomoo`0COol3003MOol0
02Yoo`03001oogoo01Uoo`<00=Moo`00:Woo00<007ooOol077oo0`00e7oo000ZOol00`00Oomoo`0S
Ool2003>Ool002Yoo`03001oogoo02Eoo`<00<]oo`00:Woo00<007ooOol0;7oo0`00a7oo000ZOol2
000`Ool30003Ool2002lOol002Yoo`03001oogoo03Eoo`<00;]oo`00:Woo00<007ooOol0=7oo1`00
^7oo000ZOol00`00Oomoo`0oOol2002bOol002Yoo`03001oogoo045oo`<00:moo`00:Woo00<007oo
Ool0B7oo0`00Z7oo000ZOol00`00Oomoo`1;Ool3002UOol002Yoo`03001oogoo055oo`<009moo`00
:Woo00<007ooOol0E7oo0`00W7oo000ZOol00`00Oomoo`1KOol2002FOol002Yoo`03001oogoo05eo
o`<009=oo`00:Woo00<007ooOol0I7oo0P00SGoo000ZOol00`00Oomoo`1VOol30005Ool20023Ool0
02Yoo`03001oogoo06eoo`@0089oo`00:Woo0P00KGoo1`00P7oo000ZOol00`00Oomoo`1fOol3001j
Ool002Yoo`03001oogoo07Uoo`<007Moo`00:Woo00<007ooOol0P7oo0P00LGoo000ZOol00`00Oomo
o`22Ool3001^Ool002Yoo`03001oogoo08Uoo`<006Moo`00:Woo00<007ooOol0S7oo0`00I7oo000Z
Ool00`00Oomoo`2BOol3001NOol002Yoo`03001oogoo09Eoo`<005]oo`00:Woo00<007ooOol0Vgoo
0`00EGoo000ZOol00`00Oomoo`2NOol3001BOol002Yoo`03001oogoo0:Eoo`@004Yoo`00:Woo00<0
07ooOol0YWoo1000BGoo000ZOol00`00Oomoo`2UOol40005Ool30012Ool002Yoo`800;9oo`<003mo
o`00:Woo00<007ooOol0]goo0`00>Goo000ZOol00`00Oomoo`2jOol3000fOol002Yoo`03001oogoo
0?=oo`00:Woo00<007ooOol0`Goo0P00<7oo000ZOol00`00Oomoo`33Ool3000]Ool002Yoo`03001o
ogoo0<Yoo`8002Moo`00:Woo00<007ooOol0c7oo0`0097oo000ZOol00`00Oomoo`3COol3000MOol0
00moo`@000Aoo`8000Eoo`@000Qoo`03001oogoo0=Ioo`<000Ioo`80019oo`003Woo0P000Woo0P00
0goo0P0017oo0P000Woo0P001goo00<007ooOol0g7oo1@004Woo000>Ool00`00Oomoo`02Ool00`00
Oomoo`06Ool20004Ool20006Ool00`00Oomoo`3MOol5000AOol000eoo`8000Aoo`8000Moo`8000Ao
o`8000Ioo`03001oogoo0?=oo`003Goo0P0017oo0P001goo0P000goo0`001Woo00<007ooOol0lgoo
000=Ool20004Ool20008Ool2000017oo000000001goo00<007ooOol0lgoo000=Ool20004Ool2000:
Ool20009Ool3003cOol000eoo`8000Aoo`8000Uoo`800003Ool007oo00Moo`03001oogoo0?=oo`00
3Goo0P0017oo0P0027oo0P000Woo0P00oGoo000=Ool20004Ool20007Ool20004Ool2003lOol000io
o`03001oogoo009oo`03001oogoo00Ioo`8000Aoo`800?aoo`003Woo0P000Woo0P002Goo0P000goo
00<007ooOol0ngoo000?Ool4000;Ool4003nOol00?moob5oo`00ogoo8Goo003oOolQOol008moo`L0
00=oo`@00003Ool0000000800003Ool0000000800003Ool00000008007Aoo`00SGoo0`001Goo0P00
0goo0P000goo0P000goo0P000goo0P00MGoo002<Ool30006Ool20003Ool20003Ool20003Ool20003
Ool2001eOol008aoo`8000Moo`8000=oo`8000=oo`8000=oo`8000=oo`8007Eoo`00Rgoo0P0027oo
0P000goo0P000goo0P000goo0P000goo0P00MGoo002;Ool20008Ool20003Ool20003Ool20003Ool2
0003Ool2001eOol008]oo`8000Ioo`D0009oo`8000=oo`8000=oo`8000=oo`8007Eoo`00Rgoo0P00
37oo0`000Woo10000Woo0P000Woo0`00MGoo002;Ool2000=Ool20003Ool2000017oo0000000017oo
0P00MGoo002<Ool20008Ool00`00Oomoo`27Ool008eoo`03001oogoo00Eoo`8008Uoo`00SGoo0`00
17oo0`00RGoo002?Ool50002Ool01000Oomoogoo0P003Goo0P00MGoo002JOol2000=Ool2001eOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {0.241746, -0.095401, 0.0176775, \
0.00346491}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(MultipleListPlot[Log[Array[y, 5]], Log[Array[ay, 5]], 
      PlotJoined \[Rule] True, 
      PlotStyle \[Rule] {GrayLevel[ .1], Dashing[{0.02, 0.02}]}, 
      PlotLabel -> "\<Log GDP per capita: \[Tau]=0.5\>", 
      PlotRange \[Rule] {\(- .4\), 1.4}, 
      AxesOrigin \[Rule] {1, \(- .4\)}]\), "\[IndentingNewLine]", 
    \(gdp2 = 
      MultipleListPlot[Log[Array[h, 5]], Log[Array[ah, 5]], 
        PlotJoined \[Rule] True, 
        PlotStyle \[Rule] {GrayLevel[ .1], Dashing[{0.02, 0.02}]}, 
        PlotLabel -> "\<Log average human capital\>", 
        PlotRange \[Rule] {\(- .4\), 1.4}, AxesOrigin \[Rule] {1, \(- .4\)}, 
        AspectRatio \[Rule] 1]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 0.137341 0.343352 [
[.2619 -0.0125 -7.03125 -24.5625 ]
[.2619 -0.0125 7.03125 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.7381 -0.0125 -7.03125 -24.5625 ]
[.7381 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[.01131 .0515 -53.125 -12.2813 ]
[.01131 .0515 0 12.2813 ]
[.01131 .13734 -14.0625 -12.2813 ]
[.01131 .13734 0 12.2813 ]
[.01131 .22318 -39.1875 -12.2813 ]
[.01131 .22318 0 12.2813 ]
[.01131 .30902 -29.125 -12.2813 ]
[.01131 .30902 0 12.2813 ]
[.01131 .39486 -39.1875 -12.2813 ]
[.01131 .39486 0 12.2813 ]
[.01131 .48069 -14.0625 -12.2813 ]
[.01131 .48069 0 12.2813 ]
[.01131 .56653 -39.1875 -12.2813 ]
[.01131 .56653 0 12.2813 ]
[.5 .63053 -111.531 0 ]
[.5 .63053 111.531 24.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .0515 m
.03006 .0515 L
s
gsave
.01131 .0515 -114.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .13734 m
.03006 .13734 L
s
gsave
.01131 .13734 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02381 .22318 m
.03006 .22318 L
s
gsave
.01131 .22318 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .30902 m
.03006 .30902 L
s
gsave
.01131 .30902 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .39486 m
.03006 .39486 L
s
gsave
.01131 .39486 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.02381 .48069 m
.03006 .48069 L
s
gsave
.01131 .48069 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .56653 m
.03006 .56653 L
s
gsave
.01131 .56653 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .06867 m
.02756 .06867 L
s
.02381 .08584 m
.02756 .08584 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .12017 m
.02756 .12017 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .17168 m
.02756 .17168 L
s
.02381 .18884 m
.02756 .18884 L
s
.02381 .20601 m
.02756 .20601 L
s
.02381 .24035 m
.02756 .24035 L
s
.02381 .25751 m
.02756 .25751 L
s
.02381 .27468 m
.02756 .27468 L
s
.02381 .29185 m
.02756 .29185 L
s
.02381 .32618 m
.02756 .32618 L
s
.02381 .34335 m
.02756 .34335 L
s
.02381 .36052 m
.02756 .36052 L
s
.02381 .37769 m
.02756 .37769 L
s
.02381 .41202 m
.02756 .41202 L
s
.02381 .42919 m
.02756 .42919 L
s
.02381 .44636 m
.02756 .44636 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .49786 m
.02756 .49786 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .5322 m
.02756 .5322 L
s
.02381 .54936 m
.02756 .54936 L
s
.02381 .03434 m
.02756 .03434 L
s
.02381 .01717 m
.02756 .01717 L
s
.02381 0 m
.02756 0 L
s
.02381 .5837 m
.02756 .5837 L
s
.02381 .60087 m
.02756 .60087 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -172.531 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
%%BeginResource: font Times-Roman-MISO
%%BeginFont: Times-Roman-MISO
/Times-Roman /Times-Roman-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
100.375 23.000 moveto
(GDP) show
145.563 23.000 moveto
(per) show
176.188 23.000 moveto
(capita) show
224.000 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(:) show
234.500 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
244.000 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
256.938 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
282.063 23.000 moveto
%%IncludeResource: font Times-Roman-MISO
%%IncludeFont: Times-Roman-MISO
/Times-Roman-MISO findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.1 g
.001 w
.02381 .08373 m
.2619 .01336 L
.5 .0595 L
.7381 .11502 L
.97619 .17167 L
s
0 g
.0001 w
.02381 .08373 -1.875 0 Mabsadd m
.02381 .08373 0 2.5 Mabsadd L
.02381 .08373 1.875 0 Mabsadd L
.02381 .08373 0 -2.5 Mabsadd L
.02381 .08373 -1.875 0 Mabsadd L closepath F
.2619 .01336 -1.875 0 Mabsadd m
.2619 .01336 0 2.5 Mabsadd L
.2619 .01336 1.875 0 Mabsadd L
.2619 .01336 0 -2.5 Mabsadd L
.2619 .01336 -1.875 0 Mabsadd L closepath F
.5 .0595 -1.875 0 Mabsadd m
.5 .0595 0 2.5 Mabsadd L
.5 .0595 1.875 0 Mabsadd L
.5 .0595 0 -2.5 Mabsadd L
.5 .0595 -1.875 0 Mabsadd L closepath F
.7381 .11502 -1.875 0 Mabsadd m
.7381 .11502 0 2.5 Mabsadd L
.7381 .11502 1.875 0 Mabsadd L
.7381 .11502 0 -2.5 Mabsadd L
.7381 .11502 -1.875 0 Mabsadd L closepath F
.97619 .17167 -1.875 0 Mabsadd m
.97619 .17167 0 2.5 Mabsadd L
.97619 .17167 1.875 0 Mabsadd L
.97619 .17167 0 -2.5 Mabsadd L
.97619 .17167 -1.875 0 Mabsadd L closepath F
.001 w
[ .02 .02 ] 0 setdash
.02381 .10484 m
.2619 .17412 L
.5 .27117 L
.7381 .40043 L
.97619 .56454 L
s
.0001 w
[ ] 0 setdash
.02381 .10484 0 2.5 Mabsadd m
.02381 .10484 -0.56518 .7779 Mabsadd L
.02381 .10484 -2.37764 .77254 Mabsadd L
.02381 .10484 -0.91448 -0.29713 Mabsadd L
.02381 .10484 -1.46946 -2.02254 Mabsadd L
.02381 .10484 0 -0.96154 Mabsadd L
.02381 .10484 1.46946 -2.02254 Mabsadd L
.02381 .10484 .91448 -0.29713 Mabsadd L
.02381 .10484 2.37764 .77254 Mabsadd L
.02381 .10484 .56518 .7779 Mabsadd L
.02381 .10484 0 2.5 Mabsadd L closepath F
.2619 .17412 0 2.5 Mabsadd m
.2619 .17412 -0.56518 .7779 Mabsadd L
.2619 .17412 -2.37764 .77254 Mabsadd L
.2619 .17412 -0.91448 -0.29713 Mabsadd L
.2619 .17412 -1.46946 -2.02254 Mabsadd L
.2619 .17412 0 -0.96154 Mabsadd L
.2619 .17412 1.46946 -2.02254 Mabsadd L
.2619 .17412 .91448 -0.29713 Mabsadd L
.2619 .17412 2.37764 .77254 Mabsadd L
.2619 .17412 .56518 .7779 Mabsadd L
.2619 .17412 0 2.5 Mabsadd L closepath F
.5 .27117 0 2.5 Mabsadd m
.5 .27117 -0.56518 .7779 Mabsadd L
.5 .27117 -2.37764 .77254 Mabsadd L
.5 .27117 -0.91448 -0.29713 Mabsadd L
.5 .27117 -1.46946 -2.02254 Mabsadd L
.5 .27117 0 -0.96154 Mabsadd L
.5 .27117 1.46946 -2.02254 Mabsadd L
.5 .27117 .91448 -0.29713 Mabsadd L
.5 .27117 2.37764 .77254 Mabsadd L
.5 .27117 .56518 .7779 Mabsadd L
.5 .27117 0 2.5 Mabsadd L closepath F
.7381 .40043 0 2.5 Mabsadd m
.7381 .40043 -0.56518 .7779 Mabsadd L
.7381 .40043 -2.37764 .77254 Mabsadd L
.7381 .40043 -0.91448 -0.29713 Mabsadd L
.7381 .40043 -1.46946 -2.02254 Mabsadd L
.7381 .40043 0 -0.96154 Mabsadd L
.7381 .40043 1.46946 -2.02254 Mabsadd L
.7381 .40043 .91448 -0.29713 Mabsadd L
.7381 .40043 2.37764 .77254 Mabsadd L
.7381 .40043 .56518 .7779 Mabsadd L
.7381 .40043 0 2.5 Mabsadd L closepath F
.97619 .56454 0 2.5 Mabsadd m
.97619 .56454 -0.56518 .7779 Mabsadd L
.97619 .56454 -2.37764 .77254 Mabsadd L
.97619 .56454 -0.91448 -0.29713 Mabsadd L
.97619 .56454 -1.46946 -2.02254 Mabsadd L
.97619 .56454 0 -0.96154 Mabsadd L
.97619 .56454 1.46946 -2.02254 Mabsadd L
.97619 .56454 .91448 -0.29713 Mabsadd L
.97619 .56454 2.37764 .77254 Mabsadd L
.97619 .56454 .56518 .7779 Mabsadd L
.97619 .56454 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Kgoo1`00:7oo1@00;goo0P00:Goo1@00
7Woo001`Ool7000WOol20002Ool2000^Ool2000YOol20003Ool00`00Oomoo`0KOol0071oo`03001o
ogoo00=oo`03001oogoo02Yoo`8002eoo`8002ioo`03001oogoo01]oo`00LGoo00<007ooOol0;goo
0P00:7oo2@00;Goo00<007ooOol06Woo001bOol00`00Oomoo`0^Ool2000XOol00`00Oomoo`02Ool2
000_Ool00`00Oomoo`0JOol007=oo`03001oogoo02aoo`<002Uoo`04001oogooOol2000^Ool2000L
Ool007=oo`8002]oo`@002Yoo`04001oogooOol2000^Ool2000LOol007Aoo`03001oogoo02Yoo`80
02aoo`03001oogoo008002aoo`<001eoo`00M7oo0P00;Goo00<007ooOol0:Woo00@007oo000002Yo
o`D001eoo`00Kgoo00<007ooOol00Woo0P00;Goo0P00:goo00@007oo000002Yoo`<001moo`00Kgoo
00@007ooOomoo`<002Qoo`03001oogoo009oo`8002aoo`<002]oo`03001oogoo01ioo`00L7oo1P00
:7oo0P000goo0P00;Goo0P00:goo1@0077oo001aOol3000/Ool4000^Ool2000[Ool5000LOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000oOoo8000IOol004Aoo`03001oogoo02]oo`8002ioo`03001oogoo02eoo`03001oogoo02aoo`03
001oogoo01aoo`00A7oo00<007ooOol0:Woo100000<<HgooOol0Z7oo0014Ool00`00Oomoo`0WOol4
36<300000goo36<<H`0336>UOol001moo`@000Aoo`8000=oo`L000=oo`D000Uoo`03001oogoo02Ao
o`<<H`Eoo`03001oogoo00Eoo`H<Himoo`007Woo0P000Woo0P000goo0P0017oo1`000Woo0P000goo
00<007ooOol01Woo00<007ooOol08Goo0`aS5Woo1@aSVWoo000NOol00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0MOol436<NOol5
36>EOol001eoo`8000Aoo`8000Uoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo01Yoo`<<
HbMoo`D<Hi1oo`007Goo0P0017oo0P002Woo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0
5goo0`aS;goo1@aSRgoo000?Ool;0003Ool20004Ool2000;Ool00`00Oomoo`08Ool20007Ool00`00
Oomoo`0COol436<gOol636>5Ool001eoo`8000Aoo`8000]oo`8000Uoo`8000Moo`80015oo`<<Hd5o
o`D<H`03Ool0000007eoo`007Goo0P0017oo0P0037oo00<007ooOol01Goo0`0027oo00<007ooOol0
3Goo0`aSBGoo100000<<HgooOol0NGoo000MOol20004Ool2000<Ool20004Ool50008Ool00`00Oomo
o`09Ool436==Ool300000goo36<<H`0236=gOol001eoo`8000Aoo`8000Moo`03001oogoo009oo`80
00Aoo`<000Yoo`03001oogoo00Ioo`<<He9oo`03001oogoo00Aoo`@<Hg=oo`007Woo00<007ooOol0
0Woo00<007ooOol01Woo00@007ooOomoo`<000Eoo`03001oogoo00Uoo`03001oogoo00=oo`<<Hf1o
o`D<Hfioo`007Woo0P000Woo0P002Goo1P001Goo1@001Woo0P0000=oo`aS36<00PaSJ7oo10aSJWoo
000OOol4000;Ool30007Ool50005Ool4001`Ool436=VOol004=oo`<007Aoo`D<Hf5oo`00A7oo00<0
07ooOol0N7oo10aSGGoo0013Ool2001nOol536=HOol004=oo`8008=oo`@<HeAoo`00>7oo10001Goo
1P00QGoo10aS00=oo`000000CGoo000gOol20002Ool20007Ool00`00Oomoo`020027Ool4001<Ool0
03Moo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Aoo`8008Aoo`<000@<HdQoo`00=Woo
0P0017oo0P001Woo00<007ooOol01Woo0`00PWoo00<007ooOol00goo10aSA7oo000fOol20004Ool2
0006Ool00`00Oomoo`0<Ool20027Ool436=0Ool003Ioo`8000Aoo`8000Ioo`03001oogoo00ioo`<0
08Qoo`@<Hcaoo`00=Woo0P0017oo0P001Woo0P005Goo0P00Qgoo10aS>7oo000fOol20004Ool20006
Ool00`00Oomoo`0FOol20029Ool436<dOol003Ioo`8000Aoo`8000Ioo`03001oogoo01]oo`8008Qo
o`@<Hc1oo`00=Woo0P0017oo0P001Woo00<007ooOol07Goo0`00RGoo10aS;7oo000gOol00`00Oomo
o`02Ool00`00Oomoo`05Ool00`00Oomoo`2]Ool436<XOol003Moo`80009oo`8000Moo`03001oogoo
02=oo`8008aoo`@<H`Eoo`03001oogoo01aoo`00>7oo100027oo00<007ooOol09Goo0`000goo0`00
Qgoo10aS0`007Goo0014Ool00`00Oomoo`0ZOol3002;Ool4000MOol004Aoo`03001oogoo02Yoo`D0
08Yoo`8001ioo`00A7oo00<007ooOol0;7oo00<007ooOol0ZWoo0014Ool00`00Oomoo`0bOol2002U
Ool001moo`@000Aoo`8000=oo`L000=oo`D000Uoo`03001oogoo03Aoo`<00:9oo`007Woo0P000Woo
0P000goo0P0017oo1`000Woo0P000goo00<007ooOol01Woo00<007ooOol0fGoo000NOol00`00Oomo
o`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomo
o`0iOol2002NOol001eoo`8000Aoo`8000Uoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo
03]oo`<009]oo`007Goo0P0017oo0P002Woo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0
fGoo000MOol20004Ool2000;Ool00`00Oomoo`08Ool20007Ool00`00Oomoo`11Ool2002FOol001eo
o`8000Aoo`8000]oo`8000Uoo`8000Moo`8004Aoo`8009Aoo`007Goo0P0017oo0P0037oo00<007oo
Ool01Goo0`0027oo00<007ooOol0fGoo000MOol20004Ool2000<Ool20004Ool50008Ool00`00Oomo
o`18Ool2002?Ool001eoo`8000Aoo`8000Moo`03001oogoo009oo`8000Aoo`<000Yoo`03001oogoo
04Yoo`<008aoo`007Woo00<007ooOol00Woo00<007ooOol01Woo00@007ooOomoo`<000Eoo`03001o
ogoo00Uoo`03001oogoo0=Uoo`007Woo0P000Woo0P002Goo1P001Goo1@001goo00<007ooOol0Cgoo
0P00R7oo000OOol4000;Ool30007Ool50007Ool00`00Oomoo`1AOol30025Ool004Aoo`03001oogoo
0=Uoo`00A7oo00<007ooOol0Egoo0P0000Aoo`00Ool007aoo`00A7oo00<007ooOol0FGoo0`00OGoo
0014Ool00`00Oomoo`1IOol5001kOol002Uoo`@000Aoo`8000=oo`D000Uoo`03001oogoo05]oo`04
001oogoo001jOol002Qoo`80009oo`8000=oo`8000=oo`8000=oo`03001oogoo00Ioo`03001oogoo
05moo`8007Qoo`00:7oo00<007ooOol00Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol0
HGoo00<007ooOol0MGoo000WOol20004Ool2000=Ool00`00Oomoo`05Ool00`00Oomoo`3IOol002Mo
o`8000Aoo`8000eoo`03001oogoo00Eoo`03001oogoo06Eoo`03001oogoo075oo`009goo0P0017oo
0P0037oo0P001goo00<007ooOol0IWoo0P00LGoo000WOol20004Ool2000<Ool20007Ool2001YOol0
0`00Oomoo`1^Ool002Moo`8000Aoo`8000Yoo`<000Qoo`03001oogoo0=Uoo`009goo0P0017oo0P00
27oo1@0027oo00<007ooOol0K7oo0P00Jgoo000WOol20004Ool20008Ool3000:Ool00`00Oomoo`1^
Ool2001YOol002Qoo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo0=Uo
o`00:7oo0P000Woo0P002Woo1@001goo00<007ooOol0Lgoo00<007ooOol0Hgoo000YOol4000;Ool5
0007Ool00`00Oomoo`1dOol2001SOol004Aoo`03001oogoo07Ioo`03001oogoo061oo`00A7oo00<0
07ooOol0fGoo0014Ool00`00Oomoo`1jOol00`00Oomoo`1LOol004Aoo`03001oogoo07]oo`8005ao
o`007goo100017oo0P001Woo00<007ooOol017oo1@002Goo00<007ooOol0OGoo00<007ooOol0FGoo
000NOol20002Ool20003Ool20007Ool00`00Oomoo`03Ool20003Ool00`00Oomoo`06Ool00`00Oomo
o`3IOol001ioo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Ioo`03
001oogoo085oo`03001oogoo05Eoo`007Goo0P0017oo0P002goo00<007ooOol02Goo00<007ooOol0
1Goo00<007ooOol0PWoo0P00EGoo000MOol20004Ool2000<Ool00`00Oomoo`08Ool00`00Oomoo`05
Ool00`00Oomoo`24Ool00`00Oomoo`1BOol001eoo`8000Aoo`8000aoo`03001oogoo00Moo`8000Mo
o`03001oogoo0=Uoo`007Goo0P0017oo0P0037oo00<007ooOol01goo0P001goo0P00RGoo1000CGoo
000MOol20004Ool2000=Ool00`00Oomoo`04Ool30008Ool00`00Oomoo`2:Ool2001=Ool001eoo`80
00Aoo`8000eoo`03001oogoo009oo`D000Qoo`03001oogoo08Qoo`D004aoo`007Goo0P0017oo0P00
3Goo00<007ooOol00Woo0`002Woo00<007ooOol0fGoo000NOol00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`2?Ool00`00Oomoo`17
Ool001ioo`80009oo`8000Uoo`L000Aoo`D000Moo`03001oogoo091oo`8004Moo`007goo10002Woo
20000goo1@001goo00<007ooOol0TWoo00<007ooOol0A7oo0014Ool00`00Oomoo`3IOol004Aoo`03
001oogoo09Eoo`03001oogoo045oo`00A7oo00<007ooOol0UWoo00<007ooOol0@7oo0014Ool00`00
Oomoo`2GOol00`00Oomoo`0oOol003Moo`H000Moo`03001oogoo09Qoo`03001oogoo03ioo`00>Goo
0P002Goo00<007ooOol0fGoo000iOol20009Ool00`00Oomoo`2LOol00`00Oomoo`0jOol003Uoo`80
00Uoo`03001oogoo09eoo`8003Yoo`00>Goo0P002Goo00<007ooOol0Wgoo00<007ooOol0=goo000i
Ool20009Ool00`00Oomoo`3IOol003Uoo`8000Uoo`800:=oo`03001oogoo03Aoo`00>Goo0P002Goo
00<007ooOol0Xgoo00<007ooOol0<goo000iOol20009Ool00`00Oomoo`2TOol2000cOol003Uoo`80
00Uoo`03001oogoo0:Ioo`03001oogoo031oo`00>Goo0P002Goo00<007ooOol0fGoo000gOol40009
Ool00`00Oomoo`2YOol00`00Oomoo`0]Ool003Uoo`8000Uoo`03001oogoo0:Yoo`8002eoo`00A7oo
00<007ooOol0[7oo00<007ooOol0:Woo0014Ool00`00Oomoo`3IOol004Aoo`03001oogoo0=Uoo`00
A7oo00<007ooOol0[goo00<007ooOol09goo000NOol60003Ool20003Ool70003Ool50009Ool00`00
Oomoo`2`Ool2000WOol0021oo`8000Eoo`8000Aoo`L0009oo`8000=oo`03001oogoo00Ioo`03001o
ogoo0;9oo`8002Eoo`0087oo0P002goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol0fGoo000POol2000<Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`2fOol0
0`00Oomoo`0POol0021oo`8000eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo0;Moo`80
021oo`0087oo0P003Woo00<007ooOol027oo0P001goo00<007ooOol0^Goo0P007Woo000POol2000>
Ool20009Ool20007Ool2002jOol2000NOol0021oo`8000moo`03001oogoo00Eoo`<000Qoo`03001o
ogoo0;Qoo`@001eoo`0087oo0P003goo0P0017oo1@0027oo00<007ooOol0fGoo000POol2000:Ool0
0`00Oomoo`02Ool20004Ool3000:Ool00`00Oomoo`3IOol0021oo`8000Yoo`04001oogooOol30005
Ool00`00Oomoo`09Ool00`00Oomoo`3IOol001ioo`@000]oo`H000Eoo`D000Moo`03001oogoo0=Uo
o`0087oo0P0037oo0`001goo1@001goo00<007ooOol0fGoo0014Ool00`00Oomoo`3IOol004Aoo`03
001oogoo0=Uoo`00A7oo00<007ooOol0fGoo0014Ool00`00Oomoo`3IOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00Bgoo1P00=Woo1000;Goo1000I7oo001:Ool20005Ool00`00Oomoo`0d
Ool2000_Ool2001UOol004Yoo`03001oogoo00Eoo`03001oogoo03=oo`8002moo`8006Eoo`00Bgoo
00<007ooOol017oo00<007ooOol0<goo0P00;goo0P00IGoo000eOol:0004Ool40005Ool7000<Ool7
0002Ool90005Ool6000<Ool2000017oo000000001Woo0`000goo10002goo0`001Goo0`0000Eoo`00
000007oo00800004Ool000000004Ool40002Ool30003Ool3000017oo000000000Woo0P002Goo0`00
57oo100017oo0P000goo1@0057oo000gOol20005Ool01000Oomoogoo0P000Woo0P000goo1`002goo
0`001Goo0P000goo0P0017oo0`001Goo0P003Woo0`000Woo0P0017oo1@000goo0P002goo1@000goo
0P000Woo0`0000=oo`0000000P000Woo0P0017oo0P000goo0P0000=oo`00Ool00P000Woo0`0000=o
o`00Ool00P002Goo0`004goo0P000Woo0P000goo0P000goo0P000goo00<007ooOol04Goo000gOol2
0006Ool01000Ool0000017oo0P000Woo00<007ooOol03Woo0`001Woo0P000goo0P001Woo0P0017oo
0P003Woo0P0017oo0P000Woo0`000goo00<007ooOol00P002Woo0`000goo00<007ooOol00P000goo
0P000Woo0P0017oo0P000goo0P000goo0P000goo0P000goo0P003Woo0P0057oo00<007ooOol00Woo
00<007ooOol02goo00<007ooOol04Goo000gOol20006Ool01000Ool0000017oo0P000goo100037oo
0P001goo0P000goo0P001Woo0P0017oo0P003Woo0P0017oo0P000Woo0P001goo0P002Woo0P001goo
0P000goo0P000Woo0P0017oo0P000goo0P000goo0P000goo0P000goo0P003Woo0P001Woo2`000Woo
0P0017oo0P003Goo00<007ooOol047oo000gOol20008Ool20004Ool20003Ool20002Ool00`00Oomo
o`08Ool20008Ool20003Ool20007Ool20003Ool2000>Ool20004Ool20002Ool20007Ool2000:Ool2
0008Ool300000goo00000002Ool20004Ool20003Ool20003Ool20004Ool300000goo0000000>Ool2
000COol20004Ool2000=Ool00`00Oomoo`0@Ool003Moo`8000Qoo`8000Aoo`80009oo`8000=oo`80
00Uoo`8000Qoo`8000=oo`8000Moo`8000=oo`H000Yoo`8000Aoo`80009oo`L0009oo`8000Yoo`80
00]oo`<0009oo`8000Aoo`8000=oo`8000=oo`8000Moo`<000ioo`8001=oo`8000Aoo`8000aoo`80
019oo`00=goo0P0027oo0P0017oo0P000Woo0P000goo0P002Goo0P001Woo1@000Woo0P001goo0P00
0goo0P000goo0P002Goo0P0017oo0P000Woo0P000goo0P000Woo0P002Woo0P0017oo00<007ooOol0
0P000goo0P000Woo0P0017oo0P000goo0P000goo0P000goo0P000goo0P003goo0P004Woo0P0017oo
0P0037oo0P004Woo000gOol20009Ool20002Ool20004Ool00`00Oomoo`040008Ool2000=Ool20007
Ool20003Ool20004Ool20007Ool40002Ool20004Ool20002Ool00`00Oomoo`0400000goo00000007
Ool20002Ool20002Ool20003Ool200000goo000000020002Ool20003Ool30003Ool20003Ool20003
Ool20003Ool20006Ool20002Ool20005Ool;0002Ool20004Ool2000:Ool3000COol003Moo`8000Yo
o`@000Ioo`<000]oo`8000eoo`8000Moo`8000=oo`8000Aoo`8000Qoo`800004Ool000000006Ool3
0004Ool2000017oo0000000027oo100017oo1@000goo0P0000Aoo`00000000Eoo`80009oo`D0009o
o`D000Aoo`8000Qoo`L000moo`8000Aoo`8000Qoo`D001=oo`00=goo0P008goo0P0027oo00@007oo
Oomoo`8000Ioo`8000Aoo`8000Aoo`8004Uoo`8002eoo`8000Aoo`8000Qoo`<001Eoo`00=goo0P00
97oo00<007ooOol01Goo0P000goo0P001Woo0P0017oo0P0017oo0P00BWoo00<007ooOol0;7oo00<0
07ooOol00Woo00<007ooOol027oo00<007ooOol057oo000gOol2000TOol30004Ool30003Ool20004
Ool30005Ool20003Ool2001;Ool00`00Oomoo`0/Ool20002Ool2000:Ool5000BOol003Eoo`H002Ao
o`D0009oo`03001oo`0000P000Eoo`P004Ioo`8003Aoo`@000]oo`D0019oo`00a7oo0P00FWoo003o
OolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.441411, -0.796327, \
0.0211306, 0.0146529}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 0.222222 0.555556 [
[.2619 -0.0125 -7.03125 -24.5625 ]
[.2619 -0.0125 7.03125 0 ]
[.5 -0.0125 -7.03125 -24.5625 ]
[.5 -0.0125 7.03125 0 ]
[.7381 -0.0125 -7.03125 -24.5625 ]
[.7381 -0.0125 7.03125 0 ]
[.97619 -0.0125 -7.03125 -24.5625 ]
[.97619 -0.0125 7.03125 0 ]
[.01131 .08333 -53.125 -12.2813 ]
[.01131 .08333 0 12.2813 ]
[.01131 .22222 -14.0625 -12.2813 ]
[.01131 .22222 0 12.2813 ]
[.01131 .36111 -39.1875 -12.2813 ]
[.01131 .36111 0 12.2813 ]
[.01131 .5 -29.125 -12.2813 ]
[.01131 .5 0 12.2813 ]
[.01131 .63889 -39.1875 -12.2813 ]
[.01131 .63889 0 12.2813 ]
[.01131 .77778 -14.0625 -12.2813 ]
[.01131 .77778 0 12.2813 ]
[.01131 .91667 -39.1875 -12.2813 ]
[.01131 .91667 0 12.2813 ]
[.5 1.0125 -110.656 0 ]
[.5 1.0125 110.656 24.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 0 m
.2619 .00625 L
s
gsave
.2619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 0 m
.7381 .00625 L
s
gsave
.7381 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .08333 m
.03006 .08333 L
s
gsave
.01131 .08333 -114.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .22222 m
.03006 .22222 L
s
gsave
.01131 .22222 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02381 .36111 m
.03006 .36111 L
s
gsave
.01131 .36111 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
1.000 setlinewidth
grestore
.02381 .5 m
.03006 .5 L
s
gsave
.01131 .5 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.02381 .63889 m
.03006 .63889 L
s
gsave
.01131 .63889 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.02381 .77778 m
.03006 .77778 L
s
gsave
.01131 .77778 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.02381 .91667 m
.03006 .91667 L
s
gsave
.01131 .91667 -100.188 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .11111 m
.02756 .11111 L
s
.02381 .13889 m
.02756 .13889 L
s
.02381 .16667 m
.02756 .16667 L
s
.02381 .19444 m
.02756 .19444 L
s
.02381 .25 m
.02756 .25 L
s
.02381 .27778 m
.02756 .27778 L
s
.02381 .30556 m
.02756 .30556 L
s
.02381 .33333 m
.02756 .33333 L
s
.02381 .38889 m
.02756 .38889 L
s
.02381 .41667 m
.02756 .41667 L
s
.02381 .44444 m
.02756 .44444 L
s
.02381 .47222 m
.02756 .47222 L
s
.02381 .52778 m
.02756 .52778 L
s
.02381 .55556 m
.02756 .55556 L
s
.02381 .58333 m
.02756 .58333 L
s
.02381 .61111 m
.02756 .61111 L
s
.02381 .66667 m
.02756 .66667 L
s
.02381 .69444 m
.02756 .69444 L
s
.02381 .72222 m
.02756 .72222 L
s
.02381 .75 m
.02756 .75 L
s
.02381 .80556 m
.02756 .80556 L
s
.02381 .83333 m
.02756 .83333 L
s
.02381 .86111 m
.02756 .86111 L
s
.02381 .88889 m
.02756 .88889 L
s
.02381 .05556 m
.02756 .05556 L
s
.02381 .02778 m
.02756 .02778 L
s
.02381 0 m
.02756 0 L
s
.02381 .94444 m
.02756 .94444 L
s
.02381 .97222 m
.02756 .97222 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
gsave
.5 1.0125 -171.656 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
100.375 23.000 moveto
(average) show
167.688 23.000 moveto
(human) show
227.125 23.000 moveto
(capital) show
280.313 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.001 w
.02381 .22222 m
.2619 .10837 L
.5 .18302 L
.7381 .27285 L
.97619 .36452 L
s
0 g
.0001 w
.02381 .22222 -1.875 0 Mabsadd m
.02381 .22222 0 2.5 Mabsadd L
.02381 .22222 1.875 0 Mabsadd L
.02381 .22222 0 -2.5 Mabsadd L
.02381 .22222 -1.875 0 Mabsadd L closepath F
.2619 .10837 -1.875 0 Mabsadd m
.2619 .10837 0 2.5 Mabsadd L
.2619 .10837 1.875 0 Mabsadd L
.2619 .10837 0 -2.5 Mabsadd L
.2619 .10837 -1.875 0 Mabsadd L closepath F
.5 .18302 -1.875 0 Mabsadd m
.5 .18302 0 2.5 Mabsadd L
.5 .18302 1.875 0 Mabsadd L
.5 .18302 0 -2.5 Mabsadd L
.5 .18302 -1.875 0 Mabsadd L closepath F
.7381 .27285 -1.875 0 Mabsadd m
.7381 .27285 0 2.5 Mabsadd L
.7381 .27285 1.875 0 Mabsadd L
.7381 .27285 0 -2.5 Mabsadd L
.7381 .27285 -1.875 0 Mabsadd L closepath F
.97619 .36452 -1.875 0 Mabsadd m
.97619 .36452 0 2.5 Mabsadd L
.97619 .36452 1.875 0 Mabsadd L
.97619 .36452 0 -2.5 Mabsadd L
.97619 .36452 -1.875 0 Mabsadd L closepath F
.001 w
[ .02 .02 ] 0 setdash
.02381 .22222 m
.2619 .33262 L
.5 .48752 L
.7381 .69437 L
.97619 .95767 L
s
.0001 w
[ ] 0 setdash
.02381 .22222 0 2.5 Mabsadd m
.02381 .22222 -0.56518 .7779 Mabsadd L
.02381 .22222 -2.37764 .77254 Mabsadd L
.02381 .22222 -0.91448 -0.29713 Mabsadd L
.02381 .22222 -1.46946 -2.02254 Mabsadd L
.02381 .22222 0 -0.96154 Mabsadd L
.02381 .22222 1.46946 -2.02254 Mabsadd L
.02381 .22222 .91448 -0.29713 Mabsadd L
.02381 .22222 2.37764 .77254 Mabsadd L
.02381 .22222 .56518 .7779 Mabsadd L
.02381 .22222 0 2.5 Mabsadd L closepath F
.2619 .33262 0 2.5 Mabsadd m
.2619 .33262 -0.56518 .7779 Mabsadd L
.2619 .33262 -2.37764 .77254 Mabsadd L
.2619 .33262 -0.91448 -0.29713 Mabsadd L
.2619 .33262 -1.46946 -2.02254 Mabsadd L
.2619 .33262 0 -0.96154 Mabsadd L
.2619 .33262 1.46946 -2.02254 Mabsadd L
.2619 .33262 .91448 -0.29713 Mabsadd L
.2619 .33262 2.37764 .77254 Mabsadd L
.2619 .33262 .56518 .7779 Mabsadd L
.2619 .33262 0 2.5 Mabsadd L closepath F
.5 .48752 0 2.5 Mabsadd m
.5 .48752 -0.56518 .7779 Mabsadd L
.5 .48752 -2.37764 .77254 Mabsadd L
.5 .48752 -0.91448 -0.29713 Mabsadd L
.5 .48752 -1.46946 -2.02254 Mabsadd L
.5 .48752 0 -0.96154 Mabsadd L
.5 .48752 1.46946 -2.02254 Mabsadd L
.5 .48752 .91448 -0.29713 Mabsadd L
.5 .48752 2.37764 .77254 Mabsadd L
.5 .48752 .56518 .7779 Mabsadd L
.5 .48752 0 2.5 Mabsadd L closepath F
.7381 .69437 0 2.5 Mabsadd m
.7381 .69437 -0.56518 .7779 Mabsadd L
.7381 .69437 -2.37764 .77254 Mabsadd L
.7381 .69437 -0.91448 -0.29713 Mabsadd L
.7381 .69437 -1.46946 -2.02254 Mabsadd L
.7381 .69437 0 -0.96154 Mabsadd L
.7381 .69437 1.46946 -2.02254 Mabsadd L
.7381 .69437 .91448 -0.29713 Mabsadd L
.7381 .69437 2.37764 .77254 Mabsadd L
.7381 .69437 .56518 .7779 Mabsadd L
.7381 .69437 0 2.5 Mabsadd L closepath F
.97619 .95767 0 2.5 Mabsadd m
.97619 .95767 -0.56518 .7779 Mabsadd L
.97619 .95767 -2.37764 .77254 Mabsadd L
.97619 .95767 -0.91448 -0.29713 Mabsadd L
.97619 .95767 -1.46946 -2.02254 Mabsadd L
.97619 .95767 0 -0.96154 Mabsadd L
.97619 .95767 1.46946 -2.02254 Mabsadd L
.97619 .95767 .91448 -0.29713 Mabsadd L
.97619 .95767 2.37764 .77254 Mabsadd L
.97619 .95767 .56518 .7779 Mabsadd L
.97619 .95767 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001/Ool7000`Ool5000gOol2
000aOol50009Ool006eoo`L002moo`80009oo`8003Ioo`80035oo`8000=oo`03001oogoo00Ioo`00
KGoo00<007ooOol00goo00<007ooOol0<Woo0P00=Goo0P00=Woo00<007ooOol01Woo001^Ool00`00
Oomoo`0gOol2000`Ool9000eOol00`00Oomoo`05Ool006moo`03001oogoo03Ioo`80031oo`03001o
ogoo009oo`8003Moo`03001oogoo00Eoo`00L7oo00<007ooOol0=7oo0`00<Goo00@007ooOomoo`80
03Ioo`8000Moo`00L7oo0P00<goo1000<Woo00@007ooOomoo`8003Ioo`8000Moo`00LGoo00<007oo
Ool0<Woo0P00=7oo00<007ooOol00P00=7oo0`0027oo001aOol2000eOol00`00Oomoo`0bOol01000
Ool00000<Woo1@0027oo001/Ool00`00Oomoo`02Ool2000eOol2000cOol01000Ool00000<Woo0`00
2Woo001/Ool01000Oomoogoo0`00<7oo00<007ooOol00Woo0P00=7oo0`00<goo00<007ooOol02Goo
001]Ool6000`Ool20003Ool2000eOol2000cOol50007Ool006ioo`<003Aoo`@003Ioo`8003=oo`D0
00Moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol003=oonX000=oo`00>Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo
00<007ooOol027oo00<007ooOol027oo00<007ooOol01goo000iOol00`00Oomoo`3TOol003Uoo`03
001oogoo0>Aoo`00>Goo00<007ooOol0i7oo000iOol00`00Oomoo`3TOol003Uoo`800>Eoo`00>Goo
00<007ooOol0i7oo000iOol00`00Oomoo`3TOol003Uoo`03001oogoo0>Aoo`00>Goo00<007ooOol0
i7oo000iOol00`00Oomoo`3TOol003Uoo`03001oogoo0>Aoo`00>Goo0P00iGoo000DOol40004Ool2
0003Ool70003Ool50009Ool00`00Oomoo`3TOol001=oo`80009oo`8000=oo`8000Aoo`L0009oo`80
00=oo`03001oogoo00Ioo`03001oogoo0>Aoo`004goo00<007ooOol00Woo00<007ooOol01goo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0i7oo000BOol20004Ool20009
Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`3TOol0019oo`8000Aoo`8000Yoo`03001o
ogoo00Yoo`03001oogoo00Eoo`03001oogoo0>Aoo`0017oo2`000goo0P0017oo0P002goo00<007oo
Ool027oo0P001goo0P00iGoo000BOol20004Ool2000;Ool20009Ool20007Ool00`00Oomoo`3TOol0
019oo`8000Aoo`8000aoo`03001oogoo00Eoo`<000Qoo`03001oogoo0>Aoo`004Woo0P0017oo0P00
37oo0P0017oo1@0027oo00<007ooOol0i7oo000BOol20004Ool20007Ool00`00Oomoo`02Ool20004
Ool3000:Ool00`00Oomoo`3TOol001=oo`03001oogoo009oo`03001oogoo00Ioo`04001oogooOol3
0005Ool00`00Oomoo`09Ool00`00Oomoo`0cOol2002_Ool001=oo`80009oo`8000Uoo`H000Eoo`D0
00Moo`03001oogoo039oo`@00:ioo`0057oo10002goo0`001goo1@001goo0P00<Woo0PaS0`000`aS
Zgoo000iOol00`00Oomoo`0_Ool236<3Ool00`00Oomoo`02Ool436>WOol003Uoo`03001oogoo02eo
o`8<H`ioo`<<HjAoo`00>Goo00<007ooOol0:goo0PaS4goo0`aSXGoo000iOol00`00Oomoo`0YOol2
36<HOol336>NOol003Uoo`03001oogoo02Moo`8<Haeoo`@<HiYoo`00>Goo0P009Woo0PaS8goo0`aS
Ugoo000iOol00`00Oomoo`0SOol236<XOol336>DOol003Uoo`03001oogoo025oo`8<Hbeoo`<<Hi5o
o`00>Goo00<007ooOol07goo0PaS<Woo0`aSSWoo000iOol00`00Oomoo`0MOol236<gOol436>:Ool0
03Uoo`03001oogoo01]oo`8<Hceoo`<<HhMoo`00>Goo00<007ooOol06Goo0PaS@Woo0`aSQ7oo000i
Ool2000HOol236=7Ool336>1Ool003Uoo`03001oogoo01Eoo`8<Hdaoo`@<Hgeoo`00>Goo00<007oo
Ool04goo0PaSDWoo0`aS00=oo`00Ool0Mgoo000iOol00`00Oomoo`0AOol236=GOol3001gOol003Uo
o`03001oogoo00moo`8<HeYoo`80008<HgEoo`00>Goo00<007ooOol03Goo0PaSG7oo00@007ooOomo
o`<<Hg9oo`00>Goo0P0037oo0PaSIGoo0`aSKgoo000]Ool40008Ool00`00Oomoo`09Ool236=ZOol2
36=]Ool002aoo`80009oo`8000Moo`03001oogoo00Moo`8<Hfioo`<<HfYoo`00;7oo00<007ooOol0
0Woo00<007ooOol01Goo00<007ooOol01Goo0PaSLgoo0`aSIgoo000[Ool20004Ool20006Ool00`00
Oomoo`03Ool236=hOol236=UOol002]oo`8000Aoo`8000Ioo`04001oogooOol236=lOol336=ROol0
02]oo`8000Aoo`8000Eoo`<0008<Hh5oo`<<Hemoo`00:goo0P0017oo0P0017oo1000QWoo0PaSGGoo
000[Ool20004Ool20005Ool40027Ool336=JOol002]oo`8000Aoo`8000Ioo`03001oogoo008008Qo
o`<<HeMoo`00:goo0P0017oo0P001Woo00<007ooOol01Goo0P00QWoo0PaSEGoo000/Ool00`00Oomo
o`02Ool00`00Oomoo`05Ool00`00Oomoo`07Ool20026Ool336=BOol002aoo`80009oo`8000Moo`03
001oogoo00Uoo`8008Moo`<<Hdmoo`00;Goo100027oo0P00UWoo0PaSCGoo000iOol00`00Oomoo`0>
Ool00`00Oomoo`26Ool336=:Ool003Uoo`03001oogoo00moo`8008Uoo`<<HdMoo`00>Goo00<007oo
Ool04Goo0P00RWoo0PaSAGoo000iOol00`00Oomoo`2OOol336<20010Ool003Uoo`03001oogoo01Io
o`03001oogoo08Qoo`@003moo`00>Goo0P0067oo0P00RGoo0`000PaS?Goo000iOol00`00Oomoo`0I
Ool20028Ool01000Oomoogoo0`aS>Woo000iOol00`00Oomoo`2ZOol236<hOol003Uoo`03001oogoo
01moo`03001oogoo08Yoo`<<HcEoo`00>Goo00<007ooOol087oo0P00SGoo0PaS<goo000iOol00`00
Oomoo`0ROol2002=Ool336<`Ool003Uoo`03001oogoo0;Aoo`8<Hbioo`00>Goo0P00:7oo00<007oo
Ool0S7oo0`aS:goo000iOol00`00Oomoo`0XOol2002?Ool236<YOol003Uoo`03001oogoo02Yoo`80
08moo`<<HbIoo`00>Goo00<007ooOol0_Woo0PaS97oo000iOol00`00Oomoo`0_Ool2002?Ool336<Q
Ool003Uoo`03001oogoo035oo`D008eoo`8<Hamoo`00>Goo0P00=7oo0P00T7oo0`aS77oo000DOol4
0004Ool20003Ool70003Ool50009Ool00`00Oomoo`0bOol5002AOol236<JOol001=oo`80009oo`80
00=oo`8000Aoo`L0009oo`8000=oo`03001oogoo00Ioo`03001oogoo03Aoo`05001oogooOol0002A
Ool336<GOol001=oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Eo
o`03001oogoo00Ioo`03001oogoo03Uoo`03001oogoo095oo`8<HaEoo`004Woo0P0017oo0P002Goo
00<007ooOol02goo00<007ooOol01Goo00<007ooOol0>Woo00<007ooOol0TWoo0`aS4Woo000BOol2
0004Ool2000:Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0kOol00`00Oomoo`2DOol2
36<@Ool0019oo`8000Aoo`8000]oo`03001oogoo00Qoo`8000Moo`03001oogoo0=Aoo`<<H`=oo`03
001oogoo00Moo`004Woo0P0017oo0P002goo0P002Goo0P001goo0P00@7oo00<007ooOol0UGoo0PaS
0`0027oo000BOol20004Ool2000<Ool00`00Oomoo`05Ool30008Ool00`00Oomoo`10Ool00`00Oomo
o`2EOol40008Ool0019oo`8000Aoo`8000aoo`8000Aoo`D000Qoo`03001oogoo045oo`8009Ioo`80
00Uoo`004Woo0P0017oo0P001goo00<007ooOol00Woo0P0017oo0`002Woo00<007ooOol0@goo00<0
07ooOol0WWoo000COol00`00Oomoo`02Ool00`00Oomoo`06Ool01000Oomoogoo0`001Goo00<007oo
Ool02Goo00<007ooOol0i7oo000COol20002Ool20009Ool60005Ool50007Ool00`00Oomoo`3TOol0
01Aoo`@000]oo`<000Moo`D000Moo`8004Qoo`03001oogoo09Yoo`00>Goo00<007ooOol0B7oo0P00
VWoo000iOol00`00Oomoo`1:Ool2002HOol003Uoo`03001oogoo0>Aoo`00>Goo00<007ooOol0i7oo
000iOol00`00Oomoo`1?Ool00`00Oomoo`2BOol003Uoo`03001oogoo051oo`80099oo`00>Goo0P00
Dgoo0P00T7oo000iOol00`00Oomoo`3TOol003Uoo`03001oogoo0>Aoo`00>Goo00<007ooOol0Egoo
00<007ooOol0RWoo000iOol00`00Oomoo`1HOol2002:Ool003Uoo`03001oogoo05Yoo`8008Qoo`00
>Goo0P00iGoo000iOol00`00Oomoo`3TOol003Uoo`03001oogoo05moo`03001oogoo089oo`00>Goo
00<007ooOol0H7oo0P00PWoo000iOol00`00Oomoo`1ROol00`00Oomoo`1oOol003Uoo`03001oogoo
0>Aoo`00>Goo00<007ooOol0i7oo000NOol40004Ool20003Ool50009Ool2001WOol00`00Oomoo`1k
Ool001eoo`80009oo`8000=oo`8000=oo`8000=oo`03001oogoo00Ioo`03001oogoo06Moo`8007]o
o`007Goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol01Woo00<007ooOol0JGoo1000Mgoo
000LOol20004Ool2000=Ool00`00Oomoo`05Ool00`00Oomoo`1[Ool00`00Oomoo`1fOol001aoo`80
00Aoo`8000eoo`03001oogoo00Eoo`03001oogoo06Uoo`D007Ioo`0077oo0P0017oo0P0037oo0P00
1goo00<007ooOol0Jgoo00@007ooOol007Eoo`0077oo0P0017oo0P0037oo0P001goo0P00L7oo00<0
07ooOol0LWoo000LOol20004Ool2000:Ool30008Ool00`00Oomoo`1`Ool00`00Oomoo`1aOol001ao
o`8000Aoo`8000Qoo`D000Qoo`03001oogoo075oo`03001oogoo071oo`0077oo0P0017oo0P0027oo
0`002Woo00<007ooOol0i7oo000MOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`3TOol001eoo`80009oo`8000Yoo`D000Moo`03001oogoo07Eoo`03001oogoo06aoo`00
7Woo10002goo1@001goo0P00Mgoo00<007ooOol0Jgoo000iOol00`00Oomoo`1gOol00`00Oomoo`1Z
Ool003Uoo`03001oogoo07Qoo`03001oogoo06Uoo`00>Goo00<007ooOol0i7oo000iOol00`00Oomo
o`3TOol003Uoo`03001oogoo07aoo`03001oogoo06Eoo`00>Goo00<007ooOol0OGoo00<007ooOol0
I7oo000iOol2001oOol00`00Oomoo`1SOol003Uoo`03001oogoo07moo`03001oogoo069oo`00>Goo
00<007ooOol0i7oo000iOol00`00Oomoo`3TOol003Uoo`03001oogoo08=oo`03001oogoo05ioo`00
>Goo00<007ooOol0Q7oo00<007ooOol0GGoo000iOol20026Ool00`00Oomoo`1LOol003Uoo`03001o
ogoo08Ioo`03001oogoo05]oo`00>Goo00<007ooOol0i7oo000iOol00`00Oomoo`3TOol003Uoo`03
001oogoo0>Aoo`00>Goo00<007ooOol0RWoo00<007ooOol0Egoo000iOol00`00Oomoo`2;Ool00`00
Oomoo`1FOol003Uoo`8008eoo`03001oogoo05Eoo`0057oo100017oo0P001Woo00<007ooOol017oo
1@002Goo00<007ooOol0SGoo00<007ooOol0E7oo000COol20002Ool20003Ool20007Ool00`00Oomo
o`03Ool20003Ool00`00Oomoo`06Ool00`00Oomoo`3TOol001=oo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo0>Aoo`004Woo0P0017oo0P002goo00<0
07ooOol02Goo00<007ooOol01Goo00<007ooOol0TGoo00<007ooOol0D7oo000BOol20004Ool2000<
Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`2BOol00`00Oomoo`1?Ool0019oo`8000Ao
o`8000aoo`03001oogoo00Moo`8000Moo`8009Aoo`03001oogoo04ioo`004Woo0P0017oo0P0037oo
00<007ooOol01goo0P001goo00<007ooOol0U7oo00<007ooOol0CGoo000BOol20004Ool2000=Ool0
0`00Oomoo`04Ool30008Ool00`00Oomoo`3TOol0019oo`8000Aoo`8000eoo`03001oogoo009oo`D0
00Qoo`03001oogoo0>Aoo`004Woo0P0017oo0P003Goo00<007ooOol00Woo0`002Woo00<007ooOol0
V7oo00<007ooOol0BGoo000COol00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`2IOol00`00Oomoo`18Ool001=oo`80009oo`8000Uo
o`L000Aoo`D000Moo`03001oogoo09Yoo`03001oogoo04Moo`0057oo10002Woo20000goo1@001goo
0P00W7oo00<007ooOol0AWoo000iOol00`00Oomoo`3TOol003Uoo`03001oogoo0>Aoo`00>Goo00<0
07ooOol0Wgoo00<007ooOol0@Woo000iOol00`00Oomoo`2POol00`00Oomoo`11Ool003Uoo`03001o
ogoo0:5oo`<0041oo`00>Goo0P00Xgoo0P00@7oo000iOol00`00Oomoo`2POol5000oOol003Uoo`03
001oogoo0>Aoo`00>Goo00<007ooOol0YWoo00<007ooOol0>goo000iOol00`00Oomoo`2WOol00`00
Oomoo`0jOol003Uoo`03001oogoo0:Moo`03001oogoo03Yoo`00>Goo00<007ooOol0Z7oo00<007oo
Ool0>Goo000iOol2002ZOol00`00Oomoo`0hOol003Uoo`03001oogoo0>Aoo`00>Goo00<007ooOol0
i7oo000iOol00`00Oomoo`2/Ool00`00Oomoo`0eOol003Uoo`03001oogoo0:eoo`03001oogoo03Ao
o`00>Goo00<007ooOol0[Goo00<007ooOol0=7oo000iOol2002_Ool00`00Oomoo`0cOol002aoo`H0
00Moo`03001oogoo0:moo`03001oogoo039oo`00;Woo0P002Goo00<007ooOol0i7oo000^Ool20009
Ool00`00Oomoo`3TOol002ioo`8000Uoo`03001oogoo0;9oo`03001oogoo02moo`00;Woo0P002Goo
00<007ooOol0/goo00<007ooOol0;Woo000^Ool20009Ool2002eOol00`00Oomoo`0]Ool002ioo`80
00Uoo`03001oogoo0;Eoo`03001oogoo02aoo`00;Woo0P002Goo00<007ooOol0i7oo000^Ool20009
Ool00`00Oomoo`3TOol002ioo`8000Uoo`03001oogoo0>Aoo`00;Woo0P002Goo00<007ooOol0^7oo
00<007ooOol0:Goo000/Ool40009Ool00`00Oomoo`2iOol00`00Oomoo`0XOol002ioo`8000Uoo`80
0;]oo`03001oogoo02Moo`00>Goo00<007ooOol0^goo00<007ooOol09Woo000iOol00`00Oomoo`3T
Ool003Uoo`03001oogoo0>Aoo`00>Goo00<007ooOol0i7oo000iOol00`00Oomoo`2nOol00`00Oomo
o`0SOol003Uoo`800<1oo`03001oogoo029oo`00>Goo00<007ooOol0`7oo0P008Woo000iOol00`00
Oomoo`32Ool00`00Oomoo`0OOol003Uoo`03001oogoo0>Aoo`00>Goo00<007ooOol0i7oo000iOol0
0`00Oomoo`3TOol003Uoo`03001oogoo0<Eoo`03001oogoo01aoo`00>Goo0P00agoo00<007ooOol0
6goo000iOol00`00Oomoo`37Ool00`00Oomoo`0JOol003Uoo`03001oogoo0<Qoo`03001oogoo01Uo
o`00>Goo00<007ooOol0i7oo000iOol00`00Oomoo`3TOol003Uoo`03001oogoo0>Aoo`00>Goo0P00
c7oo00<007ooOol05Woo000COol60003Ool20003Ool70003Ool50009Ool00`00Oomoo`3<Ool00`00
Oomoo`0EOol001Eoo`8000Eoo`8000Aoo`L0009oo`8000=oo`03001oogoo00Ioo`03001oogoo0<eo
o`03001oogoo01Aoo`005Goo0P002goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol0cWoo00<007ooOol04goo000EOol2000<Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool0
0`00Oomoo`3TOol001Eoo`8000eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo0>Aoo`00
5Goo0P003Woo00<007ooOol027oo0P001goo00<007ooOol0dGoo00<007ooOol047oo000EOol2000>
Ool20009Ool20007Ool2003COol00`00Oomoo`0?Ool001Eoo`8000moo`03001oogoo00Eoo`<000Qo
o`03001oogoo0=9oo`03001oogoo00moo`005Goo0P003goo0P0017oo1@0027oo00<007ooOol0dgoo
00<007ooOol03Woo000EOol2000:Ool00`00Oomoo`02Ool20004Ool3000:Ool00`00Oomoo`3DOol0
0`00Oomoo`0=Ool001Eoo`8000Yoo`04001oogooOol30005Ool00`00Oomoo`09Ool00`00Oomoo`3T
Ool001=oo`@000]oo`H000Eoo`D000Moo`03001oogoo0>Aoo`005Goo0P0037oo0`001goo1@001goo
0P00f7oo00<007ooOol02Woo000iOol00`00Oomoo`3HOol00`00Oomoo`09Ool003Uoo`03001oogoo
0=Uoo`8000Uoo`00>Goo00<007ooOol0fGoo0P002Goo000iOol00`00Oomoo`3HOol40008Ool003Uo
o`03001oogoo0=Yoo`03001oogoo00Moo`00>Goo00<007ooOol0i7oo000iOol2003UOol003Uoo`03
001oogoo0>Aoo`00>Goo00<007ooOol0i7oo000iOol00`00Oomoo`3TOol003Uoo`03001oogoo0>Ao
o`00>Goo00<007ooOol0i7oo000iOol00`00Oomoo`3TOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00DGoo1P00=Woo1P00GWoo1000:goo001@Ool20005Ool00`00Oomoo`0bOol20005Ool0
0`00Oomoo`1LOol2000/Ool0051oo`03001oogoo00Eoo`03001oogoo035oo`03001oogoo00Eoo`03
001oogoo05]oo`8002aoo`00DGoo00<007ooOol017oo00<007ooOol0<Woo00<007ooOol017oo00<0
07ooOol0Fgoo0P00;7oo000kOol:0004Ool40005Ool70009Ool3000017oo000000001Goo00<007oo
Ool01Goo0`000goo10001Goo0`0000Aoo`000000009oo`L000=oo`<000Uoo`@00003Ool000000080
009oo`<00004Ool00000Ool400000goo0000000200000goo000000020002Ool300000goo00000005
00000goo00000002000<Ool30005Ool300001Goo00000000Ool00P0000Aoo`00000000Aoo`@0009o
o`<000=oo`<00005Ool00000001oo`04000<Ool003eoo`8000Eoo`04001oogooOol20002Ool20003
Ool70009Ool20002Ool300000goo001oo`02Ool20006Ool50003Ool20005Ool20002Ool300000goo
000000060003Ool50009Ool20003Ool20002Ool20002Ool400000goo00000003Ool20003Ool20002
Ool20002Ool3000017oo000000000goo0P0037oo1@000goo0P000Woo0`0000=oo`0000000P000Woo
0P0017oo0P000goo0P0000=oo`00Ool00P000Woo0`0000=oo`00Ool00P003Goo000mOol20006Ool0
1000Ool0000017oo0P000Woo00<007ooOol03Goo0P000goo0P001Goo0P001Goo0`000goo00<007oo
Ool00P001Goo0P000goo0P000Woo00<007ooOol01Woo0`000goo00<007ooOol01Woo0P000goo0P00
0Woo0P000goo0P000Woo0P000goo0P000goo0P000Woo0P000goo0P000Woo0P000goo0P002goo0`00
0goo00<007ooOol00P000goo0P000Woo0P0017oo0P000goo0P000goo0P000goo0P000goo0P000goo
0P003Goo000mOol20006Ool01000Ool0000017oo0P000goo10002goo0P000goo0P0017oo0P0000=o
o`00Ool00goo0P001goo0P001Goo0P000goo0P000goo100017oo0P003Goo0P000goo0P000Woo0P00
0goo0P000Woo0P000goo0P000goo0P000Woo0P000goo0P000Woo0P000goo0P002goo0P001goo0P00
0goo0P000Woo0P0017oo0P000goo0P000goo0P000goo0P000goo0P000goo0P003Goo000mOol20008
Ool20004Ool20003Ool20002Ool00`00Oomoo`09Ool300000goo00000004Ool200000goo001oo`03
Ool20007Ool20006Ool300000goo00000003Ool20002Ool01000Oomoogoo0P003Goo0P000goo0P00
0Woo0P000goo0P000Woo0P000goo0P000goo0P000goo0`0000=oo`0000000Woo0P000goo0P002goo
0P0027oo0`0000=oo`0000000Woo0P0017oo0P000goo0P000goo0P0017oo0`0000=oo`0000000goo
0P003Goo000mOol20008Ool20004Ool20002Ool20003Ool2000=Ool30003Ool20003Ool01000Oomo
ogoo1`000Woo0P002Goo0`000Woo0P000goo0P000Woo1`0027oo0P000goo0P000Woo0P000goo0P00
0Woo0P000goo0P000goo0P001Woo0`000Woo0P000goo0P002goo0P002goo0`000Woo0P0017oo0P00
0goo0P000goo0P001goo0`000goo0P003Goo000mOol20008Ool20004Ool20002Ool20003Ool20009
Ool20003Ool20003Ool20003Ool01000Oomoogoo0P000goo0P000Woo0P001Goo0P000goo0P000Woo
0P000goo0P000Woo0P000goo0P0027oo0P000goo0P000Woo0P000goo0P000Woo0P000goo0P000goo
0P000Woo0P000goo0P000Woo0P000goo0P002goo0P0017oo00<007ooOol00P000goo0P000Woo0P00
17oo0P000goo0P000goo0P000goo0P000goo0P000goo0P003Goo000mOol20009Ool20002Ool20004
Ool00`00Oomoo`040008Ool20003Ool20002Ool20005Ool01000Oomoogoo0P000Woo00<007ooOol0
100000Aoo`00001oo`8000=oo`8000=oo`03001oogoo00@0009oo`80009oo`03001oogoo00Moo`<0
009oo`80009oo`8000=oo`800003Ool000000080009oo`<0009oo`80009oo`8000=oo`800003Ool0
00000080009oo`8000aoo`80009oo`80009oo`8000=oo`800003Ool000000080009oo`8000=oo`<0
00=oo`8000=oo`8000=oo`8000=oo`8000eoo`00?Goo0P002Woo10001Woo0`0037oo1@000Woo1000
0goo0`000goo0`0017oo0P0000Aoo`000000009oo`D000Eoo`<000Ioo`<000Yoo`800004Ool00000
0002Ool30002Ool30002Ool2000017oo000000000Woo0`0017oo1@000goo0P0000Aoo`00000000io
o`@000Aoo`D000=oo`800004Ool000000005Ool20002Ool50002Ool50004Ool2000=Ool003eoo`80
06Ioo`8005]oo`8000eoo`8000eoo`00?Goo0P00IWoo0P00G7oo00<007ooOol02goo0P003Goo000m
Ool2001VOol2001LOol00`00Oomoo`0;Ool2000=Ool003]oo`H006=oo`<005Ioo`80015oo`<000eo
o`00YGoo0P00EWoo0P004Woo0P003Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0404011, -0.613021, \
0.0180979, 0.00775625}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(rel2 = 
      MultipleListPlot[Log[Array[ha, 5]], Log[Array[aha, 5]], 
        PlotJoined \[Rule] True, 
        PlotStyle \[Rule] {GrayLevel[ .1], Dashing[{0.02, 0.02}]}, 
        PlotLabel -> "\<Log human capital of A\>", 
        AxesOrigin \[Rule] {1, \(-1\)}, AspectRatio \[Rule] 1]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.214286 0.238095 0.780612 0.775802 [
[.2619 -0.00769 -7.03125 -24.5625 ]
[.2619 -0.00769 7.03125 0 ]
[.5 -0.00769 -7.03125 -24.5625 ]
[.5 -0.00769 7.03125 0 ]
[.7381 -0.00769 -7.03125 -24.5625 ]
[.7381 -0.00769 7.03125 0 ]
[.97619 -0.00769 -7.03125 -24.5625 ]
[.97619 -0.00769 7.03125 0 ]
[.01131 .15997 -43.0625 -12.2813 ]
[.01131 .15997 0 12.2813 ]
[.01131 .31513 -43.0625 -12.2813 ]
[.01131 .31513 0 12.2813 ]
[.01131 .47029 -43.0625 -12.2813 ]
[.01131 .47029 0 12.2813 ]
[.01131 .62545 -43.0625 -12.2813 ]
[.01131 .62545 0 12.2813 ]
[.01131 .78061 -14.0625 -12.2813 ]
[.01131 .78061 0 12.2813 ]
[.01131 .93577 -29.125 -12.2813 ]
[.01131 .93577 0 12.2813 ]
[.5 1.0125 -98.7188 0 ]
[.5 1.0125 98.7188 24.5625 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .00481 m
.2619 .01106 L
s
gsave
.2619 -0.00769 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.5 .00481 m
.5 .01106 L
s
gsave
.5 -0.00769 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.7381 .00481 m
.7381 .01106 L
s
gsave
.7381 -0.00769 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.97619 .00481 m
.97619 .01106 L
s
gsave
.97619 -0.00769 -68.0313 -28.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.125 Mabswid
.07143 .00481 m
.07143 .00856 L
s
.11905 .00481 m
.11905 .00856 L
s
.16667 .00481 m
.16667 .00856 L
s
.21429 .00481 m
.21429 .00856 L
s
.30952 .00481 m
.30952 .00856 L
s
.35714 .00481 m
.35714 .00856 L
s
.40476 .00481 m
.40476 .00856 L
s
.45238 .00481 m
.45238 .00856 L
s
.54762 .00481 m
.54762 .00856 L
s
.59524 .00481 m
.59524 .00856 L
s
.64286 .00481 m
.64286 .00856 L
s
.69048 .00481 m
.69048 .00856 L
s
.78571 .00481 m
.78571 .00856 L
s
.83333 .00481 m
.83333 .00856 L
s
.88095 .00481 m
.88095 .00856 L
s
.92857 .00481 m
.92857 .00856 L
s
.25 Mabswid
0 .00481 m
1 .00481 L
s
.02381 .15997 m
.03006 .15997 L
s
gsave
.01131 .15997 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.02381 .31513 m
.03006 .31513 L
s
gsave
.01131 .31513 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.02381 .47029 m
.03006 .47029 L
s
gsave
.01131 .47029 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.02381 .62545 m
.03006 .62545 L
s
gsave
.01131 .62545 -104.063 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
76.938 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.02381 .78061 m
.03006 .78061 L
s
gsave
.01131 .78061 -75.0625 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.02381 .93577 m
.03006 .93577 L
s
gsave
.01131 .93577 -90.125 -16.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.125 Mabswid
.02381 .0436 m
.02756 .0436 L
s
.02381 .08239 m
.02756 .08239 L
s
.02381 .12118 m
.02756 .12118 L
s
.02381 .19876 m
.02756 .19876 L
s
.02381 .23755 m
.02756 .23755 L
s
.02381 .27634 m
.02756 .27634 L
s
.02381 .35392 m
.02756 .35392 L
s
.02381 .39271 m
.02756 .39271 L
s
.02381 .4315 m
.02756 .4315 L
s
.02381 .50908 m
.02756 .50908 L
s
.02381 .54787 m
.02756 .54787 L
s
.02381 .58666 m
.02756 .58666 L
s
.02381 .66424 m
.02756 .66424 L
s
.02381 .70303 m
.02756 .70303 L
s
.02381 .74182 m
.02756 .74182 L
s
.02381 .8194 m
.02756 .8194 L
s
.02381 .85819 m
.02756 .85819 L
s
.02381 .89698 m
.02756 .89698 L
s
.02381 .97456 m
.02756 .97456 L
s
.25 Mabswid
.02381 0 m
.02381 1 L
s
gsave
.5 1.0125 -159.719 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5625 translate 1 -1 scale
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Log) show
100.375 23.000 moveto
(human) show
159.813 23.000 moveto
(capital) show
218.000 23.000 moveto
(of) show
241.938 23.000 moveto
(A) show
256.438 23.000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 20.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.001 w
.02381 .02381 m
.2619 .53079 L
.5 .70479 L
.7381 .84391 L
.97619 .97619 L
s
0 g
.0001 w
.02381 .02381 -1.875 0 Mabsadd m
.02381 .02381 0 2.5 Mabsadd L
.02381 .02381 1.875 0 Mabsadd L
.02381 .02381 0 -2.5 Mabsadd L
.02381 .02381 -1.875 0 Mabsadd L closepath F
.2619 .53079 -1.875 0 Mabsadd m
.2619 .53079 0 2.5 Mabsadd L
.2619 .53079 1.875 0 Mabsadd L
.2619 .53079 0 -2.5 Mabsadd L
.2619 .53079 -1.875 0 Mabsadd L closepath F
.5 .70479 -1.875 0 Mabsadd m
.5 .70479 0 2.5 Mabsadd L
.5 .70479 1.875 0 Mabsadd L
.5 .70479 0 -2.5 Mabsadd L
.5 .70479 -1.875 0 Mabsadd L closepath F
.7381 .84391 -1.875 0 Mabsadd m
.7381 .84391 0 2.5 Mabsadd L
.7381 .84391 1.875 0 Mabsadd L
.7381 .84391 0 -2.5 Mabsadd L
.7381 .84391 -1.875 0 Mabsadd L closepath F
.97619 .97619 -1.875 0 Mabsadd m
.97619 .97619 0 2.5 Mabsadd L
.97619 .97619 1.875 0 Mabsadd L
.97619 .97619 0 -2.5 Mabsadd L
.97619 .97619 -1.875 0 Mabsadd L closepath F
.001 w
[ .02 .02 ] 0 setdash
.02381 .02381 m
.2619 .10513 L
.5 .22287 L
.7381 .38989 L
.97619 .61783 L
s
.0001 w
[ ] 0 setdash
.02381 .02381 0 2.5 Mabsadd m
.02381 .02381 -0.56518 .7779 Mabsadd L
.02381 .02381 -2.37764 .77254 Mabsadd L
.02381 .02381 -0.91448 -0.29713 Mabsadd L
.02381 .02381 -1.46946 -2.02254 Mabsadd L
.02381 .02381 0 -0.96154 Mabsadd L
.02381 .02381 1.46946 -2.02254 Mabsadd L
.02381 .02381 .91448 -0.29713 Mabsadd L
.02381 .02381 2.37764 .77254 Mabsadd L
.02381 .02381 .56518 .7779 Mabsadd L
.02381 .02381 0 2.5 Mabsadd L closepath F
.2619 .10513 0 2.5 Mabsadd m
.2619 .10513 -0.56518 .7779 Mabsadd L
.2619 .10513 -2.37764 .77254 Mabsadd L
.2619 .10513 -0.91448 -0.29713 Mabsadd L
.2619 .10513 -1.46946 -2.02254 Mabsadd L
.2619 .10513 0 -0.96154 Mabsadd L
.2619 .10513 1.46946 -2.02254 Mabsadd L
.2619 .10513 .91448 -0.29713 Mabsadd L
.2619 .10513 2.37764 .77254 Mabsadd L
.2619 .10513 .56518 .7779 Mabsadd L
.2619 .10513 0 2.5 Mabsadd L closepath F
.5 .22287 0 2.5 Mabsadd m
.5 .22287 -0.56518 .7779 Mabsadd L
.5 .22287 -2.37764 .77254 Mabsadd L
.5 .22287 -0.91448 -0.29713 Mabsadd L
.5 .22287 -1.46946 -2.02254 Mabsadd L
.5 .22287 0 -0.96154 Mabsadd L
.5 .22287 1.46946 -2.02254 Mabsadd L
.5 .22287 .91448 -0.29713 Mabsadd L
.5 .22287 2.37764 .77254 Mabsadd L
.5 .22287 .56518 .7779 Mabsadd L
.5 .22287 0 2.5 Mabsadd L closepath F
.7381 .38989 0 2.5 Mabsadd m
.7381 .38989 -0.56518 .7779 Mabsadd L
.7381 .38989 -2.37764 .77254 Mabsadd L
.7381 .38989 -0.91448 -0.29713 Mabsadd L
.7381 .38989 -1.46946 -2.02254 Mabsadd L
.7381 .38989 0 -0.96154 Mabsadd L
.7381 .38989 1.46946 -2.02254 Mabsadd L
.7381 .38989 .91448 -0.29713 Mabsadd L
.7381 .38989 2.37764 .77254 Mabsadd L
.7381 .38989 .56518 .7779 Mabsadd L
.7381 .38989 0 2.5 Mabsadd L closepath F
.97619 .61783 0 2.5 Mabsadd m
.97619 .61783 -0.56518 .7779 Mabsadd L
.97619 .61783 -2.37764 .77254 Mabsadd L
.97619 .61783 -0.91448 -0.29713 Mabsadd L
.97619 .61783 -1.46946 -2.02254 Mabsadd L
.97619 .61783 0 -0.96154 Mabsadd L
.97619 .61783 1.46946 -2.02254 Mabsadd L
.97619 .61783 .91448 -0.29713 Mabsadd L
.97619 .61783 2.37764 .77254 Mabsadd L
.97619 .61783 .56518 .7779 Mabsadd L
.97619 .61783 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo001WOol7000`Ool5000gOol2
000aOol5000>Ool006Qoo`L002moo`80009oo`8003Ioo`80035oo`8000=oo`03001oogoo00]oo`00
J7oo00<007ooOol00goo00<007ooOol0<Woo0P00=Goo0P00=Woo00<007ooOol02goo001YOol00`00
Oomoo`0gOol2000`Ool9000eOol00`00Oomoo`0:Ool006Yoo`03001oogoo03Ioo`80031oo`03001o
ogoo009oo`8003Moo`03001oogoo00Yoo`00Jgoo00<007ooOol0=7oo0`00<Goo00@007ooOomoo`80
03Ioo`8000aoo`00Jgoo0P00<goo1000<Woo00@007ooOomoo`8003Ioo`8000aoo`00K7oo00<007oo
Ool0<Woo0P00=7oo00<007ooOol00P00=7oo0`003Goo001/Ool2000eOol00`00Oomoo`0bOol01000
Ool00000<Woo1@003Goo001WOol00`00Oomoo`02Ool2000eOol2000cOol01000Ool00000<Woo0`00
3goo001WOol01000Oomoogoo0`00<7oo00<007ooOol00Woo0P00=7oo0`00<goo00<007ooOol03Woo
001XOol6000`Ool20003Ool2000eOol2000cOol5000<Ool006Uoo`<003Aoo`@003Ioo`8003=oo`D0
00aoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000cOol00`00Oomoo`3ZOol002ioonX000Qoo`00<goo00<007ooOol02Goo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02goo000cOol00`00Oomoo`3Z
Ool003=oo`800>]oo`00<Woo0`00jgoo000aOol6003YOol003=oo`04000<HgooOol2003WOol003=o
o`03000<Hgoo00Ioo`800>9oo`00<goo00<007oo36<027oo0P00h7oo000cOol200000`aSOomoo`08
Ool2003NOol003=oo`04001oogoo36<>Ool2003IOol003=oo`04001oogoo36<@Ool2003GOol003=o
o`05001oogooOol<H`0AOol2003EOol003=oo`05001oogooOol<H`0FOol00`00Oomoo`3?Ool003=o
o`03001oogoo009oo`0336=oogoo01Aoo`800<moo`00<goo00<007ooOol00Woo00<<HgooOol05Woo
0P00cGoo000cOol00`00Oomoo`03Ool00`aSOomoo`0KOol00`00Oomoo`36Ool003=oo`03001oogoo
00=oo`0336=oogoo01aoo`800<Ioo`00<goo0P001Goo00<<HgooOol07Goo0P00a7oo000cOol00`00
Oomoo`04Ool00`aSOomoo`0SOol00`00Oomoo`2mOol003=oo`03001oogoo00Eoo`0336=oogoo02=o
o`800;eoo`00<goo00<007ooOol01Goo00<<HgooOol09Goo0P00^goo000cOol00`00Oomoo`05Ool0
0`aSOomoo`0/Ool2002dOol003=oo`03001oogoo00Ioo`0336=oogoo02Uoo`@00;Aoo`00<goo00<0
07ooOol01Woo00<<HgooOol0:Woo1@00/Woo000cOol00`00Oomoo`07Ool00`aSOomoo`0[Ool00`00
Oomoo`2bOol003=oo`03001oogoo00Moo`0336=oogoo035oo`03001oogoo0:aoo`00<goo0P002Goo
00<<HgooOol0<Goo0P00[7oo000cOol00`00Oomoo`08Ool00`aSOomoo`0cOol2002ZOol003=oo`03
001oogoo00Uoo`0336=oogoo0=ioo`0067oo100017oo0P001Goo100027oo00<007ooOol02Goo00<<
HgooOol0=goo00<007ooOol0Y7oo000GOol20002Ool20003Ool20004Ool20002Ool20007Ool00`00
Oomoo`0:Ool00`aSOomoo`0gOol00`00Oomoo`2SOol001Moo`03001oogoo009oo`03001oogoo00Io
o`8000Aoo`8000Ioo`03001oogoo00Yoo`0336=oogoo03Qoo`800:=oo`005Woo0P0017oo0P001goo
0P0017oo0P001Woo00<007ooOol02goo00<<HgooOol0>Goo00<007ooOol0X7oo000FOol20004Ool2
0007Ool20003Ool30006Ool00`00Oomoo`0;Ool00`aSOomoo`3LOol000Uoo`/0009oo`8000Aoo`80
00Qoo`800004Ool000000007Ool00`00Oomoo`0<Ool00`aSOomoo`0mOol00`00Oomoo`2KOol001Io
o`8000Aoo`8000Yoo`8000Uoo`<000aoo`0336=oogoo03ioo`8009]oo`005Woo0P0017oo0P002Goo
0P0000=oo`00Ool01goo00<007ooOol03Goo00<<HgooOol0?goo0P00VGoo000FOol20004Ool20008
Ool20002Ool20007Ool00`00Oomoo`0=Ool00`aSOomoo`3JOol001Ioo`8000Aoo`8000Moo`8000Ao
o`8000Ioo`03001oogoo00eoo`0336=oogoo04Aoo`03001oogoo09=oo`005goo00<007ooOol00Woo
00<007ooOol01Woo0P0017oo0P001Woo00<007ooOol03Woo00<<HgooOol0A7oo0P00Tgoo000GOol2
0002Ool20009Ool20003Ool00`00Oomoo`05Ool00`00Oomoo`0>Ool00`aSOomoo`16Ool2002AOol0
01Qoo`@000]oo`@000Qoo`03001oogoo00moo`0336=oogoo0=Qoo`00<goo00<007ooOol03goo00<<
HgooOol0BWoo00<007ooOol0Rgoo000cOol00`00Oomoo`0@Ool00`aSOomoo`1:Ool2002;Ool003=o
o`80015oo`0336=oogoo04aoo`8008Uoo`00<goo00<007ooOol04Goo00<<HgooOol0eWoo000cOol0
0`00Oomoo`0AOol00`aSOomoo`1AOol00`00Oomoo`22Ool003=oo`03001oogoo019oo`0336=oogoo
055oo`80089oo`00<goo00<007ooOol04Woo00<<HgooOol0Dgoo0P00P7oo000cOol00`00Oomoo`0C
Ool00`aSOomoo`1FOol2001lOol003=oo`03001oogoo01=oo`0336=oogoo05Ioo`8007aoo`00<goo
00<007ooOol057oo00<<HgooOol0Dgoo1@00Ngoo000cOol00`00Oomoo`0DOol00`aSOomoo`1HOol2
001iOol003=oo`8001Ioo`0336=oogoo05Uoo`03001oogoo07Ioo`00<goo00<007ooOol05Goo00<<
HgooOol0dWoo000cOol00`00Oomoo`0EOol00`aSOomoo`3BOol003=oo`03001oogoo01Ioo`0336=o
ogoo05aoo`03001oogoo079oo`00<goo00<007ooOol05Woo00<<HgooOol0GGoo0P00LWoo000cOol0
0`00Oomoo`0GOol00`aSOomoo`1NOol00`00Oomoo`1_Ool003=oo`03001oogoo01Moo`0336=oogoo
0=1oo`00<goo00<007ooOol067oo00<<HgooOol0cgoo000cOol00`00Oomoo`0HOol00`aSOomoo`1Q
Ool00`00Oomoo`1[Ool003=oo`8001Yoo`0336=oogoo065oo`03001oogoo06Yoo`00<goo00<007oo
Ool06Goo00<<HgooOol0HWoo0P00JWoo000cOol00`00Oomoo`0JOol00`aSOomoo`1SOol00`00Oomo
o`1WOol003=oo`03001oogoo01Yoo`0336=oogoo0<eoo`0067oo100017oo0P001Goo100027oo00<0
07ooOol06goo00<<HgooOol0IWoo00<007ooOol0Hgoo000GOol20002Ool20003Ool20004Ool20002
Ool20007Ool00`00Oomoo`0KOol00`aSOomoo`1WOol00`00Oomoo`1ROol001Moo`03001oogoo009o
o`03001oogoo00Moo`03001oogoo009oo`8000Ioo`03001oogoo01aoo`0336=oogoo06Moo`80069o
o`005Woo0P0017oo0P001goo0P0017oo0P001Woo00<007ooOol077oo00<<HgooOol0JGoo00<007oo
Ool0Ggoo000FOol20004Ool20007Ool20004Ool20006Ool00`00Oomoo`0MOol00`aSOomoo`3:Ool0
00Uoo`/0009oo`8000Aoo`8000Moo`8000Aoo`8000Ioo`<001eoo`0336=oogoo0<Yoo`005Woo0P00
17oo0P001goo0`000Woo0P001goo00<007ooOol07Goo00<<HgooOol0K7oo00<007ooOol0Fgoo000F
Ool20004Ool20007Ool2000017oo0000000027oo00<007ooOol07Woo00<<HgooOol0K7oo0P00Fgoo
000FOol20004Ool20008Ool2000;Ool00`00Oomoo`0NOol00`aSOomoo`1^Ool00`00Oomoo`1HOol0
01Ioo`8000Aoo`8000Qoo`8000]oo`03001oogoo01moo`0336=oogoo0<Qoo`005goo00<007ooOol0
0Woo00<007ooOol027oo0P002Woo00<007ooOol07goo00<<HgooOol0b7oo000GOol20002Ool2000;
Ool30008Ool00`00Oomoo`0POol00`aSOomoo`1`Ool00`00Oomoo`1DOol001Qoo`@000ioo`<000Io
o`03001oogoo021oo`0336=oogoo075oo`03001oogoo05=oo`00<goo00<007ooOol08Goo00<<Hgoo
Ool0LGoo0P00Dgoo000cOol2000ROol00`aSOomoo`1cOol00`00Oomoo`1@Ool003=oo`03001oogoo
029oo`0336=oogoo0<Eoo`00<goo00<007ooOol08Woo00<<HgooOol0MWoo00<007ooOol0C7oo000c
Ool00`00Oomoo`0SOol00`aSOomoo`1fOol00`00Oomoo`1;Ool003=oo`03001oogoo02=oo`0336=o
ogoo07Moo`8004]oo`00<goo00<007ooOol097oo00<<HgooOol0N7oo00<007ooOol0B7oo000cOol0
0`00Oomoo`0TOol00`aSOomoo`33Ool003=oo`03001oogoo02Eoo`0336=oogoo0<9oo`00<goo00<0
07ooOol09Goo00<<HgooOol0NWoo0`00AGoo000cOol2000VOol00`aSOomoo`1kOol30014Ool003=o
o`03001oogoo02Ioo`0336=oogoo07Uoo`@004Aoo`00<goo00<007ooOol09Woo00<<HgooOol0OGoo
00<007ooOol0@Goo000cOol00`00Oomoo`0WOol00`aSOomoo`30Ool003=oo`03001oogoo02Moo`03
36=oogoo0<1oo`00<goo00<007ooOol0:7oo00<<HgooOol0OWoo00<007ooOol0?Woo000cOol00`00
Oomoo`0XOol00`aSOomoo`1oOol00`00Oomoo`0mOol003=oo`03001oogoo02Uoo`0336=oogoo07mo
o`8003eoo`00<goo00<007ooOol0:Goo00<<HgooOol0PGoo00<007ooOol0>Woo000cOol2000[Ool0
0`aSOomoo`2mOol003=oo`03001oogoo02Yoo`0336=oogoo0;eoo`00<goo00<007ooOol0:goo00<<
HgooOol0PWoo00<007ooOol0=goo000cOol00`00Oomoo`0[Ool00`aSOomoo`23Ool00`00Oomoo`0f
Ool001Qoo`@000Aoo`8000Moo`8000Qoo`03001oogoo02aoo`0336=oogoo089oo`03001oogoo03Io
o`005goo0P000Woo0P000goo0P001goo0P0027oo00<007ooOol0;7oo00<<HgooOol0Pgoo00<007oo
Ool0=Goo000GOol00`00Oomoo`02Ool00`00Oomoo`0:Ool20008Ool00`00Oomoo`0]Ool00`aSOomo
o`23Ool00`00Oomoo`0dOol001Ioo`8000Aoo`8000Ioo`T000Ioo`03001oogoo02eoo`0336=oogoo
0;Yoo`005Woo0P0017oo0P001Woo00<007ooOol00Woo0P0027oo00<007ooOol0;Goo00<<HgooOol0
^Woo0009Ool;0002Ool20004Ool20007Ool01000Oomoogoo0P0027oo00<007ooOol0;Woo00<<Hgoo
Ool0QWoo00<007ooOol0<7oo000FOol20004Ool20007Ool01000Oomoogoo0P0027oo0`00;Woo00<<
HgooOol0Qgoo00<007ooOol0;goo000FOol20004Ool20008Ool00`00Oomoo`020008Ool00`00Oomo
o`0_Ool00`aSOomoo`27Ool00`00Oomoo`0^Ool001Ioo`8000Aoo`8000Uoo`04001oo`000008Ool0
0`00Oomoo`0_Ool00`aSOomoo`28Ool00`00Oomoo`0]Ool001Ioo`8000Aoo`8000Uoo`04001oo`00
0008Ool00`00Oomoo`0`Ool00`aSOomoo`2gOol001Moo`03001oogoo009oo`03001oogoo00Uoo`<0
00Qoo`03001oogoo031oo`0336=oogoo0;Moo`005goo0P000Woo0P0037oo0P0027oo00<007ooOol0
<Goo00<<HgooOol0RWoo00<007ooOol0:Goo000HOol4000=Ool20008Ool00`00Oomoo`0aOol00`aS
Oomoo`2;Ool00`00Oomoo`0XOol003=oo`03001oogoo039oo`0336=oogoo08Yoo`03001oogoo02Qo
o`00<goo00<007ooOol0<Woo00<<HgooOol0Rgoo00<007ooOol09goo000cOol2000dOol00`aSOomo
o`2;Ool00`00Oomoo`0VOol003=oo`03001oogoo03=oo`0336=oogoo0;Aoo`00<goo00<007ooOol0
=7oo00<<HgooOol0/goo000cOol00`00Oomoo`0dOol00`aS001oo`2=Ool00`00Oomoo`0SOol003=o
o`03001oogoo03Aoo`<008ioo`03001oogoo029oo`00<goo00<007ooOol0<goo1000Sgoo0P008Woo
000cOol00`00Oomoo`0dOol2000236>@Ool00`00Oomoo`0OOol003=oo`03001oogoo03Qoo`0336=o
ogoo0:moo`00<goo00<007ooOol0>Goo00<<HgooOol0[Woo000cOol2000kOol236>?Ool00`00Oomo
o`0LOol003=oo`03001oogoo03aoo`0336=oogoo08eoo`03001oogoo01]oo`00<goo00<007ooOol0
?Goo00<<HgooOol0SGoo00<007ooOol06Woo000cOol00`00Oomoo`0nOol236>>Ool00`00Oomoo`0I
Ool003=oo`03001oogoo041oo`0336=oogoo0:Moo`00<goo00<007ooOol0@Goo0PaSYgoo000cOol0
0`00Oomoo`13Ool00`aSOomoo`2TOol003=oo`03001oogoo04Aoo`0336=oogoo08]oo`03001oogoo
01Eoo`00<goo00<007ooOol0AGoo0PaSS7oo00<007ooOol057oo000cOol20018Ool00`aSOomoo`2:
Ool00`00Oomoo`0COol003=oo`03001oogoo04Qoo`0336=oogoo08Yoo`03001oogoo019oo`00<goo
00<007ooOol0BGoo0PaSWgoo000HOol40004Ool20003Ool70007Ool00`00Oomoo`1;Ool00`aSOomo
o`2LOol001Moo`80009oo`8000=oo`8000Aoo`L000Ioo`03001oogoo04aoo`8<Hh]oo`03001oogoo
00ioo`005goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol017oo00<0
07ooOol0CWoo00<<HgooOol0RGoo00<007ooOol03Goo000FOol20004Ool20009Ool00`00Oomoo`09
Ool00`00Oomoo`1?Ool00`aSOomoo`29Ool2000=Ool001Ioo`8000Aoo`8000Yoo`03001oogoo00Qo
o`03001oogoo051oo`8<HhUoo`8000eoo`002Goo2`000Woo0P0017oo0P002goo00<007ooOol01goo
00<007ooOol0DWoo00<<HgooOol0Q7oo1@0037oo000FOol20004Ool2000;Ool20008Ool3001COol0
0`aSOomoo`2DOol001Ioo`8000Aoo`8000aoo`03001oogoo00Ioo`03001oogoo05Aoo`8<HiAoo`00
5Woo0P0017oo0P0037oo0P001goo00<007ooOol0EWoo00<<HgooOol0TGoo000FOol20004Ool20007
Ool00`00Oomoo`02Ool20007Ool00`00Oomoo`1GOol236>AOol001Moo`03001oogoo009oo`03001o
ogoo00Ioo`04001oogooOol30007Ool00`00Oomoo`1IOol00`aSOomoo`2>Ool001Moo`80009oo`80
00Uoo`H000Moo`03001oogoo05Yoo`0336=oogoo08eoo`0067oo10002goo0`002Goo00<007ooOol0
Fgoo0PaSSGoo000cOol00`00Oomoo`1MOol00`aSOomoo`2:Ool003=oo`03001oogoo05ioo`0336=o
ogoo08Uoo`00<goo0P00H7oo0PaSRGoo000cOol00`00Oomoo`1QOol00`aSOomoo`26Ool003=oo`03
001oogoo069oo`8<HhIoo`00<goo00<007ooOol0I7oo00<<HgooOol0Pgoo000cOol00`00Oomoo`1U
Ool00`aSOomoo`22Ool003=oo`03001oogoo06Ioo`8<Hh9oo`00<goo00<007ooOol0J7oo00<<Hgoo
Ool0Ogoo000cOol00`00Oomoo`1YOol00`aSOomoo`1nOol003=oo`03001oogoo06Yoo`8<H`03001o
ogoo07]oo`00<goo0P00K7oo0`00O7oo000cOol00`00Oomoo`1/Ool200000`aSOomoo`1iOol003=o
o`03001oogoo06aoo`03001oogoo008<HgUoo`00<goo00<007ooOol0LGoo00<<HgooOol0MWoo000c
Ool00`00Oomoo`1bOol236=fOol003=oo`03001oogoo07Aoo`8<HgAoo`00<goo00<007ooOol0MWoo
0PaSLWoo000cOol00`00Oomoo`1hOol00`aSOomoo`1_Ool003=oo`03001oogoo07Uoo`8<Hfmoo`00
<goo0P00O7oo0PaSKGoo000cOol00`00Oomoo`1mOol00`aSOomoo`1ZOol003=oo`03001oogoo07io
o`8<HfYoo`00:7oo10001goo00<007ooOol0P7oo0PaSJ7oo000WOol20002Ool20006Ool00`00Oomo
o`22Ool00`aSOomoo`1UOol002Moo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo08=oo`8<
HfEoo`009Woo0P0017oo0P001Goo00<007ooOol0QGoo0PaSHgoo000VOol20004Ool20005Ool00`00
Oomoo`27Ool00`aSOomoo`1POol002Ioo`8000Aoo`8000Eoo`03001oogoo08Qoo`8<Hf1oo`009Woo
0P0017oo0P001Goo0`00RWoo0PaSGWoo000VOol20004Ool20005Ool00`00Oomoo`2<Ool236=LOol0
02Ioo`8000Aoo`8000Eoo`03001oogoo08ioo`0336=oogoo05Uoo`009Woo0P0017oo0P001Goo00<0
07ooOol0Sgoo0PaSFGoo000WOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`2AOol236=G
Ool002Moo`80009oo`8000Ioo`03001oogoo09=oo`0336=oogoo05Aoo`00:7oo10001goo00<007oo
Ool0U7oo0PaSE7oo000cOol00`00Oomoo`2FOol236=BOol003=oo`03001oogoo09Qoo`0336=oogoo
04moo`00<goo0P00VWoo0PaSCgoo000cOol00`00Oomoo`2KOol236==Ool003=oo`03001oogoo09eo
o`8<Hd]oo`00<goo00<007ooOol0Wgoo00<<HgooOol0B7oo000cOol00`00Oomoo`2POol236<2Ool0
0`00Oomoo`13Ool003=oo`03001oogoo0:9oo`0436<000000014Ool003=oo`03001oogoo0:9oo`@0
04Aoo`00<goo00<007ooOol0Xgoo0P000PaS@goo000cOol00`00Oomoo`2WOol236=1Ool003=oo`80
0:Yoo`8<Hcmoo`00<goo00<007ooOol0Zgoo0PaS?Goo000cOol00`00Oomoo`2]Ool236<kOol003=o
o`03001oogoo0:moo`8<HcUoo`00<goo00<007ooOol0/Goo00<<HgooOol0=Woo000cOol00`00Oomo
o`2bOol236<fOol003=oo`03001oogoo0;Aoo`8<HcAoo`00<goo00<007ooOol0]Woo0PaS<Woo000c
Ool00`00Oomoo`2hOol236<`Ool003=oo`800;]oo`8<Hbioo`00<goo00<007ooOol0_7oo0PaS;7oo
000cOol00`00Oomoo`2nOol236<ZOol001Qoo`@000Aoo`8000=oo`L000Moo`03001oogoo0<1oo`03
36=oogoo02Moo`005goo0P000Woo0P000goo0P0017oo1`001Woo00<007ooOol0`Goo0PaS9goo000G
Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`33
Ool236<UOol001Ioo`8000Aoo`8000Uoo`03001oogoo00Uoo`03001oogoo0<Eoo`8<Hb=oo`005Woo
0P0017oo0P002Woo00<007ooOol027oo00<007ooOol0agoo0PaS8Goo000FOol20004Ool2000;Ool0
0`00Oomoo`07Ool00`00Oomoo`39Ool236<OOol001Ioo`8000Aoo`8000]oo`8000Qoo`<00<]oo`8<
Haeoo`005Woo0P0017oo0P0037oo00<007ooOol01Woo00<007ooOol0cGoo00<<HgooOol06Woo000F
Ool20004Ool2000<Ool20007Ool00`00Oomoo`3>Ool236<JOol001Ioo`8000Aoo`8000Moo`03001o
ogoo009oo`8000Moo`03001oogoo0=1oo`8<HaQoo`005goo00<007ooOol00Woo00<007ooOol01Woo
00@007ooOomoo`<000Moo`03001oogoo0=9oo`8<HaIoo`005goo0P000Woo0P002Goo1P001goo00<0
07ooOol0e7oo0PaS57oo000HOol4000;Ool30009Ool00`00Oomoo`3FOol236<BOol003=oo`03001o
ogoo0=Qoo`8<Ha1oo`00<goo00<007ooOol0fWoo00<<H`0000003Goo000cOol2003KOol3000=Ool0
03=oo`03001oogoo0=]oo`8000eoo`00<goo00<007ooOol0g7oo00<007ooOol02goo000cOol00`00
Oomoo`3ZOol003=oo`03001oogoo0>Yoo`00<goo00<007ooOol0jWoo000cOol00`00Oomoo`3ZOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00F7oo1P00Egoo1000Igoo001GOol20005Ool0
0`00Oomoo`1EOol2001XOol005Moo`03001oogoo00Eoo`03001oogoo05Aoo`8006Qoo`00F7oo00<0
07ooOol017oo00<007ooOol0E7oo0P00J7oo0012Ool:0004Ool40005Ool70007Ool400000goo0000
00020002Ool3000017oo000007oo100000=oo`0000000P0000=oo`0000000P000Woo0`0000=oo`00
00001@0000=oo`0000000P003Goo0`001Goo0`0000Eoo`00000007oo00800004Ool000000004Ool4
0002Ool30003Ool300001Goo00000000Ool0100027oo10000goo1P0027oo10001Goo1@007Goo0014
Ool20005Ool01000Oomoogoo0P000Woo0P000goo1`002Goo0P000goo0P000Woo0P000Woo100000=o
o`0000000goo0P000goo0P000Woo0P000Woo0`0000Aoo`00000000=oo`8000eoo`D000=oo`80009o
o`<00003Ool000000080009oo`8000Aoo`8000=oo`800003Ool007oo0080009oo`<00003Ool007oo
008000Qoo`80009oo`8000Aoo`8000]oo`8000Qoo`8001ioo`00A7oo0P001Woo00@007oo000000Ao
o`80009oo`03001oogoo00eoo`8000=oo`80009oo`8000=oo`80009oo`8000=oo`8000=oo`80009o
o`8000=oo`80009oo`8000=oo`8000aoo`<000=oo`03001oogoo008000=oo`80009oo`8000Aoo`80
00=oo`8000=oo`8000=oo`8000=oo`8000=oo`8000Moo`8000Aoo`8000=oo`8000aoo`03001oogoo
00Eoo`8001moo`00A7oo0P001Woo00@007oo000000Aoo`8000=oo`@000]oo`8000=oo`80009oo`80
00=oo`80009oo`8000=oo`8000=oo`80009oo`8000=oo`80009oo`8000=oo`8000aoo`8000Moo`80
00=oo`80009oo`8000Aoo`8000=oo`8000=oo`8000=oo`8000=oo`8000=oo`8000Moo`8000Aoo`80
00=oo`8000aoo`03001oogoo00Eoo`8001moo`00A7oo0P0027oo0P0017oo0P000goo0P000Woo00<0
07ooOol027oo0P000goo0P000Woo0P000goo0P000Woo0P000goo0P000goo0P000goo0`0000=oo`00
00000Woo0P000goo0P0037oo0P0027oo0`0000=oo`0000000Woo0P0017oo0P000goo0P000goo0P00
17oo0`0000=oo`0000000goo0P001goo0P0017oo0P000goo0P003Goo200087oo0014Ool20008Ool2
0004Ool20002Ool20003Ool20009Ool20003Ool20002Ool20003Ool20002Ool20003Ool20003Ool2
0006Ool30002Ool20003Ool2000<Ool2000;Ool30002Ool20004Ool20003Ool20003Ool20007Ool3
0003Ool20007Ool20004Ool20003Ool2000=Ool00`00Oomoo`03Ool2000POol004Aoo`8000Qoo`80
00Aoo`80009oo`8000=oo`8000Uoo`8000=oo`80009oo`8000=oo`80009oo`8000=oo`8000=oo`80
009oo`8000=oo`80009oo`8000=oo`8000aoo`8000Aoo`03001oogoo008000=oo`80009oo`8000Ao
o`8000=oo`8000=oo`8000=oo`8000=oo`8000=oo`8000Moo`8000Aoo`8000=oo`8000ioo`04001o
ogooOol2000QOol004Aoo`8000Uoo`80009oo`8000Aoo`03001oogoo00@000Qoo`<0009oo`80009o
o`8000=oo`800003Ool000000080009oo`<0009oo`80009oo`8000=oo`800003Ool000000080009o
o`8000eoo`80009oo`80009oo`8000=oo`800003Ool000000080009oo`8000=oo`<000=oo`8000=o
o`8000=oo`8000=oo`8000Qoo`80009oo`8000Aoo`8000ioo`04001oogooOol2000QOol004Aoo`80
00Yoo`@000Ioo`<000]oo`800004Ool000000002Ool30002Ool30002Ool2000017oo000000000Woo
0`0017oo1@000goo0P0000Aoo`00000000moo`@000Aoo`D000=oo`800004Ool000000005Ool20002
Ool50002Ool50004Ool20009Ool40003Ool6000=Ool00`00Oomoo`02000QOol004Aoo`80029oo`80
05aoo`8000eoo`80019oo`8000moo`04001oo`00000ROol004Aoo`80029oo`8005eoo`03001oogoo
00]oo`80019oo`80011oo`<0029oo`00A7oo0P008Woo0P00GGoo00<007ooOol02goo0P004Woo0P00
47oo0P008goo0012Ool6000OOol3001GOol2000AOol3000COol01000Oomoogoo0P0037oo00<007oo
Ool08Goo001XOol2001GOol2000BOol2000DOol4000aOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {0.0643713, -1.15191, 0.018013, \
0.00552823}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetDirectory["\<d:/paper/matthias pubpriv/\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(Display["\<gini1.eps\>", gini1, "\<EPS\>"];\)\), "\n", 
    \(\(Display["\<gdp1.eps\>", 
        gdp1, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Display["\<gini2.eps\>", gini2, "\<EPS\>"];\)\), "\n", 
    \(\(Display["\<gdp2.eps\>", 
        gdp2, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Display["\<rel1.eps\>", 
        rel1, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\(Display["\<rel2.eps\>", 
        rel2, "\<EPS\>"];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(Display::"pserr" \(\(:\)\(\ \)\) 
      "\!\(\"PostScript language error:\\nWarning: substituting font \
Utopia-Regular for Times-Roman\\n\"\)"\)], "Message"],

Cell[BoxData[
    \(Display::"pserr" \(\(:\)\(\ \)\) 
      "\!\(\"PostScript language error:\\nWarning: substituting font \
Utopia-Regular for Times-Roman\\n\"\)"\)], "Message"],

Cell[BoxData[
    \(Display::"pserr" \(\(:\)\(\ \)\) 
      "\!\(\"PostScript language error:\\nWarning: substituting font \
Utopia-Regular for Times-Roman\\n\"\)"\)], "Message"],

Cell[BoxData[
    \(Display::"pserr" \(\(:\)\(\ \)\) 
      "\!\(\"PostScript language error:\\nWarning: substituting font \
Utopia-Regular for Times-Roman\\n\"\)"\)], "Message"],

Cell[BoxData[
    \(Display::"pserr" \(\(:\)\(\ \)\) 
      "\!\(\"PostScript language error:\\nWarning: substituting font \
Utopia-Regular for Times-Roman\\n\"\)"\)], "Message"],

Cell[BoxData[
    \(Display::"pserr" \(\(:\)\(\ \)\) 
      "\!\(\"PostScript language error:\\nWarning: substituting font \
Utopia-Regular for Times-Roman\\n\"\)"\)], "Message"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
WindowSize->{828, 583},
WindowMargins->{{62, Automatic}, {Automatic, 33}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 92, 3, 150, "Title"],
Cell[1826, 56, 54, 0, 105, "Title"],
Cell[1883, 58, 28, 0, 64, "Subtitle"],
Cell[1914, 60, 62, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2001, 65, 150, 3, 30, "Input"],
Cell[2154, 70, 1625, 26, 257, "Output"]
}, Open  ]],
Cell[3794, 99, 119, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[3938, 105, 271, 4, 65, "Input"],
Cell[4212, 111, 260, 5, 25, "Print"],
Cell[4475, 118, 246, 5, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4758, 128, 35, 0, 59, "Section"],
Cell[4796, 130, 51, 1, 30, "Input"],
Cell[4850, 133, 298, 5, 130, "Input"],
Cell[5151, 140, 288, 5, 110, "Input"],
Cell[5442, 147, 1368, 23, 434, "Input"],

Cell[CellGroupData[{
Cell[6835, 174, 1981, 32, 423, "Input"],
Cell[8819, 208, 182, 3, 24, "Message"],
Cell[9004, 213, 634, 11, 25, "Print"],
Cell[9641, 226, 733, 13, 25, "Print"],
Cell[10377, 241, 732, 13, 25, "Print"],
Cell[11112, 256, 734, 13, 25, "Print"],
Cell[11849, 271, 724, 12, 25, "Print"],
Cell[12576, 285, 734, 13, 25, "Print"],
Cell[13313, 300, 734, 13, 25, "Print"],
Cell[14050, 315, 724, 12, 25, "Print"],
Cell[14777, 329, 732, 13, 25, "Print"],
Cell[15512, 344, 736, 13, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16285, 362, 224, 3, 50, "Input"],
Cell[16512, 367, 11550, 517, 186, 11427, 513, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[28065, 886, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28232, 894, 293, 6, 70, "Input"],
Cell[28528, 902, 8949, 419, 296, 8830, 415, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[37480, 1323, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37647, 1331, 696, 13, 130, "Input"],
Cell[38346, 1346, 12544, 589, 186, 12421, 585, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[50893, 1937, 130, 3, 29, "Output"],
Cell[51026, 1942, 11196, 540, 296, 11077, 536, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[62225, 2484, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62392, 2492, 320, 6, 70, "Input"],
Cell[62715, 2500, 9665, 452, 296, 9546, 448, "GraphicsData", 
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[72383, 2954, 130, 3, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[72562, 2963, 37, 0, 59, "Section"],
Cell[72602, 2965, 50, 1, 30, "Input"],
Cell[72655, 2968, 298, 5, 130, "Input"],
Cell[72956, 2975, 288, 5, 110, "Input"],
Cell[73247, 2982, 1318, 23, 393, "Input"],

Cell[CellGroupData[{
Cell[74590, 3009, 2000, 32, 443, "Input"],
Cell[76593, 3043, 634, 11, 25, "Print"],
Cell[77230, 3056, 686, 11, 25, "Print"],
Cell[77919, 3069, 685, 11, 25, "Print"],
Cell[78607, 3082, 684, 11, 25, "Print"],
Cell[79294, 3095, 684, 11, 25, "Print"],
Cell[79981, 3108, 686, 11, 25, "Print"],
Cell[80670, 3121, 688, 11, 25, "Print"],
Cell[81361, 3134, 686, 11, 25, "Print"],
Cell[82050, 3147, 689, 11, 25, "Print"],
Cell[82742, 3160, 689, 11, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83468, 3176, 325, 6, 110, "Input"],
Cell[83796, 3184, 22167, 650, 186, 11422, 513, "GraphicsData", 
"PostScript", "Graphics"],
Cell[105966, 3836, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106133, 3844, 256, 5, 50, "Input"],
Cell[106392, 3851, 21304, 571, 296, 9024, 415, "GraphicsData", 
"PostScript", "Graphics"],
Cell[127699, 4424, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127866, 4432, 695, 13, 130, "Input"],
Cell[128564, 4447, 23726, 729, 186, 12414, 585, "GraphicsData", 
"PostScript", "Graphics"],
Cell[152293, 5178, 130, 3, 29, "Output"],
Cell[152426, 5183, 26632, 733, 296, 11077, 536, "GraphicsData", 
"PostScript", "Graphics"],
Cell[179061, 5918, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[179228, 5926, 320, 6, 70, "Input"],
Cell[179551, 5934, 27472, 718, 296, 11013, 510, "GraphicsData", 
"PostScript", "Graphics"],
Cell[207026, 6654, 130, 3, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[207193, 6662, 602, 13, 170, "Input"],
Cell[207798, 6677, 178, 3, 60, "Message"],
Cell[207979, 6682, 178, 3, 60, "Message"],
Cell[208160, 6687, 178, 3, 60, "Message"],
Cell[208341, 6692, 178, 3, 60, "Message"],
Cell[208522, 6697, 178, 3, 60, "Message"],
Cell[208703, 6702, 178, 3, 60, "Message"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

