(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    159406,       6690]*)
(*NotebookOutlinePosition[    160050,       6712]*)
(*  CellTagsIndexPosition[    160006,       6708]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
Public versus Private Education
when Differential Fertility Matters\
\>", "Title"],

Cell["David de la Croix and Matthias Doepke", "Title"],

Cell["\<\
Initial conditions under which growth is higher with public education\
\>", "Subtitle"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(\(xb = 
        1 + \[Xi] \((1 - xa)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(g1i[
          xa_, \[Xi]_] = \(\((\[Eta]\/\(1 - \[Eta]\))\)\^\[Eta]\) \(\((\[Phi]\
\ xa - \[Theta])\)\^\(\[Eta] - 1\)\ xa\^\(1 + \[Tau]\)\ \[Xi] + \ \((\[Phi]\ \
xb - \[Theta])\)\^\(\[Eta] - 1\)\ xb\^\(1 + \[Tau]\)\)\/\(\(xa\/\(\[Phi]\ xa \
- \[Theta]\)\) \[Xi] + xb\/\(\[Phi]\ xb - \
\[Theta]\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(g1c[
          xa_, \[Xi]_] = \(\[Xi]\/\(\[Phi]\ \((1 - \[Eta])\)\)\ \[Theta]\^\
\[Eta]\ xa\^\[Tau] + \ \(\((\[Eta]\/\(1 - \[Eta]\))\)\^\[Eta]\) \((\[Phi]\ xb \
- \[Theta])\)\^\(\[Eta] - 1\)\ xb\^\(1 + \[Tau]\)\)\/\(\[Xi]\/\(\[Phi]\ \((1 \
- \[Eta])\)\) + xb\/\(\[Phi]\ xb - \[Theta]\)\);\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(g3[
          xa_, \[Xi]_] = \(1\/\(1 + \[Xi]\)\) \((\(\[Eta]\ \((\[Phi] + \
\[Gamma]\ \[Theta])\)\)\/\(1 + \ \[Gamma]\ \[Eta]\))\)\^\[Eta]\ \((\(xa\^\
\[Tau]\) \[Xi] + xb\^\[Tau])\);\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(par1 = {\[Eta] \[Rule] 0.6, \[Theta] \[Rule] 
            0.017, \[Phi] \[Rule]  .075, \[Gamma] -> 
            0.169};\)\), "\[IndentingNewLine]", 
    \(Print["\<Threshold for xA to get an interior solution :\>", \
\[Theta]/\((\[Eta]\ \[Phi])\)\  /. \ par1]\), "\[IndentingNewLine]", 
    \(Print["\<Threshold for \[Tau] to get stability :\>", 
      1 - \(\[Eta]\ \[Phi]\)\/\(\[Phi] - \[Theta]\)\  /. \ par1]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Threshold for xA to get an interior solution :"\
\[InvisibleSpace]0.3777777777777779`\),
      SequenceForm[ 
      "Threshold for xA to get an interior solution :", .37777777777777788],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Threshold for \[Tau] to get stability :"\
\[InvisibleSpace]0.22413793103448276`\),
      SequenceForm[ 
      "Threshold for \[Tau] to get stability :", .22413793103448276],
      Editable->False]], "Print"]
}, Open  ]],

Cell[BoxData[
    \(\(f1[xa_, \[Xi]_] = 
        If[xa > \[Theta]/\((\[Eta]\ \[Phi])\), 
          Evaluate[g1i[xa, \[Xi]] - g3[xa, \[Xi]]], 
          Evaluate[g1c[xa, \[Xi]] - g3[xa, \[Xi]]]]\ ;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Do", "[", 
      RowBox[{
        RowBox[{\(Print[tau]\), ";", 
          RowBox[{
            RowBox[{"pl", "[", 
              RowBox[{
                StyleBox["IntegerPart",
                  "MR"], 
                StyleBox["[",
                  "MR"], \(10\ tau + 1\), "]"}], "]"}], 
            "=", \(ContourPlot[ .9 +  .3 
                     f1[xa, \[Xi]]\ \ /\ Abs[f1[xa, \[Xi]]] /. 
                Join[\ par1, {\[Tau] \[Rule] 
                      tau}]\ , {xa,  .01,  .99}, {\[Xi], 1.01, 50}, 
              AxesLabel \[Rule] {"\<xa\>", "\<\[Xi]\>"}, 
              AspectRatio \[Rule] 1/GoldenRatio, PlotPoints \[Rule] 200, 
              Contours \[Rule] { .9}, ColorFunctionScaling \[Rule] False, 
              TextStyle \[Rule] {FontSize \[Rule] 12, 
                  FontFamily -> "\<Palatino\>"}]\)}]}], 
        ",", \({tau, 0,  .4,  .1}\)}], "]"}]], "Input"],

Cell[BoxData[
    \(0\)], "Print"],

Cell[BoxData[
    \(Graphics::"realu" \(\(:\)\(\ \)\) 
      "Argument in \!\(GrayLevel[1.0575`]\) is not a real number between 0 \
and 1."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00941915 0.981162 -0.000366335 0.0121303 [
[.00942 -0.0125 -5 -15.6875 ]
[.00942 -0.0125 5 0 ]
[.20565 -0.0125 -9.5 -15.6875 ]
[.20565 -0.0125 9.5 0 ]
[.40188 -0.0125 -9.5 -15.6875 ]
[.40188 -0.0125 9.5 0 ]
[.59812 -0.0125 -9.5 -15.6875 ]
[.59812 -0.0125 9.5 0 ]
[.79435 -0.0125 -9.5 -15.6875 ]
[.79435 -0.0125 9.5 0 ]
[.99058 -0.0125 -5 -15.6875 ]
[.99058 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12094 -16 -7.84375 ]
[-0.0125 .12094 0 7.84375 ]
[-0.0125 .24224 -16 -7.84375 ]
[-0.0125 .24224 0 7.84375 ]
[-0.0125 .36354 -16 -7.84375 ]
[-0.0125 .36354 0 7.84375 ]
[-0.0125 .48485 -16 -7.84375 ]
[-0.0125 .48485 0 7.84375 ]
[-0.0125 .60615 -16 -7.84375 ]
[-0.0125 .60615 0 7.84375 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00942 0 m
.00942 .00625 L
s
gsave
.00942 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20565 0 m
.20565 .00625 L
s
gsave
.20565 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40188 0 m
.40188 .00625 L
s
gsave
.40188 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59812 0 m
.59812 .00625 L
s
gsave
.59812 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.79435 0 m
.79435 .00625 L
s
gsave
.79435 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.99058 0 m
.99058 .00625 L
s
gsave
.99058 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05848 0 m
.05848 .00375 L
s
.10754 0 m
.10754 .00375 L
s
.15659 0 m
.15659 .00375 L
s
.25471 0 m
.25471 .00375 L
s
.30377 0 m
.30377 .00375 L
s
.35283 0 m
.35283 .00375 L
s
.45094 0 m
.45094 .00375 L
s
.5 0 m
.5 .00375 L
s
.54906 0 m
.54906 .00375 L
s
.64717 0 m
.64717 .00375 L
s
.69623 0 m
.69623 .00375 L
s
.74529 0 m
.74529 .00375 L
s
.84341 0 m
.84341 .00375 L
s
.89246 0 m
.89246 .00375 L
s
.94152 0 m
.94152 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12094 m
.00625 .12094 L
s
gsave
-0.0125 .12094 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .24224 m
.00625 .24224 L
s
gsave
-0.0125 .24224 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .36354 m
.00625 .36354 L
s
gsave
-0.0125 .36354 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .48485 m
.00625 .48485 L
s
gsave
-0.0125 .48485 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .60615 m
.00625 .60615 L
s
gsave
-0.0125 .60615 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02389 m
.00375 .02389 L
s
0 .04815 m
.00375 .04815 L
s
0 .07242 m
.00375 .07242 L
s
0 .09668 m
.00375 .09668 L
s
0 .1452 m
.00375 .1452 L
s
0 .16946 m
.00375 .16946 L
s
0 .19372 m
.00375 .19372 L
s
0 .21798 m
.00375 .21798 L
s
0 .2665 m
.00375 .2665 L
s
0 .29076 m
.00375 .29076 L
s
0 .31502 m
.00375 .31502 L
s
0 .33928 m
.00375 .33928 L
s
0 .3878 m
.00375 .3878 L
s
0 .41206 m
.00375 .41206 L
s
0 .43632 m
.00375 .43632 L
s
0 .46059 m
.00375 .46059 L
s
0 .50911 m
.00375 .50911 L
s
0 .53337 m
.00375 .53337 L
s
0 .55763 m
.00375 .55763 L
s
0 .58189 m
.00375 .58189 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00942 .61178 m
.00942 .61803 L
s
.20565 .61178 m
.20565 .61803 L
s
.40188 .61178 m
.40188 .61803 L
s
.59812 .61178 m
.59812 .61803 L
s
.79435 .61178 m
.79435 .61803 L
s
.99058 .61178 m
.99058 .61803 L
s
.125 Mabswid
.05848 .61428 m
.05848 .61803 L
s
.10754 .61428 m
.10754 .61803 L
s
.15659 .61428 m
.15659 .61803 L
s
.25471 .61428 m
.25471 .61803 L
s
.30377 .61428 m
.30377 .61803 L
s
.35283 .61428 m
.35283 .61803 L
s
.45094 .61428 m
.45094 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54906 .61428 m
.54906 .61803 L
s
.64717 .61428 m
.64717 .61803 L
s
.69623 .61428 m
.69623 .61803 L
s
.74529 .61428 m
.74529 .61803 L
s
.84341 .61428 m
.84341 .61803 L
s
.89246 .61428 m
.89246 .61803 L
s
.94152 .61428 m
.94152 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12094 m
1 .12094 L
s
.99375 .24224 m
1 .24224 L
s
.99375 .36354 m
1 .36354 L
s
.99375 .48485 m
1 .48485 L
s
.99375 .60615 m
1 .60615 L
s
.125 Mabswid
.99625 .02389 m
1 .02389 L
s
.99625 .04815 m
1 .04815 L
s
.99625 .07242 m
1 .07242 L
s
.99625 .09668 m
1 .09668 L
s
.99625 .1452 m
1 .1452 L
s
.99625 .16946 m
1 .16946 L
s
.99625 .19372 m
1 .19372 L
s
.99625 .21798 m
1 .21798 L
s
.99625 .2665 m
1 .2665 L
s
.99625 .29076 m
1 .29076 L
s
.99625 .31502 m
1 .31502 L
s
.99625 .33928 m
1 .33928 L
s
.99625 .3878 m
1 .3878 L
s
.99625 .41206 m
1 .41206 L
s
.99625 .43632 m
1 .43632 L
s
.99625 .46059 m
1 .46059 L
s
.99625 .50911 m
1 .50911 L
s
.99625 .53337 m
1 .53337 L
s
.99625 .55763 m
1 .55763 L
s
.99625 .58189 m
1 .58189 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 g
.01923 .60615 m
.98077 .60615 L
.98077 .01189 L
.01923 .01189 L
F
0 g
.5 Mabswid
.742 g
.01923 .03428 m
.02406 .03428 L
.02889 .03428 L
.03373 .03428 L
.03856 .03428 L
.04339 .03428 L
.04822 .03428 L
.05305 .03428 L
.05789 .03428 L
.06272 .03428 L
.06755 .03428 L
.06997 .03279 L
.07238 .0313 L
.07721 .0313 L
.08204 .0313 L
.08688 .0313 L
.09171 .0313 L
.09654 .0313 L
.10137 .0313 L
.1062 .0313 L
.11104 .0313 L
.11587 .0313 L
.1207 .0313 L
.12553 .0313 L
.12795 .0298 L
.13036 .02831 L
.1352 .02831 L
.14003 .02831 L
.14486 .02831 L
.14969 .02831 L
.15452 .02831 L
.15935 .02831 L
.16419 .02831 L
.16902 .02831 L
.17385 .02831 L
.17868 .02831 L
.18351 .02831 L
.18835 .02831 L
.19318 .02831 L
.19559 .02682 L
.19801 .02532 L
.20284 .02532 L
.20767 .02532 L
.2125 .02532 L
.21734 .02532 L
.22217 .02532 L
.227 .02532 L
.23183 .02532 L
.23666 .02532 L
.2415 .02532 L
.24633 .02532 L
.25116 .02532 L
.25599 .02532 L
.26082 .02532 L
.26566 .02532 L
.26807 .02383 L
.27049 .02234 L
.27532 .02234 L
.28015 .02234 L
.28498 .02234 L
.28981 .02234 L
.29465 .02234 L
.29948 .02234 L
.30431 .02234 L
.30914 .02234 L
.31397 .02234 L
.31881 .02234 L
.32364 .02234 L
.32847 .02234 L
.3333 .02234 L
.33813 .02234 L
.34296 .02234 L
.3478 .02234 L
.35021 .02084 L
.35263 .01935 L
.35746 .01935 L
.36229 .01935 L
.36712 .01935 L
.37196 .01935 L
.37679 .01935 L
.38162 .01935 L
.38404 .02084 L
.38645 .02234 L
.38887 .02383 L
.39128 .02532 L
.39612 .02532 L
.39853 .02682 L
.40095 .02831 L
.40336 .0298 L
.40578 .0313 L
.40819 .03279 L
.41061 .03428 L
.41303 .03578 L
.41544 .03727 L
.41786 .03876 L
.42027 .04025 L
.42269 .04175 L
.42269 .04473 L
.42511 .04623 L
.42752 .04772 L
.42994 .04921 L
.43235 .05071 L
.43235 .05369 L
.43477 .05519 L
.43719 .05668 L
.43719 .05967 L
.4396 .06116 L
.44202 .06265 L
.44202 .06564 L
.44443 .06713 L
.44685 .06862 L
.44685 .07161 L
.44927 .0731 L
.45168 .0746 L
.45168 .07758 L
.45168 .08057 L
.4541 .08206 L
.45651 .08356 L
.45651 .08654 L
.45651 .08953 L
.45893 .09102 L
.46135 .09251 L
.46135 .0955 L
.46135 .09849 L
.46135 .10147 L
.46376 .10297 L
.46618 .10446 L
.46618 .10745 L
.46618 .11043 L
.46618 .11342 L
.46859 .11491 L
.47101 .1164 L
.47101 .11939 L
.47101 .12238 L
.47101 .12536 L
.47101 .12835 L
.47342 .12984 L
.47584 .13134 L
.47584 .13432 L
.47584 .13731 L
.47584 .14029 L
.47584 .14328 L
.47826 .14477 L
.48067 .14627 L
.48067 .14925 L
.48067 .15224 L
.48067 .15523 L
.48067 .15821 L
.48067 .1612 L
.48067 .16418 L
.48309 .16568 L
.4855 .16717 L
.4855 .17016 L
.4855 .17314 L
.4855 .17613 L
.4855 .17912 L
.4855 .1821 L
.4855 .18509 L
.48792 .18658 L
.49034 .18807 L
.49034 .19106 L
.49034 .19405 L
.49034 .19703 L
.49034 .20002 L
.49034 .20301 L
.49034 .20599 L
.49034 .20898 L
.49034 .21196 L
.49275 .21346 L
.49517 .21495 L
.49517 .21794 L
.49517 .22092 L
.49517 .22391 L
.49517 .2269 L
.49517 .22988 L
.49517 .23287 L
.49517 .23585 L
.49517 .23884 L
.49517 .24183 L
.49758 .24332 L
.5 .24481 L
.5 .2478 L
.5 .25079 L
.5 .25377 L
.5 .25676 L
.5 .25974 L
.5 .26273 L
.5 .26572 L
.5 .2687 L
.5 .27169 L
.5 .27468 L
.5 .27766 L
.5 .28065 L
.50242 .28214 L
.50483 .28363 L
.50483 .28662 L
.50483 .28961 L
.50483 .29259 L
.50483 .29558 L
.50483 .29857 L
.50483 .30155 L
.50483 .30454 L
.50483 .30752 L
.50483 .31051 L
.50483 .3135 L
.50483 .31648 L
.50483 .31947 L
.50483 .32246 L
.50725 .32395 L
.50966 .32544 L
.50966 .32843 L
.50966 .33141 L
.50966 .3344 L
.50966 .33739 L
.50966 .34037 L
.50966 .34336 L
.50966 .34635 L
.50966 .34933 L
.50966 .35232 L
.50966 .3553 L
.50966 .35829 L
.50966 .36128 L
.50966 .36426 L
.50966 .36725 L
.50966 .37024 L
.50966 .37322 L
.50966 .37621 L
.51208 .3777 L
.5145 .37919 L
.5145 .38218 L
.5145 .38517 L
.5145 .38815 L
.5145 .39114 L
.5145 .39413 L
.5145 .39711 L
.5145 .4001 L
.5145 .40308 L
.5145 .40607 L
.5145 .40906 L
.5145 .41204 L
.5145 .41503 L
.5145 .41802 L
.5145 .421 L
.5145 .42399 L
.5145 .42697 L
.5145 .42996 L
.5145 .43295 L
.5145 .43593 L
.5145 .43892 L
.5145 .44191 L
.51691 .4434 L
.51933 .44489 L
.51933 .44788 L
.51933 .45086 L
.51933 .45385 L
.51933 .45684 L
.51933 .45982 L
.51933 .46281 L
.51933 .4658 L
.51933 .46878 L
.51933 .47177 L
.51933 .47475 L
.51933 .47774 L
.51933 .48073 L
.51933 .48371 L
.51933 .4867 L
.51933 .48969 L
.51933 .49267 L
.51933 .49566 L
.51933 .49864 L
.51933 .50163 L
.51933 .50462 L
.51933 .5076 L
.51933 .51059 L
.51933 .51358 L
.51933 .51656 L
.51933 .51955 L
.51933 .52253 L
.52174 .52403 L
.52416 .52552 L
.52416 .52851 L
.52416 .53149 L
.52416 .53448 L
.52416 .53747 L
.52416 .54045 L
.52416 .54344 L
.52416 .54642 L
.52416 .54941 L
.52416 .5524 L
.52416 .55538 L
.52416 .55837 L
.52416 .56135 L
.52416 .56434 L
.52416 .56733 L
.52416 .57031 L
.52416 .5733 L
.52416 .57629 L
.52416 .57927 L
.52416 .58226 L
.52416 .58524 L
.52416 .58823 L
.52416 .59122 L
.52416 .5942 L
.52416 .59719 L
.52416 .60018 L
.52416 .60316 L
.52416 .60615 L
.01923 .60615 L
F
0 g
.01923 .03428 m
.02406 .03428 L
.02889 .03428 L
.03373 .03428 L
.03856 .03428 L
.04339 .03428 L
.04822 .03428 L
.05305 .03428 L
.05789 .03428 L
.06272 .03428 L
.06755 .03428 L
.06997 .03279 L
.07238 .0313 L
.07721 .0313 L
.08204 .0313 L
.08688 .0313 L
.09171 .0313 L
.09654 .0313 L
.10137 .0313 L
.1062 .0313 L
.11104 .0313 L
.11587 .0313 L
.1207 .0313 L
.12553 .0313 L
.12795 .0298 L
.13036 .02831 L
.1352 .02831 L
.14003 .02831 L
.14486 .02831 L
.14969 .02831 L
.15452 .02831 L
.15935 .02831 L
.16419 .02831 L
.16902 .02831 L
.17385 .02831 L
.17868 .02831 L
.18351 .02831 L
.18835 .02831 L
.19318 .02831 L
.19559 .02682 L
.19801 .02532 L
.20284 .02532 L
.20767 .02532 L
.2125 .02532 L
.21734 .02532 L
.22217 .02532 L
.227 .02532 L
.23183 .02532 L
.23666 .02532 L
.2415 .02532 L
Mistroke
.24633 .02532 L
.25116 .02532 L
.25599 .02532 L
.26082 .02532 L
.26566 .02532 L
.26807 .02383 L
.27049 .02234 L
.27532 .02234 L
.28015 .02234 L
.28498 .02234 L
.28981 .02234 L
.29465 .02234 L
.29948 .02234 L
.30431 .02234 L
.30914 .02234 L
.31397 .02234 L
.31881 .02234 L
.32364 .02234 L
.32847 .02234 L
.3333 .02234 L
.33813 .02234 L
.34296 .02234 L
.3478 .02234 L
.35021 .02084 L
.35263 .01935 L
.35746 .01935 L
.36229 .01935 L
.36712 .01935 L
.37196 .01935 L
.37679 .01935 L
.38162 .01935 L
.38404 .02084 L
.38645 .02234 L
.38887 .02383 L
.39128 .02532 L
.39612 .02532 L
.39853 .02682 L
.40095 .02831 L
.40336 .0298 L
.40578 .0313 L
.40819 .03279 L
.41061 .03428 L
.41303 .03578 L
.41544 .03727 L
.41786 .03876 L
.42027 .04025 L
.42269 .04175 L
.42269 .04473 L
.42511 .04623 L
.42752 .04772 L
Mistroke
.42994 .04921 L
.43235 .05071 L
.43235 .05369 L
.43477 .05519 L
.43719 .05668 L
.43719 .05967 L
.4396 .06116 L
.44202 .06265 L
.44202 .06564 L
.44443 .06713 L
.44685 .06862 L
.44685 .07161 L
.44927 .0731 L
.45168 .0746 L
.45168 .07758 L
.45168 .08057 L
.4541 .08206 L
.45651 .08356 L
.45651 .08654 L
.45651 .08953 L
.45893 .09102 L
.46135 .09251 L
.46135 .0955 L
.46135 .09849 L
.46135 .10147 L
.46376 .10297 L
.46618 .10446 L
.46618 .10745 L
.46618 .11043 L
.46618 .11342 L
.46859 .11491 L
.47101 .1164 L
.47101 .11939 L
.47101 .12238 L
.47101 .12536 L
.47101 .12835 L
.47342 .12984 L
.47584 .13134 L
.47584 .13432 L
.47584 .13731 L
.47584 .14029 L
.47584 .14328 L
.47826 .14477 L
.48067 .14627 L
.48067 .14925 L
.48067 .15224 L
.48067 .15523 L
.48067 .15821 L
.48067 .1612 L
.48067 .16418 L
Mistroke
.48309 .16568 L
.4855 .16717 L
.4855 .17016 L
.4855 .17314 L
.4855 .17613 L
.4855 .17912 L
.4855 .1821 L
.4855 .18509 L
.48792 .18658 L
.49034 .18807 L
.49034 .19106 L
.49034 .19405 L
.49034 .19703 L
.49034 .20002 L
.49034 .20301 L
.49034 .20599 L
.49034 .20898 L
.49034 .21196 L
.49275 .21346 L
.49517 .21495 L
.49517 .21794 L
.49517 .22092 L
.49517 .22391 L
.49517 .2269 L
.49517 .22988 L
.49517 .23287 L
.49517 .23585 L
.49517 .23884 L
.49517 .24183 L
.49758 .24332 L
.5 .24481 L
.5 .2478 L
.5 .25079 L
.5 .25377 L
.5 .25676 L
.5 .25974 L
.5 .26273 L
.5 .26572 L
.5 .2687 L
.5 .27169 L
.5 .27468 L
.5 .27766 L
.5 .28065 L
.50242 .28214 L
.50483 .28363 L
.50483 .28662 L
.50483 .28961 L
.50483 .29259 L
.50483 .29558 L
.50483 .29857 L
Mistroke
.50483 .30155 L
.50483 .30454 L
.50483 .30752 L
.50483 .31051 L
.50483 .3135 L
.50483 .31648 L
.50483 .31947 L
.50483 .32246 L
.50725 .32395 L
.50966 .32544 L
.50966 .32843 L
.50966 .33141 L
.50966 .3344 L
.50966 .33739 L
.50966 .34037 L
.50966 .34336 L
.50966 .34635 L
.50966 .34933 L
.50966 .35232 L
.50966 .3553 L
.50966 .35829 L
.50966 .36128 L
.50966 .36426 L
.50966 .36725 L
.50966 .37024 L
.50966 .37322 L
.50966 .37621 L
.51208 .3777 L
.5145 .37919 L
.5145 .38218 L
.5145 .38517 L
.5145 .38815 L
.5145 .39114 L
.5145 .39413 L
.5145 .39711 L
.5145 .4001 L
.5145 .40308 L
.5145 .40607 L
.5145 .40906 L
.5145 .41204 L
.5145 .41503 L
.5145 .41802 L
.5145 .421 L
.5145 .42399 L
.5145 .42697 L
.5145 .42996 L
.5145 .43295 L
.5145 .43593 L
.5145 .43892 L
.5145 .44191 L
Mistroke
.51691 .4434 L
.51933 .44489 L
.51933 .44788 L
.51933 .45086 L
.51933 .45385 L
.51933 .45684 L
.51933 .45982 L
.51933 .46281 L
.51933 .4658 L
.51933 .46878 L
.51933 .47177 L
.51933 .47475 L
.51933 .47774 L
.51933 .48073 L
.51933 .48371 L
.51933 .4867 L
.51933 .48969 L
.51933 .49267 L
.51933 .49566 L
.51933 .49864 L
.51933 .50163 L
.51933 .50462 L
.51933 .5076 L
.51933 .51059 L
.51933 .51358 L
.51933 .51656 L
.51933 .51955 L
.51933 .52253 L
.52174 .52403 L
.52416 .52552 L
.52416 .52851 L
.52416 .53149 L
.52416 .53448 L
.52416 .53747 L
.52416 .54045 L
.52416 .54344 L
.52416 .54642 L
.52416 .54941 L
.52416 .5524 L
.52416 .55538 L
.52416 .55837 L
.52416 .56135 L
.52416 .56434 L
.52416 .56733 L
.52416 .57031 L
.52416 .5733 L
.52416 .57629 L
.52416 .57927 L
.52416 .58226 L
.52416 .58524 L
Mistroke
.52416 .58823 L
.52416 .59122 L
.52416 .5942 L
.52416 .59719 L
.52416 .60018 L
.52416 .60316 L
.52416 .60615 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000LOol3000YOol30003Ool00`00Ool00004000SOol30003Ool00`00
Oomoo`03Ool00`00Oomoo`0ROol30003Ool00`00Oomoo`03000UOol30003Ool00`00Oomoo`03000Y
Ool3000>Ool001]oo`05001oogooOol0000WOol01@00Oomoogoo00001Goo00@007ooOol0029oo`05
001oogooOol00008Ool00`00Oomoo`0QOol01@00Oomoogoo000017oo00D007ooOomoo`0002=oo`05
001oogooOol00004Ool01@00Oomoogoo0000:Goo00<007ooOol03Goo000KOol01@00Oomoogoo0000
9goo00D007ooOomoo`0000Ioo`03001oogoo029oo`05001oogooOol00004Ool6000ROol01@00Oomo
ogoo000017oo00D007ooOomoo`0002=oo`05001oogooOol00004Ool01@00Oomoogoo0000:Goo00<0
07ooOol03Goo000KOol01@00Oomoogoo00009goo00D007ooOomoo`0000Moo`03001oogoo025oo`05
001oogooOol00004Ool01@00Oomoogoo00008goo00D007ooOomoo`0000Aoo`05001oogooOol0000S
Ool01@00Oomoogoo00001Goo00<007oo0000:Woo00<007ooOol03Goo000KOol01@00Oomoogoo0000
9goo00D007ooOomoo`0000Qoo`03001oogoo021oo`05001oogooOol00005Ool01000Oomoo`008goo
00D007ooOomoo`0000Aoo`80009oo`03001oogoo025oo`05001oogooOol00006Ool00`00Oomoo`0Y
Ool00`00Oomoo`0=Ool001]oo`05001oogooOol0000WOol01@00Oomoogoo000027oo00<007ooOol0
87oo00D007ooOomoo`0000Ioo`03001oo`0002=oo`05001oogooOol00004Ool01000Ool0000097oo
00D007ooOomoo`0000Eoo`03001oo`0002Yoo`03001oogoo00eoo`006goo00D007ooOomoo`0002Mo
o`05001oogooOol00008Ool00`00Oomoo`0POol01@00Oomoogoo00001Woo00<007oo00008goo00D0
07ooOomoo`0000Eoo`03001oogoo02Aoo`05001oogooOol00004Ool01@00Oomoogoo0000:Goo00<0
07ooOol03Goo000KOol01@00Oomoogoo00009goo00D007ooOomoo`0000Aoo`05001oogooOol0000R
Ool01@00Oomoogoo00001goo0P008goo00D007ooOomoo`0000Ioo`03001oogoo02=oo`05001oogoo
Ool00004Ool01@00Oomoogoo0000:7oo0P003goo000LOol3000YOol30006Ool3000TOol30009Ool0
0`00Oomoo`0ROol30008Ool2000TOol30006Ool3000ZOol00`00Oomoo`0=Ool00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo000KOooi000<Ool001]oo`04001oogoo000;Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Ool0000<Ool001]o
o`04001oogoo000_Ool00`00Oomoo`0^Ool00`00Oomoo`0^Ool00`00Oomoo`0]Ool00`00Oomoo`0^
Ool00`00Ool0000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo
00<007ooOol02Woo000KOol00`00Oomoo`1EOol8002HOol00`00Oomoo`0:Ool001]oo`80045ooaD0
00MNm`<009Eoo`8000aoo`006goo00<007ooOol07Woo8P007Ukg1000Tgoo00<007ooOol02Woo000K
Ool00`00Oomoo`0?Ool?0013G_L2002BOol00`00Oomoo`0:Ool001]oo`03001oogoo009oo`d005AN
m`80091oo`03001oogoo00Yoo`006goo00<007ooOol00WooHUkg0P00Sgoo00<007ooOol02Woo000K
Ool00`00Oomoo`02OomTG_L00`00Oomoo`2<Ool00`00Oomoo`0:Ool001]oo`8000=oofENm`03001o
ogoo08Yoo`8000aoo`006goo00<007ooOol00WooIUkg00<007ooOol0RWoo00<007ooOol02Woo000K
Ool00`00Oomoo`02OomVG_L3002:Ool00`00Oomoo`0:Ool001]oo`03001oogoo009oofQNm`03001o
ogoo08Qoo`03001oogoo00Yoo`006goo00<007ooOol00WooJ5kg0P00RGoo00<007ooOol02Woo000K
Ool00`00Oomoo`02OomYG_L20028Ool00`00Oomoo`0:Ool001]oo`8000=oofYNm`8008Ioo`8000ao
o`006goo00<007ooOol00WooJekg00<007ooOol0QGoo00<007ooOol02Woo000KOol00`00Oomoo`02
Oom[G_L00`00Oomoo`25Ool00`00Oomoo`0:Ool001]oo`03001oogoo009oofaNm`03001oogoo08Ao
o`03001oogoo00Yoo`006goo00<007ooOol00WooK5kg00<007ooOol0Q7oo00<007ooOol02Woo000K
Ool00`00Oomoo`02Oom/G_L30024Ool00`00Oomoo`0:Ool001]oo`8000=oofiNm`03001oogoo085o
o`8000aoo`006goo00<007ooOol00WooKUkg00<007ooOol0PWoo00<007ooOol02Woo000KOol00`00
Oomoo`02Oom^G_L20023Ool00`00Oomoo`0:Ool000]oo`<000=oo`<000Moo`03001oogoo009oofmN
m`03001oogoo085oo`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03
001oogoo009oofmNm`03001oogoo085oo`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03
001oogoo00Aoo`03001oogoo009oofmNm`80089oo`03001oogoo00Yoo`0037oo00D007ooOomoo`00
00=oo`03001oogoo00Aoo`<0009oog1Nm`03001oogoo07moo`8000aoo`0037oo00D007ooOomoo`00
00=oo`03001oogoo00Aoo`03001oogoo009oog1Nm`03001oogoo081oo`03001oogoo00Yoo`0037oo
00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo009oog1Nm`03001oogoo081oo`03001o
ogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo009oog5Nm`03001o
ogoo07moo`03001oogoo00Yoo`002goo0P000goo00D007ooOomoo`0000Ioo`03001oogoo009oog5N
m`03001oogoo07moo`03001oogoo00Yoo`0037oo00<007ooOol00Woo0`001goo00<007ooOol00Woo
LEkg00<007ooOol0Ogoo00<007ooOol02Woo000KOol20003OomaG_L2001oOol2000<Ool001]oo`03
001oogoo009oog9Nm`03001oogoo07ioo`03001oogoo00Yoo`006goo00<007ooOol00WooLUkg00<0
07ooOol0OWoo00<007ooOol02Woo000KOol00`00Oomoo`02OombG_L00`00Oomoo`1nOol00`00Oomo
o`0:Ool001]oo`03001oogoo009oog9Nm`03001oogoo07ioo`03001oogoo00Yoo`006goo00<007oo
Ool00WooLUkg0P00Ogoo00<007ooOol02Woo000KOol20003OomdG_L00`00Oomoo`1kOol2000<Ool0
01]oo`03001oogoo009oogANm`03001oogoo07aoo`03001oogoo00Yoo`006goo00<007ooOol00Woo
M5kg00<007ooOol0O7oo00<007ooOol02Woo000KOol00`00Oomoo`02OomdG_L00`00Oomoo`1lOol0
0`00Oomoo`0:Ool001]oo`03001oogoo009oogANm`03001oogoo07aoo`03001oogoo00Yoo`006goo
00<007ooOol00WooM5kg0P00OGoo00<007ooOol02Woo000KOol20003OomeG_L00`00Oomoo`1jOol2
000<Ool001]oo`03001oogoo009oogENm`03001oogoo07]oo`03001oogoo00Yoo`006goo00<007oo
Ool00WooMEkg00<007ooOol0Ngoo00<007ooOol02Woo000KOol00`00Oomoo`02OomeG_L00`00Oomo
o`1kOol00`00Oomoo`0:Ool001]oo`03001oogoo009oogENm`03001oogoo07]oo`03001oogoo00Yo
o`006goo00<007ooOol00WooMEkg00<007ooOol0Ngoo00<007ooOol02Woo000KOol20003OomfG_L0
0`00Oomoo`1iOol2000<Ool001]oo`03001oogoo009oogINm`03001oogoo07Yoo`03001oogoo00Yo
o`006goo00<007ooOol00WooMUkg00<007ooOol0NWoo00<007ooOol02Woo000:Ool50002Ool30007
Ool00`00Oomoo`02OomfG_L00`00Oomoo`1jOol00`00Oomoo`0:Ool000]oo`06001oogoo001oo`00
0goo00<007ooOol017oo00<007ooOol00WooMUkg00<007ooOol0NWoo00<007ooOol02Woo000<Ool0
1@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol00WooMUkg00<007ooOol0NWoo00<007oo
Ool02Woo000=Ool01000Oomoo`000goo00<007ooOol017oo0`000WooMUkg00<007ooOol0NGoo0P00
37oo000>Ool00`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`02OomgG_L00`00Oomoo`1iOol0
0`00Oomoo`0:Ool000ioo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo009oogMNm`03001o
ogoo07Uoo`03001oogoo00Yoo`003Woo00<007oo00000goo00<007ooOol017oo00<007ooOol00Woo
Mekg00<007ooOol0NGoo00<007ooOol02Woo000:Ool01`00Oomoogoo001oo`0000=oo`03001oogoo
00Aoo`03001oogoo009oogMNm`03001oogoo07Uoo`03001oogoo00Yoo`002goo0`000goo0`001goo
00<007ooOol00WooMekg00<007ooOol0NGoo00<007ooOol02Woo000KOol20003OomgG_L00`00Oomo
o`1hOol2000<Ool001]oo`03001oogoo009oogMNm`03001oogoo07Uoo`03001oogoo00Yoo`006goo
00<007ooOol00WooMekg00<007ooOol0NGoo00<007ooOol02Woo000KOol00`00Oomoo`02OomgG_L0
0`00Oomoo`1iOol00`00Oomoo`0:Ool001]oo`03001oogoo009oogMNm`8007Yoo`03001oogoo00Yo
o`006goo00<007ooOol00WooN5kg00<007ooOol0N7oo00<007ooOol02Woo000KOol20003OomhG_L0
0`00Oomoo`1gOol2000<Ool001]oo`03001oogoo009oogQNm`03001oogoo07Qoo`03001oogoo00Yo
o`006goo00<007ooOol00WooN5kg00<007ooOol0N7oo00<007ooOol02Woo000KOol00`00Oomoo`02
OomhG_L00`00Oomoo`1hOol00`00Oomoo`0:Ool001]oo`03001oogoo009oogQNm`03001oogoo07Qo
o`03001oogoo00Yoo`006goo00<007ooOol00WooN5kg00<007ooOol0N7oo00<007ooOol02Woo000K
Ool20003OomhG_L00`00Oomoo`1gOol2000<Ool001]oo`03001oogoo009oogQNm`03001oogoo07Qo
o`03001oogoo00Yoo`006goo00<007ooOol00WooN5kg00<007ooOol0N7oo00<007ooOol02Woo000K
Ool00`00Oomoo`02OomiG_L2001hOol00`00Oomoo`0:Ool001]oo`03001oogoo009oogYNm`03001o
ogoo07Ioo`03001oogoo00Yoo`006goo00<007ooOol00WooNUkg00<007ooOol0MWoo00<007ooOol0
2Woo000KOol20003OomjG_L00`00Oomoo`1eOol2000<Ool001]oo`03001oogoo009oogYNm`03001o
ogoo07Ioo`03001oogoo00Yoo`006goo00<007ooOol00WooNUkg00<007ooOol0MWoo00<007ooOol0
2Woo000KOol00`00Oomoo`02OomjG_L00`00Oomoo`1fOol00`00Oomoo`0:Ool000Yoo`@000=oo`<0
00Moo`03001oogoo009oogYNm`03001oogoo07Ioo`03001oogoo00Yoo`003Woo00<007oo00000goo
00<007ooOol017oo00<007ooOol00WooNUkg00<007ooOol0MWoo00<007ooOol02Woo000>Ool00`00
Ool00003Ool00`00Oomoo`04Ool30002OomjG_L00`00Oomoo`1eOol2000<Ool000ioo`03001oo`00
00=oo`03001oogoo00Aoo`03001oogoo009oogYNm`03001oogoo07Ioo`03001oogoo00Yoo`0037oo
0P000Woo00D007ooOomoo`0000Ioo`03001oogoo009oogYNm`03001oogoo07Ioo`03001oogoo00Yo
o`003Goo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo009oogYNm`03001oogoo07Ioo`03
001oogoo00Yoo`003Woo00<007oo00000goo00<007ooOol017oo00<007ooOol00WooNUkg0P00Mgoo
00<007ooOol02Woo000:Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Aoo`03001oogoo009o
og]Nm`03001oogoo07Eoo`03001oogoo00Yoo`002goo0`000goo0`001goo00<007ooOol00WooNekg
00<007ooOol0MGoo00<007ooOol02Woo000KOol20003OomkG_L00`00Oomoo`1dOol2000<Ool001]o
o`03001oogoo009oog]Nm`03001oogoo07Eoo`03001oogoo00Yoo`006goo00<007ooOol00WooNekg
00<007ooOol0MGoo00<007ooOol02Woo000KOol00`00Oomoo`02OomkG_L00`00Oomoo`1eOol00`00
Oomoo`0:Ool001]oo`03001oogoo009oog]Nm`03001oogoo07Eoo`03001oogoo00Yoo`006goo00<0
07ooOol00WooNekg00<007ooOol0MGoo00<007ooOol02Woo000KOol20003OomkG_L00`00Oomoo`1d
Ool2000<Ool001]oo`03001oogoo009oog]Nm`03001oogoo07Eoo`03001oogoo00Yoo`006goo00<0
07ooOol00WooNekg00<007ooOol0MGoo00<007ooOol02Woo000KOol00`00Oomoo`02OomkG_L00`00
Oomoo`1eOol00`00Oomoo`0:Ool001]oo`03001oogoo009oog]Nm`03001oogoo07Eoo`03001oogoo
00Yoo`006goo00<007ooOol00WooNekg00<007ooOol0MGoo00<007ooOol02Woo000KOol20003Oomk
G_L00`00Oomoo`1dOol2000<Ool001]oo`03001oogoo009oog]Nm`03001oogoo07Eoo`03001oogoo
00Yoo`006goo00<007ooOol00WooO5kg00<007ooOol0M7oo00<007ooOol02Woo000KOol00`00Oomo
o`02OomlG_L00`00Oomoo`1dOol00`00Oomoo`0:Ool001]oo`03001oogoo009oogaNm`03001oogoo
07Aoo`03001oogoo00Yoo`006goo00<007ooOol00WooO5kg00<007ooOol0M7oo00<007ooOol02Woo
000KOol20003OomlG_L00`00Oomoo`1cOol2000<Ool001]oo`03001oogoo009oogaNm`03001oogoo
07Aoo`03001oogoo00Yoo`006goo00<007ooOol00WooO5kg00<007ooOol0M7oo00<007ooOol02Woo
000>Ool00`00Oomoo`030007Ool00`00Oomoo`02OomlG_L00`00Oomoo`1dOol00`00Oomoo`0:Ool0
00ioo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo009oogaNm`03001oogoo07Aoo`03001o
ogoo00Yoo`002Woo1`000goo00<007ooOol017oo00<007ooOol00WooO5kg00<007ooOol0M7oo00<0
07ooOol02Woo000:Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Aoo`<0009oogaNm`03001o
ogoo07=oo`8000aoo`002goo00H007ooOol007oo0003Ool00`00Oomoo`04Ool00`00Oomoo`02Ooml
G_L00`00Oomoo`1dOol00`00Oomoo`0:Ool000aoo`05001oo`00Ool00003Ool00`00Oomoo`04Ool0
0`00Oomoo`02OomlG_L00`00Oomoo`1dOol00`00Oomoo`0:Ool000aoo`05001oo`00Ool00003Ool0
0`00Oomoo`04Ool00`00Oomoo`02OomlG_L00`00Oomoo`1dOol00`00Oomoo`0:Ool000eoo`800003
Ool007oo009oo`03001oogoo00Aoo`03001oogoo009oogaNm`03001oogoo07Aoo`03001oogoo00Yo
o`003Woo00<007ooOol00`001goo00<007ooOol00WooO5kg00<007ooOol0M7oo00<007ooOol02Woo
000KOol20003OomlG_L00`00Oomoo`1cOol2000<Ool001]oo`03001oogoo009oogaNm`03001oogoo
07Aoo`03001oogoo00Yoo`006goo00<007ooOol00WooO5kg00<007ooOol0M7oo00<007ooOol02Woo
000KOol00`00Oomoo`02OomlG_L2001eOol00`00Oomoo`0:Ool001]oo`03001oogoo009oogeNm`03
001oogoo07=oo`03001oogoo00Yoo`006goo00<007ooOol00WooOEkg00<007ooOol0Lgoo00<007oo
Ool02Woo000KOol20003OommG_L00`00Oomoo`1bOol2000<Ool001]oo`03001oogoo009oogeNm`03
001oogoo07=oo`03001oogoo00Yoo`006goo00<007ooOol00WooOEkg00<007ooOol0Lgoo00<007oo
Ool02Woo000KOol00`00Oomoo`02OommG_L00`00Oomoo`1cOol00`00Oomoo`0:Ool001]oo`03001o
ogoo009oogeNm`03001oogoo07=oo`03001oogoo00Yoo`006goo00<007ooOol00WooOEkg00<007oo
Ool0Lgoo00<007ooOol02Woo000KOol20003OommG_L00`00Oomoo`1bOol2000<Ool001]oo`03001o
ogoo009oogeNm`03001oogoo07=oo`03001oogoo00Yoo`006goo00<007ooOol00WooOEkg00<007oo
Ool0Lgoo00<007ooOol02Woo000KOol00`00Oomoo`02OommG_L00`00Oomoo`1cOol00`00Oomoo`0:
Ool001]oo`03001oogoo009oogeNm`03001oogoo07=oo`03001oogoo00Yoo`006goo00<007ooOol0
0WooOEkg00<007ooOol0Lgoo00<007ooOol02Woo000KOol20003OommG_L00`00Oomoo`1bOol2000<
Ool001]oo`03001oogoo009oogeNm`03001oogoo07=oo`03001oogoo00Yoo`006goo00<007ooOol0
0WooOEkg00<007ooOol0Lgoo00<007ooOol02Woo000:Ool30004Ool30007Ool00`00Oomoo`02Oomm
G_L00`00Oomoo`1cOol00`00Oomoo`0:Ool000eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00
Oomoo`02OommG_L00`00Oomoo`1cOol00`00Oomoo`0:Ool000ioo`03001oo`0000=oo`03001oogoo
00Aoo`03001oogoo009oogeNm`03001oogoo07=oo`03001oogoo00Yoo`003Woo00<007oo00000goo
00<007ooOol017oo0`000WooOEkg00<007ooOol0LWoo0P0037oo000>Ool00`00Ool00003Ool00`00
Oomoo`04Ool01000Oomoo`00;goo00<007ooOol0;Woo00<007ooOol0;Woo00<007ooOol0;Goo00<0
07ooOol0;Woo00<007oo000037oo000=Ool01000Oomoo`000goo00<007ooOol017oo00@007ooOol0
00]oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oo`00
00aoo`002goo0P000goo00D007ooOomoo`0000IoooT000aoo`002goo00<007ooOol00Woo00D007oo
Oomoo`000?moo`aoo`0037oo0`000Woo0`00ogoo3Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.123594, -6.21594, \
0.00411023, 0.332456}}],

Cell[BoxData[
    \(0.1`\)], "Print"],

Cell[BoxData[
    \(Graphics::"realu" \(\(:\)\(\ \)\) 
      "Argument in \!\(GrayLevel[1.0575`]\) is not a real number between 0 \
and 1."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00941915 0.981162 -0.000366335 0.0121303 [
[.00942 -0.0125 -5 -15.6875 ]
[.00942 -0.0125 5 0 ]
[.20565 -0.0125 -9.5 -15.6875 ]
[.20565 -0.0125 9.5 0 ]
[.40188 -0.0125 -9.5 -15.6875 ]
[.40188 -0.0125 9.5 0 ]
[.59812 -0.0125 -9.5 -15.6875 ]
[.59812 -0.0125 9.5 0 ]
[.79435 -0.0125 -9.5 -15.6875 ]
[.79435 -0.0125 9.5 0 ]
[.99058 -0.0125 -5 -15.6875 ]
[.99058 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12094 -16 -7.84375 ]
[-0.0125 .12094 0 7.84375 ]
[-0.0125 .24224 -16 -7.84375 ]
[-0.0125 .24224 0 7.84375 ]
[-0.0125 .36354 -16 -7.84375 ]
[-0.0125 .36354 0 7.84375 ]
[-0.0125 .48485 -16 -7.84375 ]
[-0.0125 .48485 0 7.84375 ]
[-0.0125 .60615 -16 -7.84375 ]
[-0.0125 .60615 0 7.84375 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00942 0 m
.00942 .00625 L
s
gsave
.00942 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20565 0 m
.20565 .00625 L
s
gsave
.20565 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40188 0 m
.40188 .00625 L
s
gsave
.40188 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59812 0 m
.59812 .00625 L
s
gsave
.59812 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.79435 0 m
.79435 .00625 L
s
gsave
.79435 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.99058 0 m
.99058 .00625 L
s
gsave
.99058 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05848 0 m
.05848 .00375 L
s
.10754 0 m
.10754 .00375 L
s
.15659 0 m
.15659 .00375 L
s
.25471 0 m
.25471 .00375 L
s
.30377 0 m
.30377 .00375 L
s
.35283 0 m
.35283 .00375 L
s
.45094 0 m
.45094 .00375 L
s
.5 0 m
.5 .00375 L
s
.54906 0 m
.54906 .00375 L
s
.64717 0 m
.64717 .00375 L
s
.69623 0 m
.69623 .00375 L
s
.74529 0 m
.74529 .00375 L
s
.84341 0 m
.84341 .00375 L
s
.89246 0 m
.89246 .00375 L
s
.94152 0 m
.94152 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12094 m
.00625 .12094 L
s
gsave
-0.0125 .12094 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .24224 m
.00625 .24224 L
s
gsave
-0.0125 .24224 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .36354 m
.00625 .36354 L
s
gsave
-0.0125 .36354 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .48485 m
.00625 .48485 L
s
gsave
-0.0125 .48485 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .60615 m
.00625 .60615 L
s
gsave
-0.0125 .60615 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02389 m
.00375 .02389 L
s
0 .04815 m
.00375 .04815 L
s
0 .07242 m
.00375 .07242 L
s
0 .09668 m
.00375 .09668 L
s
0 .1452 m
.00375 .1452 L
s
0 .16946 m
.00375 .16946 L
s
0 .19372 m
.00375 .19372 L
s
0 .21798 m
.00375 .21798 L
s
0 .2665 m
.00375 .2665 L
s
0 .29076 m
.00375 .29076 L
s
0 .31502 m
.00375 .31502 L
s
0 .33928 m
.00375 .33928 L
s
0 .3878 m
.00375 .3878 L
s
0 .41206 m
.00375 .41206 L
s
0 .43632 m
.00375 .43632 L
s
0 .46059 m
.00375 .46059 L
s
0 .50911 m
.00375 .50911 L
s
0 .53337 m
.00375 .53337 L
s
0 .55763 m
.00375 .55763 L
s
0 .58189 m
.00375 .58189 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00942 .61178 m
.00942 .61803 L
s
.20565 .61178 m
.20565 .61803 L
s
.40188 .61178 m
.40188 .61803 L
s
.59812 .61178 m
.59812 .61803 L
s
.79435 .61178 m
.79435 .61803 L
s
.99058 .61178 m
.99058 .61803 L
s
.125 Mabswid
.05848 .61428 m
.05848 .61803 L
s
.10754 .61428 m
.10754 .61803 L
s
.15659 .61428 m
.15659 .61803 L
s
.25471 .61428 m
.25471 .61803 L
s
.30377 .61428 m
.30377 .61803 L
s
.35283 .61428 m
.35283 .61803 L
s
.45094 .61428 m
.45094 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54906 .61428 m
.54906 .61803 L
s
.64717 .61428 m
.64717 .61803 L
s
.69623 .61428 m
.69623 .61803 L
s
.74529 .61428 m
.74529 .61803 L
s
.84341 .61428 m
.84341 .61803 L
s
.89246 .61428 m
.89246 .61803 L
s
.94152 .61428 m
.94152 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12094 m
1 .12094 L
s
.99375 .24224 m
1 .24224 L
s
.99375 .36354 m
1 .36354 L
s
.99375 .48485 m
1 .48485 L
s
.99375 .60615 m
1 .60615 L
s
.125 Mabswid
.99625 .02389 m
1 .02389 L
s
.99625 .04815 m
1 .04815 L
s
.99625 .07242 m
1 .07242 L
s
.99625 .09668 m
1 .09668 L
s
.99625 .1452 m
1 .1452 L
s
.99625 .16946 m
1 .16946 L
s
.99625 .19372 m
1 .19372 L
s
.99625 .21798 m
1 .21798 L
s
.99625 .2665 m
1 .2665 L
s
.99625 .29076 m
1 .29076 L
s
.99625 .31502 m
1 .31502 L
s
.99625 .33928 m
1 .33928 L
s
.99625 .3878 m
1 .3878 L
s
.99625 .41206 m
1 .41206 L
s
.99625 .43632 m
1 .43632 L
s
.99625 .46059 m
1 .46059 L
s
.99625 .50911 m
1 .50911 L
s
.99625 .53337 m
1 .53337 L
s
.99625 .55763 m
1 .55763 L
s
.99625 .58189 m
1 .58189 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 g
.01923 .60615 m
.98077 .60615 L
.98077 .01189 L
.01923 .01189 L
F
0 g
.5 Mabswid
.742 g
.01923 .19853 m
.02082 .19703 L
.02082 .19405 L
.02082 .19106 L
.02082 .18807 L
.02082 .18509 L
.02082 .1821 L
.02082 .17912 L
.02082 .17613 L
.02082 .17314 L
.02082 .17016 L
.02082 .16717 L
.02406 .16568 L
.02648 .16418 L
.02648 .1612 L
.02648 .15821 L
.02648 .15523 L
.02648 .15224 L
.02648 .14925 L
.02889 .14776 L
.03131 .14627 L
.03131 .14328 L
.03131 .14029 L
.03131 .13731 L
.03131 .13432 L
.03373 .13283 L
.03614 .13134 L
.03614 .12835 L
.03614 .12536 L
.03856 .12387 L
.04097 .12238 L
.04097 .11939 L
.04097 .1164 L
.04339 .11491 L
.04581 .11342 L
.04581 .11043 L
.04822 .10894 L
.05064 .10745 L
.05064 .10446 L
.05305 .10297 L
.05547 .10147 L
.05547 .09849 L
.05789 .09699 L
.0603 .0955 L
.06272 .09401 L
.06513 .09251 L
.06513 .08953 L
.06755 .08803 L
.06997 .08654 L
.07238 .08505 L
.0748 .08356 L
.07721 .08206 L
.07963 .08057 L
.08204 .07908 L
.08446 .07758 L
.08688 .07609 L
.08929 .0746 L
.09171 .0731 L
.09412 .07161 L
.09654 .07012 L
.10137 .07012 L
.10379 .06862 L
.1062 .06713 L
.10862 .06564 L
.11104 .06414 L
.11587 .06414 L
.11828 .06265 L
.1207 .06116 L
.12553 .06116 L
.12795 .05967 L
.13036 .05817 L
.1352 .05817 L
.13761 .05668 L
.14003 .05519 L
.14486 .05519 L
.14727 .05369 L
.14969 .0522 L
.15452 .0522 L
.15935 .0522 L
.16177 .05071 L
.16419 .04921 L
.16902 .04921 L
.17385 .04921 L
.17627 .04772 L
.17868 .04623 L
.18351 .04623 L
.18835 .04623 L
.19076 .04473 L
.19318 .04324 L
.19801 .04324 L
.20284 .04324 L
.20526 .04175 L
.20767 .04025 L
.2125 .04025 L
.21734 .04025 L
.22217 .04025 L
.227 .04025 L
.22942 .03876 L
.23183 .03727 L
.23666 .03727 L
.2415 .03727 L
.24633 .03727 L
.24874 .03578 L
.25116 .03428 L
.25599 .03428 L
.26082 .03428 L
.26566 .03428 L
.27049 .03428 L
.27532 .03428 L
.27773 .03279 L
.28015 .0313 L
.28498 .0313 L
.28981 .0313 L
.29465 .0313 L
.29948 .0313 L
.30431 .0313 L
.30673 .0298 L
.30914 .02831 L
.31397 .02831 L
.31881 .02831 L
.32364 .02831 L
.32847 .02831 L
.3333 .02831 L
.33813 .02831 L
.34296 .02831 L
.34538 .02682 L
.3478 .02532 L
.35263 .02532 L
.35746 .02532 L
.36229 .02532 L
.36712 .02532 L
.37196 .02532 L
.37679 .02532 L
.38162 .02532 L
.38404 .02682 L
.38645 .02831 L
.38887 .0298 L
.39128 .0313 L
.3937 .03279 L
.39612 .03428 L
.39853 .03578 L
.40095 .03727 L
.40336 .03876 L
.40336 .04175 L
.40578 .04324 L
.40819 .04473 L
.40819 .04772 L
.41061 .04921 L
.41303 .05071 L
.41303 .05369 L
.41544 .05519 L
.41786 .05668 L
.41786 .05967 L
.42027 .06116 L
.42269 .06265 L
.42269 .06564 L
.42269 .06862 L
.42511 .07012 L
.42752 .07161 L
.42752 .0746 L
.42752 .07758 L
.42994 .07908 L
.43235 .08057 L
.43235 .08356 L
.43235 .08654 L
.43477 .08803 L
.43719 .08953 L
.43719 .09251 L
.43719 .0955 L
.43719 .09849 L
.43719 .10147 L
.4396 .10297 L
.44202 .10446 L
.44202 .10745 L
.44202 .11043 L
.44202 .11342 L
.44202 .1164 L
.44443 .1179 L
.44685 .11939 L
.44685 .12238 L
.44685 .12536 L
.44685 .12835 L
.44685 .13134 L
.44685 .13432 L
.44927 .13581 L
.45168 .13731 L
.45168 .14029 L
.45168 .14328 L
.45168 .14627 L
.45168 .14925 L
.45168 .15224 L
.45168 .15523 L
.4541 .15672 L
.45651 .15821 L
.45651 .1612 L
.45651 .16418 L
.45651 .16717 L
.45651 .17016 L
.45651 .17314 L
.45651 .17613 L
.45651 .17912 L
.45893 .18061 L
.46135 .1821 L
.46135 .18509 L
.46135 .18807 L
.46135 .19106 L
.46135 .19405 L
.46135 .19703 L
.46135 .20002 L
.46135 .20301 L
.46135 .20599 L
.46135 .20898 L
.46376 .21047 L
.46618 .21196 L
.46618 .21495 L
.46618 .21794 L
.46618 .22092 L
.46618 .22391 L
.46618 .2269 L
.46618 .22988 L
.46618 .23287 L
.46618 .23585 L
.46618 .23884 L
.46618 .24183 L
.46618 .24481 L
.46859 .24631 L
.47101 .2478 L
.47101 .25079 L
.47101 .25377 L
.47101 .25676 L
.47101 .25974 L
.47101 .26273 L
.47101 .26572 L
.47101 .2687 L
.47101 .27169 L
.47101 .27468 L
.47101 .27766 L
.47101 .28065 L
.47101 .28363 L
.47101 .28662 L
.47342 .28811 L
.47584 .28961 L
.47584 .29259 L
.47584 .29558 L
.47584 .29857 L
.47584 .30155 L
.47584 .30454 L
.47584 .30752 L
.47584 .31051 L
.47584 .3135 L
.47584 .31648 L
.47584 .31947 L
.47584 .32246 L
.47584 .32544 L
.47584 .32843 L
.47584 .33141 L
.47584 .3344 L
.47584 .33739 L
.47826 .33888 L
.48067 .34037 L
.48067 .34336 L
.48067 .34635 L
.48067 .34933 L
.48067 .35232 L
.48067 .3553 L
.48067 .35829 L
.48067 .36128 L
.48067 .36426 L
.48067 .36725 L
.48067 .37024 L
.48067 .37322 L
.48067 .37621 L
.48067 .37919 L
.48067 .38218 L
.48067 .38517 L
.48067 .38815 L
.48067 .39114 L
.48067 .39413 L
.48067 .39711 L
.48067 .4001 L
.48309 .40159 L
.4855 .40308 L
.4855 .40607 L
.4855 .40906 L
.4855 .41204 L
.4855 .41503 L
.4855 .41802 L
.4855 .421 L
.4855 .42399 L
.4855 .42697 L
.4855 .42996 L
.4855 .43295 L
.4855 .43593 L
.4855 .43892 L
.4855 .44191 L
.4855 .44489 L
.4855 .44788 L
.4855 .45086 L
.4855 .45385 L
.4855 .45684 L
.4855 .45982 L
.4855 .46281 L
.4855 .4658 L
.4855 .46878 L
.4855 .47177 L
.4855 .47475 L
.48792 .47625 L
.49034 .47774 L
.49034 .48073 L
.49034 .48371 L
.49034 .4867 L
.49034 .48969 L
.49034 .49267 L
.49034 .49566 L
.49034 .49864 L
.49034 .50163 L
.49034 .50462 L
.49034 .5076 L
.49034 .51059 L
.49034 .51358 L
.49034 .51656 L
.49034 .51955 L
.49034 .52253 L
.49034 .52552 L
.49034 .52851 L
.49034 .53149 L
.49034 .53448 L
.49034 .53747 L
.49034 .54045 L
.49034 .54344 L
.49034 .54642 L
.49034 .54941 L
.49034 .5524 L
.49034 .55538 L
.49034 .55837 L
.49034 .56135 L
.49034 .56434 L
.49034 .56733 L
.49275 .56882 L
.49517 .57031 L
.49517 .5733 L
.49517 .57629 L
.49517 .57927 L
.49517 .58226 L
.49517 .58524 L
.49517 .58823 L
.49517 .59122 L
.49517 .5942 L
.49517 .59719 L
.49517 .60018 L
.49517 .60316 L
.49517 .60615 L
.01923 .60615 L
F
0 g
.01923 .19853 m
.02082 .19703 L
.02082 .19405 L
.02082 .19106 L
.02082 .18807 L
.02082 .18509 L
.02082 .1821 L
.02082 .17912 L
.02082 .17613 L
.02082 .17314 L
.02082 .17016 L
.02082 .16717 L
.02406 .16568 L
.02648 .16418 L
.02648 .1612 L
.02648 .15821 L
.02648 .15523 L
.02648 .15224 L
.02648 .14925 L
.02889 .14776 L
.03131 .14627 L
.03131 .14328 L
.03131 .14029 L
.03131 .13731 L
.03131 .13432 L
.03373 .13283 L
.03614 .13134 L
.03614 .12835 L
.03614 .12536 L
.03856 .12387 L
.04097 .12238 L
.04097 .11939 L
.04097 .1164 L
.04339 .11491 L
.04581 .11342 L
.04581 .11043 L
.04822 .10894 L
.05064 .10745 L
.05064 .10446 L
.05305 .10297 L
.05547 .10147 L
.05547 .09849 L
.05789 .09699 L
.0603 .0955 L
.06272 .09401 L
.06513 .09251 L
.06513 .08953 L
.06755 .08803 L
.06997 .08654 L
.07238 .08505 L
Mistroke
.0748 .08356 L
.07721 .08206 L
.07963 .08057 L
.08204 .07908 L
.08446 .07758 L
.08688 .07609 L
.08929 .0746 L
.09171 .0731 L
.09412 .07161 L
.09654 .07012 L
.10137 .07012 L
.10379 .06862 L
.1062 .06713 L
.10862 .06564 L
.11104 .06414 L
.11587 .06414 L
.11828 .06265 L
.1207 .06116 L
.12553 .06116 L
.12795 .05967 L
.13036 .05817 L
.1352 .05817 L
.13761 .05668 L
.14003 .05519 L
.14486 .05519 L
.14727 .05369 L
.14969 .0522 L
.15452 .0522 L
.15935 .0522 L
.16177 .05071 L
.16419 .04921 L
.16902 .04921 L
.17385 .04921 L
.17627 .04772 L
.17868 .04623 L
.18351 .04623 L
.18835 .04623 L
.19076 .04473 L
.19318 .04324 L
.19801 .04324 L
.20284 .04324 L
.20526 .04175 L
.20767 .04025 L
.2125 .04025 L
.21734 .04025 L
.22217 .04025 L
.227 .04025 L
.22942 .03876 L
.23183 .03727 L
.23666 .03727 L
Mistroke
.2415 .03727 L
.24633 .03727 L
.24874 .03578 L
.25116 .03428 L
.25599 .03428 L
.26082 .03428 L
.26566 .03428 L
.27049 .03428 L
.27532 .03428 L
.27773 .03279 L
.28015 .0313 L
.28498 .0313 L
.28981 .0313 L
.29465 .0313 L
.29948 .0313 L
.30431 .0313 L
.30673 .0298 L
.30914 .02831 L
.31397 .02831 L
.31881 .02831 L
.32364 .02831 L
.32847 .02831 L
.3333 .02831 L
.33813 .02831 L
.34296 .02831 L
.34538 .02682 L
.3478 .02532 L
.35263 .02532 L
.35746 .02532 L
.36229 .02532 L
.36712 .02532 L
.37196 .02532 L
.37679 .02532 L
.38162 .02532 L
.38404 .02682 L
.38645 .02831 L
.38887 .0298 L
.39128 .0313 L
.3937 .03279 L
.39612 .03428 L
.39853 .03578 L
.40095 .03727 L
.40336 .03876 L
.40336 .04175 L
.40578 .04324 L
.40819 .04473 L
.40819 .04772 L
.41061 .04921 L
.41303 .05071 L
.41303 .05369 L
Mistroke
.41544 .05519 L
.41786 .05668 L
.41786 .05967 L
.42027 .06116 L
.42269 .06265 L
.42269 .06564 L
.42269 .06862 L
.42511 .07012 L
.42752 .07161 L
.42752 .0746 L
.42752 .07758 L
.42994 .07908 L
.43235 .08057 L
.43235 .08356 L
.43235 .08654 L
.43477 .08803 L
.43719 .08953 L
.43719 .09251 L
.43719 .0955 L
.43719 .09849 L
.43719 .10147 L
.4396 .10297 L
.44202 .10446 L
.44202 .10745 L
.44202 .11043 L
.44202 .11342 L
.44202 .1164 L
.44443 .1179 L
.44685 .11939 L
.44685 .12238 L
.44685 .12536 L
.44685 .12835 L
.44685 .13134 L
.44685 .13432 L
.44927 .13581 L
.45168 .13731 L
.45168 .14029 L
.45168 .14328 L
.45168 .14627 L
.45168 .14925 L
.45168 .15224 L
.45168 .15523 L
.4541 .15672 L
.45651 .15821 L
.45651 .1612 L
.45651 .16418 L
.45651 .16717 L
.45651 .17016 L
.45651 .17314 L
.45651 .17613 L
Mistroke
.45651 .17912 L
.45893 .18061 L
.46135 .1821 L
.46135 .18509 L
.46135 .18807 L
.46135 .19106 L
.46135 .19405 L
.46135 .19703 L
.46135 .20002 L
.46135 .20301 L
.46135 .20599 L
.46135 .20898 L
.46376 .21047 L
.46618 .21196 L
.46618 .21495 L
.46618 .21794 L
.46618 .22092 L
.46618 .22391 L
.46618 .2269 L
.46618 .22988 L
.46618 .23287 L
.46618 .23585 L
.46618 .23884 L
.46618 .24183 L
.46618 .24481 L
.46859 .24631 L
.47101 .2478 L
.47101 .25079 L
.47101 .25377 L
.47101 .25676 L
.47101 .25974 L
.47101 .26273 L
.47101 .26572 L
.47101 .2687 L
.47101 .27169 L
.47101 .27468 L
.47101 .27766 L
.47101 .28065 L
.47101 .28363 L
.47101 .28662 L
.47342 .28811 L
.47584 .28961 L
.47584 .29259 L
.47584 .29558 L
.47584 .29857 L
.47584 .30155 L
.47584 .30454 L
.47584 .30752 L
.47584 .31051 L
.47584 .3135 L
Mistroke
.47584 .31648 L
.47584 .31947 L
.47584 .32246 L
.47584 .32544 L
.47584 .32843 L
.47584 .33141 L
.47584 .3344 L
.47584 .33739 L
.47826 .33888 L
.48067 .34037 L
.48067 .34336 L
.48067 .34635 L
.48067 .34933 L
.48067 .35232 L
.48067 .3553 L
.48067 .35829 L
.48067 .36128 L
.48067 .36426 L
.48067 .36725 L
.48067 .37024 L
.48067 .37322 L
.48067 .37621 L
.48067 .37919 L
.48067 .38218 L
.48067 .38517 L
.48067 .38815 L
.48067 .39114 L
.48067 .39413 L
.48067 .39711 L
.48067 .4001 L
.48309 .40159 L
.4855 .40308 L
.4855 .40607 L
.4855 .40906 L
.4855 .41204 L
.4855 .41503 L
.4855 .41802 L
.4855 .421 L
.4855 .42399 L
.4855 .42697 L
.4855 .42996 L
.4855 .43295 L
.4855 .43593 L
.4855 .43892 L
.4855 .44191 L
.4855 .44489 L
.4855 .44788 L
.4855 .45086 L
.4855 .45385 L
.4855 .45684 L
Mistroke
.4855 .45982 L
.4855 .46281 L
.4855 .4658 L
.4855 .46878 L
.4855 .47177 L
.4855 .47475 L
.48792 .47625 L
.49034 .47774 L
.49034 .48073 L
.49034 .48371 L
.49034 .4867 L
.49034 .48969 L
.49034 .49267 L
.49034 .49566 L
.49034 .49864 L
.49034 .50163 L
.49034 .50462 L
.49034 .5076 L
.49034 .51059 L
.49034 .51358 L
.49034 .51656 L
.49034 .51955 L
.49034 .52253 L
.49034 .52552 L
.49034 .52851 L
.49034 .53149 L
.49034 .53448 L
.49034 .53747 L
.49034 .54045 L
.49034 .54344 L
.49034 .54642 L
.49034 .54941 L
.49034 .5524 L
.49034 .55538 L
.49034 .55837 L
.49034 .56135 L
.49034 .56434 L
.49034 .56733 L
.49275 .56882 L
.49517 .57031 L
.49517 .5733 L
.49517 .57629 L
.49517 .57927 L
.49517 .58226 L
.49517 .58524 L
.49517 .58823 L
.49517 .59122 L
.49517 .5942 L
.49517 .59719 L
.49517 .60018 L
Mistroke
.49517 .60316 L
.49517 .60615 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000LOol3000YOol30003Ool00`00Ool00004000SOol30003Ool00`00
Oomoo`03Ool00`00Oomoo`0ROol30003Ool00`00Oomoo`03000UOol30003Ool00`00Oomoo`03000Y
Ool3000>Ool001]oo`05001oogooOol0000WOol01@00Oomoogoo00001Goo00@007ooOol0029oo`05
001oogooOol00008Ool00`00Oomoo`0QOol01@00Oomoogoo000017oo00D007ooOomoo`0002=oo`05
001oogooOol00004Ool01@00Oomoogoo0000:Goo00<007ooOol03Goo000KOol01@00Oomoogoo0000
9goo00D007ooOomoo`0000Ioo`03001oogoo029oo`05001oogooOol00004Ool6000ROol01@00Oomo
ogoo000017oo00D007ooOomoo`0002=oo`05001oogooOol00004Ool01@00Oomoogoo0000:Goo00<0
07ooOol03Goo000KOol01@00Oomoogoo00009goo00D007ooOomoo`0000Moo`03001oogoo025oo`05
001oogooOol00004Ool01@00Oomoogoo00008goo00D007ooOomoo`0000Aoo`05001oogooOol0000S
Ool01@00Oomoogoo00001Goo00<007oo0000:Woo00<007ooOol03Goo000KOol01@00Oomoogoo0000
9goo00D007ooOomoo`0000Qoo`03001oogoo021oo`05001oogooOol00005Ool01000Oomoo`008goo
00D007ooOomoo`0000Aoo`80009oo`03001oogoo025oo`05001oogooOol00006Ool00`00Oomoo`0Y
Ool00`00Oomoo`0=Ool001]oo`05001oogooOol0000WOol01@00Oomoogoo000027oo00<007ooOol0
87oo00D007ooOomoo`0000Ioo`03001oo`0002=oo`05001oogooOol00004Ool01000Ool0000097oo
00D007ooOomoo`0000Eoo`03001oo`0002Yoo`03001oogoo00eoo`006goo00D007ooOomoo`0002Mo
o`05001oogooOol00008Ool00`00Oomoo`0POol01@00Oomoogoo00001Woo00<007oo00008goo00D0
07ooOomoo`0000Eoo`03001oogoo02Aoo`05001oogooOol00004Ool01@00Oomoogoo0000:Goo00<0
07ooOol03Goo000KOol01@00Oomoogoo00009goo00D007ooOomoo`0000Aoo`05001oogooOol0000R
Ool01@00Oomoogoo00001goo0P008goo00D007ooOomoo`0000Ioo`03001oogoo02=oo`05001oogoo
Ool00004Ool01@00Oomoogoo0000:7oo0P003goo000LOol3000YOol30006Ool3000TOol30009Ool0
0`00Oomoo`0ROol30008Ool2000TOol30006Ool3000ZOol00`00Oomoo`0=Ool00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo000KOooi000<Ool001]oo`04001oogoo000;Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Ool0000<Ool001]o
o`04001oogoo000_Ool00`00Oomoo`0^Ool00`00Oomoo`0^Ool00`00Oomoo`0]Ool00`00Oomoo`0^
Ool00`00Ool0000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo
00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`800?Eoo`8000aoo`00
6goo00<007ooOol0BWoo5000Ugoo00<007ooOol02Woo000KOol00`00Oomoo`12Ool8000DG_L2002E
Ool00`00Oomoo`0:Ool001]oo`03001oogoo03]oo`P001aNm`8009Aoo`03001oogoo00Yoo`006goo
00<007ooOol0<Goo2P009Ukg00<007ooOol0TGoo00<007ooOol02Woo000KOol00`00Oomoo`0]Ool4
000`G_L2002BOol00`00Oomoo`0:Ool001]oo`8002Yoo`@003ENm`03001oogoo08moo`8000aoo`00
6goo00<007ooOol08Woo1`00>Ukg0P00T7oo00<007ooOol02Woo000KOol00`00Oomoo`0OOol40011
G_L2002?Ool00`00Oomoo`0:Ool001]oo`03001oogoo01eoo`<004ENm`03001oogoo08eoo`03001o
ogoo00Yoo`006goo00<007ooOol06Goo1000B5kg0P00SWoo00<007ooOol02Woo000KOol00`00Oomo
o`0GOol2001=G_L00`00Oomoo`2<Ool00`00Oomoo`0:Ool001]oo`8001Eoo`<0051Nm`03001oogoo
08Yoo`8000aoo`006goo00<007ooOol04goo00<005kgG_L0DEkg00<007ooOol0Rgoo00<007ooOol0
2Woo000KOol00`00Oomoo`0AOol2001DG_L2002<Ool00`00Oomoo`0:Ool001]oo`03001oogoo00mo
o`8005MNm`03001oogoo08Yoo`03001oogoo00Yoo`006goo00<007ooOol03Woo0P00F5kg0P00Rgoo
00<007ooOol02Woo000KOol00`00Oomoo`0=Ool00`00G_MNm`1JG_L00`00Oomoo`28Ool00`00Oomo
o`0:Ool001]oo`8000eoo`8005aNm`03001oogoo08Moo`8000aoo`006goo00<007ooOol02goo00<0
05kgG_L0G5kg00<007ooOol0R7oo00<007ooOol02Woo000KOol00`00Oomoo`0:Ool2001NG_L20029
Ool00`00Oomoo`0:Ool000]oo`<000=oo`<000Moo`03001oogoo00Uoo`80061Nm`03001oogoo08Mo
o`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Uoo`03
001Nmekg05mNm`03001oogoo08Moo`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03001o
ogoo00Aoo`03001oogoo00Moo`80069Nm`03001oogoo08Moo`03001oogoo00Yoo`0037oo00D007oo
Oomoo`0000=oo`03001oogoo00Aoo`<000Moo`03001Nmekg065Nm`8008Moo`8000aoo`0037oo00D0
07ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Ioo`8006ANm`03001oogoo08Ioo`03001o
ogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Ioo`03001Nmekg
06=Nm`03001oogoo08Ioo`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03001oogoo00Ao
o`03001oogoo00Ioo`03001Nmekg06=Nm`03001oogoo08Ioo`03001oogoo00Yoo`002goo0P000goo
00D007ooOomoo`0000Ioo`03001oogoo00Eoo`03001Nmekg06ANm`8008Moo`03001oogoo00Yoo`00
37oo00<007ooOol00Woo0`001goo00<007ooOol01Goo00<005kgG_L0IEkg00<007ooOol0QGoo00<0
07ooOol02Woo000KOol20006Ool00`00G_MNm`1UG_L00`00Oomoo`24Ool2000<Ool001]oo`03001o
ogoo00Aoo`8006MNm`03001oogoo08Eoo`03001oogoo00Yoo`006goo00<007ooOol017oo00<005kg
G_L0IUkg00<007ooOol0QGoo00<007ooOol02Woo000KOol00`00Oomoo`04Ool00`00G_MNm`1VG_L2
0026Ool00`00Oomoo`0:Ool001]oo`03001oogoo00Aoo`03001Nmekg06MNm`03001oogoo08Aoo`03
001oogoo00Yoo`006goo00<007ooOol00goo0P00JEkg00<007ooOol0Q7oo00<007ooOol02Woo000K
Ool20003Ool00`00G_MNm`1YG_L00`00Oomoo`23Ool2000<Ool001]oo`03001oogoo009oo`03001N
mekg06UNm`03001oogoo08Aoo`03001oogoo00Yoo`006goo00<007ooOol00Woo00<005kgG_L0JEkg
00<007ooOol0Q7oo00<007ooOol02Woo000KOol00`00Oomoo`02Ool00`00G_MNm`1YG_L20025Ool0
0`00Oomoo`0:Ool001]oo`03001oogoo009oo`03001Nmekg06]Nm`03001oogoo089oo`03001oogoo
00Yoo`006goo00<007ooOol00Woo00<005kgG_L0Jekg00<007ooOol0PWoo00<007ooOol02Woo000K
Ool20003Ool00`00G_MNm`1[G_L00`00Oomoo`21Ool2000<Ool001]oo`03001oogoo009oo`03001N
mekg06]Nm`03001oogoo089oo`03001oogoo00Yoo`006goo00<007ooOol00Woo00<005kgG_L0Jekg
00<007ooOol0PWoo00<007ooOol02Woo000KOol00`00Oomoo`02Oom^G_L00`00Oomoo`22Ool00`00
Oomoo`0:Ool001]oo`03001oogoo009oofiNm`03001oogoo089oo`03001oogoo00Yoo`006goo00<0
07ooOol00WooKUkg0P00Pgoo00<007ooOol02Woo000KOol20003Oom_G_L00`00Oomoo`20Ool2000<
Ool001]oo`03001oogoo009oofmNm`03001oogoo085oo`03001oogoo00Yoo`006goo00<007ooOol0
0WooKekg00<007ooOol0PGoo00<007ooOol02Woo000:Ool50002Ool30007Ool00`00Oomoo`02Oom_
G_L00`00Oomoo`21Ool00`00Oomoo`0:Ool000]oo`06001oogoo001oo`000goo00<007ooOol017oo
00<007ooOol00WooKekg00<007ooOol0PGoo00<007ooOol02Woo000<Ool01@00Oomoogoo00000goo
00<007ooOol017oo00<007ooOol00WooKekg00<007ooOol0PGoo00<007ooOol02Woo000=Ool01000
Oomoo`000goo00<007ooOol017oo0`000WooKekg00<007ooOol0P7oo0P0037oo000>Ool00`00Ool0
0003Ool00`00Oomoo`04Ool00`00Oomoo`02Oom_G_L00`00Oomoo`21Ool00`00Oomoo`0:Ool000io
o`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo009oog1Nm`03001oogoo081oo`03001oogoo
00Yoo`003Woo00<007oo00000goo00<007ooOol017oo00<007ooOol00WooL5kg00<007ooOol0P7oo
00<007ooOol02Woo000:Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Aoo`03001oogoo009o
og1Nm`03001oogoo081oo`03001oogoo00Yoo`002goo0`000goo0`001goo00<007ooOol00WooL5kg
00<007ooOol0P7oo00<007ooOol02Woo000KOol20003Oom`G_L00`00Oomoo`1oOol2000<Ool001]o
o`03001oogoo009oog1Nm`03001oogoo081oo`03001oogoo00Yoo`006goo00<007ooOol00WooL5kg
00<007ooOol0P7oo00<007ooOol02Woo000KOol00`00Oomoo`02Oom`G_L00`00Oomoo`20Ool00`00
Oomoo`0:Ool001]oo`03001oogoo009oog1Nm`03001oogoo081oo`03001oogoo00Yoo`006goo00<0
07ooOol00WooL5kg00<007ooOol0P7oo00<007ooOol02Woo000KOol20003OomaG_L00`00Oomoo`1n
Ool2000<Ool001]oo`03001oogoo009oog5Nm`03001oogoo07moo`03001oogoo00Yoo`006goo00<0
07ooOol00WooLEkg00<007ooOol0Ogoo00<007ooOol02Woo000KOol00`00Oomoo`02OomaG_L00`00
Oomoo`1oOol00`00Oomoo`0:Ool001]oo`03001oogoo009oog5Nm`03001oogoo07moo`03001oogoo
00Yoo`006goo00<007ooOol00WooLEkg00<007ooOol0Ogoo00<007ooOol02Woo000KOol20003Ooma
G_L00`00Oomoo`1nOol2000<Ool001]oo`03001oogoo009oog5Nm`03001oogoo07moo`03001oogoo
00Yoo`006goo00<007ooOol00WooLEkg00<007ooOol0Ogoo00<007ooOol02Woo000KOol00`00Oomo
o`02OomaG_L00`00Oomoo`1oOol00`00Oomoo`0:Ool001]oo`03001oogoo009oog5Nm`03001oogoo
07moo`03001oogoo00Yoo`006goo00<007ooOol00WooLEkg00<007ooOol0Ogoo00<007ooOol02Woo
000KOol20003OomaG_L2001oOol2000<Ool001]oo`03001oogoo009oog9Nm`03001oogoo07ioo`03
001oogoo00Yoo`006goo00<007ooOol00WooLUkg00<007ooOol0OWoo00<007ooOol02Woo000KOol0
0`00Oomoo`02OombG_L00`00Oomoo`1nOol00`00Oomoo`0:Ool000Yoo`@000=oo`<000Moo`03001o
ogoo009oog9Nm`03001oogoo07ioo`03001oogoo00Yoo`003Woo00<007oo00000goo00<007ooOol0
17oo00<007ooOol00WooLUkg00<007ooOol0OWoo00<007ooOol02Woo000>Ool00`00Ool00003Ool0
0`00Oomoo`04Ool30002OombG_L00`00Oomoo`1mOol2000<Ool000ioo`03001oo`0000=oo`03001o
ogoo00Aoo`03001oogoo009oog9Nm`03001oogoo07ioo`03001oogoo00Yoo`0037oo0P000Woo00D0
07ooOomoo`0000Ioo`03001oogoo009oog9Nm`03001oogoo07ioo`03001oogoo00Yoo`003Goo00@0
07ooOol000=oo`03001oogoo00Aoo`03001oogoo009oog9Nm`03001oogoo07ioo`03001oogoo00Yo
o`003Woo00<007oo00000goo00<007ooOol017oo00<007ooOol00WooLUkg00<007ooOol0OWoo00<0
07ooOol02Woo000:Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Aoo`03001oogoo009oog9N
m`03001oogoo07ioo`03001oogoo00Yoo`002goo0`000goo0`001goo00<007ooOol00WooLUkg00<0
07ooOol0OWoo00<007ooOol02Woo000KOol20003OombG_L00`00Oomoo`1mOol2000<Ool001]oo`03
001oogoo009oog9Nm`03001oogoo07ioo`03001oogoo00Yoo`006goo00<007ooOol00WooLUkg00<0
07ooOol0OWoo00<007ooOol02Woo000KOol00`00Oomoo`02OombG_L3001nOol00`00Oomoo`0:Ool0
01]oo`03001oogoo009oogANm`03001oogoo07aoo`03001oogoo00Yoo`006goo00<007ooOol00Woo
M5kg00<007ooOol0O7oo00<007ooOol02Woo000KOol20003OomdG_L00`00Oomoo`1kOol2000<Ool0
01]oo`03001oogoo009oogANm`03001oogoo07aoo`03001oogoo00Yoo`006goo00<007ooOol00Woo
M5kg00<007ooOol0O7oo00<007ooOol02Woo000KOol00`00Oomoo`02OomdG_L00`00Oomoo`1lOol0
0`00Oomoo`0:Ool001]oo`03001oogoo009oogANm`03001oogoo07aoo`03001oogoo00Yoo`006goo
00<007ooOol00WooM5kg00<007ooOol0O7oo00<007ooOol02Woo000KOol20003OomdG_L00`00Oomo
o`1kOol2000<Ool001]oo`03001oogoo009oogANm`03001oogoo07aoo`03001oogoo00Yoo`006goo
00<007ooOol00WooM5kg00<007ooOol0O7oo00<007ooOol02Woo000KOol00`00Oomoo`02OomdG_L0
0`00Oomoo`1lOol00`00Oomoo`0:Ool001]oo`03001oogoo009oogANm`03001oogoo07aoo`03001o
ogoo00Yoo`006goo00<007ooOol00WooM5kg00<007ooOol0O7oo00<007ooOol02Woo000KOol20003
OomdG_L00`00Oomoo`1kOol2000<Ool001]oo`03001oogoo009oogANm`03001oogoo07aoo`03001o
ogoo00Yoo`006goo00<007ooOol00WooM5kg00<007ooOol0O7oo00<007ooOol02Woo000>Ool00`00
Oomoo`030007Ool00`00Oomoo`02OomdG_L00`00Oomoo`1lOol00`00Oomoo`0:Ool000ioo`03001o
o`0000=oo`03001oogoo00Aoo`03001oogoo009oogENm`03001oogoo07]oo`03001oogoo00Yoo`00
2Woo1`000goo00<007ooOol017oo00<007ooOol00WooMEkg00<007ooOol0Ngoo00<007ooOol02Woo
000:Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Aoo`<0009oogENm`03001oogoo07Yoo`80
00aoo`002goo00H007ooOol007oo0003Ool00`00Oomoo`04Ool00`00Oomoo`02OomeG_L00`00Oomo
o`1kOol00`00Oomoo`0:Ool000aoo`05001oo`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`02
OomeG_L00`00Oomoo`1kOol00`00Oomoo`0:Ool000aoo`05001oo`00Ool00003Ool00`00Oomoo`04
Ool00`00Oomoo`02OomeG_L00`00Oomoo`1kOol00`00Oomoo`0:Ool000eoo`800003Ool007oo009o
o`03001oogoo00Aoo`03001oogoo009oogENm`03001oogoo07]oo`03001oogoo00Yoo`003Woo00<0
07ooOol00`001goo00<007ooOol00WooMEkg00<007ooOol0Ngoo00<007ooOol02Woo000KOol20003
OomeG_L00`00Oomoo`1jOol2000<Ool001]oo`03001oogoo009oogENm`03001oogoo07]oo`03001o
ogoo00Yoo`006goo00<007ooOol00WooMEkg00<007ooOol0Ngoo00<007ooOol02Woo000KOol00`00
Oomoo`02OomeG_L00`00Oomoo`1kOol00`00Oomoo`0:Ool001]oo`03001oogoo009oogENm`03001o
ogoo07]oo`03001oogoo00Yoo`006goo00<007ooOol00WooMEkg00<007ooOol0Ngoo00<007ooOol0
2Woo000KOol20003OomeG_L00`00Oomoo`1jOol2000<Ool001]oo`03001oogoo009oogENm`03001o
ogoo07]oo`03001oogoo00Yoo`006goo00<007ooOol00WooMEkg00<007ooOol0Ngoo00<007ooOol0
2Woo000KOol00`00Oomoo`02OomeG_L00`00Oomoo`1kOol00`00Oomoo`0:Ool001]oo`03001oogoo
009oogENm`03001oogoo07]oo`03001oogoo00Yoo`006goo00<007ooOol00WooMEkg00<007ooOol0
Ngoo00<007ooOol02Woo000KOol20003OomeG_L00`00Oomoo`1jOol2000<Ool001]oo`03001oogoo
009oogENm`03001oogoo07]oo`03001oogoo00Yoo`006goo00<007ooOol00WooMEkg00<007ooOol0
Ngoo00<007ooOol02Woo000KOol00`00Oomoo`02OomfG_L00`00Oomoo`1jOol00`00Oomoo`0:Ool0
01]oo`03001oogoo009oogINm`03001oogoo07Yoo`03001oogoo00Yoo`006goo00<007ooOol00Woo
MUkg00<007ooOol0NWoo00<007ooOol02Woo000KOol20003OomfG_L00`00Oomoo`1iOol2000<Ool0
01]oo`03001oogoo009oogINm`03001oogoo07Yoo`03001oogoo00Yoo`006goo00<007ooOol00Woo
MUkg00<007ooOol0NWoo00<007ooOol02Woo000:Ool30004Ool30007Ool00`00Oomoo`02OomfG_L0
0`00Oomoo`1jOol00`00Oomoo`0:Ool000eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomo
o`02OomfG_L00`00Oomoo`1jOol00`00Oomoo`0:Ool000ioo`03001oo`0000=oo`03001oogoo00Ao
o`03001oogoo009oogINm`03001oogoo07Yoo`03001oogoo00Yoo`003Woo00<007oo00000goo00<0
07ooOol017oo0`000WooMUkg00<007ooOol0NGoo0P0037oo000>Ool00`00Ool00003Ool00`00Oomo
o`04Ool01000Oomoo`00;goo00<007ooOol0;Woo00<007ooOol0;Woo00<007ooOol0;Goo00<007oo
Ool0;Woo00<007oo000037oo000=Ool01000Oomoo`000goo00<007ooOol017oo00@007ooOol000]o
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oo`0000ao
o`002goo0P000goo00D007ooOomoo`0000IoooT000aoo`002goo00<007ooOol00Woo00D007ooOomo
o`000?moo`aoo`0037oo0`000Woo0`00ogoo3Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.123594, -6.21594, \
0.00411023, 0.332456}}],

Cell[BoxData[
    \(0.2`\)], "Print"],

Cell[BoxData[
    \(Graphics::"realu" \(\(:\)\(\ \)\) 
      "Argument in \!\(GrayLevel[1.0575`]\) is not a real number between 0 \
and 1."\)], "Message"],

Cell[BoxData[
    \(General::"stop" \(\(:\)\(\ \)\) 
      "Further output of \!\(Graphics :: \"realu\"\) will be suppressed \
during this calculation."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00941915 0.981162 -0.000366335 0.0121303 [
[.00942 -0.0125 -5 -15.6875 ]
[.00942 -0.0125 5 0 ]
[.20565 -0.0125 -9.5 -15.6875 ]
[.20565 -0.0125 9.5 0 ]
[.40188 -0.0125 -9.5 -15.6875 ]
[.40188 -0.0125 9.5 0 ]
[.59812 -0.0125 -9.5 -15.6875 ]
[.59812 -0.0125 9.5 0 ]
[.79435 -0.0125 -9.5 -15.6875 ]
[.79435 -0.0125 9.5 0 ]
[.99058 -0.0125 -5 -15.6875 ]
[.99058 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12094 -16 -7.84375 ]
[-0.0125 .12094 0 7.84375 ]
[-0.0125 .24224 -16 -7.84375 ]
[-0.0125 .24224 0 7.84375 ]
[-0.0125 .36354 -16 -7.84375 ]
[-0.0125 .36354 0 7.84375 ]
[-0.0125 .48485 -16 -7.84375 ]
[-0.0125 .48485 0 7.84375 ]
[-0.0125 .60615 -16 -7.84375 ]
[-0.0125 .60615 0 7.84375 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00942 0 m
.00942 .00625 L
s
gsave
.00942 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20565 0 m
.20565 .00625 L
s
gsave
.20565 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40188 0 m
.40188 .00625 L
s
gsave
.40188 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59812 0 m
.59812 .00625 L
s
gsave
.59812 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.79435 0 m
.79435 .00625 L
s
gsave
.79435 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.99058 0 m
.99058 .00625 L
s
gsave
.99058 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05848 0 m
.05848 .00375 L
s
.10754 0 m
.10754 .00375 L
s
.15659 0 m
.15659 .00375 L
s
.25471 0 m
.25471 .00375 L
s
.30377 0 m
.30377 .00375 L
s
.35283 0 m
.35283 .00375 L
s
.45094 0 m
.45094 .00375 L
s
.5 0 m
.5 .00375 L
s
.54906 0 m
.54906 .00375 L
s
.64717 0 m
.64717 .00375 L
s
.69623 0 m
.69623 .00375 L
s
.74529 0 m
.74529 .00375 L
s
.84341 0 m
.84341 .00375 L
s
.89246 0 m
.89246 .00375 L
s
.94152 0 m
.94152 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12094 m
.00625 .12094 L
s
gsave
-0.0125 .12094 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .24224 m
.00625 .24224 L
s
gsave
-0.0125 .24224 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .36354 m
.00625 .36354 L
s
gsave
-0.0125 .36354 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .48485 m
.00625 .48485 L
s
gsave
-0.0125 .48485 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .60615 m
.00625 .60615 L
s
gsave
-0.0125 .60615 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02389 m
.00375 .02389 L
s
0 .04815 m
.00375 .04815 L
s
0 .07242 m
.00375 .07242 L
s
0 .09668 m
.00375 .09668 L
s
0 .1452 m
.00375 .1452 L
s
0 .16946 m
.00375 .16946 L
s
0 .19372 m
.00375 .19372 L
s
0 .21798 m
.00375 .21798 L
s
0 .2665 m
.00375 .2665 L
s
0 .29076 m
.00375 .29076 L
s
0 .31502 m
.00375 .31502 L
s
0 .33928 m
.00375 .33928 L
s
0 .3878 m
.00375 .3878 L
s
0 .41206 m
.00375 .41206 L
s
0 .43632 m
.00375 .43632 L
s
0 .46059 m
.00375 .46059 L
s
0 .50911 m
.00375 .50911 L
s
0 .53337 m
.00375 .53337 L
s
0 .55763 m
.00375 .55763 L
s
0 .58189 m
.00375 .58189 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00942 .61178 m
.00942 .61803 L
s
.20565 .61178 m
.20565 .61803 L
s
.40188 .61178 m
.40188 .61803 L
s
.59812 .61178 m
.59812 .61803 L
s
.79435 .61178 m
.79435 .61803 L
s
.99058 .61178 m
.99058 .61803 L
s
.125 Mabswid
.05848 .61428 m
.05848 .61803 L
s
.10754 .61428 m
.10754 .61803 L
s
.15659 .61428 m
.15659 .61803 L
s
.25471 .61428 m
.25471 .61803 L
s
.30377 .61428 m
.30377 .61803 L
s
.35283 .61428 m
.35283 .61803 L
s
.45094 .61428 m
.45094 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54906 .61428 m
.54906 .61803 L
s
.64717 .61428 m
.64717 .61803 L
s
.69623 .61428 m
.69623 .61803 L
s
.74529 .61428 m
.74529 .61803 L
s
.84341 .61428 m
.84341 .61803 L
s
.89246 .61428 m
.89246 .61803 L
s
.94152 .61428 m
.94152 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12094 m
1 .12094 L
s
.99375 .24224 m
1 .24224 L
s
.99375 .36354 m
1 .36354 L
s
.99375 .48485 m
1 .48485 L
s
.99375 .60615 m
1 .60615 L
s
.125 Mabswid
.99625 .02389 m
1 .02389 L
s
.99625 .04815 m
1 .04815 L
s
.99625 .07242 m
1 .07242 L
s
.99625 .09668 m
1 .09668 L
s
.99625 .1452 m
1 .1452 L
s
.99625 .16946 m
1 .16946 L
s
.99625 .19372 m
1 .19372 L
s
.99625 .21798 m
1 .21798 L
s
.99625 .2665 m
1 .2665 L
s
.99625 .29076 m
1 .29076 L
s
.99625 .31502 m
1 .31502 L
s
.99625 .33928 m
1 .33928 L
s
.99625 .3878 m
1 .3878 L
s
.99625 .41206 m
1 .41206 L
s
.99625 .43632 m
1 .43632 L
s
.99625 .46059 m
1 .46059 L
s
.99625 .50911 m
1 .50911 L
s
.99625 .53337 m
1 .53337 L
s
.99625 .55763 m
1 .55763 L
s
.99625 .58189 m
1 .58189 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 g
.01923 .60615 m
.98077 .60615 L
.98077 .01189 L
.01923 .01189 L
F
0 g
.5 Mabswid
.742 g
.45168 .60615 m
.45168 .60316 L
.45168 .60018 L
.45168 .59719 L
.45168 .5942 L
.45168 .59122 L
.45168 .58823 L
.45168 .58524 L
.45168 .58226 L
.45168 .57927 L
.45168 .57629 L
.45168 .5733 L
.45168 .57031 L
.45168 .56733 L
.44927 .56583 L
.44685 .56434 L
.44685 .56135 L
.44685 .55837 L
.44685 .55538 L
.44685 .5524 L
.44685 .54941 L
.44685 .54642 L
.44685 .54344 L
.44685 .54045 L
.44685 .53747 L
.44685 .53448 L
.44685 .53149 L
.44685 .52851 L
.44685 .52552 L
.44685 .52253 L
.44685 .51955 L
.44685 .51656 L
.44685 .51358 L
.44685 .51059 L
.44685 .5076 L
.44685 .50462 L
.44685 .50163 L
.44685 .49864 L
.44685 .49566 L
.44685 .49267 L
.44685 .48969 L
.44685 .4867 L
.44685 .48371 L
.44685 .48073 L
.44685 .47774 L
.44685 .47475 L
.44685 .47177 L
.44685 .46878 L
.44685 .4658 L
.44685 .46281 L
.44685 .45982 L
.44685 .45684 L
.44685 .45385 L
.44685 .45086 L
.44685 .44788 L
.44443 .44638 L
.44202 .44489 L
.44202 .44191 L
.44202 .43892 L
.44202 .43593 L
.44202 .43295 L
.44202 .42996 L
.44202 .42697 L
.44202 .42399 L
.44202 .421 L
.44202 .41802 L
.44202 .41503 L
.44202 .41204 L
.44202 .40906 L
.44202 .40607 L
.44202 .40308 L
.44202 .4001 L
.44202 .39711 L
.44202 .39413 L
.44202 .39114 L
.44202 .38815 L
.44202 .38517 L
.44202 .38218 L
.44202 .37919 L
.44202 .37621 L
.44202 .37322 L
.44202 .37024 L
.44202 .36725 L
.44202 .36426 L
.44202 .36128 L
.44202 .35829 L
.44202 .3553 L
.4396 .35381 L
.43719 .35232 L
.43719 .34933 L
.43719 .34635 L
.43719 .34336 L
.43719 .34037 L
.43719 .33739 L
.43719 .3344 L
.43719 .33141 L
.43719 .32843 L
.43719 .32544 L
.43719 .32246 L
.43719 .31947 L
.43719 .31648 L
.43719 .3135 L
.43719 .31051 L
.43719 .30752 L
.43719 .30454 L
.43719 .30155 L
.43719 .29857 L
.43719 .29558 L
.43719 .29259 L
.43719 .28961 L
.43719 .28662 L
.43719 .28363 L
.43719 .28065 L
.43477 .27915 L
.43235 .27766 L
.43235 .27468 L
.43235 .27169 L
.43235 .2687 L
.43235 .26572 L
.43235 .26273 L
.43235 .25974 L
.43235 .25676 L
.43235 .25377 L
.43235 .25079 L
.43235 .2478 L
.43235 .24481 L
.43235 .24183 L
.43235 .23884 L
.43235 .23585 L
.43235 .23287 L
.43235 .22988 L
.43235 .2269 L
.43235 .22391 L
.42994 .22242 L
.42752 .22092 L
.42752 .21794 L
.42752 .21495 L
.42752 .21196 L
.42752 .20898 L
.42752 .20599 L
.42752 .20301 L
.42752 .20002 L
.42752 .19703 L
.42752 .19405 L
.42752 .19106 L
.42752 .18807 L
.42752 .18509 L
.42752 .1821 L
.42752 .17912 L
.42511 .17762 L
.42269 .17613 L
.42269 .17314 L
.42269 .17016 L
.42269 .16717 L
.42269 .16418 L
.42269 .1612 L
.42269 .15821 L
.42269 .15523 L
.42269 .15224 L
.42269 .14925 L
.42269 .14627 L
.42269 .14328 L
.42027 .14179 L
.41786 .14029 L
.41786 .13731 L
.41786 .13432 L
.41786 .13134 L
.41786 .12835 L
.41786 .12536 L
.41786 .12238 L
.41786 .11939 L
.41786 .1164 L
.41544 .11491 L
.41303 .11342 L
.41303 .11043 L
.41303 .10745 L
.41303 .10446 L
.41303 .10147 L
.41303 .09849 L
.41303 .0955 L
.41061 .09401 L
.40819 .09251 L
.40819 .08953 L
.40819 .08654 L
.40819 .08356 L
.40819 .08057 L
.40819 .07758 L
.40578 .07609 L
.40336 .0746 L
.40336 .07161 L
.40336 .06862 L
.40336 .06564 L
.40095 .06414 L
.39853 .06265 L
.39853 .05967 L
.39853 .05668 L
.39612 .05519 L
.3937 .05369 L
.3937 .05071 L
.3937 .04772 L
.39128 .04623 L
.38887 .04473 L
.38887 .04175 L
.38645 .04025 L
.38404 .03876 L
.38404 .03578 L
.38162 .03428 L
.37679 .03428 L
.37196 .03428 L
.36712 .03428 L
.36471 .03578 L
.36229 .03727 L
.35746 .03727 L
.35263 .03727 L
.3478 .03727 L
.34538 .03876 L
.34296 .04025 L
.33813 .04025 L
.33572 .04175 L
.3333 .04324 L
.32847 .04324 L
.32364 .04324 L
.32122 .04473 L
.31881 .04623 L
.31397 .04623 L
.31156 .04772 L
.30914 .04921 L
.30673 .05071 L
.30431 .0522 L
.29948 .0522 L
.29706 .05369 L
.29465 .05519 L
.29223 .05668 L
.28981 .05817 L
.28498 .05817 L
.28257 .05967 L
.28015 .06116 L
.27773 .06265 L
.27532 .06414 L
.2729 .06564 L
.27049 .06713 L
.26807 .06862 L
.26566 .07012 L
.26324 .07161 L
.26082 .0731 L
.25841 .0746 L
.25599 .07609 L
.25358 .07758 L
.25358 .08057 L
.25116 .08206 L
.24874 .08356 L
.24633 .08505 L
.24391 .08654 L
.24391 .08953 L
.2415 .09102 L
.23908 .09251 L
.23666 .09401 L
.23425 .0955 L
.23425 .09849 L
.23183 .09998 L
.22942 .10147 L
.22942 .10446 L
.227 .10595 L
.22458 .10745 L
.22458 .11043 L
.22217 .11192 L
.21975 .11342 L
.21975 .1164 L
.21975 .11939 L
.21734 .12088 L
.21492 .12238 L
.21492 .12536 L
.2125 .12686 L
.21009 .12835 L
.21009 .13134 L
.21009 .13432 L
.20767 .13581 L
.20526 .13731 L
.20526 .14029 L
.20526 .14328 L
.20284 .14477 L
.20043 .14627 L
.20043 .14925 L
.20043 .15224 L
.20043 .15523 L
.19801 .15672 L
.19559 .15821 L
.19559 .1612 L
.19559 .16418 L
.19559 .16717 L
.19318 .16866 L
.19076 .17016 L
.19076 .17314 L
.19076 .17613 L
.19076 .17912 L
.18835 .18061 L
.18593 .1821 L
.18593 .18509 L
.18593 .18807 L
.18593 .19106 L
.18351 .19255 L
.1811 .19405 L
.1811 .19703 L
.1811 .20002 L
.1811 .20301 L
.1811 .20599 L
.17868 .20748 L
.17627 .20898 L
.17627 .21196 L
.17627 .21495 L
.17627 .21794 L
.17627 .22092 L
.17627 .22391 L
.17385 .2254 L
.17143 .2269 L
.17143 .22988 L
.17143 .23287 L
.17143 .23585 L
.17143 .23884 L
.17143 .24183 L
.16902 .24332 L
.1666 .24481 L
.1666 .2478 L
.1666 .25079 L
.1666 .25377 L
.1666 .25676 L
.1666 .25974 L
.16419 .26124 L
.16177 .26273 L
.16177 .26572 L
.16177 .2687 L
.16177 .27169 L
.16177 .27468 L
.16177 .27766 L
.16177 .28065 L
.15935 .28214 L
.15694 .28363 L
.15694 .28662 L
.15694 .28961 L
.15694 .29259 L
.15694 .29558 L
.15694 .29857 L
.15694 .30155 L
.15694 .30454 L
.15452 .30603 L
.15211 .30752 L
.15211 .31051 L
.15211 .3135 L
.15211 .31648 L
.15211 .31947 L
.15211 .32246 L
.15211 .32544 L
.15211 .32843 L
.15211 .33141 L
.14969 .33291 L
.14727 .3344 L
.14727 .33739 L
.14727 .34037 L
.14727 .34336 L
.14727 .34635 L
.14727 .34933 L
.14727 .35232 L
.14727 .3553 L
.14727 .35829 L
.14486 .35978 L
.14244 .36128 L
.14244 .36426 L
.14244 .36725 L
.14244 .37024 L
.14244 .37322 L
.14244 .37621 L
.14244 .37919 L
.14244 .38218 L
.14244 .38517 L
.14244 .38815 L
.14244 .39114 L
.14003 .39263 L
.13761 .39413 L
.13761 .39711 L
.13761 .4001 L
.13761 .40308 L
.13761 .40607 L
.13761 .40906 L
.13761 .41204 L
.13761 .41503 L
.13761 .41802 L
.13761 .421 L
.13761 .42399 L
.1352 .42548 L
.13278 .42697 L
.13278 .42996 L
.13278 .43295 L
.13278 .43593 L
.13278 .43892 L
.13278 .44191 L
.13278 .44489 L
.13278 .44788 L
.13278 .45086 L
.13278 .45385 L
.13278 .45684 L
.13278 .45982 L
.13278 .46281 L
.13036 .4643 L
.12795 .4658 L
.12795 .46878 L
.12795 .47177 L
.12795 .47475 L
.12795 .47774 L
.12795 .48073 L
.12795 .48371 L
.12795 .4867 L
.12795 .48969 L
.12795 .49267 L
.12795 .49566 L
.12795 .49864 L
.12795 .50163 L
.12795 .50462 L
.12553 .50611 L
.12312 .5076 L
.12312 .51059 L
.12312 .51358 L
.12312 .51656 L
.12312 .51955 L
.12312 .52253 L
.12312 .52552 L
.12312 .52851 L
.12312 .53149 L
.12312 .53448 L
.12312 .53747 L
.12312 .54045 L
.12312 .54344 L
.12312 .54642 L
.12312 .54941 L
.1207 .5509 L
.11828 .5524 L
.11828 .55538 L
.11828 .55837 L
.11828 .56135 L
.11828 .56434 L
.11828 .56733 L
.11828 .57031 L
.11828 .5733 L
.11828 .57629 L
.11828 .57927 L
.11828 .58226 L
.11828 .58524 L
.11828 .58823 L
.11828 .59122 L
.11828 .5942 L
.11828 .59719 L
.11828 .60018 L
.11828 .60316 L
.11587 .60517 L
.11345 .60615 L
F
0 g
.45168 .60615 m
.45168 .60316 L
.45168 .60018 L
.45168 .59719 L
.45168 .5942 L
.45168 .59122 L
.45168 .58823 L
.45168 .58524 L
.45168 .58226 L
.45168 .57927 L
.45168 .57629 L
.45168 .5733 L
.45168 .57031 L
.45168 .56733 L
.44927 .56583 L
.44685 .56434 L
.44685 .56135 L
.44685 .55837 L
.44685 .55538 L
.44685 .5524 L
.44685 .54941 L
.44685 .54642 L
.44685 .54344 L
.44685 .54045 L
.44685 .53747 L
.44685 .53448 L
.44685 .53149 L
.44685 .52851 L
.44685 .52552 L
.44685 .52253 L
.44685 .51955 L
.44685 .51656 L
.44685 .51358 L
.44685 .51059 L
.44685 .5076 L
.44685 .50462 L
.44685 .50163 L
.44685 .49864 L
.44685 .49566 L
.44685 .49267 L
.44685 .48969 L
.44685 .4867 L
.44685 .48371 L
.44685 .48073 L
.44685 .47774 L
.44685 .47475 L
.44685 .47177 L
.44685 .46878 L
.44685 .4658 L
.44685 .46281 L
Mistroke
.44685 .45982 L
.44685 .45684 L
.44685 .45385 L
.44685 .45086 L
.44685 .44788 L
.44443 .44638 L
.44202 .44489 L
.44202 .44191 L
.44202 .43892 L
.44202 .43593 L
.44202 .43295 L
.44202 .42996 L
.44202 .42697 L
.44202 .42399 L
.44202 .421 L
.44202 .41802 L
.44202 .41503 L
.44202 .41204 L
.44202 .40906 L
.44202 .40607 L
.44202 .40308 L
.44202 .4001 L
.44202 .39711 L
.44202 .39413 L
.44202 .39114 L
.44202 .38815 L
.44202 .38517 L
.44202 .38218 L
.44202 .37919 L
.44202 .37621 L
.44202 .37322 L
.44202 .37024 L
.44202 .36725 L
.44202 .36426 L
.44202 .36128 L
.44202 .35829 L
.44202 .3553 L
.4396 .35381 L
.43719 .35232 L
.43719 .34933 L
.43719 .34635 L
.43719 .34336 L
.43719 .34037 L
.43719 .33739 L
.43719 .3344 L
.43719 .33141 L
.43719 .32843 L
.43719 .32544 L
.43719 .32246 L
.43719 .31947 L
Mistroke
.43719 .31648 L
.43719 .3135 L
.43719 .31051 L
.43719 .30752 L
.43719 .30454 L
.43719 .30155 L
.43719 .29857 L
.43719 .29558 L
.43719 .29259 L
.43719 .28961 L
.43719 .28662 L
.43719 .28363 L
.43719 .28065 L
.43477 .27915 L
.43235 .27766 L
.43235 .27468 L
.43235 .27169 L
.43235 .2687 L
.43235 .26572 L
.43235 .26273 L
.43235 .25974 L
.43235 .25676 L
.43235 .25377 L
.43235 .25079 L
.43235 .2478 L
.43235 .24481 L
.43235 .24183 L
.43235 .23884 L
.43235 .23585 L
.43235 .23287 L
.43235 .22988 L
.43235 .2269 L
.43235 .22391 L
.42994 .22242 L
.42752 .22092 L
.42752 .21794 L
.42752 .21495 L
.42752 .21196 L
.42752 .20898 L
.42752 .20599 L
.42752 .20301 L
.42752 .20002 L
.42752 .19703 L
.42752 .19405 L
.42752 .19106 L
.42752 .18807 L
.42752 .18509 L
.42752 .1821 L
.42752 .17912 L
.42511 .17762 L
Mistroke
.42269 .17613 L
.42269 .17314 L
.42269 .17016 L
.42269 .16717 L
.42269 .16418 L
.42269 .1612 L
.42269 .15821 L
.42269 .15523 L
.42269 .15224 L
.42269 .14925 L
.42269 .14627 L
.42269 .14328 L
.42027 .14179 L
.41786 .14029 L
.41786 .13731 L
.41786 .13432 L
.41786 .13134 L
.41786 .12835 L
.41786 .12536 L
.41786 .12238 L
.41786 .11939 L
.41786 .1164 L
.41544 .11491 L
.41303 .11342 L
.41303 .11043 L
.41303 .10745 L
.41303 .10446 L
.41303 .10147 L
.41303 .09849 L
.41303 .0955 L
.41061 .09401 L
.40819 .09251 L
.40819 .08953 L
.40819 .08654 L
.40819 .08356 L
.40819 .08057 L
.40819 .07758 L
.40578 .07609 L
.40336 .0746 L
.40336 .07161 L
.40336 .06862 L
.40336 .06564 L
.40095 .06414 L
.39853 .06265 L
.39853 .05967 L
.39853 .05668 L
.39612 .05519 L
.3937 .05369 L
.3937 .05071 L
.3937 .04772 L
Mistroke
.39128 .04623 L
.38887 .04473 L
.38887 .04175 L
.38645 .04025 L
.38404 .03876 L
.38404 .03578 L
.38162 .03428 L
.37679 .03428 L
.37196 .03428 L
.36712 .03428 L
.36471 .03578 L
.36229 .03727 L
.35746 .03727 L
.35263 .03727 L
.3478 .03727 L
.34538 .03876 L
.34296 .04025 L
.33813 .04025 L
.33572 .04175 L
.3333 .04324 L
.32847 .04324 L
.32364 .04324 L
.32122 .04473 L
.31881 .04623 L
.31397 .04623 L
.31156 .04772 L
.30914 .04921 L
.30673 .05071 L
.30431 .0522 L
.29948 .0522 L
.29706 .05369 L
.29465 .05519 L
.29223 .05668 L
.28981 .05817 L
.28498 .05817 L
.28257 .05967 L
.28015 .06116 L
.27773 .06265 L
.27532 .06414 L
.2729 .06564 L
.27049 .06713 L
.26807 .06862 L
.26566 .07012 L
.26324 .07161 L
.26082 .0731 L
.25841 .0746 L
.25599 .07609 L
.25358 .07758 L
.25358 .08057 L
.25116 .08206 L
Mistroke
.24874 .08356 L
.24633 .08505 L
.24391 .08654 L
.24391 .08953 L
.2415 .09102 L
.23908 .09251 L
.23666 .09401 L
.23425 .0955 L
.23425 .09849 L
.23183 .09998 L
.22942 .10147 L
.22942 .10446 L
.227 .10595 L
.22458 .10745 L
.22458 .11043 L
.22217 .11192 L
.21975 .11342 L
.21975 .1164 L
.21975 .11939 L
.21734 .12088 L
.21492 .12238 L
.21492 .12536 L
.2125 .12686 L
.21009 .12835 L
.21009 .13134 L
.21009 .13432 L
.20767 .13581 L
.20526 .13731 L
.20526 .14029 L
.20526 .14328 L
.20284 .14477 L
.20043 .14627 L
.20043 .14925 L
.20043 .15224 L
.20043 .15523 L
.19801 .15672 L
.19559 .15821 L
.19559 .1612 L
.19559 .16418 L
.19559 .16717 L
.19318 .16866 L
.19076 .17016 L
.19076 .17314 L
.19076 .17613 L
.19076 .17912 L
.18835 .18061 L
.18593 .1821 L
.18593 .18509 L
.18593 .18807 L
.18593 .19106 L
Mistroke
.18351 .19255 L
.1811 .19405 L
.1811 .19703 L
.1811 .20002 L
.1811 .20301 L
.1811 .20599 L
.17868 .20748 L
.17627 .20898 L
.17627 .21196 L
.17627 .21495 L
.17627 .21794 L
.17627 .22092 L
.17627 .22391 L
.17385 .2254 L
.17143 .2269 L
.17143 .22988 L
.17143 .23287 L
.17143 .23585 L
.17143 .23884 L
.17143 .24183 L
.16902 .24332 L
.1666 .24481 L
.1666 .2478 L
.1666 .25079 L
.1666 .25377 L
.1666 .25676 L
.1666 .25974 L
.16419 .26124 L
.16177 .26273 L
.16177 .26572 L
.16177 .2687 L
.16177 .27169 L
.16177 .27468 L
.16177 .27766 L
.16177 .28065 L
.15935 .28214 L
.15694 .28363 L
.15694 .28662 L
.15694 .28961 L
.15694 .29259 L
.15694 .29558 L
.15694 .29857 L
.15694 .30155 L
.15694 .30454 L
.15452 .30603 L
.15211 .30752 L
.15211 .31051 L
.15211 .3135 L
.15211 .31648 L
.15211 .31947 L
Mistroke
.15211 .32246 L
.15211 .32544 L
.15211 .32843 L
.15211 .33141 L
.14969 .33291 L
.14727 .3344 L
.14727 .33739 L
.14727 .34037 L
.14727 .34336 L
.14727 .34635 L
.14727 .34933 L
.14727 .35232 L
.14727 .3553 L
.14727 .35829 L
.14486 .35978 L
.14244 .36128 L
.14244 .36426 L
.14244 .36725 L
.14244 .37024 L
.14244 .37322 L
.14244 .37621 L
.14244 .37919 L
.14244 .38218 L
.14244 .38517 L
.14244 .38815 L
.14244 .39114 L
.14003 .39263 L
.13761 .39413 L
.13761 .39711 L
.13761 .4001 L
.13761 .40308 L
.13761 .40607 L
.13761 .40906 L
.13761 .41204 L
.13761 .41503 L
.13761 .41802 L
.13761 .421 L
.13761 .42399 L
.1352 .42548 L
.13278 .42697 L
.13278 .42996 L
.13278 .43295 L
.13278 .43593 L
.13278 .43892 L
.13278 .44191 L
.13278 .44489 L
.13278 .44788 L
.13278 .45086 L
.13278 .45385 L
.13278 .45684 L
Mistroke
.13278 .45982 L
.13278 .46281 L
.13036 .4643 L
.12795 .4658 L
.12795 .46878 L
.12795 .47177 L
.12795 .47475 L
.12795 .47774 L
.12795 .48073 L
.12795 .48371 L
.12795 .4867 L
.12795 .48969 L
.12795 .49267 L
.12795 .49566 L
.12795 .49864 L
.12795 .50163 L
.12795 .50462 L
.12553 .50611 L
.12312 .5076 L
.12312 .51059 L
.12312 .51358 L
.12312 .51656 L
.12312 .51955 L
.12312 .52253 L
.12312 .52552 L
.12312 .52851 L
.12312 .53149 L
.12312 .53448 L
.12312 .53747 L
.12312 .54045 L
.12312 .54344 L
.12312 .54642 L
.12312 .54941 L
.1207 .5509 L
.11828 .5524 L
.11828 .55538 L
.11828 .55837 L
.11828 .56135 L
.11828 .56434 L
.11828 .56733 L
.11828 .57031 L
.11828 .5733 L
.11828 .57629 L
.11828 .57927 L
.11828 .58226 L
.11828 .58524 L
.11828 .58823 L
.11828 .59122 L
.11828 .5942 L
.11828 .59719 L
Mistroke
.11828 .60018 L
.11828 .60316 L
.11587 .60517 L
.11345 .60615 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000LOol3000YOol30003Ool00`00Ool00004000SOol30003Ool00`00
Oomoo`03Ool00`00Oomoo`0ROol30003Ool00`00Oomoo`03000UOol30003Ool00`00Oomoo`03000Y
Ool3000>Ool001]oo`05001oogooOol0000WOol01@00Oomoogoo00001Goo00@007ooOol0029oo`05
001oogooOol00008Ool00`00Oomoo`0QOol01@00Oomoogoo000017oo00D007ooOomoo`0002=oo`05
001oogooOol00004Ool01@00Oomoogoo0000:Goo00<007ooOol03Goo000KOol01@00Oomoogoo0000
9goo00D007ooOomoo`0000Ioo`03001oogoo029oo`05001oogooOol00004Ool6000ROol01@00Oomo
ogoo000017oo00D007ooOomoo`0002=oo`05001oogooOol00004Ool01@00Oomoogoo0000:Goo00<0
07ooOol03Goo000KOol01@00Oomoogoo00009goo00D007ooOomoo`0000Moo`03001oogoo025oo`05
001oogooOol00004Ool01@00Oomoogoo00008goo00D007ooOomoo`0000Aoo`05001oogooOol0000S
Ool01@00Oomoogoo00001Goo00<007oo0000:Woo00<007ooOol03Goo000KOol01@00Oomoogoo0000
9goo00D007ooOomoo`0000Qoo`03001oogoo021oo`05001oogooOol00005Ool01000Oomoo`008goo
00D007ooOomoo`0000Aoo`80009oo`03001oogoo025oo`05001oogooOol00006Ool00`00Oomoo`0Y
Ool00`00Oomoo`0=Ool001]oo`05001oogooOol0000WOol01@00Oomoogoo000027oo00<007ooOol0
87oo00D007ooOomoo`0000Ioo`03001oo`0002=oo`05001oogooOol00004Ool01000Ool0000097oo
00D007ooOomoo`0000Eoo`03001oo`0002Yoo`03001oogoo00eoo`006goo00D007ooOomoo`0002Mo
o`05001oogooOol00008Ool00`00Oomoo`0POol01@00Oomoogoo00001Woo00<007oo00008goo00D0
07ooOomoo`0000Eoo`03001oogoo02Aoo`05001oogooOol00004Ool01@00Oomoogoo0000:Goo00<0
07ooOol03Goo000KOol01@00Oomoogoo00009goo00D007ooOomoo`0000Aoo`05001oogooOol0000R
Ool01@00Oomoogoo00001goo0P008goo00D007ooOomoo`0000Ioo`03001oogoo02=oo`05001oogoo
Ool00004Ool01@00Oomoogoo0000:7oo0P003goo000LOol3000YOol30006Ool3000TOol30009Ool0
0`00Oomoo`0ROol30008Ool2000TOol30006Ool3000ZOol00`00Oomoo`0=Ool00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo000KOooi000<Ool001]oo`04001oogoo000;Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Ool0000<Ool001]o
o`04001oogoo000_Ool00`00Oomoo`0^Ool00`00Oomoo`0^Ool00`00Oomoo`0]Ool00`00Oomoo`0^
Ool00`00Ool0000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo
00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`800?Eoo`8000aoo`00
6goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]o
o`03001oogoo05Qoo`D009Qoo`03001oogoo00Yoo`006goo00<007ooOol0DGoo1`0015kg0P00Ugoo
00<007ooOol02Woo000KOol00`00Oomoo`1=Ool4000=G_L00`00Oomoo`2DOol00`00Oomoo`0:Ool0
01]oo`8004]oo`<0015Nm`8009Aoo`8000aoo`006goo00<007ooOol0Agoo100055kg00<007ooOol0
Tgoo00<007ooOol02Woo000KOol00`00Oomoo`16Ool2000GG_L2002DOol00`00Oomoo`0:Ool001]o
o`03001oogoo04=oo`<001YNm`03001oogoo099oo`03001oogoo00Yoo`006goo00<007ooOol0@Woo
0P0075kg0P00Tgoo00<007ooOol02Woo000KOol00`00Oomoo`10Ool2000OG_L00`00Oomoo`2AOol0
0`00Oomoo`0:Ool001]oo`8003moo`80025Nm`03001oogoo091oo`8000aoo`006goo00<007ooOol0
?Goo00<005kgG_L08Ekg0P00TWoo00<007ooOol02Woo000KOol00`00Oomoo`0lOol00`00G_MNm`0S
G_L00`00Oomoo`2@Ool00`00Oomoo`0:Ool001]oo`03001oogoo03Yoo`<002ENm`03001oogoo091o
o`03001oogoo00Yoo`006goo00<007ooOol0>Woo00<005kgG_L09Ekg00<007ooOol0T7oo00<007oo
Ool02Woo000KOol00`00Oomoo`0iOol2000WG_L00`00Oomoo`2@Ool00`00Oomoo`0:Ool001]oo`80
03Qoo`8002YNm`8008moo`8000aoo`006goo00<007ooOol0=goo00<005kgG_L0:Ukg00<007ooOol0
SWoo00<007ooOol02Woo000KOol00`00Oomoo`0fOol00`00G_MNm`0[G_L00`00Oomoo`2>Ool00`00
Oomoo`0:Ool000]oo`<000=oo`<000Moo`03001oogoo03Eoo`8002eNm`03001oogoo08ioo`03001o
ogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo03Aoo`8002iNm`03
001oogoo08ioo`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001o
ogoo03Aoo`03001Nmekg02eNm`8008moo`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03
001oogoo00Aoo`<003=oo`80031Nm`03001oogoo08aoo`8000aoo`0037oo00D007ooOomoo`0000=o
o`03001oogoo00Aoo`03001oogoo03=oo`03001Nmekg02mNm`03001oogoo08eoo`03001oogoo00Yo
o`0037oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo035oo`80039Nm`03001oogoo
08eoo`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo035o
o`03001Nmekg035Nm`03001oogoo08eoo`03001oogoo00Yoo`002goo0P000goo00D007ooOomoo`00
00Ioo`03001oogoo031oo`8003=Nm`03001oogoo08eoo`03001oogoo00Yoo`0037oo00<007ooOol0
0Woo0`001goo00<007ooOol0<7oo00<005kgG_L0<Ukg00<007ooOol0SGoo00<007ooOol02Woo000K
Ool2000aOol00`00G_MNm`0bG_L2002=Ool2000<Ool001]oo`03001oogoo02moo`03001Nmekg03AN
m`03001oogoo08aoo`03001oogoo00Yoo`006goo00<007ooOol0;goo00<005kgG_L0=5kg00<007oo
Ool0S7oo00<007ooOol02Woo000KOol00`00Oomoo`0^Ool2000fG_L00`00Oomoo`2<Ool00`00Oomo
o`0:Ool001]oo`03001oogoo02ioo`03001Nmekg03ENm`03001oogoo08aoo`03001oogoo00Yoo`00
6goo00<007ooOol0;Woo00<005kgG_L0=Ekg00<007ooOol0S7oo00<007ooOol02Woo000KOol2000^
Ool2000gG_L00`00Oomoo`2;Ool2000<Ool001]oo`03001oogoo02eoo`03001Nmekg03INm`03001o
ogoo08aoo`03001oogoo00Yoo`006goo00<007ooOol0;Goo00<005kgG_L0=Ukg0P00SGoo00<007oo
Ool02Woo000KOol00`00Oomoo`0/Ool2000iG_L00`00Oomoo`2;Ool00`00Oomoo`0:Ool001]oo`03
001oogoo02]oo`03001Nmekg03UNm`03001oogoo08]oo`03001oogoo00Yoo`006goo00<007ooOol0
:goo00<005kgG_L0>Ekg00<007ooOol0Rgoo00<007ooOol02Woo000KOol2000[Ool2000kG_L00`00
Oomoo`2:Ool2000<Ool001]oo`03001oogoo02Yoo`03001Nmekg03YNm`03001oogoo08]oo`03001o
ogoo00Yoo`006goo00<007ooOol0:Woo00<005kgG_L0>Ukg00<007ooOol0Rgoo00<007ooOol02Woo
000KOol00`00Oomoo`0ZOol00`00G_MNm`0jG_L00`00Oomoo`2;Ool00`00Oomoo`0:Ool001]oo`03
001oogoo02Uoo`8003aNm`03001oogoo08]oo`03001oogoo00Yoo`006goo00<007ooOol0:Goo00<0
05kgG_L0>ekg00<007ooOol0Rgoo00<007ooOol02Woo000KOol2000ZOol00`00G_MNm`0kG_L00`00
Oomoo`2:Ool2000<Ool001]oo`03001oogoo02Uoo`03001Nmekg03]Nm`03001oogoo08]oo`03001o
ogoo00Yoo`006goo00<007ooOol0:7oo0P00?Ukg00<007ooOol0RWoo00<007ooOol02Woo000:Ool5
0002Ool30007Ool00`00Oomoo`0XOol00`00G_MNm`0mG_L00`00Oomoo`2:Ool00`00Oomoo`0:Ool0
00]oo`06001oogoo001oo`000goo00<007ooOol017oo00<007ooOol0:7oo00<005kgG_L0?Ekg00<0
07ooOol0RWoo00<007ooOol02Woo000<Ool01@00Oomoogoo00000goo00<007ooOol017oo00<007oo
Ool0:7oo00<005kgG_L0?Ekg00<007ooOol0RWoo00<007ooOol02Woo000=Ool01000Oomoo`000goo
00<007ooOol017oo0`00:7oo00<005kgG_L0?Ekg00<007ooOol0RGoo0P0037oo000>Ool00`00Ool0
0003Ool00`00Oomoo`04Ool00`00Oomoo`0WOol00`00G_MNm`0nG_L00`00Oomoo`2:Ool00`00Oomo
o`0:Ool000ioo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo02Moo`03001Nmekg03iNm`03
001oogoo08Yoo`03001oogoo00Yoo`003Woo00<007oo00000goo00<007ooOol017oo00<007ooOol0
9goo00<005kgG_L0?Ukg00<007ooOol0RWoo00<007ooOol02Woo000:Ool01`00Oomoogoo001oo`00
00=oo`03001oogoo00Aoo`03001oogoo02Moo`03001Nmekg03iNm`03001oogoo08Yoo`03001oogoo
00Yoo`002goo0`000goo0`001goo00<007ooOol09Goo0`00@5kg00<007ooOol0RWoo00<007ooOol0
2Woo000KOol2000VOol00`00G_MNm`10G_L00`00Oomoo`29Ool2000<Ool001]oo`03001oogoo02Eo
o`03001Nmekg041Nm`03001oogoo08Yoo`03001oogoo00Yoo`006goo00<007ooOol09Goo00<005kg
G_L0@5kg00<007ooOol0RWoo00<007ooOol02Woo000KOol00`00Oomoo`0UOol00`00G_MNm`10G_L0
0`00Oomoo`2:Ool00`00Oomoo`0:Ool001]oo`03001oogoo02Eoo`03001Nmekg045Nm`8008Yoo`03
001oogoo00Yoo`006goo00<007ooOol097oo00<005kgG_L0@ekg00<007ooOol0R7oo00<007ooOol0
2Woo000KOol2000UOol00`00G_MNm`13G_L00`00Oomoo`27Ool2000<Ool001]oo`03001oogoo02Ao
o`03001Nmekg04=Nm`03001oogoo08Qoo`03001oogoo00Yoo`006goo00<007ooOol097oo00<005kg
G_L0@ekg00<007ooOol0R7oo00<007ooOol02Woo000KOol00`00Oomoo`0TOol00`00G_MNm`13G_L0
0`00Oomoo`28Ool00`00Oomoo`0:Ool001]oo`03001oogoo02Aoo`03001Nmekg04=Nm`03001oogoo
08Qoo`03001oogoo00Yoo`006goo00<007ooOol08goo00<005kgG_L0A5kg00<007ooOol0R7oo00<0
07ooOol02Woo000KOol2000TOol00`00G_MNm`14G_L00`00Oomoo`27Ool2000<Ool001]oo`03001o
ogoo02=oo`03001Nmekg04ANm`03001oogoo08Qoo`03001oogoo00Yoo`006goo00<007ooOol08goo
00<005kgG_L0A5kg00<007ooOol0R7oo00<007ooOol02Woo000KOol00`00Oomoo`0SOol00`00G_MN
m`14G_L00`00Oomoo`28Ool00`00Oomoo`0:Ool001]oo`03001oogoo02=oo`03001Nmekg04ANm`03
001oogoo08Qoo`03001oogoo00Yoo`006goo00<007ooOol08Woo0P00AUkg00<007ooOol0R7oo00<0
07ooOol02Woo000KOol2000SOol00`00G_MNm`15G_L00`00Oomoo`27Ool2000<Ool001]oo`03001o
ogoo029oo`03001Nmekg04ENm`03001oogoo08Qoo`03001oogoo00Yoo`006goo00<007ooOol08Woo
00<005kgG_L0AEkg00<007ooOol0R7oo00<007ooOol02Woo000KOol00`00Oomoo`0ROol00`00G_MN
m`15G_L00`00Oomoo`28Ool00`00Oomoo`0:Ool000Yoo`@000=oo`<000Moo`03001oogoo029oo`03
001Nmekg04ENm`8008Uoo`03001oogoo00Yoo`003Woo00<007oo00000goo00<007ooOol017oo00<0
07ooOol08Woo00<005kgG_L0AUkg00<007ooOol0Qgoo00<007ooOol02Woo000>Ool00`00Ool00003
Ool00`00Oomoo`04Ool3000QOol00`00G_MNm`17G_L00`00Oomoo`26Ool2000<Ool000ioo`03001o
o`0000=oo`03001oogoo00Aoo`03001oogoo025oo`03001Nmekg04MNm`03001oogoo08Moo`03001o
ogoo00Yoo`0037oo0P000Woo00D007ooOomoo`0000Ioo`03001oogoo025oo`03001Nmekg04MNm`03
001oogoo08Moo`03001oogoo00Yoo`003Goo00@007ooOol000=oo`03001oogoo00Aoo`03001oogoo
025oo`03001Nmekg04MNm`03001oogoo08Moo`03001oogoo00Yoo`003Woo00<007oo00000goo00<0
07ooOol017oo00<007ooOol08Goo00<005kgG_L0Aekg00<007ooOol0Qgoo00<007ooOol02Woo000:
Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Aoo`03001oogoo025oo`03001Nmekg04MNm`03
001oogoo08Moo`03001oogoo00Yoo`002goo0`000goo0`001goo00<007ooOol08Goo00<005kgG_L0
Aekg00<007ooOol0Qgoo00<007ooOol02Woo000KOol2000ROol00`00G_MNm`17G_L00`00Oomoo`26
Ool2000<Ool001]oo`03001oogoo01moo`8004YNm`03001oogoo08Moo`03001oogoo00Yoo`006goo
00<007ooOol07goo00<005kgG_L0BEkg00<007ooOol0Qgoo00<007ooOol02Woo000KOol00`00Oomo
o`0OOol00`00G_MNm`19G_L00`00Oomoo`27Ool00`00Oomoo`0:Ool001]oo`03001oogoo01moo`03
001Nmekg04UNm`03001oogoo08Moo`03001oogoo00Yoo`006goo00<007ooOol07goo00<005kgG_L0
BEkg00<007ooOol0Qgoo00<007ooOol02Woo000KOol2000POol00`00G_MNm`19G_L00`00Oomoo`26
Ool2000<Ool001]oo`03001oogoo01moo`03001Nmekg04UNm`03001oogoo08Moo`03001oogoo00Yo
o`006goo00<007ooOol07goo00<005kgG_L0BEkg00<007ooOol0Qgoo00<007ooOol02Woo000KOol0
0`00Oomoo`0NOol2001;G_L00`00Oomoo`27Ool00`00Oomoo`0:Ool001]oo`03001oogoo01ioo`03
001Nmekg04YNm`03001oogoo08Moo`03001oogoo00Yoo`006goo00<007ooOol07Woo00<005kgG_L0
BUkg00<007ooOol0Qgoo00<007ooOol02Woo000KOol2000OOol00`00G_MNm`1:G_L00`00Oomoo`26
Ool2000<Ool001]oo`03001oogoo01ioo`03001Nmekg04YNm`03001oogoo08Moo`03001oogoo00Yo
o`006goo00<007ooOol07Woo00<005kgG_L0BUkg0P00R7oo00<007ooOol02Woo000KOol00`00Oomo
o`0NOol00`00G_MNm`1;G_L00`00Oomoo`26Ool00`00Oomoo`0:Ool001]oo`03001oogoo01ioo`03
001Nmekg04]Nm`03001oogoo08Ioo`03001oogoo00Yoo`006goo00<007ooOol07Woo00<005kgG_L0
Bekg00<007ooOol0QWoo00<007ooOol02Woo000KOol2000OOol00`00G_MNm`1;G_L00`00Oomoo`25
Ool2000<Ool001]oo`03001oogoo01eoo`03001Nmekg04aNm`03001oogoo08Ioo`03001oogoo00Yo
o`006goo00<007ooOol07Goo00<005kgG_L0C5kg00<007ooOol0QWoo00<007ooOol02Woo000>Ool0
0`00Oomoo`030007Ool00`00Oomoo`0MOol00`00G_MNm`1<G_L00`00Oomoo`26Ool00`00Oomoo`0:
Ool000ioo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo01eoo`03001Nmekg04aNm`03001o
ogoo08Ioo`03001oogoo00Yoo`002Woo1`000goo00<007ooOol017oo00<007ooOol07Goo00<005kg
G_L0C5kg00<007ooOol0QWoo00<007ooOol02Woo000:Ool01`00Oomoogoo001oo`0000=oo`03001o
ogoo00Aoo`<001eoo`03001Nmekg04aNm`03001oogoo08Eoo`8000aoo`002goo00H007ooOol007oo
0003Ool00`00Oomoo`04Ool00`00Oomoo`0MOol00`00G_MNm`1<G_L00`00Oomoo`26Ool00`00Oomo
o`0:Ool000aoo`05001oo`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`0MOol00`00G_MNm`1<
G_L00`00Oomoo`26Ool00`00Oomoo`0:Ool000aoo`05001oo`00Ool00003Ool00`00Oomoo`04Ool0
0`00Oomoo`0MOol00`00G_MNm`1<G_L00`00Oomoo`26Ool00`00Oomoo`0:Ool000eoo`800003Ool0
07oo009oo`03001oogoo00Aoo`03001oogoo01eoo`03001Nmekg04aNm`03001oogoo08Ioo`03001o
ogoo00Yoo`003Woo00<007ooOol00`001goo00<007ooOol077oo00<005kgG_L0CEkg00<007ooOol0
QWoo00<007ooOol02Woo000KOol2000MOol00`00G_MNm`1=G_L00`00Oomoo`25Ool2000<Ool001]o
o`03001oogoo01aoo`03001Nmekg04eNm`03001oogoo08Ioo`03001oogoo00Yoo`006goo00<007oo
Ool077oo00<005kgG_L0CEkg00<007ooOol0QWoo00<007ooOol02Woo000KOol00`00Oomoo`0LOol0
0`00G_MNm`1=G_L00`00Oomoo`26Ool00`00Oomoo`0:Ool001]oo`03001oogoo01aoo`03001Nmekg
04eNm`03001oogoo08Ioo`03001oogoo00Yoo`006goo00<007ooOol077oo00<005kgG_L0CEkg00<0
07ooOol0QWoo00<007ooOol02Woo000KOol2000MOol00`00G_MNm`1=G_L00`00Oomoo`25Ool2000<
Ool001]oo`03001oogoo01aoo`03001Nmekg04eNm`03001oogoo08Ioo`03001oogoo00Yoo`006goo
00<007ooOol077oo00<005kgG_L0CEkg00<007ooOol0QWoo00<007ooOol02Woo000KOol00`00Oomo
o`0LOol00`00G_MNm`1=G_L00`00Oomoo`26Ool00`00Oomoo`0:Ool001]oo`03001oogoo01]oo`80
04mNm`03001oogoo08Ioo`03001oogoo00Yoo`006goo00<007ooOol06goo00<005kgG_L0CUkg00<0
07ooOol0QWoo00<007ooOol02Woo000KOol2000LOol00`00G_MNm`1>G_L00`00Oomoo`25Ool2000<
Ool001]oo`03001oogoo01]oo`03001Nmekg04iNm`03001oogoo08Ioo`03001oogoo00Yoo`006goo
00<007ooOol06goo00<005kgG_L0Cekg00<007ooOol0QGoo00<007ooOol02Woo000KOol00`00Oomo
o`0KOol00`00G_MNm`1?G_L00`00Oomoo`25Ool00`00Oomoo`0:Ool001]oo`03001oogoo01]oo`03
001Nmekg04mNm`03001oogoo08Eoo`03001oogoo00Yoo`006goo00<007ooOol06goo00<005kgG_L0
Cekg00<007ooOol0QGoo00<007ooOol02Woo000KOol2000LOol00`00G_MNm`1?G_L00`00Oomoo`24
Ool2000<Ool001]oo`03001oogoo01]oo`03001Nmekg04mNm`03001oogoo08Eoo`03001oogoo00Yo
o`006goo00<007ooOol06goo00<005kgG_L0Cekg00<007ooOol0QGoo00<007ooOol02Woo000:Ool3
0004Ool30007Ool00`00Oomoo`0KOol00`00G_MNm`1?G_L00`00Oomoo`25Ool00`00Oomoo`0:Ool0
00eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`0KOol00`00G_MNm`1?G_L00`00Oomo
o`25Ool00`00Oomoo`0:Ool000ioo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo01Yoo`80
055Nm`03001oogoo08Eoo`03001oogoo00Yoo`003Woo00<007oo00000goo00<007ooOol017oo0`00
6Goo00<005kgG_L0DEkg00<007ooOol0Q7oo0P0037oo000>Ool00`00Ool00003Ool00`00Oomoo`04
Ool01000Oomoo`00;goo00<007ooOol0;Woo00<007ooOol0;Woo00<007ooOol0;Goo00<007ooOol0
;Woo00<007oo000037oo000=Ool01000Oomoo`000goo00<007ooOol017oo00@007ooOol000]oo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oo`0000aoo`00
2goo0P000goo00D007ooOomoo`0000IoooT000aoo`002goo00<007ooOol00Woo00D007ooOomoo`00
0?moo`aoo`0037oo0`000Woo0`00ogoo3Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.123594, -6.21594, \
0.00411023, 0.332456}}],

Cell[BoxData[
    \(0.30000000000000004`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00941915 0.981162 -0.000366335 0.0121303 [
[.00942 -0.0125 -5 -15.6875 ]
[.00942 -0.0125 5 0 ]
[.20565 -0.0125 -9.5 -15.6875 ]
[.20565 -0.0125 9.5 0 ]
[.40188 -0.0125 -9.5 -15.6875 ]
[.40188 -0.0125 9.5 0 ]
[.59812 -0.0125 -9.5 -15.6875 ]
[.59812 -0.0125 9.5 0 ]
[.79435 -0.0125 -9.5 -15.6875 ]
[.79435 -0.0125 9.5 0 ]
[.99058 -0.0125 -5 -15.6875 ]
[.99058 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12094 -16 -7.84375 ]
[-0.0125 .12094 0 7.84375 ]
[-0.0125 .24224 -16 -7.84375 ]
[-0.0125 .24224 0 7.84375 ]
[-0.0125 .36354 -16 -7.84375 ]
[-0.0125 .36354 0 7.84375 ]
[-0.0125 .48485 -16 -7.84375 ]
[-0.0125 .48485 0 7.84375 ]
[-0.0125 .60615 -16 -7.84375 ]
[-0.0125 .60615 0 7.84375 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00942 0 m
.00942 .00625 L
s
gsave
.00942 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20565 0 m
.20565 .00625 L
s
gsave
.20565 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40188 0 m
.40188 .00625 L
s
gsave
.40188 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59812 0 m
.59812 .00625 L
s
gsave
.59812 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.79435 0 m
.79435 .00625 L
s
gsave
.79435 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.99058 0 m
.99058 .00625 L
s
gsave
.99058 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05848 0 m
.05848 .00375 L
s
.10754 0 m
.10754 .00375 L
s
.15659 0 m
.15659 .00375 L
s
.25471 0 m
.25471 .00375 L
s
.30377 0 m
.30377 .00375 L
s
.35283 0 m
.35283 .00375 L
s
.45094 0 m
.45094 .00375 L
s
.5 0 m
.5 .00375 L
s
.54906 0 m
.54906 .00375 L
s
.64717 0 m
.64717 .00375 L
s
.69623 0 m
.69623 .00375 L
s
.74529 0 m
.74529 .00375 L
s
.84341 0 m
.84341 .00375 L
s
.89246 0 m
.89246 .00375 L
s
.94152 0 m
.94152 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12094 m
.00625 .12094 L
s
gsave
-0.0125 .12094 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .24224 m
.00625 .24224 L
s
gsave
-0.0125 .24224 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .36354 m
.00625 .36354 L
s
gsave
-0.0125 .36354 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .48485 m
.00625 .48485 L
s
gsave
-0.0125 .48485 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .60615 m
.00625 .60615 L
s
gsave
-0.0125 .60615 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02389 m
.00375 .02389 L
s
0 .04815 m
.00375 .04815 L
s
0 .07242 m
.00375 .07242 L
s
0 .09668 m
.00375 .09668 L
s
0 .1452 m
.00375 .1452 L
s
0 .16946 m
.00375 .16946 L
s
0 .19372 m
.00375 .19372 L
s
0 .21798 m
.00375 .21798 L
s
0 .2665 m
.00375 .2665 L
s
0 .29076 m
.00375 .29076 L
s
0 .31502 m
.00375 .31502 L
s
0 .33928 m
.00375 .33928 L
s
0 .3878 m
.00375 .3878 L
s
0 .41206 m
.00375 .41206 L
s
0 .43632 m
.00375 .43632 L
s
0 .46059 m
.00375 .46059 L
s
0 .50911 m
.00375 .50911 L
s
0 .53337 m
.00375 .53337 L
s
0 .55763 m
.00375 .55763 L
s
0 .58189 m
.00375 .58189 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00942 .61178 m
.00942 .61803 L
s
.20565 .61178 m
.20565 .61803 L
s
.40188 .61178 m
.40188 .61803 L
s
.59812 .61178 m
.59812 .61803 L
s
.79435 .61178 m
.79435 .61803 L
s
.99058 .61178 m
.99058 .61803 L
s
.125 Mabswid
.05848 .61428 m
.05848 .61803 L
s
.10754 .61428 m
.10754 .61803 L
s
.15659 .61428 m
.15659 .61803 L
s
.25471 .61428 m
.25471 .61803 L
s
.30377 .61428 m
.30377 .61803 L
s
.35283 .61428 m
.35283 .61803 L
s
.45094 .61428 m
.45094 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54906 .61428 m
.54906 .61803 L
s
.64717 .61428 m
.64717 .61803 L
s
.69623 .61428 m
.69623 .61803 L
s
.74529 .61428 m
.74529 .61803 L
s
.84341 .61428 m
.84341 .61803 L
s
.89246 .61428 m
.89246 .61803 L
s
.94152 .61428 m
.94152 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12094 m
1 .12094 L
s
.99375 .24224 m
1 .24224 L
s
.99375 .36354 m
1 .36354 L
s
.99375 .48485 m
1 .48485 L
s
.99375 .60615 m
1 .60615 L
s
.125 Mabswid
.99625 .02389 m
1 .02389 L
s
.99625 .04815 m
1 .04815 L
s
.99625 .07242 m
1 .07242 L
s
.99625 .09668 m
1 .09668 L
s
.99625 .1452 m
1 .1452 L
s
.99625 .16946 m
1 .16946 L
s
.99625 .19372 m
1 .19372 L
s
.99625 .21798 m
1 .21798 L
s
.99625 .2665 m
1 .2665 L
s
.99625 .29076 m
1 .29076 L
s
.99625 .31502 m
1 .31502 L
s
.99625 .33928 m
1 .33928 L
s
.99625 .3878 m
1 .3878 L
s
.99625 .41206 m
1 .41206 L
s
.99625 .43632 m
1 .43632 L
s
.99625 .46059 m
1 .46059 L
s
.99625 .50911 m
1 .50911 L
s
.99625 .53337 m
1 .53337 L
s
.99625 .55763 m
1 .55763 L
s
.99625 .58189 m
1 .58189 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 g
.01923 .60615 m
.98077 .60615 L
.98077 .01189 L
.01923 .01189 L
F
0 g
.5 Mabswid
.742 g
.3937 .60615 m
.3937 .60316 L
.3937 .60018 L
.3937 .59719 L
.3937 .5942 L
.3937 .59122 L
.3937 .58823 L
.3937 .58524 L
.3937 .58226 L
.3937 .57927 L
.3937 .57629 L
.3937 .5733 L
.3937 .57031 L
.3937 .56733 L
.3937 .56434 L
.3937 .56135 L
.3937 .55837 L
.3937 .55538 L
.3937 .5524 L
.3937 .54941 L
.3937 .54642 L
.3937 .54344 L
.3937 .54045 L
.3937 .53747 L
.3937 .53448 L
.3937 .53149 L
.3937 .52851 L
.3937 .52552 L
.3937 .52253 L
.3937 .51955 L
.3937 .51656 L
.3937 .51358 L
.3937 .51059 L
.3937 .5076 L
.3937 .50462 L
.3937 .50163 L
.3937 .49864 L
.3937 .49566 L
.3937 .49267 L
.3937 .48969 L
.3937 .4867 L
.3937 .48371 L
.3937 .48073 L
.3937 .47774 L
.3937 .47475 L
.3937 .47177 L
.3937 .46878 L
.3937 .4658 L
.3937 .46281 L
.3937 .45982 L
.3937 .45684 L
.3937 .45385 L
.3937 .45086 L
.3937 .44788 L
.3937 .44489 L
.3937 .44191 L
.3937 .43892 L
.3937 .43593 L
.3937 .43295 L
.3937 .42996 L
.3937 .42697 L
.3937 .42399 L
.3937 .421 L
.3937 .41802 L
.3937 .41503 L
.3937 .41204 L
.3937 .40906 L
.3937 .40607 L
.3937 .40308 L
.3937 .4001 L
.3937 .39711 L
.3937 .39413 L
.3937 .39114 L
.3937 .38815 L
.3937 .38517 L
.3937 .38218 L
.3937 .37919 L
.3937 .37621 L
.3937 .37322 L
.3937 .37024 L
.3937 .36725 L
.3937 .36426 L
.3937 .36128 L
.3937 .35829 L
.3937 .3553 L
.3937 .35232 L
.3937 .34933 L
.3937 .34635 L
.3937 .34336 L
.3937 .34037 L
.3937 .33739 L
.3937 .3344 L
.3937 .33141 L
.3937 .32843 L
.3937 .32544 L
.3937 .32246 L
.3937 .31947 L
.3937 .31648 L
.3937 .3135 L
.3937 .31051 L
.3937 .30752 L
.3937 .30454 L
.3937 .30155 L
.3937 .29857 L
.3937 .29558 L
.3937 .29259 L
.3937 .28961 L
.3937 .28662 L
.3937 .28363 L
.3937 .28065 L
.39128 .27915 L
.38887 .27766 L
.38887 .27468 L
.38887 .27169 L
.38887 .2687 L
.38887 .26572 L
.38887 .26273 L
.38887 .25974 L
.38887 .25676 L
.38887 .25377 L
.38887 .25079 L
.38887 .2478 L
.38887 .24481 L
.38887 .24183 L
.38887 .23884 L
.38887 .23585 L
.38887 .23287 L
.38887 .22988 L
.38887 .2269 L
.38887 .22391 L
.38887 .22092 L
.38887 .21794 L
.38887 .21495 L
.38887 .21196 L
.38887 .20898 L
.38887 .20599 L
.38887 .20301 L
.38887 .20002 L
.38887 .19703 L
.38887 .19405 L
.38887 .19106 L
.38887 .18807 L
.38887 .18509 L
.38887 .1821 L
.38887 .17912 L
.38887 .17613 L
.38887 .17314 L
.38887 .17016 L
.38887 .16717 L
.38887 .16418 L
.38887 .1612 L
.38887 .15821 L
.38887 .15523 L
.38887 .15224 L
.38887 .14925 L
.38887 .14627 L
.38887 .14328 L
.38887 .14029 L
.38887 .13731 L
.38887 .13432 L
.38887 .13134 L
.38887 .12835 L
.38645 .12686 L
.38404 .12536 L
.38404 .12238 L
.38404 .11939 L
.38404 .1164 L
.38404 .11342 L
.38404 .11043 L
.38404 .10745 L
.38404 .10446 L
.38404 .10147 L
.38404 .09849 L
.38404 .0955 L
.38404 .09251 L
.38404 .08953 L
.38404 .08654 L
.38404 .08356 L
.38404 .08057 L
.38404 .07758 L
.38162 .07609 L
.37947 .0746 L
.37679 .0731 L
.37411 .0746 L
.37437 .07758 L
.37196 .07908 L
.36954 .08057 L
.36954 .08356 L
.36954 .08654 L
.36712 .08803 L
.36471 .08953 L
.36471 .09251 L
.36471 .0955 L
.36471 .09849 L
.36471 .10147 L
.36229 .10297 L
.35988 .10446 L
.35988 .10745 L
.35988 .11043 L
.35988 .11342 L
.35988 .1164 L
.35988 .11939 L
.35746 .12088 L
.35504 .12238 L
.35504 .12536 L
.35504 .12835 L
.35504 .13134 L
.35504 .13432 L
.35504 .13731 L
.35504 .14029 L
.35504 .14328 L
.35504 .14627 L
.35504 .14925 L
.35263 .15075 L
.35021 .15224 L
.35021 .15523 L
.35021 .15821 L
.35021 .1612 L
.35021 .16418 L
.35021 .16717 L
.35021 .17016 L
.35021 .17314 L
.35021 .17613 L
.35021 .17912 L
.35021 .1821 L
.35021 .18509 L
.35021 .18807 L
.35021 .19106 L
.3478 .19255 L
.34538 .19405 L
.34538 .19703 L
.34538 .20002 L
.34538 .20301 L
.34538 .20599 L
.34538 .20898 L
.34538 .21196 L
.34538 .21495 L
.34538 .21794 L
.34538 .22092 L
.34538 .22391 L
.34538 .2269 L
.34538 .22988 L
.34538 .23287 L
.34538 .23585 L
.34538 .23884 L
.34538 .24183 L
.34538 .24481 L
.34538 .2478 L
.34538 .25079 L
.34538 .25377 L
.34538 .25676 L
.34538 .25974 L
.34296 .26124 L
.34055 .26273 L
.34055 .26572 L
.34055 .2687 L
.34055 .27169 L
.34055 .27468 L
.34055 .27766 L
.34055 .28065 L
.34055 .28363 L
.34055 .28662 L
.34055 .28961 L
.34055 .29259 L
.34055 .29558 L
.34055 .29857 L
.34055 .30155 L
.34055 .30454 L
.34055 .30752 L
.34055 .31051 L
.34055 .3135 L
.34055 .31648 L
.34055 .31947 L
.34055 .32246 L
.34055 .32544 L
.34055 .32843 L
.34055 .33141 L
.34055 .3344 L
.34055 .33739 L
.34055 .34037 L
.34055 .34336 L
.34055 .34635 L
.34055 .34933 L
.34055 .35232 L
.34055 .3553 L
.33813 .3568 L
.33572 .35829 L
.33572 .36128 L
.33572 .36426 L
.33572 .36725 L
.33572 .37024 L
.33572 .37322 L
.33572 .37621 L
.33572 .37919 L
.33572 .38218 L
.33572 .38517 L
.33572 .38815 L
.33572 .39114 L
.33572 .39413 L
.33572 .39711 L
.33572 .4001 L
.33572 .40308 L
.33572 .40607 L
.33572 .40906 L
.33572 .41204 L
.33572 .41503 L
.33572 .41802 L
.33572 .421 L
.33572 .42399 L
.33572 .42697 L
.33572 .42996 L
.33572 .43295 L
.33572 .43593 L
.33572 .43892 L
.33572 .44191 L
.33572 .44489 L
.33572 .44788 L
.33572 .45086 L
.33572 .45385 L
.33572 .45684 L
.33572 .45982 L
.33572 .46281 L
.33572 .4658 L
.33572 .46878 L
.33572 .47177 L
.33572 .47475 L
.33572 .47774 L
.3333 .47923 L
.33089 .48073 L
.33089 .48371 L
.33089 .4867 L
.33089 .48969 L
.33089 .49267 L
.33089 .49566 L
.33089 .49864 L
.33089 .50163 L
.33089 .50462 L
.33089 .5076 L
.33089 .51059 L
.33089 .51358 L
.33089 .51656 L
.33089 .51955 L
.33089 .52253 L
.33089 .52552 L
.33089 .52851 L
.33089 .53149 L
.33089 .53448 L
.33089 .53747 L
.33089 .54045 L
.33089 .54344 L
.33089 .54642 L
.33089 .54941 L
.33089 .5524 L
.33089 .55538 L
.33089 .55837 L
.33089 .56135 L
.33089 .56434 L
.33089 .56733 L
.33089 .57031 L
.33089 .5733 L
.33089 .57629 L
.33089 .57927 L
.33089 .58226 L
.33089 .58524 L
.33089 .58823 L
.33089 .59122 L
.33089 .5942 L
.33089 .59719 L
.33089 .60018 L
.33089 .60316 L
.33089 .60615 L
F
0 g
.3937 .60615 m
.3937 .60316 L
.3937 .60018 L
.3937 .59719 L
.3937 .5942 L
.3937 .59122 L
.3937 .58823 L
.3937 .58524 L
.3937 .58226 L
.3937 .57927 L
.3937 .57629 L
.3937 .5733 L
.3937 .57031 L
.3937 .56733 L
.3937 .56434 L
.3937 .56135 L
.3937 .55837 L
.3937 .55538 L
.3937 .5524 L
.3937 .54941 L
.3937 .54642 L
.3937 .54344 L
.3937 .54045 L
.3937 .53747 L
.3937 .53448 L
.3937 .53149 L
.3937 .52851 L
.3937 .52552 L
.3937 .52253 L
.3937 .51955 L
.3937 .51656 L
.3937 .51358 L
.3937 .51059 L
.3937 .5076 L
.3937 .50462 L
.3937 .50163 L
.3937 .49864 L
.3937 .49566 L
.3937 .49267 L
.3937 .48969 L
.3937 .4867 L
.3937 .48371 L
.3937 .48073 L
.3937 .47774 L
.3937 .47475 L
.3937 .47177 L
.3937 .46878 L
.3937 .4658 L
.3937 .46281 L
.3937 .45982 L
Mistroke
.3937 .45684 L
.3937 .45385 L
.3937 .45086 L
.3937 .44788 L
.3937 .44489 L
.3937 .44191 L
.3937 .43892 L
.3937 .43593 L
.3937 .43295 L
.3937 .42996 L
.3937 .42697 L
.3937 .42399 L
.3937 .421 L
.3937 .41802 L
.3937 .41503 L
.3937 .41204 L
.3937 .40906 L
.3937 .40607 L
.3937 .40308 L
.3937 .4001 L
.3937 .39711 L
.3937 .39413 L
.3937 .39114 L
.3937 .38815 L
.3937 .38517 L
.3937 .38218 L
.3937 .37919 L
.3937 .37621 L
.3937 .37322 L
.3937 .37024 L
.3937 .36725 L
.3937 .36426 L
.3937 .36128 L
.3937 .35829 L
.3937 .3553 L
.3937 .35232 L
.3937 .34933 L
.3937 .34635 L
.3937 .34336 L
.3937 .34037 L
.3937 .33739 L
.3937 .3344 L
.3937 .33141 L
.3937 .32843 L
.3937 .32544 L
.3937 .32246 L
.3937 .31947 L
.3937 .31648 L
.3937 .3135 L
.3937 .31051 L
Mistroke
.3937 .30752 L
.3937 .30454 L
.3937 .30155 L
.3937 .29857 L
.3937 .29558 L
.3937 .29259 L
.3937 .28961 L
.3937 .28662 L
.3937 .28363 L
.3937 .28065 L
.39128 .27915 L
.38887 .27766 L
.38887 .27468 L
.38887 .27169 L
.38887 .2687 L
.38887 .26572 L
.38887 .26273 L
.38887 .25974 L
.38887 .25676 L
.38887 .25377 L
.38887 .25079 L
.38887 .2478 L
.38887 .24481 L
.38887 .24183 L
.38887 .23884 L
.38887 .23585 L
.38887 .23287 L
.38887 .22988 L
.38887 .2269 L
.38887 .22391 L
.38887 .22092 L
.38887 .21794 L
.38887 .21495 L
.38887 .21196 L
.38887 .20898 L
.38887 .20599 L
.38887 .20301 L
.38887 .20002 L
.38887 .19703 L
.38887 .19405 L
.38887 .19106 L
.38887 .18807 L
.38887 .18509 L
.38887 .1821 L
.38887 .17912 L
.38887 .17613 L
.38887 .17314 L
.38887 .17016 L
.38887 .16717 L
.38887 .16418 L
Mistroke
.38887 .1612 L
.38887 .15821 L
.38887 .15523 L
.38887 .15224 L
.38887 .14925 L
.38887 .14627 L
.38887 .14328 L
.38887 .14029 L
.38887 .13731 L
.38887 .13432 L
.38887 .13134 L
.38887 .12835 L
.38645 .12686 L
.38404 .12536 L
.38404 .12238 L
.38404 .11939 L
.38404 .1164 L
.38404 .11342 L
.38404 .11043 L
.38404 .10745 L
.38404 .10446 L
.38404 .10147 L
.38404 .09849 L
.38404 .0955 L
.38404 .09251 L
.38404 .08953 L
.38404 .08654 L
.38404 .08356 L
.38404 .08057 L
.38404 .07758 L
.38162 .07609 L
.37947 .0746 L
.37679 .0731 L
.37411 .0746 L
.37437 .07758 L
.37196 .07908 L
.36954 .08057 L
.36954 .08356 L
.36954 .08654 L
.36712 .08803 L
.36471 .08953 L
.36471 .09251 L
.36471 .0955 L
.36471 .09849 L
.36471 .10147 L
.36229 .10297 L
.35988 .10446 L
.35988 .10745 L
.35988 .11043 L
.35988 .11342 L
Mistroke
.35988 .1164 L
.35988 .11939 L
.35746 .12088 L
.35504 .12238 L
.35504 .12536 L
.35504 .12835 L
.35504 .13134 L
.35504 .13432 L
.35504 .13731 L
.35504 .14029 L
.35504 .14328 L
.35504 .14627 L
.35504 .14925 L
.35263 .15075 L
.35021 .15224 L
.35021 .15523 L
.35021 .15821 L
.35021 .1612 L
.35021 .16418 L
.35021 .16717 L
.35021 .17016 L
.35021 .17314 L
.35021 .17613 L
.35021 .17912 L
.35021 .1821 L
.35021 .18509 L
.35021 .18807 L
.35021 .19106 L
.3478 .19255 L
.34538 .19405 L
.34538 .19703 L
.34538 .20002 L
.34538 .20301 L
.34538 .20599 L
.34538 .20898 L
.34538 .21196 L
.34538 .21495 L
.34538 .21794 L
.34538 .22092 L
.34538 .22391 L
.34538 .2269 L
.34538 .22988 L
.34538 .23287 L
.34538 .23585 L
.34538 .23884 L
.34538 .24183 L
.34538 .24481 L
.34538 .2478 L
.34538 .25079 L
.34538 .25377 L
Mistroke
.34538 .25676 L
.34538 .25974 L
.34296 .26124 L
.34055 .26273 L
.34055 .26572 L
.34055 .2687 L
.34055 .27169 L
.34055 .27468 L
.34055 .27766 L
.34055 .28065 L
.34055 .28363 L
.34055 .28662 L
.34055 .28961 L
.34055 .29259 L
.34055 .29558 L
.34055 .29857 L
.34055 .30155 L
.34055 .30454 L
.34055 .30752 L
.34055 .31051 L
.34055 .3135 L
.34055 .31648 L
.34055 .31947 L
.34055 .32246 L
.34055 .32544 L
.34055 .32843 L
.34055 .33141 L
.34055 .3344 L
.34055 .33739 L
.34055 .34037 L
.34055 .34336 L
.34055 .34635 L
.34055 .34933 L
.34055 .35232 L
.34055 .3553 L
.33813 .3568 L
.33572 .35829 L
.33572 .36128 L
.33572 .36426 L
.33572 .36725 L
.33572 .37024 L
.33572 .37322 L
.33572 .37621 L
.33572 .37919 L
.33572 .38218 L
.33572 .38517 L
.33572 .38815 L
.33572 .39114 L
.33572 .39413 L
.33572 .39711 L
Mistroke
.33572 .4001 L
.33572 .40308 L
.33572 .40607 L
.33572 .40906 L
.33572 .41204 L
.33572 .41503 L
.33572 .41802 L
.33572 .421 L
.33572 .42399 L
.33572 .42697 L
.33572 .42996 L
.33572 .43295 L
.33572 .43593 L
.33572 .43892 L
.33572 .44191 L
.33572 .44489 L
.33572 .44788 L
.33572 .45086 L
.33572 .45385 L
.33572 .45684 L
.33572 .45982 L
.33572 .46281 L
.33572 .4658 L
.33572 .46878 L
.33572 .47177 L
.33572 .47475 L
.33572 .47774 L
.3333 .47923 L
.33089 .48073 L
.33089 .48371 L
.33089 .4867 L
.33089 .48969 L
.33089 .49267 L
.33089 .49566 L
.33089 .49864 L
.33089 .50163 L
.33089 .50462 L
.33089 .5076 L
.33089 .51059 L
.33089 .51358 L
.33089 .51656 L
.33089 .51955 L
.33089 .52253 L
.33089 .52552 L
.33089 .52851 L
.33089 .53149 L
.33089 .53448 L
.33089 .53747 L
.33089 .54045 L
.33089 .54344 L
Mistroke
.33089 .54642 L
.33089 .54941 L
.33089 .5524 L
.33089 .55538 L
.33089 .55837 L
.33089 .56135 L
.33089 .56434 L
.33089 .56733 L
.33089 .57031 L
.33089 .5733 L
.33089 .57629 L
.33089 .57927 L
.33089 .58226 L
.33089 .58524 L
.33089 .58823 L
.33089 .59122 L
.33089 .5942 L
.33089 .59719 L
.33089 .60018 L
.33089 .60316 L
.33089 .60615 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000LOol3000YOol30003Ool00`00Ool00004000SOol30003Ool00`00
Oomoo`03Ool00`00Oomoo`0ROol30003Ool00`00Oomoo`03000UOol30003Ool00`00Oomoo`03000Y
Ool3000>Ool001]oo`05001oogooOol0000WOol01@00Oomoogoo00001Goo00@007ooOol0029oo`05
001oogooOol00008Ool00`00Oomoo`0QOol01@00Oomoogoo000017oo00D007ooOomoo`0002=oo`05
001oogooOol00004Ool01@00Oomoogoo0000:Goo00<007ooOol03Goo000KOol01@00Oomoogoo0000
9goo00D007ooOomoo`0000Ioo`03001oogoo029oo`05001oogooOol00004Ool6000ROol01@00Oomo
ogoo000017oo00D007ooOomoo`0002=oo`05001oogooOol00004Ool01@00Oomoogoo0000:Goo00<0
07ooOol03Goo000KOol01@00Oomoogoo00009goo00D007ooOomoo`0000Moo`03001oogoo025oo`05
001oogooOol00004Ool01@00Oomoogoo00008goo00D007ooOomoo`0000Aoo`05001oogooOol0000S
Ool01@00Oomoogoo00001Goo00<007oo0000:Woo00<007ooOol03Goo000KOol01@00Oomoogoo0000
9goo00D007ooOomoo`0000Qoo`03001oogoo021oo`05001oogooOol00005Ool01000Oomoo`008goo
00D007ooOomoo`0000Aoo`80009oo`03001oogoo025oo`05001oogooOol00006Ool00`00Oomoo`0Y
Ool00`00Oomoo`0=Ool001]oo`05001oogooOol0000WOol01@00Oomoogoo000027oo00<007ooOol0
87oo00D007ooOomoo`0000Ioo`03001oo`0002=oo`05001oogooOol00004Ool01000Ool0000097oo
00D007ooOomoo`0000Eoo`03001oo`0002Yoo`03001oogoo00eoo`006goo00D007ooOomoo`0002Mo
o`05001oogooOol00008Ool00`00Oomoo`0POol01@00Oomoogoo00001Woo00<007oo00008goo00D0
07ooOomoo`0000Eoo`03001oogoo02Aoo`05001oogooOol00004Ool01@00Oomoogoo0000:Goo00<0
07ooOol03Goo000KOol01@00Oomoogoo00009goo00D007ooOomoo`0000Aoo`05001oogooOol0000R
Ool01@00Oomoogoo00001goo0P008goo00D007ooOomoo`0000Ioo`03001oogoo02=oo`05001oogoo
Ool00004Ool01@00Oomoogoo0000:7oo0P003goo000LOol3000YOol30006Ool3000TOol30009Ool0
0`00Oomoo`0ROol30008Ool2000TOol30006Ool3000ZOol00`00Oomoo`0=Ool00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo000KOooi000<Ool001]oo`04001oogoo000;Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Ool0000<Ool001]o
o`04001oogoo000_Ool00`00Oomoo`0^Ool00`00Oomoo`0^Ool00`00Oomoo`0]Ool00`00Oomoo`0^
Ool00`00Ool0000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo
00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`800?Eoo`8000aoo`00
6goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]o
o`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol0
0`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`800?Eoo`8000aoo`006goo00<007ooOol0mGoo00<0
07ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03001o
ogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomo
o`0:Ool001]oo`8005aoo`03001oogoo09Ioo`8000aoo`006goo00<007ooOol0FWoo0`00V7oo00<0
07ooOol02Woo000KOol00`00Oomoo`1IOol200000ekg001oo`2GOol00`00Oomoo`0:Ool001]oo`03
001oogoo05Uoo`04001Nmekg002HOol00`00Oomoo`0:Ool001]oo`03001oogoo05Qoo`80009Nm`03
001oogoo09Ioo`03001oogoo00Yoo`006goo00<007ooOol0F7oo00D005kgG_MNm`0009Qoo`03001o
ogoo00Yoo`006goo0P00FGoo00D005kgG_MNm`0009Moo`8000aoo`006goo00<007ooOol0F7oo00D0
05kgG_MNm`0009Qoo`03001oogoo00Yoo`006goo00<007ooOol0EWoo0`000ekg00<007ooOol0UWoo
00<007ooOol02Woo000;Ool30003Ool30007Ool00`00Oomoo`1FOol00`00G_MNm`03G_L00`00Oomo
o`2FOol00`00Oomoo`0:Ool000aoo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`1F
Ool00`00G_MNm`03G_L00`00Oomoo`2FOol00`00Oomoo`0:Ool000aoo`05001oogooOol00003Ool0
0`00Oomoo`04Ool00`00Oomoo`1FOol00`00G_MNm`03G_L00`00Oomoo`2FOol00`00Oomoo`0:Ool0
00aoo`05001oogooOol00003Ool00`00Oomoo`04Ool3001FOol00`00G_MNm`03G_L00`00Oomoo`2E
Ool2000<Ool000aoo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`1EOol00`00G_MN
m`04G_L00`00Oomoo`2FOol00`00Oomoo`0:Ool000aoo`05001oogooOol00003Ool00`00Oomoo`04
Ool00`00Oomoo`1EOol00`00G_MNm`05G_L2002FOol00`00Oomoo`0:Ool000aoo`05001oogooOol0
0003Ool00`00Oomoo`04Ool00`00Oomoo`1EOol00`00G_MNm`06G_L00`00Oomoo`2DOol00`00Oomo
o`0:Ool000]oo`8000=oo`05001oogooOol00006Ool00`00Oomoo`1EOol00`00G_MNm`06G_L00`00
Oomoo`2DOol00`00Oomoo`0:Ool000aoo`03001oogoo009oo`<000Moo`03001oogoo05Eoo`03001N
mekg00INm`03001oogoo09Aoo`03001oogoo00Yoo`006goo0P00EWoo00<005kgG_L01Ukg00<007oo
Ool0Tgoo0P0037oo000KOol00`00Oomoo`1EOol00`00G_MNm`06G_L00`00Oomoo`2DOol00`00Oomo
o`0:Ool001]oo`03001oogoo05Aoo`8000QNm`03001oogoo09Aoo`03001oogoo00Yoo`006goo00<0
07ooOol0E7oo00<005kgG_L01ekg00<007ooOol0U7oo00<007ooOol02Woo000KOol00`00Oomoo`1D
Ool00`00G_MNm`07G_L00`00Oomoo`2DOol00`00Oomoo`0:Ool001]oo`03001oogoo05Aoo`03001N
mekg00MNm`03001oogoo09Aoo`03001oogoo00Yoo`006goo0P00EGoo00<005kgG_L01ekg00<007oo
Ool0Tgoo0P0037oo000KOol00`00Oomoo`1DOol00`00G_MNm`07G_L00`00Oomoo`2DOol00`00Oomo
o`0:Ool001]oo`03001oogoo05Aoo`03001Nmekg00MNm`03001oogoo09Aoo`03001oogoo00Yoo`00
6goo00<007ooOol0E7oo00<005kgG_L01ekg00<007ooOol0U7oo00<007ooOol02Woo000KOol00`00
Oomoo`1DOol00`00G_MNm`07G_L00`00Oomoo`2DOol00`00Oomoo`0:Ool001]oo`03001oogoo05Ao
o`03001Nmekg00MNm`03001oogoo09Aoo`03001oogoo00Yoo`006goo0P00E7oo0P002Ekg00<007oo
Ool0Tgoo0P0037oo000KOol00`00Oomoo`1COol00`00G_MNm`08G_L00`00Oomoo`2DOol00`00Oomo
o`0:Ool001]oo`03001oogoo05=oo`03001Nmekg00QNm`03001oogoo09Aoo`03001oogoo00Yoo`00
6goo00<007ooOol0Dgoo00<005kgG_L025kg00<007ooOol0U7oo00<007ooOol02Woo000KOol00`00
Oomoo`1COol00`00G_MNm`08G_L00`00Oomoo`2DOol00`00Oomoo`0:Ool001]oo`03001oogoo05=o
o`03001Nmekg00QNm`03001oogoo09Aoo`03001oogoo00Yoo`006goo0P00E7oo00<005kgG_L025kg
00<007ooOol0Tgoo0P0037oo000KOol00`00Oomoo`1COol00`00G_MNm`08G_L00`00Oomoo`2DOol0
0`00Oomoo`0:Ool001]oo`03001oogoo05=oo`03001Nmekg00QNm`03001oogoo09Aoo`03001oogoo
00Yoo`002Woo1@000Woo0`001goo00<007ooOol0Dgoo00<005kgG_L025kg00<007ooOol0U7oo00<0
07ooOol02Woo000;Ool01P00Oomoo`00Ool000=oo`03001oogoo00Aoo`03001oogoo05=oo`03001N
mekg00QNm`03001oogoo09Aoo`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03001oogoo
00Aoo`03001oogoo05=oo`03001Nmekg00QNm`03001oogoo09Aoo`03001oogoo00Yoo`003Goo00@0
07ooOol000=oo`03001oogoo00Aoo`<005=oo`03001Nmekg00QNm`03001oogoo09=oo`8000aoo`00
3Woo00<007oo00000goo00<007ooOol017oo00<007ooOol0Dgoo00<005kgG_L025kg00<007ooOol0
U7oo00<007ooOol02Woo000>Ool00`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`1COol00`00
G_MNm`08G_L00`00Oomoo`2DOol00`00Oomoo`0:Ool000ioo`03001oo`0000=oo`03001oogoo00Ao
o`03001oogoo05=oo`03001Nmekg00QNm`03001oogoo09Aoo`03001oogoo00Yoo`002Woo00L007oo
Oomoo`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`1COol00`00G_MNm`08G_L00`00Oomoo`2D
Ool00`00Oomoo`0:Ool000]oo`<000=oo`<000Moo`03001oogoo059oo`8000YNm`03001oogoo09Ao
o`03001oogoo00Yoo`006goo0P00Dgoo00<005kgG_L02Ekg00<007ooOol0Tgoo0P0037oo000KOol0
0`00Oomoo`1BOol00`00G_MNm`09G_L00`00Oomoo`2DOol00`00Oomoo`0:Ool001]oo`03001oogoo
059oo`03001Nmekg00UNm`03001oogoo09Aoo`03001oogoo00Yoo`006goo00<007ooOol0DWoo00<0
05kgG_L02Ekg00<007ooOol0U7oo00<007ooOol02Woo000KOol00`00Oomoo`1BOol00`00G_MNm`09
G_L2002EOol00`00Oomoo`0:Ool001]oo`03001oogoo059oo`03001Nmekg00YNm`03001oogoo09=o
o`03001oogoo00Yoo`006goo0P00Dgoo00<005kgG_L02Ukg00<007ooOol0TWoo0P0037oo000KOol0
0`00Oomoo`1BOol00`00G_MNm`0:G_L00`00Oomoo`2COol00`00Oomoo`0:Ool001]oo`03001oogoo
059oo`03001Nmekg00YNm`03001oogoo09=oo`03001oogoo00Yoo`006goo00<007ooOol0DWoo00<0
05kgG_L02Ukg00<007ooOol0Tgoo00<007ooOol02Woo000KOol00`00Oomoo`1BOol00`00G_MNm`0:
G_L00`00Oomoo`2COol00`00Oomoo`0:Ool001]oo`03001oogoo059oo`03001Nmekg00YNm`03001o
ogoo09=oo`03001oogoo00Yoo`006goo0P00Dgoo00<005kgG_L02Ukg00<007ooOol0TWoo0P0037oo
000KOol00`00Oomoo`1BOol00`00G_MNm`0:G_L00`00Oomoo`2COol00`00Oomoo`0:Ool001]oo`03
001oogoo059oo`03001Nmekg00YNm`03001oogoo09=oo`03001oogoo00Yoo`006goo00<007ooOol0
DWoo00<005kgG_L02Ukg00<007ooOol0Tgoo00<007ooOol02Woo000KOol00`00Oomoo`1BOol00`00
G_MNm`0:G_L00`00Oomoo`2COol00`00Oomoo`0:Ool001]oo`03001oogoo059oo`03001Nmekg00YN
m`03001oogoo09=oo`03001oogoo00Yoo`006goo0P00Dgoo00<005kgG_L02Ukg00<007ooOol0TWoo
0P0037oo000KOol00`00Oomoo`1BOol00`00G_MNm`0:G_L00`00Oomoo`2COol00`00Oomoo`0:Ool0
01]oo`03001oogoo059oo`03001Nmekg00YNm`03001oogoo09=oo`03001oogoo00Yoo`006goo00<0
07ooOol0DWoo00<005kgG_L02Ukg00<007ooOol0Tgoo00<007ooOol02Woo000:Ool40003Ool30007
Ool00`00Oomoo`1BOol00`00G_MNm`0:G_L00`00Oomoo`2COol00`00Oomoo`0:Ool000ioo`03001o
o`0000=oo`03001oogoo00Aoo`03001oogoo051oo`8000eNm`03001oogoo09=oo`03001oogoo00Yo
o`003Woo00<007oo00000goo00<007ooOol017oo0`00D7oo00<005kgG_L035kg00<007ooOol0TWoo
0P0037oo000>Ool00`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`1@Ool00`00G_MNm`0<G_L0
0`00Oomoo`2COol00`00Oomoo`0:Ool000aoo`80009oo`05001oogooOol00006Ool00`00Oomoo`1@
Ool00`00G_MNm`0<G_L00`00Oomoo`2COol00`00Oomoo`0:Ool000eoo`04001oogoo0003Ool00`00
Oomoo`04Ool00`00Oomoo`1@Ool00`00G_MNm`0<G_L00`00Oomoo`2COol00`00Oomoo`0:Ool000io
o`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo051oo`03001Nmekg00aNm`03001oogoo09=o
o`03001oogoo00Yoo`002Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`1@
Ool00`00G_MNm`0<G_L00`00Oomoo`2COol00`00Oomoo`0:Ool000]oo`<000=oo`<000Moo`03001o
ogoo051oo`03001Nmekg00aNm`03001oogoo09=oo`03001oogoo00Yoo`006goo0P00DGoo00<005kg
G_L035kg00<007ooOol0TWoo0P0037oo000KOol00`00Oomoo`1@Ool00`00G_MNm`0<G_L00`00Oomo
o`2COol00`00Oomoo`0:Ool001]oo`03001oogoo051oo`03001Nmekg00aNm`03001oogoo09=oo`03
001oogoo00Yoo`006goo00<007ooOol0D7oo00<005kgG_L035kg00<007ooOol0Tgoo00<007ooOol0
2Woo000KOol00`00Oomoo`1@Ool00`00G_MNm`0<G_L00`00Oomoo`2COol00`00Oomoo`0:Ool001]o
o`03001oogoo051oo`03001Nmekg00aNm`03001oogoo09=oo`03001oogoo00Yoo`006goo0P00DGoo
00<005kgG_L035kg00<007ooOol0TWoo0P0037oo000KOol00`00Oomoo`1@Ool00`00G_MNm`0<G_L0
0`00Oomoo`2COol00`00Oomoo`0:Ool001]oo`03001oogoo051oo`03001Nmekg00aNm`03001oogoo
09=oo`03001oogoo00Yoo`006goo00<007ooOol0D7oo00<005kgG_L035kg00<007ooOol0Tgoo00<0
07ooOol02Woo000KOol00`00Oomoo`1@Ool00`00G_MNm`0<G_L00`00Oomoo`2COol00`00Oomoo`0:
Ool001]oo`03001oogoo051oo`03001Nmekg00aNm`03001oogoo09=oo`03001oogoo00Yoo`006goo
0P00DGoo00<005kgG_L035kg00<007ooOol0TWoo0P0037oo000KOol00`00Oomoo`1@Ool00`00G_MN
m`0<G_L00`00Oomoo`2COol00`00Oomoo`0:Ool001]oo`03001oogoo051oo`03001Nmekg00aNm`03
001oogoo09=oo`03001oogoo00Yoo`006goo00<007ooOol0D7oo00<005kgG_L035kg00<007ooOol0
Tgoo00<007ooOol02Woo000KOol00`00Oomoo`1@Ool00`00G_MNm`0<G_L00`00Oomoo`2COol00`00
Oomoo`0:Ool001]oo`03001oogoo051oo`03001Nmekg00aNm`03001oogoo09=oo`03001oogoo00Yo
o`006goo0P00DGoo00<005kgG_L035kg00<007ooOol0TWoo0P0037oo000KOol00`00Oomoo`1@Ool0
0`00G_MNm`0<G_L00`00Oomoo`2COol00`00Oomoo`0:Ool001]oo`03001oogoo051oo`03001Nmekg
00aNm`03001oogoo09=oo`03001oogoo00Yoo`003Woo00<007ooOol00`001goo00<007ooOol0D7oo
00<005kgG_L035kg00<007ooOol0Tgoo00<007ooOol02Woo000>Ool00`00Ool00003Ool00`00Oomo
o`04Ool00`00Oomoo`1@Ool00`00G_MNm`0<G_L00`00Oomoo`2COol00`00Oomoo`0:Ool000Yoo`L0
00=oo`03001oogoo00Aoo`03001oogoo04moo`03001Nmekg00eNm`03001oogoo09=oo`03001oogoo
00Yoo`002Woo00L007ooOomoo`00Ool00003Ool00`00Oomoo`04Ool3001?Ool00`00G_MNm`0=G_L0
0`00Oomoo`2BOol2000<Ool000]oo`06001oogoo001oo`000goo00<007ooOol017oo00<007ooOol0
Cgoo00<005kgG_L03Ekg00<007ooOol0Tgoo00<007ooOol02Woo000<Ool01@00Ool007oo00000goo
00<007ooOol017oo00<007ooOol0Cgoo00<005kgG_L03Ekg00<007ooOol0Tgoo00<007ooOol02Woo
000<Ool01@00Ool007oo00000goo00<007ooOol017oo00<007ooOol0Cgoo00<005kgG_L03Ekg00<0
07ooOol0Tgoo00<007ooOol02Woo000=Ool200000goo001oo`02Ool00`00Oomoo`04Ool00`00Oomo
o`1?Ool00`00G_MNm`0=G_L00`00Oomoo`2COol00`00Oomoo`0:Ool000ioo`03001oogoo00<000Mo
o`03001oogoo04moo`03001Nmekg00eNm`03001oogoo09=oo`03001oogoo00Yoo`006goo0P00D7oo
00<005kgG_L03Ekg00<007ooOol0TWoo0P0037oo000KOol00`00Oomoo`1?Ool00`00G_MNm`0=G_L0
0`00Oomoo`2COol00`00Oomoo`0:Ool001]oo`03001oogoo04moo`03001Nmekg00eNm`03001oogoo
09=oo`03001oogoo00Yoo`006goo00<007ooOol0Cgoo00<005kgG_L03Ekg00<007ooOol0Tgoo00<0
07ooOol02Woo000KOol00`00Oomoo`1?Ool00`00G_MNm`0=G_L00`00Oomoo`2COol00`00Oomoo`0:
Ool001]oo`03001oogoo04moo`03001Nmekg00eNm`03001oogoo09=oo`03001oogoo00Yoo`006goo
0P00D7oo00<005kgG_L03Ekg00<007ooOol0TWoo0P0037oo000KOol00`00Oomoo`1?Ool00`00G_MN
m`0=G_L00`00Oomoo`2COol00`00Oomoo`0:Ool001]oo`03001oogoo04moo`03001Nmekg00eNm`03
001oogoo09=oo`03001oogoo00Yoo`006goo00<007ooOol0Cgoo00<005kgG_L03Ekg00<007ooOol0
Tgoo00<007ooOol02Woo000KOol00`00Oomoo`1?Ool00`00G_MNm`0=G_L00`00Oomoo`2COol00`00
Oomoo`0:Ool001]oo`03001oogoo04moo`03001Nmekg00eNm`03001oogoo09=oo`03001oogoo00Yo
o`006goo0P00D7oo00<005kgG_L03Ekg00<007ooOol0TWoo0P0037oo000KOol00`00Oomoo`1?Ool0
0`00G_MNm`0=G_L00`00Oomoo`2COol00`00Oomoo`0:Ool001]oo`03001oogoo04moo`03001Nmekg
00eNm`03001oogoo09=oo`03001oogoo00Yoo`006goo00<007ooOol0Cgoo00<005kgG_L03Ekg00<0
07ooOol0Tgoo00<007ooOol02Woo000KOol00`00Oomoo`1?Ool00`00G_MNm`0=G_L00`00Oomoo`2C
Ool00`00Oomoo`0:Ool001]oo`03001oogoo04moo`03001Nmekg00eNm`03001oogoo09=oo`03001o
ogoo00Yoo`006goo0P00D7oo00<005kgG_L03Ekg00<007ooOol0TWoo0P0037oo000KOol00`00Oomo
o`1?Ool00`00G_MNm`0=G_L00`00Oomoo`2COol00`00Oomoo`0:Ool001]oo`03001oogoo04moo`03
001Nmekg00eNm`03001oogoo09=oo`03001oogoo00Yoo`002Woo0`0017oo0`001goo00<007ooOol0
Cgoo00<005kgG_L03Ekg00<007ooOol0Tgoo00<007ooOol02Woo000=Ool01000Oomoo`000goo00<0
07ooOol017oo00<007ooOol0Cgoo00<005kgG_L03Ekg00<007ooOol0Tgoo00<007ooOol02Woo000>
Ool00`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`1?Ool00`00G_MNm`0=G_L00`00Oomoo`2C
Ool00`00Oomoo`0:Ool000ioo`03001oo`0000=oo`03001oogoo00Aoo`<004moo`03001Nmekg00eN
m`03001oogoo099oo`8000aoo`003Woo00<007oo00000goo00<007ooOol017oo00@007ooOol002mo
o`03001oogoo02ioo`03001oogoo02ioo`03001oogoo02eoo`03001oogoo02ioo`03001oo`0000ao
o`003Goo00@007ooOol000=oo`03001oogoo00Aoo`04001oogoo000;Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Ool0000<Ool000]oo`8000=oo`05001o
ogooOol00006Oooi000<Ool000]oo`03001oogoo009oo`05001oogooOol0003oOol<Ool000aoo`<0
009oo`<00?moo`eoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.123594, -6.21594, \
0.00411023, 0.332456}}],

Cell[BoxData[
    \(0.4`\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00941915 0.981162 -0.000366335 0.0121303 [
[.00942 -0.0125 -5 -15.6875 ]
[.00942 -0.0125 5 0 ]
[.20565 -0.0125 -9.5 -15.6875 ]
[.20565 -0.0125 9.5 0 ]
[.40188 -0.0125 -9.5 -15.6875 ]
[.40188 -0.0125 9.5 0 ]
[.59812 -0.0125 -9.5 -15.6875 ]
[.59812 -0.0125 9.5 0 ]
[.79435 -0.0125 -9.5 -15.6875 ]
[.79435 -0.0125 9.5 0 ]
[.99058 -0.0125 -5 -15.6875 ]
[.99058 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .12094 -16 -7.84375 ]
[-0.0125 .12094 0 7.84375 ]
[-0.0125 .24224 -16 -7.84375 ]
[-0.0125 .24224 0 7.84375 ]
[-0.0125 .36354 -16 -7.84375 ]
[-0.0125 .36354 0 7.84375 ]
[-0.0125 .48485 -16 -7.84375 ]
[-0.0125 .48485 0 7.84375 ]
[-0.0125 .60615 -16 -7.84375 ]
[-0.0125 .60615 0 7.84375 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00942 0 m
.00942 .00625 L
s
gsave
.00942 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.20565 0 m
.20565 .00625 L
s
gsave
.20565 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.40188 0 m
.40188 .00625 L
s
gsave
.40188 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.59812 0 m
.59812 .00625 L
s
gsave
.59812 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.79435 0 m
.79435 .00625 L
s
gsave
.79435 -0.0125 -70.5 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.99058 0 m
.99058 .00625 L
s
gsave
.99058 -0.0125 -66 -19.6875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.05848 0 m
.05848 .00375 L
s
.10754 0 m
.10754 .00375 L
s
.15659 0 m
.15659 .00375 L
s
.25471 0 m
.25471 .00375 L
s
.30377 0 m
.30377 .00375 L
s
.35283 0 m
.35283 .00375 L
s
.45094 0 m
.45094 .00375 L
s
.5 0 m
.5 .00375 L
s
.54906 0 m
.54906 .00375 L
s
.64717 0 m
.64717 .00375 L
s
.69623 0 m
.69623 .00375 L
s
.74529 0 m
.74529 .00375 L
s
.84341 0 m
.84341 .00375 L
s
.89246 0 m
.89246 .00375 L
s
.94152 0 m
.94152 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .12094 m
.00625 .12094 L
s
gsave
-0.0125 .12094 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .24224 m
.00625 .24224 L
s
gsave
-0.0125 .24224 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .36354 m
.00625 .36354 L
s
gsave
-0.0125 .36354 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .48485 m
.00625 .48485 L
s
gsave
-0.0125 .48485 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .60615 m
.00625 .60615 L
s
gsave
-0.0125 .60615 -77 -11.8438 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23.6875 translate 1 -1 scale
63.000 15.813 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .02389 m
.00375 .02389 L
s
0 .04815 m
.00375 .04815 L
s
0 .07242 m
.00375 .07242 L
s
0 .09668 m
.00375 .09668 L
s
0 .1452 m
.00375 .1452 L
s
0 .16946 m
.00375 .16946 L
s
0 .19372 m
.00375 .19372 L
s
0 .21798 m
.00375 .21798 L
s
0 .2665 m
.00375 .2665 L
s
0 .29076 m
.00375 .29076 L
s
0 .31502 m
.00375 .31502 L
s
0 .33928 m
.00375 .33928 L
s
0 .3878 m
.00375 .3878 L
s
0 .41206 m
.00375 .41206 L
s
0 .43632 m
.00375 .43632 L
s
0 .46059 m
.00375 .46059 L
s
0 .50911 m
.00375 .50911 L
s
0 .53337 m
.00375 .53337 L
s
0 .55763 m
.00375 .55763 L
s
0 .58189 m
.00375 .58189 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.00942 .61178 m
.00942 .61803 L
s
.20565 .61178 m
.20565 .61803 L
s
.40188 .61178 m
.40188 .61803 L
s
.59812 .61178 m
.59812 .61803 L
s
.79435 .61178 m
.79435 .61803 L
s
.99058 .61178 m
.99058 .61803 L
s
.125 Mabswid
.05848 .61428 m
.05848 .61803 L
s
.10754 .61428 m
.10754 .61803 L
s
.15659 .61428 m
.15659 .61803 L
s
.25471 .61428 m
.25471 .61803 L
s
.30377 .61428 m
.30377 .61803 L
s
.35283 .61428 m
.35283 .61803 L
s
.45094 .61428 m
.45094 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54906 .61428 m
.54906 .61803 L
s
.64717 .61428 m
.64717 .61803 L
s
.69623 .61428 m
.69623 .61803 L
s
.74529 .61428 m
.74529 .61803 L
s
.84341 .61428 m
.84341 .61803 L
s
.89246 .61428 m
.89246 .61803 L
s
.94152 .61428 m
.94152 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12094 m
1 .12094 L
s
.99375 .24224 m
1 .24224 L
s
.99375 .36354 m
1 .36354 L
s
.99375 .48485 m
1 .48485 L
s
.99375 .60615 m
1 .60615 L
s
.125 Mabswid
.99625 .02389 m
1 .02389 L
s
.99625 .04815 m
1 .04815 L
s
.99625 .07242 m
1 .07242 L
s
.99625 .09668 m
1 .09668 L
s
.99625 .1452 m
1 .1452 L
s
.99625 .16946 m
1 .16946 L
s
.99625 .19372 m
1 .19372 L
s
.99625 .21798 m
1 .21798 L
s
.99625 .2665 m
1 .2665 L
s
.99625 .29076 m
1 .29076 L
s
.99625 .31502 m
1 .31502 L
s
.99625 .33928 m
1 .33928 L
s
.99625 .3878 m
1 .3878 L
s
.99625 .41206 m
1 .41206 L
s
.99625 .43632 m
1 .43632 L
s
.99625 .46059 m
1 .46059 L
s
.99625 .50911 m
1 .50911 L
s
.99625 .53337 m
1 .53337 L
s
.99625 .55763 m
1 .55763 L
s
.99625 .58189 m
1 .58189 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 g
.01923 .60615 m
.98077 .60615 L
.98077 .01189 L
.01923 .01189 L
F
0 g
.5 Mabswid
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo000LOol3000YOol30003Ool00`00Ool00004000SOol30003Ool00`00
Oomoo`03Ool00`00Oomoo`0ROol30003Ool00`00Oomoo`03000UOol30003Ool00`00Oomoo`03000Y
Ool3000>Ool001]oo`05001oogooOol0000WOol01@00Oomoogoo00001Goo00@007ooOol0029oo`05
001oogooOol00008Ool00`00Oomoo`0QOol01@00Oomoogoo000017oo00D007ooOomoo`0002=oo`05
001oogooOol00004Ool01@00Oomoogoo0000:Goo00<007ooOol03Goo000KOol01@00Oomoogoo0000
9goo00D007ooOomoo`0000Ioo`03001oogoo029oo`05001oogooOol00004Ool6000ROol01@00Oomo
ogoo000017oo00D007ooOomoo`0002=oo`05001oogooOol00004Ool01@00Oomoogoo0000:Goo00<0
07ooOol03Goo000KOol01@00Oomoogoo00009goo00D007ooOomoo`0000Moo`03001oogoo025oo`05
001oogooOol00004Ool01@00Oomoogoo00008goo00D007ooOomoo`0000Aoo`05001oogooOol0000S
Ool01@00Oomoogoo00001Goo00<007oo0000:Woo00<007ooOol03Goo000KOol01@00Oomoogoo0000
9goo00D007ooOomoo`0000Qoo`03001oogoo021oo`05001oogooOol00005Ool01000Oomoo`008goo
00D007ooOomoo`0000Aoo`80009oo`03001oogoo025oo`05001oogooOol00006Ool00`00Oomoo`0Y
Ool00`00Oomoo`0=Ool001]oo`05001oogooOol0000WOol01@00Oomoogoo000027oo00<007ooOol0
87oo00D007ooOomoo`0000Ioo`03001oo`0002=oo`05001oogooOol00004Ool01000Ool0000097oo
00D007ooOomoo`0000Eoo`03001oo`0002Yoo`03001oogoo00eoo`006goo00D007ooOomoo`0002Mo
o`05001oogooOol00008Ool00`00Oomoo`0POol01@00Oomoogoo00001Woo00<007oo00008goo00D0
07ooOomoo`0000Eoo`03001oogoo02Aoo`05001oogooOol00004Ool01@00Oomoogoo0000:Goo00<0
07ooOol03Goo000KOol01@00Oomoogoo00009goo00D007ooOomoo`0000Aoo`05001oogooOol0000R
Ool01@00Oomoogoo00001goo0P008goo00D007ooOomoo`0000Ioo`03001oogoo02=oo`05001oogoo
Ool00004Ool01@00Oomoogoo0000:7oo0P003goo000LOol3000YOol30006Ool3000TOol30009Ool0
0`00Oomoo`0ROol30008Ool2000TOol30006Ool3000ZOol00`00Oomoo`0=Ool00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo000KOooi000<Ool001]oo`04001oogoo000;Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Ool0000<Ool001]o
o`04001oogoo000_Ool00`00Oomoo`0^Ool00`00Oomoo`0^Ool00`00Oomoo`0]Ool00`00Oomoo`0^
Ool00`00Ool0000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo
00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`800?Eoo`8000aoo`00
6goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]o
o`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol0
0`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`800?Eoo`8000aoo`006goo00<007ooOol0mGoo00<0
07ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03001o
ogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomo
o`0:Ool001]oo`800?Eoo`8000aoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00
Oomoo`3eOol00`00Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007oo
Ool0mGoo00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`800?Eoo`80
00aoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:
Ool000]oo`<000=oo`<000Moo`03001oogoo0?Eoo`03001oogoo00Yoo`0037oo00D007ooOomoo`00
00=oo`03001oogoo00Aoo`03001oogoo0?Eoo`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=o
o`03001oogoo00Aoo`03001oogoo0?Eoo`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03
001oogoo00Aoo`<00?Aoo`8000aoo`0037oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001o
ogoo0?Eoo`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo
0?Eoo`03001oogoo00Yoo`0037oo00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo0?Eo
o`03001oogoo00Yoo`002goo0P000goo00D007ooOomoo`0000Ioo`03001oogoo0?Eoo`03001oogoo
00Yoo`0037oo00<007ooOol00Woo0`001goo00<007ooOol0mGoo00<007ooOol02Woo000KOol2003e
Ool2000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007oo
Ool02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03001oogoo
00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol2003eOol2000<Ool001]oo`03001o
ogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomo
o`3eOol00`00Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0
mGoo00<007ooOol02Woo000KOol2003eOol2000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yo
o`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool0
01]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000K
Ool2003eOol2000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo
00<007ooOol02Woo000:Ool50002Ool30007Ool00`00Oomoo`3eOol00`00Oomoo`0:Ool000]oo`06
001oogoo001oo`000goo00<007ooOol017oo00<007ooOol0mGoo00<007ooOol02Woo000<Ool01@00
Oomoogoo00000goo00<007ooOol017oo00<007ooOol0mGoo00<007ooOol02Woo000=Ool01000Oomo
o`000goo00<007ooOol017oo0`00m7oo0P0037oo000>Ool00`00Ool00003Ool00`00Oomoo`04Ool0
0`00Oomoo`3eOol00`00Oomoo`0:Ool000ioo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo
0?Eoo`03001oogoo00Yoo`003Woo00<007oo00000goo00<007ooOol017oo00<007ooOol0mGoo00<0
07ooOol02Woo000:Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Aoo`03001oogoo0?Eoo`03
001oogoo00Yoo`002goo0`000goo0`001goo00<007ooOol0mGoo00<007ooOol02Woo000KOol2003e
Ool2000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007oo
Ool02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03001oogoo
00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol2003eOol2000<Ool001]oo`03001o
ogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomo
o`3eOol00`00Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0
mGoo00<007ooOol02Woo000KOol2003eOol2000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yo
o`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool0
01]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000K
Ool2003eOol2000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo
00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool000Yoo`@000=oo`<000Moo`03
001oogoo0?Eoo`03001oogoo00Yoo`003Woo00<007oo00000goo00<007ooOol017oo00<007ooOol0
mGoo00<007ooOol02Woo000>Ool00`00Ool00003Ool00`00Oomoo`04Ool3003dOol2000<Ool000io
o`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo0?Eoo`03001oogoo00Yoo`0037oo0P000Woo
00D007ooOomoo`0000Ioo`03001oogoo0?Eoo`03001oogoo00Yoo`003Goo00@007ooOol000=oo`03
001oogoo00Aoo`03001oogoo0?Eoo`03001oogoo00Yoo`003Woo00<007oo00000goo00<007ooOol0
17oo00<007ooOol0mGoo00<007ooOol02Woo000:Ool01`00Oomoogoo001oo`0000=oo`03001oogoo
00Aoo`03001oogoo0?Eoo`03001oogoo00Yoo`002goo0`000goo0`001goo00<007ooOol0mGoo00<0
07ooOol02Woo000KOol2003eOol2000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo
00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`03
001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol2003e
Ool2000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007oo
Ool02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03001oogoo
00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol2003eOol2000<Ool001]oo`03001o
ogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomo
o`3eOol00`00Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0
mGoo00<007ooOol02Woo000KOol2003eOol2000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yo
o`006goo00<007ooOol0mGoo00<007ooOol02Woo000>Ool00`00Oomoo`030007Ool00`00Oomoo`3e
Ool00`00Oomoo`0:Ool000ioo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo0?Eoo`03001o
ogoo00Yoo`002Woo1`000goo00<007ooOol017oo00<007ooOol0mGoo00<007ooOol02Woo000:Ool0
1`00Oomoogoo001oo`0000=oo`03001oogoo00Aoo`<00?Aoo`8000aoo`002goo00H007ooOol007oo
0003Ool00`00Oomoo`04Ool00`00Oomoo`3eOol00`00Oomoo`0:Ool000aoo`05001oo`00Ool00003
Ool00`00Oomoo`04Ool00`00Oomoo`3eOol00`00Oomoo`0:Ool000aoo`05001oo`00Ool00003Ool0
0`00Oomoo`04Ool00`00Oomoo`3eOol00`00Oomoo`0:Ool000eoo`800003Ool007oo009oo`03001o
ogoo00Aoo`03001oogoo0?Eoo`03001oogoo00Yoo`003Woo00<007ooOol00`001goo00<007ooOol0
mGoo00<007ooOol02Woo000KOol2003eOol2000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yo
o`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool0
01]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000K
Ool2003eOol2000<Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo
00<007ooOol02Woo000KOol00`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03
001oogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol2003eOol2000<Ool001]o
o`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000KOol0
0`00Oomoo`3eOol00`00Oomoo`0:Ool001]oo`03001oogoo0?Eoo`03001oogoo00Yoo`006goo00<0
07ooOol0mGoo00<007ooOol02Woo000KOol2003eOol2000<Ool001]oo`03001oogoo0?Eoo`03001o
ogoo00Yoo`006goo00<007ooOol0mGoo00<007ooOol02Woo000:Ool30004Ool30007Ool00`00Oomo
o`3eOol00`00Oomoo`0:Ool000eoo`04001oogoo0003Ool00`00Oomoo`04Ool00`00Oomoo`3eOol0
0`00Oomoo`0:Ool000ioo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo0?Eoo`03001oogoo
00Yoo`003Woo00<007oo00000goo00<007ooOol017oo0`00m7oo0P0037oo000>Ool00`00Ool00003
Ool00`00Oomoo`04Ool01000Oomoo`00;goo00<007ooOol0;Woo00<007ooOol0;Woo00<007ooOol0
;Goo00<007ooOol0;Woo00<007oo000037oo000=Ool01000Oomoo`000goo00<007ooOol017oo00@0
07ooOol000]oo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oo`0000aoo`002goo0P000goo00D007ooOomoo`0000IoooT000aoo`002goo00<007ooOol00Woo
00D007ooOomoo`000?moo`aoo`0037oo0`000Woo0`00ogoo3Goo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.123594, -6.21594, \
0.00411023, 0.332456}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetDirectory["\<d:/paper/matthias pubpriv/\>"];\)\), "\n", 
    \(\(Display["\<contour1.eps\>", pl[1], "\<EPS\>"];\)\), "\n", 
    \(\(Display["\<contour2.eps\>", pl[2], "\<EPS\>"];\)\), "\n", 
    \(\(Display["\<contour3.eps\>", pl[3], "\<EPS\>"];\)\), "\n", 
    \(\(Display["\<contour4.eps\>", pl[4], "\<EPS\>"];\)\), "\n", 
    \(\(Display["\<contour5.eps\>", pl[5], "\<EPS\>"];\)\), "\n", 
    \(\)}], "Input"],

Cell[BoxData[
    \(Graphics::"realu" \(\(:\)\(\ \)\) 
      "Argument in \!\(GrayLevel[1.0575`]\) is not a real number between 0 \
and 1."\)], "Message"],

Cell[BoxData[
    \(Display::"pserr" \(\(:\)\(\ \)\) 
      "\!\(\"PostScript language error:\\nWarning: substituting font \
Utopia-Regular for Times-Roman\\n\"\)"\)], "Message"],

Cell[BoxData[
    \(Graphics::"realu" \(\(:\)\(\ \)\) 
      "Argument in \!\(GrayLevel[1.0575`]\) is not a real number between 0 \
and 1."\)], "Message"],

Cell[BoxData[
    \(Display::"pserr" \(\(:\)\(\ \)\) 
      "\!\(\"PostScript language error:\\nWarning: substituting font \
Utopia-Regular for Times-Roman\\n\"\)"\)], "Message"],

Cell[BoxData[
    \(Graphics::"realu" \(\(:\)\(\ \)\) 
      "Argument in \!\(GrayLevel[1.0575`]\) is not a real number between 0 \
and 1."\)], "Message"],

Cell[BoxData[
    \(Display::"pserr" \(\(:\)\(\ \)\) 
      "\!\(\"PostScript language error:\\nWarning: substituting font \
Utopia-Regular for Times-Roman\\n\"\)"\)], "Message"],

Cell[BoxData[
    \(Graphics::"realu" \(\(:\)\(\ \)\) 
      "Argument in \!\(GrayLevel[1.0575`]\) is not a real number between 0 \
and 1."\)], "Message"],

Cell[BoxData[
    \(Display::"pserr" \(\(:\)\(\ \)\) 
      "\!\(\"PostScript language error:\\nWarning: substituting font \
Utopia-Regular for Times-Roman\\n\"\)"\)], "Message"],

Cell[BoxData[
    \(Graphics::"realu" \(\(:\)\(\ \)\) 
      "Argument in \!\(GrayLevel[1.0500000000000014`]\) is not a real number \
between 0 and 1."\)], "Message"],

Cell[BoxData[
    \(Display::"pserr" \(\(:\)\(\ \)\) 
      "\!\(\"PostScript language error:\\nWarning: substituting font \
Utopia-Regular for Times-Roman\\n\"\)"\)], "Message"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 92, 3, 170, "Title"],
Cell[1822, 57, 54, 0, 115, "Title"],
Cell[1879, 59, 97, 2, 64, "Subtitle"],
Cell[1979, 63, 1109, 21, 279, "Input"],

Cell[CellGroupData[{
Cell[3113, 88, 448, 7, 85, "Input"],
Cell[3564, 97, 259, 5, 25, "Print"],
Cell[3826, 104, 246, 5, 25, "Print"]
}, Open  ]],
Cell[4087, 112, 211, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[4323, 120, 913, 20, 90, "Input"],
Cell[5239, 142, 34, 1, 25, "Print"],
Cell[5276, 145, 154, 3, 24, "Message"],
Cell[5433, 150, 30415, 1309, 186, 17711, 1148, "GraphicsData", "PostScript", \
"Graphics"],
Cell[35851, 1461, 37, 1, 25, "Print"],
Cell[35891, 1464, 154, 3, 24, "Message"],
Cell[36048, 1469, 32288, 1404, 186, 19264, 1239, "GraphicsData", \
"PostScript", "Graphics"],
Cell[68339, 2875, 37, 1, 25, "Print"],
Cell[68379, 2878, 154, 3, 24, "Message"],
Cell[68536, 2883, 167, 3, 24, "Message"],
Cell[68706, 2888, 36700, 1623, 186, 22546, 1444, "GraphicsData", \
"PostScript", "Graphics"],
Cell[105409, 4513, 53, 1, 25, "Print"],
Cell[105465, 4516, 33761, 1454, 186, 19704, 1276, "GraphicsData", \
"PostScript", "Graphics"],
Cell[139229, 5972, 37, 1, 25, "Print"],
Cell[139269, 5975, 17932, 649, 186, 8055, 523, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[157238, 6629, 438, 7, 150, "Input"],
Cell[157679, 6638, 154, 3, 24, "Message"],
Cell[157836, 6643, 178, 3, 60, "Message"],
Cell[158017, 6648, 154, 3, 24, "Message"],
Cell[158174, 6653, 178, 3, 60, "Message"],
Cell[158355, 6658, 154, 3, 24, "Message"],
Cell[158512, 6663, 178, 3, 60, "Message"],
Cell[158693, 6668, 154, 3, 24, "Message"],
Cell[158850, 6673, 178, 3, 60, "Message"],
Cell[159031, 6678, 166, 3, 24, "Message"],
Cell[159200, 6683, 178, 3, 60, "Message"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

